# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/camera/proto/yolo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/camera/proto/yolo.proto',
  package='apollo.perception.camera.yolo',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*modules/perception/camera/proto/yolo.proto\x12\x1d\x61pollo.perception.camera.yolo\"\xc7\x01\n\tYoloParam\x12>\n\x0bmodel_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.yolo.ModelParam\x12>\n\tnet_param\x18\x02 \x01(\x0b\x32+.apollo.perception.camera.yolo.NetworkParam\x12:\n\tnms_param\x18\x03 \x01(\x0b\x32\'.apollo.perception.camera.yolo.NMSParam\"\xc9\t\n\nModelParam\x12\x1b\n\nmodel_name\x18\x01 \x01(\t:\x07yolo-2d\x12\x1c\n\nproto_file\x18\x02 \x01(\t:\x08\x63\x61\x66\x66\x65.pt\x12 \n\x0bweight_file\x18\x03 \x01(\t:\x0b\x63\x61\x66\x66\x65.model\x12\x1b\n\tstage1_pt\x18\x15 \x01(\t:\x08\x63\x61\x66\x66\x65.pt\x12\x1e\n\tstage1_md\x18\x16 \x01(\t:\x0b\x63\x61\x66\x66\x65.model\x12\x1b\n\tstage2_pt\x18\x17 \x01(\t:\x08\x63\x61\x66\x66\x65.pt\x12\x1e\n\tstage2_md\x18\x18 \x01(\t:\x0b\x63\x61\x66\x66\x65.model\x12!\n\x0c\x61nchors_file\x18\x04 \x01(\t:\x0b\x61nchors.txt\x12\x1d\n\ntypes_file\x18\x05 \x01(\t:\ttypes.txt\x12 \n\x0c\x66\x65\x61ture_file\x18\x06 \x01(\t:\nfeature.pt\x12\x1e\n\x0coffset_ratio\x18\x07 \x01(\x02:\x08\x30.288889\x12\x1f\n\rcropped_ratio\x18\r \x01(\x02:\x08\x30.711111\x12\x1b\n\rresized_width\x18\x0e \x01(\x05:\x04\x31\x34\x34\x30\x12\x19\n\raligned_pixel\x18\x0f \x01(\x05:\x02\x33\x32\x12!\n\x14\x63onfidence_threshold\x18\x08 \x01(\x02:\x03\x30.1\x12%\n\x18light_vis_conf_threshold\x18! \x01(\x02:\x03\x30.5\x12%\n\x18light_swt_conf_threshold\x18\" \x01(\x02:\x03\x30.5\x12\x1f\n\x12roi_conf_threshold\x18\x19 \x01(\x02:\x03\x30.1\x12\x1f\n\x12\x62ox_conf_threshold\x18\x1a \x01(\x02:\x03\x30.5\x12!\n\x14stage2_nms_threshold\x18\x1b \x01(\x02:\x03\x30.4\x12\x18\n\rmin_2d_height\x18\t \x01(\x02:\x01\x30\x12\x18\n\rmin_3d_height\x18\x1e \x01(\x02:\x01\x30\x12\x17\n\x0cmin_3d_width\x18\x1f \x01(\x02:\x01\x30\x12\x18\n\rmin_3d_length\x18  \x01(\x02:\x01\x30\x12\x1f\n\x13\x63\x61libratetable_root\x18\x0b \x01(\t:\x02./\x12\x1c\n\nmodel_type\x18\x0c \x01(\t:\x08\x43\x61\x66\x66\x65Net\x12\x14\n\tori_cycle\x18\x10 \x01(\x05:\x01\x31\x12\x1a\n\x0bper_cls_reg\x18\x11 \x01(\x08:\x05\x66\x61lse\x12P\n\x14\x64imension_statistics\x18\x12 \x03(\x0b\x32\x32.apollo.perception.camera.yolo.DimensionStatistics\x12\x46\n\x0f\x62\x62ox_statistics\x18\x13 \x03(\x0b\x32-.apollo.perception.camera.yolo.BBoxStatistics\x12\x1f\n\x0b\x65xpand_file\x18\x14 \x01(\t:\nexpand.txt\x12\x19\n\nwith_box3d\x18) \x01(\x08:\x05\x66\x61lse\x12\x19\n\nwith_frbox\x18* \x01(\x08:\x05\x66\x61lse\x12\x1a\n\x0bwith_lights\x18+ \x01(\x08:\x05\x66\x61lse\x12\x1a\n\x0bwith_ratios\x18, \x01(\x08:\x05\x66\x61lse\x12\x14\n\tnum_areas\x18. \x01(\x05:\x01\x30\x12\x1a\n\x0c\x62order_ratio\x18- \x01(\x02:\x04\x30.01\"\x84\n\n\x0cNetworkParam\x12\'\n\rdet1_loc_blob\x18\x01 \x01(\t:\x10\x64\x65tect1_loc_pred\x12\'\n\rdet1_obj_blob\x18\x02 \x01(\t:\x10\x64\x65tect1_obj_pred\x12\'\n\rdet1_cls_blob\x18\x03 \x01(\t:\x10\x64\x65tect1_cls_pred\x12\'\n\rdet1_ori_blob\x18\x04 \x01(\t:\x10\x64\x65tect1_ori_pred\x12\x31\n\x12\x64\x65t1_ori_conf_blob\x18\x05 \x01(\t:\x15\x64\x65tect1_ori_conf_pred\x12\'\n\rdet1_dim_blob\x18\x06 \x01(\t:\x10\x64\x65tect1_dim_pred\x12\'\n\rdet2_loc_blob\x18\x07 \x01(\t:\x10\x64\x65tect2_loc_pred\x12\'\n\rdet2_obj_blob\x18\x08 \x01(\t:\x10\x64\x65tect2_obj_pred\x12\'\n\rdet2_cls_blob\x18\t \x01(\t:\x10\x64\x65tect2_cls_pred\x12\'\n\rdet2_ori_blob\x18\n \x01(\t:\x10\x64\x65tect2_ori_pred\x12\x31\n\x12\x64\x65t2_ori_conf_blob\x18\x0b \x01(\t:\x15\x64\x65tect2_ori_conf_pred\x12\'\n\rdet2_dim_blob\x18\x0c \x01(\t:\x10\x64\x65tect2_dim_pred\x12\'\n\rdet3_loc_blob\x18\r \x01(\t:\x10\x64\x65tect3_loc_pred\x12\'\n\rdet3_obj_blob\x18\x0e \x01(\t:\x10\x64\x65tect3_obj_pred\x12\'\n\rdet3_cls_blob\x18\x0f \x01(\t:\x10\x64\x65tect3_cls_pred\x12\'\n\rdet3_ori_blob\x18\x10 \x01(\t:\x10\x64\x65tect3_ori_pred\x12\x31\n\x12\x64\x65t3_ori_conf_blob\x18\x11 \x01(\t:\x15\x64\x65tect3_ori_conf_pred\x12\'\n\rdet3_dim_blob\x18\x12 \x01(\t:\x10\x64\x65tect3_dim_pred\x12\x1a\n\x08lof_blob\x18\x13 \x01(\t:\x08lof_pred\x12\x1a\n\x08lor_blob\x18\x14 \x01(\t:\x08lor_pred\x12\x18\n\ninput_blob\x18\x15 \x01(\t:\x04\x64\x61ta\x12\x1c\n\trois_blob\x18\x16 \x01(\t:\trois_pred\x12\x1c\n\tfeat_blob\x18\x17 \x01(\t:\tconv_feat\x12\x1a\n\x08\x62ox_blob\x18\x18 \x01(\t:\x08\x62ox_pred\x12\x1a\n\x08iou_blob\x18\x19 \x01(\t:\x08iou_pred\x12\x1e\n\nbrvis_blob\x18\x1a \x01(\t:\nbrvis_pred\x12\x1e\n\nbrswt_blob\x18\x1b \x01(\t:\nbrswt_pred\x12\x1e\n\nltvis_blob\x18\x1c \x01(\t:\nltvis_pred\x12\x1e\n\nltswt_blob\x18\x1d \x01(\t:\nltswt_pred\x12\x1e\n\nrtvis_blob\x18\x1e \x01(\t:\nrtvis_pred\x12\x1e\n\nrtswt_blob\x18\x1f \x01(\t:\nrtswt_pred\x12\"\n\x0c\x61rea_id_blob\x18  \x01(\t:\x0c\x61rea_id_pred\x12$\n\x12visible_ratio_blob\x18! \x01(\t:\x08vis_pred\x12$\n\x12\x63ut_off_ratio_blob\x18\" \x01(\t:\x08\x63ut_pred\"\x94\x01\n\x08NMSParam\x12\x17\n\x04type\x18\x01 \x01(\t:\tNormalNMS\x12\x16\n\tthreshold\x18\x02 \x01(\x02:\x03\x30.4\x12\x12\n\x05sigma\x18\x03 \x01(\x02:\x03\x30.4\x12\"\n\x15inter_cls_conf_thresh\x18\x04 \x01(\x02:\x03\x30.1\x12\x1f\n\x14inter_cls_nms_thresh\x18\x05 \x01(\x02:\x01\x31\"+\n\x0e\x42\x42oxStatistics\x12\x0c\n\x04mean\x18\x01 \x03(\x02\x12\x0b\n\x03std\x18\x02 \x03(\x02\"\x84\x01\n\x13\x44imensionStatistics\x12\x11\n\x06mean_h\x18\x01 \x01(\x02:\x01\x30\x12\x11\n\x06mean_w\x18\x02 \x01(\x02:\x01\x30\x12\x11\n\x06mean_l\x18\x03 \x01(\x02:\x01\x30\x12\x10\n\x05std_h\x18\x04 \x01(\x02:\x01\x31\x12\x10\n\x05std_w\x18\x05 \x01(\x02:\x01\x31\x12\x10\n\x05std_l\x18\x06 \x01(\x02:\x01\x31'
)




_YOLOPARAM = _descriptor.Descriptor(
  name='YoloParam',
  full_name='apollo.perception.camera.yolo.YoloParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_param', full_name='apollo.perception.camera.yolo.YoloParam.model_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='net_param', full_name='apollo.perception.camera.yolo.YoloParam.net_param', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nms_param', full_name='apollo.perception.camera.yolo.YoloParam.nms_param', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=277,
)


_MODELPARAM = _descriptor.Descriptor(
  name='ModelParam',
  full_name='apollo.perception.camera.yolo.ModelParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_name', full_name='apollo.perception.camera.yolo.ModelParam.model_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"yolo-2d".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proto_file', full_name='apollo.perception.camera.yolo.ModelParam.proto_file', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"caffe.pt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_file', full_name='apollo.perception.camera.yolo.ModelParam.weight_file', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"caffe.model".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage1_pt', full_name='apollo.perception.camera.yolo.ModelParam.stage1_pt', index=3,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"caffe.pt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage1_md', full_name='apollo.perception.camera.yolo.ModelParam.stage1_md', index=4,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"caffe.model".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage2_pt', full_name='apollo.perception.camera.yolo.ModelParam.stage2_pt', index=5,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"caffe.pt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage2_md', full_name='apollo.perception.camera.yolo.ModelParam.stage2_md', index=6,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"caffe.model".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='anchors_file', full_name='apollo.perception.camera.yolo.ModelParam.anchors_file', index=7,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"anchors.txt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='types_file', full_name='apollo.perception.camera.yolo.ModelParam.types_file', index=8,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"types.txt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_file', full_name='apollo.perception.camera.yolo.ModelParam.feature_file', index=9,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"feature.pt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset_ratio', full_name='apollo.perception.camera.yolo.ModelParam.offset_ratio', index=10,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.288889),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cropped_ratio', full_name='apollo.perception.camera.yolo.ModelParam.cropped_ratio', index=11,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.711111),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resized_width', full_name='apollo.perception.camera.yolo.ModelParam.resized_width', index=12,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=1440,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aligned_pixel', full_name='apollo.perception.camera.yolo.ModelParam.aligned_pixel', index=13,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=32,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence_threshold', full_name='apollo.perception.camera.yolo.ModelParam.confidence_threshold', index=14,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='light_vis_conf_threshold', full_name='apollo.perception.camera.yolo.ModelParam.light_vis_conf_threshold', index=15,
      number=33, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='light_swt_conf_threshold', full_name='apollo.perception.camera.yolo.ModelParam.light_swt_conf_threshold', index=16,
      number=34, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_conf_threshold', full_name='apollo.perception.camera.yolo.ModelParam.roi_conf_threshold', index=17,
      number=25, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='box_conf_threshold', full_name='apollo.perception.camera.yolo.ModelParam.box_conf_threshold', index=18,
      number=26, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage2_nms_threshold', full_name='apollo.perception.camera.yolo.ModelParam.stage2_nms_threshold', index=19,
      number=27, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_2d_height', full_name='apollo.perception.camera.yolo.ModelParam.min_2d_height', index=20,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_3d_height', full_name='apollo.perception.camera.yolo.ModelParam.min_3d_height', index=21,
      number=30, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_3d_width', full_name='apollo.perception.camera.yolo.ModelParam.min_3d_width', index=22,
      number=31, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_3d_length', full_name='apollo.perception.camera.yolo.ModelParam.min_3d_length', index=23,
      number=32, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibratetable_root', full_name='apollo.perception.camera.yolo.ModelParam.calibratetable_root', index=24,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"./".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_type', full_name='apollo.perception.camera.yolo.ModelParam.model_type', index=25,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"CaffeNet".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ori_cycle', full_name='apollo.perception.camera.yolo.ModelParam.ori_cycle', index=26,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='per_cls_reg', full_name='apollo.perception.camera.yolo.ModelParam.per_cls_reg', index=27,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dimension_statistics', full_name='apollo.perception.camera.yolo.ModelParam.dimension_statistics', index=28,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bbox_statistics', full_name='apollo.perception.camera.yolo.ModelParam.bbox_statistics', index=29,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expand_file', full_name='apollo.perception.camera.yolo.ModelParam.expand_file', index=30,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"expand.txt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_box3d', full_name='apollo.perception.camera.yolo.ModelParam.with_box3d', index=31,
      number=41, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_frbox', full_name='apollo.perception.camera.yolo.ModelParam.with_frbox', index=32,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_lights', full_name='apollo.perception.camera.yolo.ModelParam.with_lights', index=33,
      number=43, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_ratios', full_name='apollo.perception.camera.yolo.ModelParam.with_ratios', index=34,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_areas', full_name='apollo.perception.camera.yolo.ModelParam.num_areas', index=35,
      number=46, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='border_ratio', full_name='apollo.perception.camera.yolo.ModelParam.border_ratio', index=36,
      number=45, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.01),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=1505,
)


_NETWORKPARAM = _descriptor.Descriptor(
  name='NetworkParam',
  full_name='apollo.perception.camera.yolo.NetworkParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='det1_loc_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det1_loc_blob', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect1_loc_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det1_obj_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det1_obj_blob', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect1_obj_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det1_cls_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det1_cls_blob', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect1_cls_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det1_ori_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det1_ori_blob', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect1_ori_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det1_ori_conf_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det1_ori_conf_blob', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect1_ori_conf_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det1_dim_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det1_dim_blob', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect1_dim_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det2_loc_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det2_loc_blob', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect2_loc_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det2_obj_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det2_obj_blob', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect2_obj_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det2_cls_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det2_cls_blob', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect2_cls_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det2_ori_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det2_ori_blob', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect2_ori_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det2_ori_conf_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det2_ori_conf_blob', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect2_ori_conf_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det2_dim_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det2_dim_blob', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect2_dim_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det3_loc_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det3_loc_blob', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect3_loc_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det3_obj_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det3_obj_blob', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect3_obj_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det3_cls_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det3_cls_blob', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect3_cls_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det3_ori_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det3_ori_blob', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect3_ori_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det3_ori_conf_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det3_ori_conf_blob', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect3_ori_conf_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det3_dim_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det3_dim_blob', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect3_dim_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lof_blob', full_name='apollo.perception.camera.yolo.NetworkParam.lof_blob', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"lof_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lor_blob', full_name='apollo.perception.camera.yolo.NetworkParam.lor_blob', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"lor_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_blob', full_name='apollo.perception.camera.yolo.NetworkParam.input_blob', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"data".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rois_blob', full_name='apollo.perception.camera.yolo.NetworkParam.rois_blob', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"rois_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feat_blob', full_name='apollo.perception.camera.yolo.NetworkParam.feat_blob', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"conv_feat".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='box_blob', full_name='apollo.perception.camera.yolo.NetworkParam.box_blob', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"box_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iou_blob', full_name='apollo.perception.camera.yolo.NetworkParam.iou_blob', index=24,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"iou_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brvis_blob', full_name='apollo.perception.camera.yolo.NetworkParam.brvis_blob', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"brvis_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brswt_blob', full_name='apollo.perception.camera.yolo.NetworkParam.brswt_blob', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"brswt_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ltvis_blob', full_name='apollo.perception.camera.yolo.NetworkParam.ltvis_blob', index=27,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"ltvis_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ltswt_blob', full_name='apollo.perception.camera.yolo.NetworkParam.ltswt_blob', index=28,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"ltswt_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtvis_blob', full_name='apollo.perception.camera.yolo.NetworkParam.rtvis_blob', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"rtvis_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtswt_blob', full_name='apollo.perception.camera.yolo.NetworkParam.rtswt_blob', index=30,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"rtswt_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_id_blob', full_name='apollo.perception.camera.yolo.NetworkParam.area_id_blob', index=31,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"area_id_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visible_ratio_blob', full_name='apollo.perception.camera.yolo.NetworkParam.visible_ratio_blob', index=32,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"vis_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cut_off_ratio_blob', full_name='apollo.perception.camera.yolo.NetworkParam.cut_off_ratio_blob', index=33,
      number=34, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"cut_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1508,
  serialized_end=2792,
)


_NMSPARAM = _descriptor.Descriptor(
  name='NMSParam',
  full_name='apollo.perception.camera.yolo.NMSParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.perception.camera.yolo.NMSParam.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"NormalNMS".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='apollo.perception.camera.yolo.NMSParam.threshold', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sigma', full_name='apollo.perception.camera.yolo.NMSParam.sigma', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inter_cls_conf_thresh', full_name='apollo.perception.camera.yolo.NMSParam.inter_cls_conf_thresh', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inter_cls_nms_thresh', full_name='apollo.perception.camera.yolo.NMSParam.inter_cls_nms_thresh', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2795,
  serialized_end=2943,
)


_BBOXSTATISTICS = _descriptor.Descriptor(
  name='BBoxStatistics',
  full_name='apollo.perception.camera.yolo.BBoxStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mean', full_name='apollo.perception.camera.yolo.BBoxStatistics.mean', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='std', full_name='apollo.perception.camera.yolo.BBoxStatistics.std', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2945,
  serialized_end=2988,
)


_DIMENSIONSTATISTICS = _descriptor.Descriptor(
  name='DimensionStatistics',
  full_name='apollo.perception.camera.yolo.DimensionStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mean_h', full_name='apollo.perception.camera.yolo.DimensionStatistics.mean_h', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_w', full_name='apollo.perception.camera.yolo.DimensionStatistics.mean_w', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_l', full_name='apollo.perception.camera.yolo.DimensionStatistics.mean_l', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='std_h', full_name='apollo.perception.camera.yolo.DimensionStatistics.std_h', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='std_w', full_name='apollo.perception.camera.yolo.DimensionStatistics.std_w', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='std_l', full_name='apollo.perception.camera.yolo.DimensionStatistics.std_l', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2991,
  serialized_end=3123,
)

_YOLOPARAM.fields_by_name['model_param'].message_type = _MODELPARAM
_YOLOPARAM.fields_by_name['net_param'].message_type = _NETWORKPARAM
_YOLOPARAM.fields_by_name['nms_param'].message_type = _NMSPARAM
_MODELPARAM.fields_by_name['dimension_statistics'].message_type = _DIMENSIONSTATISTICS
_MODELPARAM.fields_by_name['bbox_statistics'].message_type = _BBOXSTATISTICS
DESCRIPTOR.message_types_by_name['YoloParam'] = _YOLOPARAM
DESCRIPTOR.message_types_by_name['ModelParam'] = _MODELPARAM
DESCRIPTOR.message_types_by_name['NetworkParam'] = _NETWORKPARAM
DESCRIPTOR.message_types_by_name['NMSParam'] = _NMSPARAM
DESCRIPTOR.message_types_by_name['BBoxStatistics'] = _BBOXSTATISTICS
DESCRIPTOR.message_types_by_name['DimensionStatistics'] = _DIMENSIONSTATISTICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

YoloParam = _reflection.GeneratedProtocolMessageType('YoloParam', (_message.Message,), {
  'DESCRIPTOR' : _YOLOPARAM,
  '__module__' : 'modules.perception.camera.proto.yolo_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.yolo.YoloParam)
  })
_sym_db.RegisterMessage(YoloParam)

ModelParam = _reflection.GeneratedProtocolMessageType('ModelParam', (_message.Message,), {
  'DESCRIPTOR' : _MODELPARAM,
  '__module__' : 'modules.perception.camera.proto.yolo_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.yolo.ModelParam)
  })
_sym_db.RegisterMessage(ModelParam)

NetworkParam = _reflection.GeneratedProtocolMessageType('NetworkParam', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKPARAM,
  '__module__' : 'modules.perception.camera.proto.yolo_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.yolo.NetworkParam)
  })
_sym_db.RegisterMessage(NetworkParam)

NMSParam = _reflection.GeneratedProtocolMessageType('NMSParam', (_message.Message,), {
  'DESCRIPTOR' : _NMSPARAM,
  '__module__' : 'modules.perception.camera.proto.yolo_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.yolo.NMSParam)
  })
_sym_db.RegisterMessage(NMSParam)

BBoxStatistics = _reflection.GeneratedProtocolMessageType('BBoxStatistics', (_message.Message,), {
  'DESCRIPTOR' : _BBOXSTATISTICS,
  '__module__' : 'modules.perception.camera.proto.yolo_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.yolo.BBoxStatistics)
  })
_sym_db.RegisterMessage(BBoxStatistics)

DimensionStatistics = _reflection.GeneratedProtocolMessageType('DimensionStatistics', (_message.Message,), {
  'DESCRIPTOR' : _DIMENSIONSTATISTICS,
  '__module__' : 'modules.perception.camera.proto.yolo_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.yolo.DimensionStatistics)
  })
_sym_db.RegisterMessage(DimensionStatistics)


# @@protoc_insertion_point(module_scope)
