# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/map_manager_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/map_manager_config.proto',
  package='apollo.perception.lidar',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1modules/perception/proto/map_manager_config.proto\x12\x17\x61pollo.perception.lidar\"v\n\x10MapManagerConfig\x12\x1a\n\x0bupdate_pose\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x13roi_search_distance\x18\x02 \x01(\x01:\x02\x38\x30\x12\x12\n\nlane_range\x18\x03 \x01(\x01\x12\x11\n\tmax_depth\x18\x04 \x01(\x01'
)




_MAPMANAGERCONFIG = _descriptor.Descriptor(
  name='MapManagerConfig',
  full_name='apollo.perception.lidar.MapManagerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_pose', full_name='apollo.perception.lidar.MapManagerConfig.update_pose', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_search_distance', full_name='apollo.perception.lidar.MapManagerConfig.roi_search_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(80),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_range', full_name='apollo.perception.lidar.MapManagerConfig.lane_range', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_depth', full_name='apollo.perception.lidar.MapManagerConfig.max_depth', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=196,
)

DESCRIPTOR.message_types_by_name['MapManagerConfig'] = _MAPMANAGERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MapManagerConfig = _reflection.GeneratedProtocolMessageType('MapManagerConfig', (_message.Message,), {
  'DESCRIPTOR' : _MAPMANAGERCONFIG,
  '__module__' : 'modules.perception.proto.map_manager_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.lidar.MapManagerConfig)
  })
_sym_db.RegisterMessage(MapManagerConfig)


# @@protoc_insertion_point(module_scope)
