# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/microphone/proto/microphone_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/microphone/proto/microphone_config.proto',
  package='apollo.drivers.microphone.config',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n8modules/drivers/microphone/proto/microphone_config.proto\x12 apollo.drivers.microphone.config\"\xf4\x02\n\x10MicrophoneConfig\x12\\\n\x10microphone_model\x18\x02 \x01(\x0e\x32\x42.apollo.drivers.microphone.config.MicrophoneConfig.MicrophoneModel\x12\r\n\x05\x63hunk\x18\x03 \x01(\x05\x12\x13\n\x0bsample_rate\x18\x04 \x01(\x02\x12\x16\n\x0erecord_seconds\x18\x05 \x01(\x02\x12\x14\n\x0csample_width\x18\x06 \x01(\x05\x12\x14\n\x0c\x63hannel_name\x18\x07 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x08 \x01(\t\x12\x14\n\x0cmic_distance\x18\t \x01(\x02\x12\x43\n\x0c\x63hannel_type\x18\x01 \x03(\x0e\x32-.apollo.drivers.microphone.config.ChannelType\"-\n\x0fMicrophoneModel\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tRESPEAKER\x10\x01*:\n\x0b\x43hannelType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x41SR\x10\x01\x12\x07\n\x03RAW\x10\x02\x12\x0c\n\x08PLAYBACK\x10\x03'
)

_CHANNELTYPE = _descriptor.EnumDescriptor(
  name='ChannelType',
  full_name='apollo.drivers.microphone.config.ChannelType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAW', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLAYBACK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=469,
  serialized_end=527,
)
_sym_db.RegisterEnumDescriptor(_CHANNELTYPE)

ChannelType = enum_type_wrapper.EnumTypeWrapper(_CHANNELTYPE)
UNKNOWN = 0
ASR = 1
RAW = 2
PLAYBACK = 3


_MICROPHONECONFIG_MICROPHONEMODEL = _descriptor.EnumDescriptor(
  name='MicrophoneModel',
  full_name='apollo.drivers.microphone.config.MicrophoneConfig.MicrophoneModel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESPEAKER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=422,
  serialized_end=467,
)
_sym_db.RegisterEnumDescriptor(_MICROPHONECONFIG_MICROPHONEMODEL)


_MICROPHONECONFIG = _descriptor.Descriptor(
  name='MicrophoneConfig',
  full_name='apollo.drivers.microphone.config.MicrophoneConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='microphone_model', full_name='apollo.drivers.microphone.config.MicrophoneConfig.microphone_model', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunk', full_name='apollo.drivers.microphone.config.MicrophoneConfig.chunk', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='apollo.drivers.microphone.config.MicrophoneConfig.sample_rate', index=2,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='record_seconds', full_name='apollo.drivers.microphone.config.MicrophoneConfig.record_seconds', index=3,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_width', full_name='apollo.drivers.microphone.config.MicrophoneConfig.sample_width', index=4,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_name', full_name='apollo.drivers.microphone.config.MicrophoneConfig.channel_name', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.drivers.microphone.config.MicrophoneConfig.frame_id', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mic_distance', full_name='apollo.drivers.microphone.config.MicrophoneConfig.mic_distance', index=7,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_type', full_name='apollo.drivers.microphone.config.MicrophoneConfig.channel_type', index=8,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MICROPHONECONFIG_MICROPHONEMODEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=467,
)

_MICROPHONECONFIG.fields_by_name['microphone_model'].enum_type = _MICROPHONECONFIG_MICROPHONEMODEL
_MICROPHONECONFIG.fields_by_name['channel_type'].enum_type = _CHANNELTYPE
_MICROPHONECONFIG_MICROPHONEMODEL.containing_type = _MICROPHONECONFIG
DESCRIPTOR.message_types_by_name['MicrophoneConfig'] = _MICROPHONECONFIG
DESCRIPTOR.enum_types_by_name['ChannelType'] = _CHANNELTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MicrophoneConfig = _reflection.GeneratedProtocolMessageType('MicrophoneConfig', (_message.Message,), {
  'DESCRIPTOR' : _MICROPHONECONFIG,
  '__module__' : 'modules.drivers.microphone.proto.microphone_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.microphone.config.MicrophoneConfig)
  })
_sym_db.RegisterMessage(MicrophoneConfig)


# @@protoc_insertion_point(module_scope)
