# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/prediction/proto/feature.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2
from modules.map.proto import map_lane_pb2 as modules_dot_map_dot_proto_dot_map__lane__pb2
from modules.perception.proto import perception_obstacle_pb2 as modules_dot_perception_dot_proto_dot_perception__obstacle__pb2
from modules.prediction.proto import lane_graph_pb2 as modules_dot_prediction_dot_proto_dot_lane__graph__pb2
from modules.prediction.proto import prediction_point_pb2 as modules_dot_prediction_dot_proto_dot_prediction__point__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/prediction/proto/feature.proto',
  package='apollo.prediction',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&modules/prediction/proto/feature.proto\x12\x11\x61pollo.prediction\x1a#modules/common/proto/geometry.proto\x1a$modules/common/proto/pnc_point.proto\x1a modules/map/proto/map_lane.proto\x1a\x32modules/perception/proto/perception_obstacle.proto\x1a)modules/prediction/proto/lane_graph.proto\x1a/modules/prediction/proto/prediction_point.proto\"\xc4\x02\n\x04Lane\x12<\n\x14\x63urrent_lane_feature\x18\x01 \x03(\x0b\x32\x1e.apollo.prediction.LaneFeature\x12\x34\n\x0clane_feature\x18\x02 \x01(\x0b\x32\x1e.apollo.prediction.LaneFeature\x12;\n\x13nearby_lane_feature\x18\x03 \x03(\x0b\x32\x1e.apollo.prediction.LaneFeature\x12\x30\n\nlane_graph\x18\x04 \x01(\x0b\x32\x1c.apollo.prediction.LaneGraph\x12\x38\n\x12lane_graph_ordered\x18\x05 \x01(\x0b\x32\x1c.apollo.prediction.LaneGraph\x12\x1f\n\x17label_update_time_delta\x18\x1a \x01(\x01\"\xef\x01\n\x0bLaneFeature\x12\x0f\n\x07lane_id\x18\x01 \x01(\t\x12\x16\n\x0elane_turn_type\x18\x02 \x01(\r\x12\x0e\n\x06lane_s\x18\x03 \x01(\x01\x12\x0e\n\x06lane_l\x18\x04 \x01(\x01\x12\x12\n\nangle_diff\x18\x05 \x01(\x01\x12\x1d\n\x15\x64ist_to_left_boundary\x18\x06 \x01(\x01\x12\x1e\n\x16\x64ist_to_right_boundary\x18\x07 \x01(\x01\x12\x14\n\x0clane_heading\x18\x08 \x01(\x01\x12.\n\tlane_type\x18\t \x01(\x0e\x32\x1b.apollo.hdmap.Lane.LaneType\"}\n\x0cJunctionExit\x12\x14\n\x0c\x65xit_lane_id\x18\x01 \x01(\t\x12-\n\rexit_position\x18\x02 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x14\n\x0c\x65xit_heading\x18\x03 \x01(\x01\x12\x12\n\nexit_width\x18\x04 \x01(\x01\"\x9d\x02\n\x0fJunctionFeature\x12\x13\n\x0bjunction_id\x18\x01 \x01(\t\x12\x16\n\x0ejunction_range\x18\x02 \x01(\x01\x12\x32\n\nenter_lane\x18\x03 \x01(\x0b\x32\x1e.apollo.prediction.LaneFeature\x12\x36\n\rjunction_exit\x18\x04 \x03(\x0b\x32\x1f.apollo.prediction.JunctionExit\x12\x1c\n\x14junction_mlp_feature\x18\x05 \x03(\x01\x12\x1a\n\x12junction_mlp_label\x18\x06 \x03(\x05\x12 \n\x18junction_mlp_probability\x18\x07 \x03(\x01\x12\x15\n\rstart_lane_id\x18\x08 \x03(\t\"\x8b\x01\n\x10ObstaclePriority\x12\x46\n\x08priority\x18\x19 \x01(\x0e\x32,.apollo.prediction.ObstaclePriority.Priority:\x06NORMAL\"/\n\x08Priority\x12\x0b\n\x07\x43\x41UTION\x10\x01\x12\n\n\x06NORMAL\x10\x02\x12\n\n\x06IGNORE\x10\x03\"[\n\nTrajectory\x12\x13\n\x0bprobability\x18\x01 \x01(\x01\x12\x38\n\x10trajectory_point\x18\x02 \x03(\x0b\x32\x1e.apollo.common.TrajectoryPoint\"\x9b\n\n\x07\x46\x65\x61ture\x12\n\n\x02id\x18\x01 \x01(\x05\x12-\n\rpolygon_point\x18\x1e \x03(\x0b\x32\x16.apollo.common.Point3D\x12(\n\x08position\x18\x02 \x01(\x0b\x32\x16.apollo.common.Point3D\x12.\n\x0e\x66ront_position\x18\x1b \x01(\x0b\x32\x16.apollo.common.Point3D\x12(\n\x08velocity\x18\x03 \x01(\x0b\x32\x16.apollo.common.Point3D\x12,\n\x0craw_velocity\x18\x1c \x01(\x0b\x32\x16.apollo.common.Point3D\x12,\n\x0c\x61\x63\x63\x65leration\x18\x04 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x18\n\x10velocity_heading\x18\x05 \x01(\x01\x12\r\n\x05speed\x18\x06 \x01(\x01\x12\x0b\n\x03\x61\x63\x63\x18\x07 \x01(\x01\x12\r\n\x05theta\x18\x08 \x01(\x01\x12\x0e\n\x06length\x18\t \x01(\x01\x12\r\n\x05width\x18\n \x01(\x01\x12\x0e\n\x06height\x18\x0b \x01(\x01\x12\x15\n\rtracking_time\x18\x0c \x01(\x01\x12\x11\n\ttimestamp\x18\r \x01(\x01\x12%\n\x04lane\x18\x0e \x01(\x0b\x32\x17.apollo.prediction.Lane\x12<\n\x10junction_feature\x18\x1a \x01(\x0b\x32\".apollo.prediction.JunctionFeature\x12*\n\nt_position\x18\x10 \x01(\x0b\x32\x16.apollo.common.Point3D\x12.\n\nt_velocity\x18\x11 \x01(\x0b\x32\x16.apollo.common.Point3DB\x02\x18\x01\x12\x1e\n\x12t_velocity_heading\x18\x12 \x01(\x01\x42\x02\x18\x01\x12\x13\n\x07t_speed\x18\x13 \x01(\x01\x42\x02\x18\x01\x12\x32\n\x0et_acceleration\x18\x14 \x01(\x0b\x32\x16.apollo.common.Point3DB\x02\x18\x01\x12\x11\n\x05t_acc\x18\x15 \x01(\x01\x42\x02\x18\x01\x12\x17\n\x08is_still\x18\x16 \x01(\x08:\x05\x66\x61lse\x12\x38\n\x04type\x18\x17 \x01(\x0e\x32*.apollo.perception.PerceptionObstacle.Type\x12\x1f\n\x17label_update_time_delta\x18\x18 \x01(\x01\x12\x35\n\x08priority\x18\x19 \x01(\x0b\x32#.apollo.prediction.ObstaclePriority\x12\x1f\n\x10is_near_junction\x18\x1d \x01(\x08:\x05\x66\x61lse\x12N\n\x18\x66uture_trajectory_points\x18\x1f \x03(\x0b\x32,.apollo.prediction.PredictionTrajectoryPoint\x12N\n&short_term_predicted_trajectory_points\x18  \x03(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12;\n\x14predicted_trajectory\x18! \x03(\x0b\x32\x1d.apollo.prediction.Trajectory\x12<\n\x14\x61\x64\x63_trajectory_point\x18\" \x03(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12\x1b\n\x13surrounding_lane_id\x18# \x03(\t\x12\x16\n\x0ewithin_lane_id\x18$ \x03(\t\"[\n\x0fObstacleHistory\x12+\n\x07\x66\x65\x61ture\x18\x01 \x03(\x0b\x32\x1a.apollo.prediction.Feature\x12\x1b\n\x0cis_trainable\x18\x02 \x01(\x08:\x05\x66\x61lse\"\x95\x01\n\x08\x46rameEnv\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x37\n\x0b\x65go_history\x18\x02 \x01(\x0b\x32\".apollo.prediction.ObstacleHistory\x12=\n\x11obstacles_history\x18\x03 \x03(\x0b\x32\".apollo.prediction.ObstacleHistory'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__lane__pb2.DESCRIPTOR,modules_dot_perception_dot_proto_dot_perception__obstacle__pb2.DESCRIPTOR,modules_dot_prediction_dot_proto_dot_lane__graph__pb2.DESCRIPTOR,modules_dot_prediction_dot_proto_dot_prediction__point__pb2.DESCRIPTOR,])



_OBSTACLEPRIORITY_PRIORITY = _descriptor.EnumDescriptor(
  name='Priority',
  full_name='apollo.prediction.ObstaclePriority.Priority',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAUTION', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IGNORE', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1391,
  serialized_end=1438,
)
_sym_db.RegisterEnumDescriptor(_OBSTACLEPRIORITY_PRIORITY)


_LANE = _descriptor.Descriptor(
  name='Lane',
  full_name='apollo.prediction.Lane',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_lane_feature', full_name='apollo.prediction.Lane.current_lane_feature', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_feature', full_name='apollo.prediction.Lane.lane_feature', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nearby_lane_feature', full_name='apollo.prediction.Lane.nearby_lane_feature', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_graph', full_name='apollo.prediction.Lane.lane_graph', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_graph_ordered', full_name='apollo.prediction.Lane.lane_graph_ordered', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label_update_time_delta', full_name='apollo.prediction.Lane.label_update_time_delta', index=5,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=639,
)


_LANEFEATURE = _descriptor.Descriptor(
  name='LaneFeature',
  full_name='apollo.prediction.LaneFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.prediction.LaneFeature.lane_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_turn_type', full_name='apollo.prediction.LaneFeature.lane_turn_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_s', full_name='apollo.prediction.LaneFeature.lane_s', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_l', full_name='apollo.prediction.LaneFeature.lane_l', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angle_diff', full_name='apollo.prediction.LaneFeature.angle_diff', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dist_to_left_boundary', full_name='apollo.prediction.LaneFeature.dist_to_left_boundary', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dist_to_right_boundary', full_name='apollo.prediction.LaneFeature.dist_to_right_boundary', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_heading', full_name='apollo.prediction.LaneFeature.lane_heading', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_type', full_name='apollo.prediction.LaneFeature.lane_type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=642,
  serialized_end=881,
)


_JUNCTIONEXIT = _descriptor.Descriptor(
  name='JunctionExit',
  full_name='apollo.prediction.JunctionExit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exit_lane_id', full_name='apollo.prediction.JunctionExit.exit_lane_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exit_position', full_name='apollo.prediction.JunctionExit.exit_position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exit_heading', full_name='apollo.prediction.JunctionExit.exit_heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exit_width', full_name='apollo.prediction.JunctionExit.exit_width', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=1008,
)


_JUNCTIONFEATURE = _descriptor.Descriptor(
  name='JunctionFeature',
  full_name='apollo.prediction.JunctionFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='junction_id', full_name='apollo.prediction.JunctionFeature.junction_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_range', full_name='apollo.prediction.JunctionFeature.junction_range', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enter_lane', full_name='apollo.prediction.JunctionFeature.enter_lane', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_exit', full_name='apollo.prediction.JunctionFeature.junction_exit', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_mlp_feature', full_name='apollo.prediction.JunctionFeature.junction_mlp_feature', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_mlp_label', full_name='apollo.prediction.JunctionFeature.junction_mlp_label', index=5,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_mlp_probability', full_name='apollo.prediction.JunctionFeature.junction_mlp_probability', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_lane_id', full_name='apollo.prediction.JunctionFeature.start_lane_id', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1011,
  serialized_end=1296,
)


_OBSTACLEPRIORITY = _descriptor.Descriptor(
  name='ObstaclePriority',
  full_name='apollo.prediction.ObstaclePriority',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='apollo.prediction.ObstaclePriority.priority', index=0,
      number=25, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OBSTACLEPRIORITY_PRIORITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1299,
  serialized_end=1438,
)


_TRAJECTORY = _descriptor.Descriptor(
  name='Trajectory',
  full_name='apollo.prediction.Trajectory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='probability', full_name='apollo.prediction.Trajectory.probability', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_point', full_name='apollo.prediction.Trajectory.trajectory_point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=1531,
)


_FEATURE = _descriptor.Descriptor(
  name='Feature',
  full_name='apollo.prediction.Feature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.prediction.Feature.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon_point', full_name='apollo.prediction.Feature.polygon_point', index=1,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.prediction.Feature.position', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_position', full_name='apollo.prediction.Feature.front_position', index=3,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='apollo.prediction.Feature.velocity', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_velocity', full_name='apollo.prediction.Feature.raw_velocity', index=5,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='apollo.prediction.Feature.acceleration', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_heading', full_name='apollo.prediction.Feature.velocity_heading', index=7,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.prediction.Feature.speed', index=8,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc', full_name='apollo.prediction.Feature.acc', index=9,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='apollo.prediction.Feature.theta', index=10,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.prediction.Feature.length', index=11,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.prediction.Feature.width', index=12,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.prediction.Feature.height', index=13,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracking_time', full_name='apollo.prediction.Feature.tracking_time', index=14,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.prediction.Feature.timestamp', index=15,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane', full_name='apollo.prediction.Feature.lane', index=16,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_feature', full_name='apollo.prediction.Feature.junction_feature', index=17,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_position', full_name='apollo.prediction.Feature.t_position', index=18,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_velocity', full_name='apollo.prediction.Feature.t_velocity', index=19,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_velocity_heading', full_name='apollo.prediction.Feature.t_velocity_heading', index=20,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_speed', full_name='apollo.prediction.Feature.t_speed', index=21,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_acceleration', full_name='apollo.prediction.Feature.t_acceleration', index=22,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t_acc', full_name='apollo.prediction.Feature.t_acc', index=23,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_still', full_name='apollo.prediction.Feature.is_still', index=24,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.prediction.Feature.type', index=25,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label_update_time_delta', full_name='apollo.prediction.Feature.label_update_time_delta', index=26,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='apollo.prediction.Feature.priority', index=27,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_near_junction', full_name='apollo.prediction.Feature.is_near_junction', index=28,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='future_trajectory_points', full_name='apollo.prediction.Feature.future_trajectory_points', index=29,
      number=31, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short_term_predicted_trajectory_points', full_name='apollo.prediction.Feature.short_term_predicted_trajectory_points', index=30,
      number=32, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predicted_trajectory', full_name='apollo.prediction.Feature.predicted_trajectory', index=31,
      number=33, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_trajectory_point', full_name='apollo.prediction.Feature.adc_trajectory_point', index=32,
      number=34, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='surrounding_lane_id', full_name='apollo.prediction.Feature.surrounding_lane_id', index=33,
      number=35, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='within_lane_id', full_name='apollo.prediction.Feature.within_lane_id', index=34,
      number=36, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1534,
  serialized_end=2841,
)


_OBSTACLEHISTORY = _descriptor.Descriptor(
  name='ObstacleHistory',
  full_name='apollo.prediction.ObstacleHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature', full_name='apollo.prediction.ObstacleHistory.feature', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_trainable', full_name='apollo.prediction.ObstacleHistory.is_trainable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2843,
  serialized_end=2934,
)


_FRAMEENV = _descriptor.Descriptor(
  name='FrameEnv',
  full_name='apollo.prediction.FrameEnv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.prediction.FrameEnv.timestamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ego_history', full_name='apollo.prediction.FrameEnv.ego_history', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacles_history', full_name='apollo.prediction.FrameEnv.obstacles_history', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2937,
  serialized_end=3086,
)

_LANE.fields_by_name['current_lane_feature'].message_type = _LANEFEATURE
_LANE.fields_by_name['lane_feature'].message_type = _LANEFEATURE
_LANE.fields_by_name['nearby_lane_feature'].message_type = _LANEFEATURE
_LANE.fields_by_name['lane_graph'].message_type = modules_dot_prediction_dot_proto_dot_lane__graph__pb2._LANEGRAPH
_LANE.fields_by_name['lane_graph_ordered'].message_type = modules_dot_prediction_dot_proto_dot_lane__graph__pb2._LANEGRAPH
_LANEFEATURE.fields_by_name['lane_type'].enum_type = modules_dot_map_dot_proto_dot_map__lane__pb2._LANE_LANETYPE
_JUNCTIONEXIT.fields_by_name['exit_position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_JUNCTIONFEATURE.fields_by_name['enter_lane'].message_type = _LANEFEATURE
_JUNCTIONFEATURE.fields_by_name['junction_exit'].message_type = _JUNCTIONEXIT
_OBSTACLEPRIORITY.fields_by_name['priority'].enum_type = _OBSTACLEPRIORITY_PRIORITY
_OBSTACLEPRIORITY_PRIORITY.containing_type = _OBSTACLEPRIORITY
_TRAJECTORY.fields_by_name['trajectory_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_FEATURE.fields_by_name['polygon_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['front_position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['raw_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['acceleration'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['lane'].message_type = _LANE
_FEATURE.fields_by_name['junction_feature'].message_type = _JUNCTIONFEATURE
_FEATURE.fields_by_name['t_position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['t_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['t_acceleration'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_FEATURE.fields_by_name['type'].enum_type = modules_dot_perception_dot_proto_dot_perception__obstacle__pb2._PERCEPTIONOBSTACLE_TYPE
_FEATURE.fields_by_name['priority'].message_type = _OBSTACLEPRIORITY
_FEATURE.fields_by_name['future_trajectory_points'].message_type = modules_dot_prediction_dot_proto_dot_prediction__point__pb2._PREDICTIONTRAJECTORYPOINT
_FEATURE.fields_by_name['short_term_predicted_trajectory_points'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_FEATURE.fields_by_name['predicted_trajectory'].message_type = _TRAJECTORY
_FEATURE.fields_by_name['adc_trajectory_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_OBSTACLEHISTORY.fields_by_name['feature'].message_type = _FEATURE
_FRAMEENV.fields_by_name['ego_history'].message_type = _OBSTACLEHISTORY
_FRAMEENV.fields_by_name['obstacles_history'].message_type = _OBSTACLEHISTORY
DESCRIPTOR.message_types_by_name['Lane'] = _LANE
DESCRIPTOR.message_types_by_name['LaneFeature'] = _LANEFEATURE
DESCRIPTOR.message_types_by_name['JunctionExit'] = _JUNCTIONEXIT
DESCRIPTOR.message_types_by_name['JunctionFeature'] = _JUNCTIONFEATURE
DESCRIPTOR.message_types_by_name['ObstaclePriority'] = _OBSTACLEPRIORITY
DESCRIPTOR.message_types_by_name['Trajectory'] = _TRAJECTORY
DESCRIPTOR.message_types_by_name['Feature'] = _FEATURE
DESCRIPTOR.message_types_by_name['ObstacleHistory'] = _OBSTACLEHISTORY
DESCRIPTOR.message_types_by_name['FrameEnv'] = _FRAMEENV
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Lane = _reflection.GeneratedProtocolMessageType('Lane', (_message.Message,), {
  'DESCRIPTOR' : _LANE,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Lane)
  })
_sym_db.RegisterMessage(Lane)

LaneFeature = _reflection.GeneratedProtocolMessageType('LaneFeature', (_message.Message,), {
  'DESCRIPTOR' : _LANEFEATURE,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.LaneFeature)
  })
_sym_db.RegisterMessage(LaneFeature)

JunctionExit = _reflection.GeneratedProtocolMessageType('JunctionExit', (_message.Message,), {
  'DESCRIPTOR' : _JUNCTIONEXIT,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.JunctionExit)
  })
_sym_db.RegisterMessage(JunctionExit)

JunctionFeature = _reflection.GeneratedProtocolMessageType('JunctionFeature', (_message.Message,), {
  'DESCRIPTOR' : _JUNCTIONFEATURE,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.JunctionFeature)
  })
_sym_db.RegisterMessage(JunctionFeature)

ObstaclePriority = _reflection.GeneratedProtocolMessageType('ObstaclePriority', (_message.Message,), {
  'DESCRIPTOR' : _OBSTACLEPRIORITY,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ObstaclePriority)
  })
_sym_db.RegisterMessage(ObstaclePriority)

Trajectory = _reflection.GeneratedProtocolMessageType('Trajectory', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORY,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Trajectory)
  })
_sym_db.RegisterMessage(Trajectory)

Feature = _reflection.GeneratedProtocolMessageType('Feature', (_message.Message,), {
  'DESCRIPTOR' : _FEATURE,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Feature)
  })
_sym_db.RegisterMessage(Feature)

ObstacleHistory = _reflection.GeneratedProtocolMessageType('ObstacleHistory', (_message.Message,), {
  'DESCRIPTOR' : _OBSTACLEHISTORY,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ObstacleHistory)
  })
_sym_db.RegisterMessage(ObstacleHistory)

FrameEnv = _reflection.GeneratedProtocolMessageType('FrameEnv', (_message.Message,), {
  'DESCRIPTOR' : _FRAMEENV,
  '__module__' : 'modules.prediction.proto.feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.FrameEnv)
  })
_sym_db.RegisterMessage(FrameEnv)


_FEATURE.fields_by_name['t_velocity']._options = None
_FEATURE.fields_by_name['t_velocity_heading']._options = None
_FEATURE.fields_by_name['t_speed']._options = None
_FEATURE.fields_by_name['t_acceleration']._options = None
_FEATURE.fields_by_name['t_acc']._options = None
# @@protoc_insertion_point(module_scope)
