# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/proto/mobileye.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/proto/mobileye.proto',
  package='apollo.drivers',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/drivers/proto/mobileye.proto\x12\x0e\x61pollo.drivers\x1a!modules/common/proto/header.proto\"\xa3\x01\n\x07Lka_768\x12\x11\n\tlane_type\x18\x01 \x01(\x05\x12\x0f\n\x07quality\x18\x02 \x01(\x05\x12\x14\n\x0cmodel_degree\x18\x03 \x01(\x05\x12\x10\n\x08position\x18\x04 \x01(\x01\x12\x11\n\tcurvature\x18\x05 \x01(\x01\x12\x1c\n\x14\x63urvature_derivative\x18\x06 \x01(\x01\x12\x1b\n\x13width_right_marking\x18\x07 \x01(\x01\"1\n\x07Num_76b\x12&\n\x1enum_of_next_lane_mark_reported\x18\x01 \x01(\x05\"\xea\x01\n\x0f\x41\x66termarket_669\x12\x16\n\x0elane_conf_left\x18\x01 \x01(\x05\x12\x1d\n\x15ldw_availability_left\x18\x02 \x01(\x08\x12\x16\n\x0elane_type_left\x18\x03 \x01(\x05\x12\x1a\n\x12\x64istance_to_lane_l\x18\x04 \x01(\x01\x12\x17\n\x0flane_conf_right\x18\x05 \x01(\x05\x12\x1e\n\x16ldw_availability_right\x18\x06 \x01(\x08\x12\x17\n\x0flane_type_right\x18\x07 \x01(\x05\x12\x1a\n\x12\x64istance_to_lane_r\x18\x08 \x01(\x01\"U\n\x07Lka_769\x12\x15\n\rheading_angle\x18\x01 \x01(\x01\x12\x12\n\nview_range\x18\x02 \x01(\x01\x12\x1f\n\x17view_range_availability\x18\x03 \x01(\x08\"\xc3\x01\n\rReference_76a\x12\x1c\n\x14ref_point_1_position\x18\x01 \x01(\x01\x12\x1c\n\x14ref_point_1_distance\x18\x02 \x01(\x01\x12\x1c\n\x14ref_point_1_validity\x18\x03 \x01(\x08\x12\x1c\n\x14ref_point_2_position\x18\x04 \x01(\x01\x12\x1c\n\x14ref_point_2_distance\x18\x05 \x01(\x01\x12\x1c\n\x14ref_point_2_validity\x18\x06 \x01(\x08\"\x9c\x02\n\x0b\x44\x65tails_738\x12\x15\n\rnum_obstacles\x18\x01 \x01(\x05\x12\x11\n\ttimestamp\x18\x02 \x01(\x05\x12\x1b\n\x13\x61pplication_version\x18\x03 \x01(\x05\x12%\n\x1d\x61\x63tive_version_number_section\x18\x04 \x01(\x05\x12\x1e\n\x16left_close_rang_cut_in\x18\x05 \x01(\x08\x12\x1f\n\x17right_close_rang_cut_in\x18\x06 \x01(\x08\x12\n\n\x02go\x18\x07 \x01(\x05\x12\x18\n\x10protocol_version\x18\x08 \x01(\x05\x12\x11\n\tclose_car\x18\t \x01(\x08\x12\x10\n\x08\x66\x61ilsafe\x18\n \x01(\x05\x12\x13\n\x0breserved_10\x18\x0b \x01(\x05\"\xa0\x01\n\x08Next_76c\x12\x11\n\tlane_type\x18\x01 \x01(\x05\x12\x0f\n\x07quality\x18\x02 \x01(\x05\x12\x14\n\x0cmodel_degree\x18\x03 \x01(\x05\x12\x10\n\x08position\x18\x04 \x01(\x01\x12\x11\n\tcurvature\x18\x05 \x01(\x01\x12\x1c\n\x14\x63urvature_derivative\x18\x06 \x01(\x01\x12\x17\n\x0flane_mark_width\x18\x07 \x01(\x01\"\xd4\x01\n\x0b\x44\x65tails_737\x12\x16\n\x0elane_curvature\x18\x01 \x01(\x01\x12\x14\n\x0clane_heading\x18\x02 \x01(\x01\x12\x1c\n\x14\x63\x61_construction_area\x18\x03 \x01(\x08\x12\x1e\n\x16right_ldw_availability\x18\x04 \x01(\x08\x12\x1d\n\x15left_ldw_availability\x18\x05 \x01(\x08\x12\x12\n\nreserved_1\x18\x06 \x01(\x08\x12\x11\n\tyaw_angle\x18\x07 \x01(\x01\x12\x13\n\x0bpitch_angle\x18\x08 \x01(\x01\"U\n\x07Lka_767\x12\x15\n\rheading_angle\x18\x01 \x01(\x01\x12\x12\n\nview_range\x18\x02 \x01(\x01\x12\x1f\n\x17view_range_availability\x18\x03 \x01(\x08\"\xa2\x01\n\x07Lka_766\x12\x11\n\tlane_type\x18\x01 \x01(\x05\x12\x0f\n\x07quality\x18\x02 \x01(\x05\x12\x14\n\x0cmodel_degree\x18\x03 \x01(\x05\x12\x10\n\x08position\x18\x04 \x01(\x01\x12\x11\n\tcurvature\x18\x05 \x01(\x01\x12\x1c\n\x14\x63urvature_derivative\x18\x06 \x01(\x01\x12\x1a\n\x12width_left_marking\x18\x07 \x01(\x01\"V\n\x08Next_76d\x12\x15\n\rheading_angle\x18\x01 \x01(\x01\x12\x12\n\nview_range\x18\x02 \x01(\x01\x12\x1f\n\x17view_range_availability\x18\x03 \x01(\x08\"\xbe\x02\n\x0b\x44\x65tails_739\x12\x13\n\x0bobstacle_id\x18\x01 \x01(\x05\x12\x16\n\x0eobstacle_pos_x\x18\x02 \x01(\x01\x12\x11\n\treseved_2\x18\x03 \x01(\x05\x12\x16\n\x0eobstacle_pos_y\x18\x04 \x01(\x01\x12\x14\n\x0c\x62linker_info\x18\x05 \x01(\x05\x12\x16\n\x0e\x63ut_in_and_out\x18\x06 \x01(\x05\x12\x1a\n\x12obstacle_rel_vel_x\x18\x07 \x01(\x01\x12\x15\n\robstacle_type\x18\x08 \x01(\x05\x12\x12\n\nreserved_3\x18\t \x01(\x08\x12\x17\n\x0fobstacle_status\x18\n \x01(\x05\x12\x1d\n\x15obstacle_brake_lights\x18\x0b \x01(\x08\x12\x12\n\nreserved_4\x18\x0c \x01(\x05\x12\x16\n\x0eobstacle_valid\x18\r \x01(\x05\"\x9e\x02\n\x0b\x44\x65tails_73a\x12\x17\n\x0fobstacle_length\x18\x01 \x01(\x01\x12\x16\n\x0eobstacle_width\x18\x02 \x01(\x01\x12\x14\n\x0cobstacle_age\x18\x03 \x01(\x05\x12\x15\n\robstacle_lane\x18\x04 \x01(\x05\x12\x11\n\tcipv_flag\x18\x05 \x01(\x08\x12\x12\n\nreserved_5\x18\x06 \x01(\x08\x12\x13\n\x0bradar_pos_x\x18\x07 \x01(\x01\x12\x13\n\x0bradar_vel_x\x18\x08 \x01(\x01\x12\x1e\n\x16radar_match_confidence\x18\t \x01(\x05\x12\x12\n\nreserved_6\x18\n \x01(\x08\x12\x18\n\x10matched_radar_id\x18\x0b \x01(\x05\x12\x12\n\nreserved_7\x18\x0c \x01(\x08\"\xbc\x01\n\x0b\x44\x65tails_73b\x12\x1b\n\x13obstacle_angle_rate\x18\x01 \x01(\x01\x12\x1d\n\x15obstacle_scale_change\x18\x02 \x01(\x01\x12\x16\n\x0eobject_accel_x\x18\x03 \x01(\x01\x12\x12\n\nreserved_8\x18\x04 \x01(\x05\x12\x19\n\x11obstacle_replaced\x18\x05 \x01(\x08\x12\x12\n\nreserved_9\x18\x06 \x01(\x05\x12\x16\n\x0eobstacle_angle\x18\x07 \x01(\x01\"\xc5\x05\n\x08Mobileye\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x38\n\x0f\x61\x66termarket_669\x18\x02 \x01(\x0b\x32\x1f.apollo.drivers.Aftermarket_669\x12\x30\n\x0b\x64\x65tails_737\x18\x03 \x01(\x0b\x32\x1b.apollo.drivers.Details_737\x12\x30\n\x0b\x64\x65tails_738\x18\x04 \x01(\x0b\x32\x1b.apollo.drivers.Details_738\x12\x30\n\x0b\x64\x65tails_739\x18\x05 \x03(\x0b\x32\x1b.apollo.drivers.Details_739\x12\x30\n\x0b\x64\x65tails_73a\x18\x06 \x03(\x0b\x32\x1b.apollo.drivers.Details_73a\x12\x30\n\x0b\x64\x65tails_73b\x18\x07 \x03(\x0b\x32\x1b.apollo.drivers.Details_73b\x12(\n\x07lka_766\x18\x08 \x01(\x0b\x32\x17.apollo.drivers.Lka_766\x12(\n\x07lka_767\x18\t \x01(\x0b\x32\x17.apollo.drivers.Lka_767\x12(\n\x07lka_768\x18\n \x01(\x0b\x32\x17.apollo.drivers.Lka_768\x12(\n\x07lka_769\x18\x0b \x01(\x0b\x32\x17.apollo.drivers.Lka_769\x12\x34\n\rreference_76a\x18\x0c \x01(\x0b\x32\x1d.apollo.drivers.Reference_76a\x12(\n\x07num_76b\x18\r \x01(\x0b\x32\x17.apollo.drivers.Num_76b\x12*\n\x08next_76c\x18\x0e \x03(\x0b\x32\x18.apollo.drivers.Next_76c\x12*\n\x08next_76d\x18\x0f \x03(\x0b\x32\x18.apollo.drivers.Next_76d'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])




_LKA_768 = _descriptor.Descriptor(
  name='Lka_768',
  full_name='apollo.drivers.Lka_768',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_type', full_name='apollo.drivers.Lka_768.lane_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='apollo.drivers.Lka_768.quality', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_degree', full_name='apollo.drivers.Lka_768.model_degree', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.drivers.Lka_768.position', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature', full_name='apollo.drivers.Lka_768.curvature', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature_derivative', full_name='apollo.drivers.Lka_768.curvature_derivative', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width_right_marking', full_name='apollo.drivers.Lka_768.width_right_marking', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=255,
)


_NUM_76B = _descriptor.Descriptor(
  name='Num_76b',
  full_name='apollo.drivers.Num_76b',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_of_next_lane_mark_reported', full_name='apollo.drivers.Num_76b.num_of_next_lane_mark_reported', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=306,
)


_AFTERMARKET_669 = _descriptor.Descriptor(
  name='Aftermarket_669',
  full_name='apollo.drivers.Aftermarket_669',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_conf_left', full_name='apollo.drivers.Aftermarket_669.lane_conf_left', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ldw_availability_left', full_name='apollo.drivers.Aftermarket_669.ldw_availability_left', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_type_left', full_name='apollo.drivers.Aftermarket_669.lane_type_left', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_to_lane_l', full_name='apollo.drivers.Aftermarket_669.distance_to_lane_l', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_conf_right', full_name='apollo.drivers.Aftermarket_669.lane_conf_right', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ldw_availability_right', full_name='apollo.drivers.Aftermarket_669.ldw_availability_right', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_type_right', full_name='apollo.drivers.Aftermarket_669.lane_type_right', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_to_lane_r', full_name='apollo.drivers.Aftermarket_669.distance_to_lane_r', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=309,
  serialized_end=543,
)


_LKA_769 = _descriptor.Descriptor(
  name='Lka_769',
  full_name='apollo.drivers.Lka_769',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='heading_angle', full_name='apollo.drivers.Lka_769.heading_angle', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_range', full_name='apollo.drivers.Lka_769.view_range', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_range_availability', full_name='apollo.drivers.Lka_769.view_range_availability', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=545,
  serialized_end=630,
)


_REFERENCE_76A = _descriptor.Descriptor(
  name='Reference_76a',
  full_name='apollo.drivers.Reference_76a',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ref_point_1_position', full_name='apollo.drivers.Reference_76a.ref_point_1_position', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_point_1_distance', full_name='apollo.drivers.Reference_76a.ref_point_1_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_point_1_validity', full_name='apollo.drivers.Reference_76a.ref_point_1_validity', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_point_2_position', full_name='apollo.drivers.Reference_76a.ref_point_2_position', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_point_2_distance', full_name='apollo.drivers.Reference_76a.ref_point_2_distance', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_point_2_validity', full_name='apollo.drivers.Reference_76a.ref_point_2_validity', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=828,
)


_DETAILS_738 = _descriptor.Descriptor(
  name='Details_738',
  full_name='apollo.drivers.Details_738',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_obstacles', full_name='apollo.drivers.Details_738.num_obstacles', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.drivers.Details_738.timestamp', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_version', full_name='apollo.drivers.Details_738.application_version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_version_number_section', full_name='apollo.drivers.Details_738.active_version_number_section', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_close_rang_cut_in', full_name='apollo.drivers.Details_738.left_close_rang_cut_in', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_close_rang_cut_in', full_name='apollo.drivers.Details_738.right_close_rang_cut_in', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='go', full_name='apollo.drivers.Details_738.go', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='apollo.drivers.Details_738.protocol_version', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_car', full_name='apollo.drivers.Details_738.close_car', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failsafe', full_name='apollo.drivers.Details_738.failsafe', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_10', full_name='apollo.drivers.Details_738.reserved_10', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=831,
  serialized_end=1115,
)


_NEXT_76C = _descriptor.Descriptor(
  name='Next_76c',
  full_name='apollo.drivers.Next_76c',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_type', full_name='apollo.drivers.Next_76c.lane_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='apollo.drivers.Next_76c.quality', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_degree', full_name='apollo.drivers.Next_76c.model_degree', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.drivers.Next_76c.position', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature', full_name='apollo.drivers.Next_76c.curvature', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature_derivative', full_name='apollo.drivers.Next_76c.curvature_derivative', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_mark_width', full_name='apollo.drivers.Next_76c.lane_mark_width', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1118,
  serialized_end=1278,
)


_DETAILS_737 = _descriptor.Descriptor(
  name='Details_737',
  full_name='apollo.drivers.Details_737',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_curvature', full_name='apollo.drivers.Details_737.lane_curvature', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_heading', full_name='apollo.drivers.Details_737.lane_heading', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ca_construction_area', full_name='apollo.drivers.Details_737.ca_construction_area', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_ldw_availability', full_name='apollo.drivers.Details_737.right_ldw_availability', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_ldw_availability', full_name='apollo.drivers.Details_737.left_ldw_availability', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_1', full_name='apollo.drivers.Details_737.reserved_1', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_angle', full_name='apollo.drivers.Details_737.yaw_angle', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pitch_angle', full_name='apollo.drivers.Details_737.pitch_angle', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1281,
  serialized_end=1493,
)


_LKA_767 = _descriptor.Descriptor(
  name='Lka_767',
  full_name='apollo.drivers.Lka_767',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='heading_angle', full_name='apollo.drivers.Lka_767.heading_angle', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_range', full_name='apollo.drivers.Lka_767.view_range', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_range_availability', full_name='apollo.drivers.Lka_767.view_range_availability', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1495,
  serialized_end=1580,
)


_LKA_766 = _descriptor.Descriptor(
  name='Lka_766',
  full_name='apollo.drivers.Lka_766',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_type', full_name='apollo.drivers.Lka_766.lane_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='apollo.drivers.Lka_766.quality', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_degree', full_name='apollo.drivers.Lka_766.model_degree', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.drivers.Lka_766.position', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature', full_name='apollo.drivers.Lka_766.curvature', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature_derivative', full_name='apollo.drivers.Lka_766.curvature_derivative', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width_left_marking', full_name='apollo.drivers.Lka_766.width_left_marking', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1583,
  serialized_end=1745,
)


_NEXT_76D = _descriptor.Descriptor(
  name='Next_76d',
  full_name='apollo.drivers.Next_76d',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='heading_angle', full_name='apollo.drivers.Next_76d.heading_angle', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_range', full_name='apollo.drivers.Next_76d.view_range', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_range_availability', full_name='apollo.drivers.Next_76d.view_range_availability', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1747,
  serialized_end=1833,
)


_DETAILS_739 = _descriptor.Descriptor(
  name='Details_739',
  full_name='apollo.drivers.Details_739',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obstacle_id', full_name='apollo.drivers.Details_739.obstacle_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_pos_x', full_name='apollo.drivers.Details_739.obstacle_pos_x', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reseved_2', full_name='apollo.drivers.Details_739.reseved_2', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_pos_y', full_name='apollo.drivers.Details_739.obstacle_pos_y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blinker_info', full_name='apollo.drivers.Details_739.blinker_info', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cut_in_and_out', full_name='apollo.drivers.Details_739.cut_in_and_out', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_rel_vel_x', full_name='apollo.drivers.Details_739.obstacle_rel_vel_x', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_type', full_name='apollo.drivers.Details_739.obstacle_type', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_3', full_name='apollo.drivers.Details_739.reserved_3', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_status', full_name='apollo.drivers.Details_739.obstacle_status', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_brake_lights', full_name='apollo.drivers.Details_739.obstacle_brake_lights', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_4', full_name='apollo.drivers.Details_739.reserved_4', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_valid', full_name='apollo.drivers.Details_739.obstacle_valid', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1836,
  serialized_end=2154,
)


_DETAILS_73A = _descriptor.Descriptor(
  name='Details_73a',
  full_name='apollo.drivers.Details_73a',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obstacle_length', full_name='apollo.drivers.Details_73a.obstacle_length', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_width', full_name='apollo.drivers.Details_73a.obstacle_width', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_age', full_name='apollo.drivers.Details_73a.obstacle_age', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_lane', full_name='apollo.drivers.Details_73a.obstacle_lane', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cipv_flag', full_name='apollo.drivers.Details_73a.cipv_flag', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_5', full_name='apollo.drivers.Details_73a.reserved_5', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_pos_x', full_name='apollo.drivers.Details_73a.radar_pos_x', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_vel_x', full_name='apollo.drivers.Details_73a.radar_vel_x', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_match_confidence', full_name='apollo.drivers.Details_73a.radar_match_confidence', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_6', full_name='apollo.drivers.Details_73a.reserved_6', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matched_radar_id', full_name='apollo.drivers.Details_73a.matched_radar_id', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_7', full_name='apollo.drivers.Details_73a.reserved_7', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2157,
  serialized_end=2443,
)


_DETAILS_73B = _descriptor.Descriptor(
  name='Details_73b',
  full_name='apollo.drivers.Details_73b',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obstacle_angle_rate', full_name='apollo.drivers.Details_73b.obstacle_angle_rate', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_scale_change', full_name='apollo.drivers.Details_73b.obstacle_scale_change', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_accel_x', full_name='apollo.drivers.Details_73b.object_accel_x', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_8', full_name='apollo.drivers.Details_73b.reserved_8', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_replaced', full_name='apollo.drivers.Details_73b.obstacle_replaced', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_9', full_name='apollo.drivers.Details_73b.reserved_9', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_angle', full_name='apollo.drivers.Details_73b.obstacle_angle', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2446,
  serialized_end=2634,
)


_MOBILEYE = _descriptor.Descriptor(
  name='Mobileye',
  full_name='apollo.drivers.Mobileye',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.Mobileye.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aftermarket_669', full_name='apollo.drivers.Mobileye.aftermarket_669', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details_737', full_name='apollo.drivers.Mobileye.details_737', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details_738', full_name='apollo.drivers.Mobileye.details_738', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details_739', full_name='apollo.drivers.Mobileye.details_739', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details_73a', full_name='apollo.drivers.Mobileye.details_73a', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details_73b', full_name='apollo.drivers.Mobileye.details_73b', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lka_766', full_name='apollo.drivers.Mobileye.lka_766', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lka_767', full_name='apollo.drivers.Mobileye.lka_767', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lka_768', full_name='apollo.drivers.Mobileye.lka_768', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lka_769', full_name='apollo.drivers.Mobileye.lka_769', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_76a', full_name='apollo.drivers.Mobileye.reference_76a', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_76b', full_name='apollo.drivers.Mobileye.num_76b', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_76c', full_name='apollo.drivers.Mobileye.next_76c', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_76d', full_name='apollo.drivers.Mobileye.next_76d', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2637,
  serialized_end=3346,
)

_MOBILEYE.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_MOBILEYE.fields_by_name['aftermarket_669'].message_type = _AFTERMARKET_669
_MOBILEYE.fields_by_name['details_737'].message_type = _DETAILS_737
_MOBILEYE.fields_by_name['details_738'].message_type = _DETAILS_738
_MOBILEYE.fields_by_name['details_739'].message_type = _DETAILS_739
_MOBILEYE.fields_by_name['details_73a'].message_type = _DETAILS_73A
_MOBILEYE.fields_by_name['details_73b'].message_type = _DETAILS_73B
_MOBILEYE.fields_by_name['lka_766'].message_type = _LKA_766
_MOBILEYE.fields_by_name['lka_767'].message_type = _LKA_767
_MOBILEYE.fields_by_name['lka_768'].message_type = _LKA_768
_MOBILEYE.fields_by_name['lka_769'].message_type = _LKA_769
_MOBILEYE.fields_by_name['reference_76a'].message_type = _REFERENCE_76A
_MOBILEYE.fields_by_name['num_76b'].message_type = _NUM_76B
_MOBILEYE.fields_by_name['next_76c'].message_type = _NEXT_76C
_MOBILEYE.fields_by_name['next_76d'].message_type = _NEXT_76D
DESCRIPTOR.message_types_by_name['Lka_768'] = _LKA_768
DESCRIPTOR.message_types_by_name['Num_76b'] = _NUM_76B
DESCRIPTOR.message_types_by_name['Aftermarket_669'] = _AFTERMARKET_669
DESCRIPTOR.message_types_by_name['Lka_769'] = _LKA_769
DESCRIPTOR.message_types_by_name['Reference_76a'] = _REFERENCE_76A
DESCRIPTOR.message_types_by_name['Details_738'] = _DETAILS_738
DESCRIPTOR.message_types_by_name['Next_76c'] = _NEXT_76C
DESCRIPTOR.message_types_by_name['Details_737'] = _DETAILS_737
DESCRIPTOR.message_types_by_name['Lka_767'] = _LKA_767
DESCRIPTOR.message_types_by_name['Lka_766'] = _LKA_766
DESCRIPTOR.message_types_by_name['Next_76d'] = _NEXT_76D
DESCRIPTOR.message_types_by_name['Details_739'] = _DETAILS_739
DESCRIPTOR.message_types_by_name['Details_73a'] = _DETAILS_73A
DESCRIPTOR.message_types_by_name['Details_73b'] = _DETAILS_73B
DESCRIPTOR.message_types_by_name['Mobileye'] = _MOBILEYE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Lka_768 = _reflection.GeneratedProtocolMessageType('Lka_768', (_message.Message,), {
  'DESCRIPTOR' : _LKA_768,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Lka_768)
  })
_sym_db.RegisterMessage(Lka_768)

Num_76b = _reflection.GeneratedProtocolMessageType('Num_76b', (_message.Message,), {
  'DESCRIPTOR' : _NUM_76B,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Num_76b)
  })
_sym_db.RegisterMessage(Num_76b)

Aftermarket_669 = _reflection.GeneratedProtocolMessageType('Aftermarket_669', (_message.Message,), {
  'DESCRIPTOR' : _AFTERMARKET_669,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Aftermarket_669)
  })
_sym_db.RegisterMessage(Aftermarket_669)

Lka_769 = _reflection.GeneratedProtocolMessageType('Lka_769', (_message.Message,), {
  'DESCRIPTOR' : _LKA_769,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Lka_769)
  })
_sym_db.RegisterMessage(Lka_769)

Reference_76a = _reflection.GeneratedProtocolMessageType('Reference_76a', (_message.Message,), {
  'DESCRIPTOR' : _REFERENCE_76A,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Reference_76a)
  })
_sym_db.RegisterMessage(Reference_76a)

Details_738 = _reflection.GeneratedProtocolMessageType('Details_738', (_message.Message,), {
  'DESCRIPTOR' : _DETAILS_738,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Details_738)
  })
_sym_db.RegisterMessage(Details_738)

Next_76c = _reflection.GeneratedProtocolMessageType('Next_76c', (_message.Message,), {
  'DESCRIPTOR' : _NEXT_76C,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Next_76c)
  })
_sym_db.RegisterMessage(Next_76c)

Details_737 = _reflection.GeneratedProtocolMessageType('Details_737', (_message.Message,), {
  'DESCRIPTOR' : _DETAILS_737,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Details_737)
  })
_sym_db.RegisterMessage(Details_737)

Lka_767 = _reflection.GeneratedProtocolMessageType('Lka_767', (_message.Message,), {
  'DESCRIPTOR' : _LKA_767,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Lka_767)
  })
_sym_db.RegisterMessage(Lka_767)

Lka_766 = _reflection.GeneratedProtocolMessageType('Lka_766', (_message.Message,), {
  'DESCRIPTOR' : _LKA_766,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Lka_766)
  })
_sym_db.RegisterMessage(Lka_766)

Next_76d = _reflection.GeneratedProtocolMessageType('Next_76d', (_message.Message,), {
  'DESCRIPTOR' : _NEXT_76D,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Next_76d)
  })
_sym_db.RegisterMessage(Next_76d)

Details_739 = _reflection.GeneratedProtocolMessageType('Details_739', (_message.Message,), {
  'DESCRIPTOR' : _DETAILS_739,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Details_739)
  })
_sym_db.RegisterMessage(Details_739)

Details_73a = _reflection.GeneratedProtocolMessageType('Details_73a', (_message.Message,), {
  'DESCRIPTOR' : _DETAILS_73A,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Details_73a)
  })
_sym_db.RegisterMessage(Details_73a)

Details_73b = _reflection.GeneratedProtocolMessageType('Details_73b', (_message.Message,), {
  'DESCRIPTOR' : _DETAILS_73B,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Details_73b)
  })
_sym_db.RegisterMessage(Details_73b)

Mobileye = _reflection.GeneratedProtocolMessageType('Mobileye', (_message.Message,), {
  'DESCRIPTOR' : _MOBILEYE,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Mobileye)
  })
_sym_db.RegisterMessage(Mobileye)


# @@protoc_insertion_point(module_scope)
