# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/audio/proto/audio_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/audio/proto/audio_conf.proto',
  package='apollo.audio',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/audio/proto/audio_conf.proto\x12\x0c\x61pollo.audio\"\xae\x01\n\tTopicConf\x12\x1d\n\x15\x61udio_data_topic_name\x18\x01 \x01(\t\x12\"\n\x1a\x61udio_detection_topic_name\x18\x02 \x01(\t\x12\x1f\n\x17localization_topic_name\x18\x03 \x01(\t\x12\x1e\n\x16\x61udio_event_topic_name\x18\x04 \x01(\t\x12\x1d\n\x15perception_topic_name\x18\x05 \x01(\t\"[\n\tAudioConf\x12+\n\ntopic_conf\x18\x01 \x01(\x0b\x32\x17.apollo.audio.TopicConf\x12!\n\x19respeaker_extrinsics_path\x18\x02 \x01(\t'
)




_TOPICCONF = _descriptor.Descriptor(
  name='TopicConf',
  full_name='apollo.audio.TopicConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_data_topic_name', full_name='apollo.audio.TopicConf.audio_data_topic_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_detection_topic_name', full_name='apollo.audio.TopicConf.audio_detection_topic_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localization_topic_name', full_name='apollo.audio.TopicConf.localization_topic_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_event_topic_name', full_name='apollo.audio.TopicConf.audio_event_topic_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perception_topic_name', full_name='apollo.audio.TopicConf.perception_topic_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=229,
)


_AUDIOCONF = _descriptor.Descriptor(
  name='AudioConf',
  full_name='apollo.audio.AudioConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic_conf', full_name='apollo.audio.AudioConf.topic_conf', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='respeaker_extrinsics_path', full_name='apollo.audio.AudioConf.respeaker_extrinsics_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=322,
)

_AUDIOCONF.fields_by_name['topic_conf'].message_type = _TOPICCONF
DESCRIPTOR.message_types_by_name['TopicConf'] = _TOPICCONF
DESCRIPTOR.message_types_by_name['AudioConf'] = _AUDIOCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicConf = _reflection.GeneratedProtocolMessageType('TopicConf', (_message.Message,), {
  'DESCRIPTOR' : _TOPICCONF,
  '__module__' : 'modules.audio.proto.audio_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.audio.TopicConf)
  })
_sym_db.RegisterMessage(TopicConf)

AudioConf = _reflection.GeneratedProtocolMessageType('AudioConf', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOCONF,
  '__module__' : 'modules.audio.proto.audio_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.audio.AudioConf)
  })
_sym_db.RegisterMessage(AudioConf)


# @@protoc_insertion_point(module_scope)
