# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/classic_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/classic_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x63yber/proto/classic_conf.proto\x12\x12\x61pollo.cyber.proto\"@\n\x0b\x43lassicTask\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x04prio\x18\x02 \x01(\r:\x01\x31\x12\x12\n\ngroup_name\x18\x03 \x01(\t\"\xc5\x01\n\nSchedGroup\x12\x19\n\x04name\x18\x01 \x02(\t:\x0b\x64\x65\x66\x61ult_grp\x12\x15\n\rprocessor_num\x18\x02 \x01(\r\x12\x10\n\x08\x61\x66\x66inity\x18\x03 \x01(\t\x12\x0e\n\x06\x63puset\x18\x04 \x01(\t\x12\x18\n\x10processor_policy\x18\x05 \x01(\t\x12\x19\n\x0eprocessor_prio\x18\x06 \x01(\x05:\x01\x30\x12.\n\x05tasks\x18\x07 \x03(\x0b\x32\x1f.apollo.cyber.proto.ClassicTask\"=\n\x0b\x43lassicConf\x12.\n\x06groups\x18\x01 \x03(\x0b\x32\x1e.apollo.cyber.proto.SchedGroup'
)




_CLASSICTASK = _descriptor.Descriptor(
  name='ClassicTask',
  full_name='apollo.cyber.proto.ClassicTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.ClassicTask.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prio', full_name='apollo.cyber.proto.ClassicTask.prio', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_name', full_name='apollo.cyber.proto.ClassicTask.group_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=118,
)


_SCHEDGROUP = _descriptor.Descriptor(
  name='SchedGroup',
  full_name='apollo.cyber.proto.SchedGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.SchedGroup.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=True, default_value=b"default_grp".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processor_num', full_name='apollo.cyber.proto.SchedGroup.processor_num', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affinity', full_name='apollo.cyber.proto.SchedGroup.affinity', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpuset', full_name='apollo.cyber.proto.SchedGroup.cpuset', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processor_policy', full_name='apollo.cyber.proto.SchedGroup.processor_policy', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processor_prio', full_name='apollo.cyber.proto.SchedGroup.processor_prio', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='apollo.cyber.proto.SchedGroup.tasks', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=318,
)


_CLASSICCONF = _descriptor.Descriptor(
  name='ClassicConf',
  full_name='apollo.cyber.proto.ClassicConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='apollo.cyber.proto.ClassicConf.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=381,
)

_SCHEDGROUP.fields_by_name['tasks'].message_type = _CLASSICTASK
_CLASSICCONF.fields_by_name['groups'].message_type = _SCHEDGROUP
DESCRIPTOR.message_types_by_name['ClassicTask'] = _CLASSICTASK
DESCRIPTOR.message_types_by_name['SchedGroup'] = _SCHEDGROUP
DESCRIPTOR.message_types_by_name['ClassicConf'] = _CLASSICCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClassicTask = _reflection.GeneratedProtocolMessageType('ClassicTask', (_message.Message,), {
  'DESCRIPTOR' : _CLASSICTASK,
  '__module__' : 'cyber.proto.classic_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ClassicTask)
  })
_sym_db.RegisterMessage(ClassicTask)

SchedGroup = _reflection.GeneratedProtocolMessageType('SchedGroup', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDGROUP,
  '__module__' : 'cyber.proto.classic_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.SchedGroup)
  })
_sym_db.RegisterMessage(SchedGroup)

ClassicConf = _reflection.GeneratedProtocolMessageType('ClassicConf', (_message.Message,), {
  'DESCRIPTOR' : _CLASSICCONF,
  '__module__' : 'cyber.proto.classic_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ClassicConf)
  })
_sym_db.RegisterMessage(ClassicConf)


# @@protoc_insertion_point(module_scope)
