# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/v2x_junction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/v2x_junction.proto',
  package='apollo.v2x',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/v2x/proto/v2x_junction.proto\x12\napollo.v2x\x1a#modules/common/proto/geometry.proto\"\x10\n\x02Id\x12\n\n\x02id\x18\x01 \x01(\x0c\"\x8c\x03\n\x08Junction\x12\x1a\n\x02id\x18\x01 \x01(\x0b\x32\x0e.apollo.v2x.Id\x12\'\n\x07polygon\x18\x02 \x01(\x0b\x32\x16.apollo.common.Polygon\x12$\n\x0c\x63rosswalk_id\x18\x03 \x03(\x0b\x32\x0e.apollo.v2x.Id\x12\"\n\noverlap_id\x18\x04 \x03(\x0b\x32\x0e.apollo.v2x.Id\x12\x1c\n\x11num_road_segments\x18\x05 \x01(\x05:\x01\x34\x12\x1f\n\x07lane_id\x18\x06 \x03(\x0b\x32\x0e.apollo.v2x.Id\x12\'\n\x04type\x18\x07 \x01(\x0e\x32\x19.apollo.v2x.Junction.Type\x12\x30\n\tedge_type\x18\x08 \x03(\x0e\x32\x1d.apollo.v2x.Junction.EdgeType\"0\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07IN_ROAD\x10\x01\x12\x0e\n\nCROSS_ROAD\x10\x02\"%\n\x08\x45\x64geType\x12\x0c\n\x08PHYSICAL\x10\x00\x12\x0b\n\x07VIRTUAL\x10\x01'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])



_JUNCTION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.v2x.Junction.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IN_ROAD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CROSS_ROAD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=417,
  serialized_end=465,
)
_sym_db.RegisterEnumDescriptor(_JUNCTION_TYPE)

_JUNCTION_EDGETYPE = _descriptor.EnumDescriptor(
  name='EdgeType',
  full_name='apollo.v2x.Junction.EdgeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PHYSICAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIRTUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=467,
  serialized_end=504,
)
_sym_db.RegisterEnumDescriptor(_JUNCTION_EDGETYPE)


_ID = _descriptor.Descriptor(
  name='Id',
  full_name='apollo.v2x.Id',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.v2x.Id.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=105,
)


_JUNCTION = _descriptor.Descriptor(
  name='Junction',
  full_name='apollo.v2x.Junction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.v2x.Junction.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='apollo.v2x.Junction.polygon', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalk_id', full_name='apollo.v2x.Junction.crosswalk_id', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overlap_id', full_name='apollo.v2x.Junction.overlap_id', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_road_segments', full_name='apollo.v2x.Junction.num_road_segments', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.v2x.Junction.lane_id', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.v2x.Junction.type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edge_type', full_name='apollo.v2x.Junction.edge_type', index=7,
      number=8, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _JUNCTION_TYPE,
    _JUNCTION_EDGETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=504,
)

_JUNCTION.fields_by_name['id'].message_type = _ID
_JUNCTION.fields_by_name['polygon'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POLYGON
_JUNCTION.fields_by_name['crosswalk_id'].message_type = _ID
_JUNCTION.fields_by_name['overlap_id'].message_type = _ID
_JUNCTION.fields_by_name['lane_id'].message_type = _ID
_JUNCTION.fields_by_name['type'].enum_type = _JUNCTION_TYPE
_JUNCTION.fields_by_name['edge_type'].enum_type = _JUNCTION_EDGETYPE
_JUNCTION_TYPE.containing_type = _JUNCTION
_JUNCTION_EDGETYPE.containing_type = _JUNCTION
DESCRIPTOR.message_types_by_name['Id'] = _ID
DESCRIPTOR.message_types_by_name['Junction'] = _JUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Id = _reflection.GeneratedProtocolMessageType('Id', (_message.Message,), {
  'DESCRIPTOR' : _ID,
  '__module__' : 'modules.v2x.proto.v2x_junction_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Id)
  })
_sym_db.RegisterMessage(Id)

Junction = _reflection.GeneratedProtocolMessageType('Junction', (_message.Message,), {
  'DESCRIPTOR' : _JUNCTION,
  '__module__' : 'modules.v2x.proto.v2x_junction_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Junction)
  })
_sym_db.RegisterMessage(Junction)


# @@protoc_insertion_point(module_scope)
