# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/bridge/proto/udp_bridge_remote_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/bridge/proto/udp_bridge_remote_info.proto',
  package='apollo.bridge',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1modules/bridge/proto/udp_bridge_remote_info.proto\x12\rapollo.bridge\"v\n\x19UDPBridgeSenderRemoteInfo\x12\x1c\n\tremote_ip\x18\x01 \x01(\t:\t127.0.0.1\x12\x19\n\x0bremote_port\x18\x02 \x01(\x05:\x04\x38\x39\x30\x30\x12 \n\nproto_name\x18\x03 \x01(\t:\x0cProtoMsgName\"\x8c\x01\n\x1bUDPBridgeReceiverRemoteInfo\x12\x14\n\ntopic_name\x18\x01 \x01(\t:\x00\x12\x17\n\tbind_port\x18\x02 \x01(\x05:\x04\x38\x35\x30\x30\x12 \n\nproto_name\x18\x03 \x01(\t:\x0cProtoMsgName\x12\x1c\n\x0e\x65nable_timeout\x18\x04 \x01(\x08:\x04true'
)




_UDPBRIDGESENDERREMOTEINFO = _descriptor.Descriptor(
  name='UDPBridgeSenderRemoteInfo',
  full_name='apollo.bridge.UDPBridgeSenderRemoteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='remote_ip', full_name='apollo.bridge.UDPBridgeSenderRemoteInfo.remote_ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"127.0.0.1".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_port', full_name='apollo.bridge.UDPBridgeSenderRemoteInfo.remote_port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=8900,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proto_name', full_name='apollo.bridge.UDPBridgeSenderRemoteInfo.proto_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"ProtoMsgName".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=186,
)


_UDPBRIDGERECEIVERREMOTEINFO = _descriptor.Descriptor(
  name='UDPBridgeReceiverRemoteInfo',
  full_name='apollo.bridge.UDPBridgeReceiverRemoteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic_name', full_name='apollo.bridge.UDPBridgeReceiverRemoteInfo.topic_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bind_port', full_name='apollo.bridge.UDPBridgeReceiverRemoteInfo.bind_port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=8500,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proto_name', full_name='apollo.bridge.UDPBridgeReceiverRemoteInfo.proto_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"ProtoMsgName".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_timeout', full_name='apollo.bridge.UDPBridgeReceiverRemoteInfo.enable_timeout', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=329,
)

DESCRIPTOR.message_types_by_name['UDPBridgeSenderRemoteInfo'] = _UDPBRIDGESENDERREMOTEINFO
DESCRIPTOR.message_types_by_name['UDPBridgeReceiverRemoteInfo'] = _UDPBRIDGERECEIVERREMOTEINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UDPBridgeSenderRemoteInfo = _reflection.GeneratedProtocolMessageType('UDPBridgeSenderRemoteInfo', (_message.Message,), {
  'DESCRIPTOR' : _UDPBRIDGESENDERREMOTEINFO,
  '__module__' : 'modules.bridge.proto.udp_bridge_remote_info_pb2'
  # @@protoc_insertion_point(class_scope:apollo.bridge.UDPBridgeSenderRemoteInfo)
  })
_sym_db.RegisterMessage(UDPBridgeSenderRemoteInfo)

UDPBridgeReceiverRemoteInfo = _reflection.GeneratedProtocolMessageType('UDPBridgeReceiverRemoteInfo', (_message.Message,), {
  'DESCRIPTOR' : _UDPBRIDGERECEIVERREMOTEINFO,
  '__module__' : 'modules.bridge.proto.udp_bridge_remote_info_pb2'
  # @@protoc_insertion_point(class_scope:apollo.bridge.UDPBridgeReceiverRemoteInfo)
  })
_sym_db.RegisterMessage(UDPBridgeReceiverRemoteInfo)


# @@protoc_insertion_point(module_scope)
