# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/camera/app/proto/perception.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/camera/app/proto/perception.proto',
  package='apollo.perception.camera.app',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4modules/perception/camera/app/proto/perception.proto\x12\x1c\x61pollo.perception.camera.app\"B\n\x0bPluginParam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08root_dir\x18\x02 \x01(\t\x12\x13\n\x0b\x63onfig_file\x18\x03 \x01(\t\"e\n\rDetectorParam\x12?\n\x0cplugin_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\x12\x13\n\x0b\x63\x61mera_name\x18\x02 \x01(\t\"O\n\x0cTrackerParam\x12?\n\x0cplugin_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\"S\n\x10TransformerParam\x12?\n\x0cplugin_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\"U\n\x12PostprocessorParam\x12?\n\x0cplugin_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\"O\n\x0c\x46\x65\x61tureParam\x12?\n\x0cplugin_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\"\xd0\x01\n\nDebugParam\x12\x19\n\x11\x64\x65tection_out_dir\x18\x01 \x01(\t\x12!\n\x19tracked_detection_out_dir\x18\x02 \x01(\t\x12\x16\n\x0etrack_out_file\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65tect_feature_dir\x18\x04 \x01(\t\x12\x14\n\x0clane_out_dir\x18\x05 \x01(\t\x12\x1d\n\x15\x63\x61mera2world_out_file\x18\x06 \x01(\t\x12\x1b\n\x13\x63\x61libration_out_dir\x18\x07 \x01(\t\"\x83\x02\n\x13LanePerceptionParam\x12H\n\x13lane_detector_param\x18\x01 \x01(\x0b\x32+.apollo.perception.camera.app.DetectorParam\x12K\n\x18lane_postprocessor_param\x18\x02 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\x12\x45\n\x12lane_tracker_param\x18\x03 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\x12\x0e\n\x06gpu_id\x18\x04 \x01(\x05\"u\n\x17\x43\x61librationServiceParam\x12\x19\n\x11\x63\x61librator_method\x18\x02 \x01(\t\x12?\n\x0cplugin_param\x18\x03 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\"V\n\x13ObjectTemplateParam\x12?\n\x0cplugin_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\"\xd3\x05\n\x0fPerceptionParam\x12\x43\n\x0e\x64\x65tector_param\x18\x01 \x03(\x0b\x32+.apollo.perception.camera.app.DetectorParam\x12\x41\n\rtracker_param\x18\x02 \x01(\x0b\x32*.apollo.perception.camera.app.TrackerParam\x12I\n\x11transformer_param\x18\x03 \x01(\x0b\x32..apollo.perception.camera.app.TransformerParam\x12M\n\x13postprocessor_param\x18\x04 \x01(\x0b\x32\x30.apollo.perception.camera.app.PostprocessorParam\x12\x0e\n\x06gpu_id\x18\x05 \x01(\x05\x12\x19\n\x11\x63\x61mera_intrinsics\x18\x06 \x01(\t\x12\x41\n\rfeature_param\x18\x07 \x01(\x0b\x32*.apollo.perception.camera.app.FeatureParam\x12\x45\n\nlane_param\x18\x08 \x03(\x0b\x32\x31.apollo.perception.camera.app.LanePerceptionParam\x12X\n\x19\x63\x61libration_service_param\x18\t \x01(\x0b\x32\x35.apollo.perception.camera.app.CalibrationServiceParam\x12=\n\x0b\x64\x65\x62ug_param\x18\n \x01(\x0b\x32(.apollo.perception.camera.app.DebugParam\x12P\n\x15object_template_param\x18\x0b \x01(\x0b\x32\x31.apollo.perception.camera.app.ObjectTemplateParam\"\xab\x01\n\x11TrafficLightParam\x12\x43\n\x0e\x64\x65tector_param\x18\x01 \x03(\x0b\x32+.apollo.perception.camera.app.DetectorParam\x12\x41\n\rtracker_param\x18\x02 \x01(\x0b\x32*.apollo.perception.camera.app.TrackerParam\x12\x0e\n\x06gpu_id\x18\x03 \x01(\x05'
)




_PLUGINPARAM = _descriptor.Descriptor(
  name='PluginParam',
  full_name='apollo.perception.camera.app.PluginParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.camera.app.PluginParam.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root_dir', full_name='apollo.perception.camera.app.PluginParam.root_dir', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_file', full_name='apollo.perception.camera.app.PluginParam.config_file', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=152,
)


_DETECTORPARAM = _descriptor.Descriptor(
  name='DetectorParam',
  full_name='apollo.perception.camera.app.DetectorParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.DetectorParam.plugin_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_name', full_name='apollo.perception.camera.app.DetectorParam.camera_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=255,
)


_TRACKERPARAM = _descriptor.Descriptor(
  name='TrackerParam',
  full_name='apollo.perception.camera.app.TrackerParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.TrackerParam.plugin_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=336,
)


_TRANSFORMERPARAM = _descriptor.Descriptor(
  name='TransformerParam',
  full_name='apollo.perception.camera.app.TransformerParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.TransformerParam.plugin_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=421,
)


_POSTPROCESSORPARAM = _descriptor.Descriptor(
  name='PostprocessorParam',
  full_name='apollo.perception.camera.app.PostprocessorParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.PostprocessorParam.plugin_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=508,
)


_FEATUREPARAM = _descriptor.Descriptor(
  name='FeatureParam',
  full_name='apollo.perception.camera.app.FeatureParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.FeatureParam.plugin_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=510,
  serialized_end=589,
)


_DEBUGPARAM = _descriptor.Descriptor(
  name='DebugParam',
  full_name='apollo.perception.camera.app.DebugParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_out_dir', full_name='apollo.perception.camera.app.DebugParam.detection_out_dir', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracked_detection_out_dir', full_name='apollo.perception.camera.app.DebugParam.tracked_detection_out_dir', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='track_out_file', full_name='apollo.perception.camera.app.DebugParam.track_out_file', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detect_feature_dir', full_name='apollo.perception.camera.app.DebugParam.detect_feature_dir', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_out_dir', full_name='apollo.perception.camera.app.DebugParam.lane_out_dir', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera2world_out_file', full_name='apollo.perception.camera.app.DebugParam.camera2world_out_file', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration_out_dir', full_name='apollo.perception.camera.app.DebugParam.calibration_out_dir', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=800,
)


_LANEPERCEPTIONPARAM = _descriptor.Descriptor(
  name='LanePerceptionParam',
  full_name='apollo.perception.camera.app.LanePerceptionParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_detector_param', full_name='apollo.perception.camera.app.LanePerceptionParam.lane_detector_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_postprocessor_param', full_name='apollo.perception.camera.app.LanePerceptionParam.lane_postprocessor_param', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_tracker_param', full_name='apollo.perception.camera.app.LanePerceptionParam.lane_tracker_param', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_id', full_name='apollo.perception.camera.app.LanePerceptionParam.gpu_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=803,
  serialized_end=1062,
)


_CALIBRATIONSERVICEPARAM = _descriptor.Descriptor(
  name='CalibrationServiceParam',
  full_name='apollo.perception.camera.app.CalibrationServiceParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='calibrator_method', full_name='apollo.perception.camera.app.CalibrationServiceParam.calibrator_method', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.CalibrationServiceParam.plugin_param', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1064,
  serialized_end=1181,
)


_OBJECTTEMPLATEPARAM = _descriptor.Descriptor(
  name='ObjectTemplateParam',
  full_name='apollo.perception.camera.app.ObjectTemplateParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.ObjectTemplateParam.plugin_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1183,
  serialized_end=1269,
)


_PERCEPTIONPARAM = _descriptor.Descriptor(
  name='PerceptionParam',
  full_name='apollo.perception.camera.app.PerceptionParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detector_param', full_name='apollo.perception.camera.app.PerceptionParam.detector_param', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracker_param', full_name='apollo.perception.camera.app.PerceptionParam.tracker_param', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transformer_param', full_name='apollo.perception.camera.app.PerceptionParam.transformer_param', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postprocessor_param', full_name='apollo.perception.camera.app.PerceptionParam.postprocessor_param', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_id', full_name='apollo.perception.camera.app.PerceptionParam.gpu_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_intrinsics', full_name='apollo.perception.camera.app.PerceptionParam.camera_intrinsics', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_param', full_name='apollo.perception.camera.app.PerceptionParam.feature_param', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_param', full_name='apollo.perception.camera.app.PerceptionParam.lane_param', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration_service_param', full_name='apollo.perception.camera.app.PerceptionParam.calibration_service_param', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug_param', full_name='apollo.perception.camera.app.PerceptionParam.debug_param', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_template_param', full_name='apollo.perception.camera.app.PerceptionParam.object_template_param', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1272,
  serialized_end=1995,
)


_TRAFFICLIGHTPARAM = _descriptor.Descriptor(
  name='TrafficLightParam',
  full_name='apollo.perception.camera.app.TrafficLightParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detector_param', full_name='apollo.perception.camera.app.TrafficLightParam.detector_param', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracker_param', full_name='apollo.perception.camera.app.TrafficLightParam.tracker_param', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_id', full_name='apollo.perception.camera.app.TrafficLightParam.gpu_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1998,
  serialized_end=2169,
)

_DETECTORPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_TRACKERPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_TRANSFORMERPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_POSTPROCESSORPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_FEATUREPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_LANEPERCEPTIONPARAM.fields_by_name['lane_detector_param'].message_type = _DETECTORPARAM
_LANEPERCEPTIONPARAM.fields_by_name['lane_postprocessor_param'].message_type = _PLUGINPARAM
_LANEPERCEPTIONPARAM.fields_by_name['lane_tracker_param'].message_type = _PLUGINPARAM
_CALIBRATIONSERVICEPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_OBJECTTEMPLATEPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_PERCEPTIONPARAM.fields_by_name['detector_param'].message_type = _DETECTORPARAM
_PERCEPTIONPARAM.fields_by_name['tracker_param'].message_type = _TRACKERPARAM
_PERCEPTIONPARAM.fields_by_name['transformer_param'].message_type = _TRANSFORMERPARAM
_PERCEPTIONPARAM.fields_by_name['postprocessor_param'].message_type = _POSTPROCESSORPARAM
_PERCEPTIONPARAM.fields_by_name['feature_param'].message_type = _FEATUREPARAM
_PERCEPTIONPARAM.fields_by_name['lane_param'].message_type = _LANEPERCEPTIONPARAM
_PERCEPTIONPARAM.fields_by_name['calibration_service_param'].message_type = _CALIBRATIONSERVICEPARAM
_PERCEPTIONPARAM.fields_by_name['debug_param'].message_type = _DEBUGPARAM
_PERCEPTIONPARAM.fields_by_name['object_template_param'].message_type = _OBJECTTEMPLATEPARAM
_TRAFFICLIGHTPARAM.fields_by_name['detector_param'].message_type = _DETECTORPARAM
_TRAFFICLIGHTPARAM.fields_by_name['tracker_param'].message_type = _TRACKERPARAM
DESCRIPTOR.message_types_by_name['PluginParam'] = _PLUGINPARAM
DESCRIPTOR.message_types_by_name['DetectorParam'] = _DETECTORPARAM
DESCRIPTOR.message_types_by_name['TrackerParam'] = _TRACKERPARAM
DESCRIPTOR.message_types_by_name['TransformerParam'] = _TRANSFORMERPARAM
DESCRIPTOR.message_types_by_name['PostprocessorParam'] = _POSTPROCESSORPARAM
DESCRIPTOR.message_types_by_name['FeatureParam'] = _FEATUREPARAM
DESCRIPTOR.message_types_by_name['DebugParam'] = _DEBUGPARAM
DESCRIPTOR.message_types_by_name['LanePerceptionParam'] = _LANEPERCEPTIONPARAM
DESCRIPTOR.message_types_by_name['CalibrationServiceParam'] = _CALIBRATIONSERVICEPARAM
DESCRIPTOR.message_types_by_name['ObjectTemplateParam'] = _OBJECTTEMPLATEPARAM
DESCRIPTOR.message_types_by_name['PerceptionParam'] = _PERCEPTIONPARAM
DESCRIPTOR.message_types_by_name['TrafficLightParam'] = _TRAFFICLIGHTPARAM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PluginParam = _reflection.GeneratedProtocolMessageType('PluginParam', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.PluginParam)
  })
_sym_db.RegisterMessage(PluginParam)

DetectorParam = _reflection.GeneratedProtocolMessageType('DetectorParam', (_message.Message,), {
  'DESCRIPTOR' : _DETECTORPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.DetectorParam)
  })
_sym_db.RegisterMessage(DetectorParam)

TrackerParam = _reflection.GeneratedProtocolMessageType('TrackerParam', (_message.Message,), {
  'DESCRIPTOR' : _TRACKERPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.TrackerParam)
  })
_sym_db.RegisterMessage(TrackerParam)

TransformerParam = _reflection.GeneratedProtocolMessageType('TransformerParam', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMERPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.TransformerParam)
  })
_sym_db.RegisterMessage(TransformerParam)

PostprocessorParam = _reflection.GeneratedProtocolMessageType('PostprocessorParam', (_message.Message,), {
  'DESCRIPTOR' : _POSTPROCESSORPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.PostprocessorParam)
  })
_sym_db.RegisterMessage(PostprocessorParam)

FeatureParam = _reflection.GeneratedProtocolMessageType('FeatureParam', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.FeatureParam)
  })
_sym_db.RegisterMessage(FeatureParam)

DebugParam = _reflection.GeneratedProtocolMessageType('DebugParam', (_message.Message,), {
  'DESCRIPTOR' : _DEBUGPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.DebugParam)
  })
_sym_db.RegisterMessage(DebugParam)

LanePerceptionParam = _reflection.GeneratedProtocolMessageType('LanePerceptionParam', (_message.Message,), {
  'DESCRIPTOR' : _LANEPERCEPTIONPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.LanePerceptionParam)
  })
_sym_db.RegisterMessage(LanePerceptionParam)

CalibrationServiceParam = _reflection.GeneratedProtocolMessageType('CalibrationServiceParam', (_message.Message,), {
  'DESCRIPTOR' : _CALIBRATIONSERVICEPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.CalibrationServiceParam)
  })
_sym_db.RegisterMessage(CalibrationServiceParam)

ObjectTemplateParam = _reflection.GeneratedProtocolMessageType('ObjectTemplateParam', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTTEMPLATEPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.ObjectTemplateParam)
  })
_sym_db.RegisterMessage(ObjectTemplateParam)

PerceptionParam = _reflection.GeneratedProtocolMessageType('PerceptionParam', (_message.Message,), {
  'DESCRIPTOR' : _PERCEPTIONPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.PerceptionParam)
  })
_sym_db.RegisterMessage(PerceptionParam)

TrafficLightParam = _reflection.GeneratedProtocolMessageType('TrafficLightParam', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICLIGHTPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.TrafficLightParam)
  })
_sym_db.RegisterMessage(TrafficLightParam)


# @@protoc_insertion_point(module_scope)
