# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/mrac_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/mrac_conf.proto',
  package='apollo.control',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%modules/control/proto/mrac_conf.proto\x12\x0e\x61pollo.control\"\xef\x02\n\x08MracConf\x12\x1b\n\x10mrac_model_order\x18\x01 \x01(\x05:\x01\x31\x12\x1f\n\x17reference_time_constant\x18\x02 \x01(\x01\x12#\n\x1breference_natural_frequency\x18\x03 \x01(\x01\x12\x1f\n\x17reference_damping_ratio\x18\x04 \x01(\x01\x12\x1b\n\x13\x61\x64\x61ption_state_gain\x18\x05 \x03(\x01\x12\x1d\n\x15\x61\x64\x61ption_desired_gain\x18\x06 \x01(\x01\x12\x1f\n\x17\x61\x64\x61ption_nonlinear_gain\x18\x07 \x01(\x01\x12\x19\n\x11\x61\x64\x61ption_matrix_p\x18\x08 \x03(\x01\x12 \n\x15mrac_saturation_level\x18\t \x01(\x01:\x01\x31\x12%\n\x1d\x61nti_windup_compensation_gain\x18\n \x03(\x01\x12\x1e\n\x16\x63lamping_time_constant\x18\x0b \x01(\x01'
)




_MRACCONF = _descriptor.Descriptor(
  name='MracConf',
  full_name='apollo.control.MracConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mrac_model_order', full_name='apollo.control.MracConf.mrac_model_order', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_time_constant', full_name='apollo.control.MracConf.reference_time_constant', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_natural_frequency', full_name='apollo.control.MracConf.reference_natural_frequency', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_damping_ratio', full_name='apollo.control.MracConf.reference_damping_ratio', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adaption_state_gain', full_name='apollo.control.MracConf.adaption_state_gain', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adaption_desired_gain', full_name='apollo.control.MracConf.adaption_desired_gain', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adaption_nonlinear_gain', full_name='apollo.control.MracConf.adaption_nonlinear_gain', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adaption_matrix_p', full_name='apollo.control.MracConf.adaption_matrix_p', index=7,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mrac_saturation_level', full_name='apollo.control.MracConf.mrac_saturation_level', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='anti_windup_compensation_gain', full_name='apollo.control.MracConf.anti_windup_compensation_gain', index=9,
      number=10, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clamping_time_constant', full_name='apollo.control.MracConf.clamping_time_constant', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=425,
)

DESCRIPTOR.message_types_by_name['MracConf'] = _MRACCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MracConf = _reflection.GeneratedProtocolMessageType('MracConf', (_message.Message,), {
  'DESCRIPTOR' : _MRACCONF,
  '__module__' : 'modules.control.proto.mrac_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.MracConf)
  })
_sym_db.RegisterMessage(MracConf)


# @@protoc_insertion_point(module_scope)
