# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/unit_test.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/unit_test.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x63yber/proto/unit_test.proto\x12\x12\x61pollo.cyber.proto\"1\n\x08UnitTest\x12\x12\n\nclass_name\x18\x01 \x01(\t\x12\x11\n\tcase_name\x18\x02 \x01(\t\"S\n\x07\x43hatter\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x17\n\x0flidar_timestamp\x18\x02 \x01(\x04\x12\x0b\n\x03seq\x18\x03 \x01(\x04\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\"?\n\x10\x43hatterBenchmark\x12\r\n\x05stamp\x18\x01 \x01(\x04\x12\x0b\n\x03seq\x18\x02 \x01(\x04\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t'
)




_UNITTEST = _descriptor.Descriptor(
  name='UnitTest',
  full_name='apollo.cyber.proto.UnitTest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_name', full_name='apollo.cyber.proto.UnitTest.class_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_name', full_name='apollo.cyber.proto.UnitTest.case_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=100,
)


_CHATTER = _descriptor.Descriptor(
  name='Chatter',
  full_name='apollo.cyber.proto.Chatter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.cyber.proto.Chatter.timestamp', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lidar_timestamp', full_name='apollo.cyber.proto.Chatter.lidar_timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq', full_name='apollo.cyber.proto.Chatter.seq', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='apollo.cyber.proto.Chatter.content', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=185,
)


_CHATTERBENCHMARK = _descriptor.Descriptor(
  name='ChatterBenchmark',
  full_name='apollo.cyber.proto.ChatterBenchmark',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stamp', full_name='apollo.cyber.proto.ChatterBenchmark.stamp', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq', full_name='apollo.cyber.proto.ChatterBenchmark.seq', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='apollo.cyber.proto.ChatterBenchmark.content', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=250,
)

DESCRIPTOR.message_types_by_name['UnitTest'] = _UNITTEST
DESCRIPTOR.message_types_by_name['Chatter'] = _CHATTER
DESCRIPTOR.message_types_by_name['ChatterBenchmark'] = _CHATTERBENCHMARK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UnitTest = _reflection.GeneratedProtocolMessageType('UnitTest', (_message.Message,), {
  'DESCRIPTOR' : _UNITTEST,
  '__module__' : 'cyber.proto.unit_test_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.UnitTest)
  })
_sym_db.RegisterMessage(UnitTest)

Chatter = _reflection.GeneratedProtocolMessageType('Chatter', (_message.Message,), {
  'DESCRIPTOR' : _CHATTER,
  '__module__' : 'cyber.proto.unit_test_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.Chatter)
  })
_sym_db.RegisterMessage(Chatter)

ChatterBenchmark = _reflection.GeneratedProtocolMessageType('ChatterBenchmark', (_message.Message,), {
  'DESCRIPTOR' : _CHATTERBENCHMARK,
  '__module__' : 'cyber.proto.unit_test_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ChatterBenchmark)
  })
_sym_db.RegisterMessage(ChatterBenchmark)


# @@protoc_insertion_point(module_scope)
