# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/parameter.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/parameter.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x63yber/proto/parameter.proto\x12\x12\x61pollo.cyber.proto\"\xd3\x01\n\x05Param\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x1d.apollo.cyber.proto.ParamType\x12\x11\n\ttype_name\x18\x03 \x01(\t\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x05 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x06 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x07 \x01(\tH\x00\x12\x12\n\nproto_desc\x18\x08 \x01(\x0c\x42\r\n\x0boneof_value\"\x19\n\x08NodeName\x12\r\n\x05value\x18\x01 \x01(\t\"\x1a\n\tParamName\x12\r\n\x05value\x18\x01 \x01(\t\"\x1b\n\nBoolResult\x12\r\n\x05value\x18\x01 \x01(\x08\"2\n\x06Params\x12(\n\x05param\x18\x01 \x03(\x0b\x32\x19.apollo.cyber.proto.Param*Q\n\tParamType\x12\x0b\n\x07NOT_SET\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\x07\n\x03INT\x10\x02\x12\n\n\x06\x44OUBLE\x10\x03\x12\n\n\x06STRING\x10\x04\x12\x0c\n\x08PROTOBUF\x10\x05'
)

_PARAMTYPE = _descriptor.EnumDescriptor(
  name='ParamType',
  full_name='apollo.cyber.proto.ParamType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_SET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOOL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROTOBUF', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=401,
  serialized_end=482,
)
_sym_db.RegisterEnumDescriptor(_PARAMTYPE)

ParamType = enum_type_wrapper.EnumTypeWrapper(_PARAMTYPE)
NOT_SET = 0
BOOL = 1
INT = 2
DOUBLE = 3
STRING = 4
PROTOBUF = 5



_PARAM = _descriptor.Descriptor(
  name='Param',
  full_name='apollo.cyber.proto.Param',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.Param.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.cyber.proto.Param.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_name', full_name='apollo.cyber.proto.Param.type_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='apollo.cyber.proto.Param.bool_value', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='apollo.cyber.proto.Param.int_value', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='apollo.cyber.proto.Param.double_value', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='apollo.cyber.proto.Param.string_value', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proto_desc', full_name='apollo.cyber.proto.Param.proto_desc', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_value', full_name='apollo.cyber.proto.Param.oneof_value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=52,
  serialized_end=263,
)


_NODENAME = _descriptor.Descriptor(
  name='NodeName',
  full_name='apollo.cyber.proto.NodeName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.cyber.proto.NodeName.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=265,
  serialized_end=290,
)


_PARAMNAME = _descriptor.Descriptor(
  name='ParamName',
  full_name='apollo.cyber.proto.ParamName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.cyber.proto.ParamName.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=318,
)


_BOOLRESULT = _descriptor.Descriptor(
  name='BoolResult',
  full_name='apollo.cyber.proto.BoolResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.cyber.proto.BoolResult.value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=347,
)


_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='apollo.cyber.proto.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='param', full_name='apollo.cyber.proto.Params.param', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=399,
)

_PARAM.fields_by_name['type'].enum_type = _PARAMTYPE
_PARAM.oneofs_by_name['oneof_value'].fields.append(
  _PARAM.fields_by_name['bool_value'])
_PARAM.fields_by_name['bool_value'].containing_oneof = _PARAM.oneofs_by_name['oneof_value']
_PARAM.oneofs_by_name['oneof_value'].fields.append(
  _PARAM.fields_by_name['int_value'])
_PARAM.fields_by_name['int_value'].containing_oneof = _PARAM.oneofs_by_name['oneof_value']
_PARAM.oneofs_by_name['oneof_value'].fields.append(
  _PARAM.fields_by_name['double_value'])
_PARAM.fields_by_name['double_value'].containing_oneof = _PARAM.oneofs_by_name['oneof_value']
_PARAM.oneofs_by_name['oneof_value'].fields.append(
  _PARAM.fields_by_name['string_value'])
_PARAM.fields_by_name['string_value'].containing_oneof = _PARAM.oneofs_by_name['oneof_value']
_PARAMS.fields_by_name['param'].message_type = _PARAM
DESCRIPTOR.message_types_by_name['Param'] = _PARAM
DESCRIPTOR.message_types_by_name['NodeName'] = _NODENAME
DESCRIPTOR.message_types_by_name['ParamName'] = _PARAMNAME
DESCRIPTOR.message_types_by_name['BoolResult'] = _BOOLRESULT
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.enum_types_by_name['ParamType'] = _PARAMTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Param = _reflection.GeneratedProtocolMessageType('Param', (_message.Message,), {
  'DESCRIPTOR' : _PARAM,
  '__module__' : 'cyber.proto.parameter_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.Param)
  })
_sym_db.RegisterMessage(Param)

NodeName = _reflection.GeneratedProtocolMessageType('NodeName', (_message.Message,), {
  'DESCRIPTOR' : _NODENAME,
  '__module__' : 'cyber.proto.parameter_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.NodeName)
  })
_sym_db.RegisterMessage(NodeName)

ParamName = _reflection.GeneratedProtocolMessageType('ParamName', (_message.Message,), {
  'DESCRIPTOR' : _PARAMNAME,
  '__module__' : 'cyber.proto.parameter_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ParamName)
  })
_sym_db.RegisterMessage(ParamName)

BoolResult = _reflection.GeneratedProtocolMessageType('BoolResult', (_message.Message,), {
  'DESCRIPTOR' : _BOOLRESULT,
  '__module__' : 'cyber.proto.parameter_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.BoolResult)
  })
_sym_db.RegisterMessage(BoolResult)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'cyber.proto.parameter_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.Params)
  })
_sym_db.RegisterMessage(Params)


# @@protoc_insertion_point(module_scope)
