# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/dag_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cyber.proto import component_conf_pb2 as cyber_dot_proto_dot_component__conf__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/dag_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x63yber/proto/dag_conf.proto\x12\x12\x61pollo.cyber.proto\x1a cyber/proto/component_conf.proto\"X\n\rComponentInfo\x12\x12\n\nclass_name\x18\x01 \x01(\t\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32#.apollo.cyber.proto.ComponentConfig\"b\n\x12TimerComponentInfo\x12\x12\n\nclass_name\x18\x01 \x01(\t\x12\x38\n\x06\x63onfig\x18\x02 \x01(\x0b\x32(.apollo.cyber.proto.TimerComponentConfig\"\x9f\x01\n\x0cModuleConfig\x12\x16\n\x0emodule_library\x18\x01 \x01(\t\x12\x35\n\ncomponents\x18\x02 \x03(\x0b\x32!.apollo.cyber.proto.ComponentInfo\x12@\n\x10timer_components\x18\x03 \x03(\x0b\x32&.apollo.cyber.proto.TimerComponentInfo\"D\n\tDagConfig\x12\x37\n\rmodule_config\x18\x01 \x03(\x0b\x32 .apollo.cyber.proto.ModuleConfig'
  ,
  dependencies=[cyber_dot_proto_dot_component__conf__pb2.DESCRIPTOR,])




_COMPONENTINFO = _descriptor.Descriptor(
  name='ComponentInfo',
  full_name='apollo.cyber.proto.ComponentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_name', full_name='apollo.cyber.proto.ComponentInfo.class_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='apollo.cyber.proto.ComponentInfo.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=172,
)


_TIMERCOMPONENTINFO = _descriptor.Descriptor(
  name='TimerComponentInfo',
  full_name='apollo.cyber.proto.TimerComponentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_name', full_name='apollo.cyber.proto.TimerComponentInfo.class_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='apollo.cyber.proto.TimerComponentInfo.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=272,
)


_MODULECONFIG = _descriptor.Descriptor(
  name='ModuleConfig',
  full_name='apollo.cyber.proto.ModuleConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='module_library', full_name='apollo.cyber.proto.ModuleConfig.module_library', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='components', full_name='apollo.cyber.proto.ModuleConfig.components', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timer_components', full_name='apollo.cyber.proto.ModuleConfig.timer_components', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=434,
)


_DAGCONFIG = _descriptor.Descriptor(
  name='DagConfig',
  full_name='apollo.cyber.proto.DagConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='module_config', full_name='apollo.cyber.proto.DagConfig.module_config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=436,
  serialized_end=504,
)

_COMPONENTINFO.fields_by_name['config'].message_type = cyber_dot_proto_dot_component__conf__pb2._COMPONENTCONFIG
_TIMERCOMPONENTINFO.fields_by_name['config'].message_type = cyber_dot_proto_dot_component__conf__pb2._TIMERCOMPONENTCONFIG
_MODULECONFIG.fields_by_name['components'].message_type = _COMPONENTINFO
_MODULECONFIG.fields_by_name['timer_components'].message_type = _TIMERCOMPONENTINFO
_DAGCONFIG.fields_by_name['module_config'].message_type = _MODULECONFIG
DESCRIPTOR.message_types_by_name['ComponentInfo'] = _COMPONENTINFO
DESCRIPTOR.message_types_by_name['TimerComponentInfo'] = _TIMERCOMPONENTINFO
DESCRIPTOR.message_types_by_name['ModuleConfig'] = _MODULECONFIG
DESCRIPTOR.message_types_by_name['DagConfig'] = _DAGCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ComponentInfo = _reflection.GeneratedProtocolMessageType('ComponentInfo', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTINFO,
  '__module__' : 'cyber.proto.dag_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ComponentInfo)
  })
_sym_db.RegisterMessage(ComponentInfo)

TimerComponentInfo = _reflection.GeneratedProtocolMessageType('TimerComponentInfo', (_message.Message,), {
  'DESCRIPTOR' : _TIMERCOMPONENTINFO,
  '__module__' : 'cyber.proto.dag_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.TimerComponentInfo)
  })
_sym_db.RegisterMessage(TimerComponentInfo)

ModuleConfig = _reflection.GeneratedProtocolMessageType('ModuleConfig', (_message.Message,), {
  'DESCRIPTOR' : _MODULECONFIG,
  '__module__' : 'cyber.proto.dag_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ModuleConfig)
  })
_sym_db.RegisterMessage(ModuleConfig)

DagConfig = _reflection.GeneratedProtocolMessageType('DagConfig', (_message.Message,), {
  'DESCRIPTOR' : _DAGCONFIG,
  '__module__' : 'cyber.proto.dag_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.DagConfig)
  })
_sym_db.RegisterMessage(DagConfig)


# @@protoc_insertion_point(module_scope)
