# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/gnss/proto/gnss_raw_observation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/gnss/proto/gnss_raw_observation.proto',
  package='apollo.drivers.gnss',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5modules/drivers/gnss/proto/gnss_raw_observation.proto\x12\x13\x61pollo.drivers.gnss\"\x92\x02\n\x0f\x42\x61ndObservation\x12>\n\x07\x62\x61nd_id\x18\x01 \x01(\x0e\x32\x1f.apollo.drivers.gnss.GnssBandID:\x0c\x42\x41ND_UNKNOWN\x12\x17\n\x0f\x66requency_value\x18\x02 \x01(\x01\x12\x42\n\x0bpseudo_type\x18\x03 \x01(\x0e\x32\x1f.apollo.drivers.gnss.PseudoType:\x0c\x43ODE_UNKNOWN\x12\x14\n\x0cpseudo_range\x18\x04 \x01(\x01\x12\x15\n\rcarrier_phase\x18\x05 \x01(\x01\x12\x17\n\x0floss_lock_index\x18\x06 \x01(\r\x12\x0f\n\x07\x64oppler\x18\x07 \x01(\x01\x12\x0b\n\x03snr\x18\x08 \x01(\x02\"\xae\x01\n\x14SatelliteObservation\x12\x0f\n\x07sat_prn\x18\x01 \x01(\r\x12\x37\n\x07sat_sys\x18\x02 \x01(\x0e\x32\x1d.apollo.drivers.gnss.GnssType:\x07GPS_SYS\x12\x14\n\x0c\x62\x61nd_obs_num\x18\x03 \x01(\r\x12\x36\n\x08\x62\x61nd_obs\x18\x04 \x03(\x0b\x32$.apollo.drivers.gnss.BandObservation\"\xbb\x02\n\x10\x45pochObservation\x12\x13\n\x0breceiver_id\x18\x01 \x01(\r\x12\x43\n\x0egnss_time_type\x18\x02 \x01(\x0e\x32!.apollo.drivers.gnss.GnssTimeType:\x08GPS_TIME\x12\x11\n\tgnss_week\x18\x03 \x01(\r\x12\x15\n\rgnss_second_s\x18\x04 \x01(\x01\x12\x12\n\nposition_x\x18\x05 \x01(\x01\x12\x12\n\nposition_y\x18\x06 \x01(\x01\x12\x12\n\nposition_z\x18\x07 \x01(\x01\x12\x16\n\x0bhealth_flag\x18\x08 \x01(\r:\x01\x30\x12\x13\n\x0bsat_obs_num\x18\t \x01(\r\x12:\n\x07sat_obs\x18\n \x03(\x0b\x32).apollo.drivers.gnss.SatelliteObservation\"\xa7\x05\n\x0cKepplerOrbit\x12\x39\n\tgnss_type\x18\x01 \x01(\x0e\x32\x1d.apollo.drivers.gnss.GnssType:\x07GPS_SYS\x12\x0f\n\x07sat_prn\x18\x02 \x01(\r\x12\x43\n\x0egnss_time_type\x18\x03 \x01(\x0e\x32!.apollo.drivers.gnss.GnssTimeType:\x08GPS_TIME\x12\x0c\n\x04year\x18\x04 \x01(\r\x12\r\n\x05month\x18\x05 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x06 \x01(\r\x12\x0c\n\x04hour\x18\x07 \x01(\r\x12\x0e\n\x06minute\x18\x08 \x01(\r\x12\x10\n\x08second_s\x18\t \x01(\x01\x12\x10\n\x08week_num\x18\n \x01(\r\x12\x10\n\x08reserved\x18\x0b \x01(\x01\x12\x0b\n\x03\x61\x66\x30\x18\x0c \x01(\x01\x12\x0b\n\x03\x61\x66\x31\x18\r \x01(\x01\x12\x0b\n\x03\x61\x66\x32\x18\x0e \x01(\x01\x12\x0c\n\x04iode\x18\x0f \x01(\x01\x12\x0e\n\x06\x64\x65ltan\x18\x10 \x01(\x01\x12\n\n\x02m0\x18\x11 \x01(\x01\x12\t\n\x01\x65\x18\x12 \x01(\x01\x12\r\n\x05roota\x18\x13 \x01(\x01\x12\x0b\n\x03toe\x18\x14 \x01(\x01\x12\x0b\n\x03toc\x18\x15 \x01(\x01\x12\x0b\n\x03\x63ic\x18\x16 \x01(\x01\x12\x0b\n\x03\x63rc\x18\x17 \x01(\x01\x12\x0b\n\x03\x63is\x18\x18 \x01(\x01\x12\x0b\n\x03\x63rs\x18\x19 \x01(\x01\x12\x0b\n\x03\x63uc\x18\x1a \x01(\x01\x12\x0b\n\x03\x63us\x18\x1b \x01(\x01\x12\x0e\n\x06omega0\x18\x1c \x01(\x01\x12\r\n\x05omega\x18\x1d \x01(\x01\x12\n\n\x02i0\x18\x1e \x01(\x01\x12\x10\n\x08omegadot\x18\x1f \x01(\x01\x12\x0c\n\x04idot\x18  \x01(\x01\x12\x18\n\x10\x63odesonL2channel\x18! \x01(\x01\x12\x13\n\x0bL2Pdataflag\x18\" \x01(\r\x12\x10\n\x08\x61\x63\x63uracy\x18# \x01(\r\x12\x0e\n\x06health\x18$ \x01(\r\x12\x0b\n\x03tgd\x18% \x01(\x01\x12\x0c\n\x04iodc\x18& \x01(\x01\"\xeb\x04\n\x0cGlonassOrbit\x12\x39\n\tgnss_type\x18\x01 \x01(\x0e\x32\x1d.apollo.drivers.gnss.GnssType:\x07GLO_SYS\x12\x10\n\x08slot_prn\x18\x02 \x01(\r\x12\x43\n\x0egnss_time_type\x18\x03 \x01(\x0e\x32!.apollo.drivers.gnss.GnssTimeType:\x08GLO_TIME\x12\x0b\n\x03toe\x18\x04 \x01(\x01\x12\x0c\n\x04year\x18\x05 \x01(\r\x12\r\n\x05month\x18\x06 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x07 \x01(\r\x12\x0c\n\x04hour\x18\x08 \x01(\r\x12\x0e\n\x06minute\x18\t \x01(\r\x12\x10\n\x08second_s\x18\n \x01(\x01\x12\x14\n\x0c\x66requency_no\x18\x0b \x01(\x05\x12\x10\n\x08week_num\x18\x0c \x01(\r\x12\x15\n\rweek_second_s\x18\r \x01(\x01\x12\n\n\x02tk\x18\x0e \x01(\x01\x12\x14\n\x0c\x63lock_offset\x18\x0f \x01(\x01\x12\x13\n\x0b\x63lock_drift\x18\x10 \x01(\x01\x12\x0e\n\x06health\x18\x11 \x01(\r\x12\x12\n\nposition_x\x18\x12 \x01(\x01\x12\x12\n\nposition_y\x18\x13 \x01(\x01\x12\x12\n\nposition_z\x18\x14 \x01(\x01\x12\x12\n\nvelocity_x\x18\x15 \x01(\x01\x12\x12\n\nvelocity_y\x18\x16 \x01(\x01\x12\x12\n\nvelocity_z\x18\x17 \x01(\x01\x12\x14\n\x0c\x61\x63\x63\x65lerate_x\x18\x18 \x01(\x01\x12\x14\n\x0c\x61\x63\x63\x65lerate_y\x18\x19 \x01(\x01\x12\x14\n\x0c\x61\x63\x63\x65lerate_z\x18\x1a \x01(\x01\x12\x11\n\tinfor_age\x18\x1b \x01(\x01\x12\x0f\n\x07sat_prn\x18\x1c \x01(\r\"\xbe\x01\n\rGnssEphemeris\x12\x39\n\tgnss_type\x18\x01 \x01(\x0e\x32\x1d.apollo.drivers.gnss.GnssType:\x07GLO_SYS\x12\x38\n\rkeppler_orbit\x18\x02 \x01(\x0b\x32!.apollo.drivers.gnss.KepplerOrbit\x12\x38\n\rglonass_orbit\x18\x03 \x01(\x0b\x32!.apollo.drivers.gnss.GlonassOrbit*\x8a\x01\n\nGnssBandID\x12\x10\n\x0c\x42\x41ND_UNKNOWN\x10\x00\x12\n\n\x06GPS_L1\x10\x01\x12\n\n\x06GPS_L2\x10\x02\x12\n\n\x06GPS_L5\x10\x03\x12\n\n\x06\x42\x44S_B1\x10\x04\x12\n\n\x06\x42\x44S_B2\x10\x05\x12\n\n\x06\x42\x44S_B3\x10\x06\x12\n\n\x06GLO_G1\x10\x07\x12\n\n\x06GLO_G2\x10\x08\x12\n\n\x06GLO_G3\x10\t*X\n\x0cGnssTimeType\x12\x10\n\x0cTIME_UNKNOWN\x10\x00\x12\x0c\n\x08GPS_TIME\x10\x01\x12\x0c\n\x08\x42\x44S_TIME\x10\x02\x12\x0c\n\x08GLO_TIME\x10\x03\x12\x0c\n\x08GAL_TIME\x10\x04*O\n\x08GnssType\x12\x0f\n\x0bSYS_UNKNOWN\x10\x00\x12\x0b\n\x07GPS_SYS\x10\x01\x12\x0b\n\x07\x42\x44S_SYS\x10\x02\x12\x0b\n\x07GLO_SYS\x10\x03\x12\x0b\n\x07GAL_SYS\x10\x04*B\n\nPseudoType\x12\x10\n\x0c\x43ODE_UNKNOWN\x10\x00\x12\x0e\n\nCORSE_CODE\x10\x01\x12\x12\n\x0ePRECISION_CODE\x10\x02'
)

_GNSSBANDID = _descriptor.EnumDescriptor(
  name='GnssBandID',
  full_name='apollo.drivers.gnss.GnssBandID',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BAND_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPS_L1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPS_L2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPS_L5', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BDS_B1', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BDS_B2', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BDS_B3', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLO_G1', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLO_G2', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLO_G3', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2348,
  serialized_end=2486,
)
_sym_db.RegisterEnumDescriptor(_GNSSBANDID)

GnssBandID = enum_type_wrapper.EnumTypeWrapper(_GNSSBANDID)
_GNSSTIMETYPE = _descriptor.EnumDescriptor(
  name='GnssTimeType',
  full_name='apollo.drivers.gnss.GnssTimeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TIME_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPS_TIME', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BDS_TIME', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLO_TIME', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAL_TIME', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2488,
  serialized_end=2576,
)
_sym_db.RegisterEnumDescriptor(_GNSSTIMETYPE)

GnssTimeType = enum_type_wrapper.EnumTypeWrapper(_GNSSTIMETYPE)
_GNSSTYPE = _descriptor.EnumDescriptor(
  name='GnssType',
  full_name='apollo.drivers.gnss.GnssType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SYS_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPS_SYS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BDS_SYS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLO_SYS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAL_SYS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2578,
  serialized_end=2657,
)
_sym_db.RegisterEnumDescriptor(_GNSSTYPE)

GnssType = enum_type_wrapper.EnumTypeWrapper(_GNSSTYPE)
_PSEUDOTYPE = _descriptor.EnumDescriptor(
  name='PseudoType',
  full_name='apollo.drivers.gnss.PseudoType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CODE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CORSE_CODE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRECISION_CODE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2659,
  serialized_end=2725,
)
_sym_db.RegisterEnumDescriptor(_PSEUDOTYPE)

PseudoType = enum_type_wrapper.EnumTypeWrapper(_PSEUDOTYPE)
BAND_UNKNOWN = 0
GPS_L1 = 1
GPS_L2 = 2
GPS_L5 = 3
BDS_B1 = 4
BDS_B2 = 5
BDS_B3 = 6
GLO_G1 = 7
GLO_G2 = 8
GLO_G3 = 9
TIME_UNKNOWN = 0
GPS_TIME = 1
BDS_TIME = 2
GLO_TIME = 3
GAL_TIME = 4
SYS_UNKNOWN = 0
GPS_SYS = 1
BDS_SYS = 2
GLO_SYS = 3
GAL_SYS = 4
CODE_UNKNOWN = 0
CORSE_CODE = 1
PRECISION_CODE = 2



_BANDOBSERVATION = _descriptor.Descriptor(
  name='BandObservation',
  full_name='apollo.drivers.gnss.BandObservation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='band_id', full_name='apollo.drivers.gnss.BandObservation.band_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frequency_value', full_name='apollo.drivers.gnss.BandObservation.frequency_value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pseudo_type', full_name='apollo.drivers.gnss.BandObservation.pseudo_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pseudo_range', full_name='apollo.drivers.gnss.BandObservation.pseudo_range', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='carrier_phase', full_name='apollo.drivers.gnss.BandObservation.carrier_phase', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loss_lock_index', full_name='apollo.drivers.gnss.BandObservation.loss_lock_index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doppler', full_name='apollo.drivers.gnss.BandObservation.doppler', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snr', full_name='apollo.drivers.gnss.BandObservation.snr', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=353,
)


_SATELLITEOBSERVATION = _descriptor.Descriptor(
  name='SatelliteObservation',
  full_name='apollo.drivers.gnss.SatelliteObservation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sat_prn', full_name='apollo.drivers.gnss.SatelliteObservation.sat_prn', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sat_sys', full_name='apollo.drivers.gnss.SatelliteObservation.sat_sys', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='band_obs_num', full_name='apollo.drivers.gnss.SatelliteObservation.band_obs_num', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='band_obs', full_name='apollo.drivers.gnss.SatelliteObservation.band_obs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=530,
)


_EPOCHOBSERVATION = _descriptor.Descriptor(
  name='EpochObservation',
  full_name='apollo.drivers.gnss.EpochObservation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='receiver_id', full_name='apollo.drivers.gnss.EpochObservation.receiver_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gnss_time_type', full_name='apollo.drivers.gnss.EpochObservation.gnss_time_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gnss_week', full_name='apollo.drivers.gnss.EpochObservation.gnss_week', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gnss_second_s', full_name='apollo.drivers.gnss.EpochObservation.gnss_second_s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_x', full_name='apollo.drivers.gnss.EpochObservation.position_x', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_y', full_name='apollo.drivers.gnss.EpochObservation.position_y', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_z', full_name='apollo.drivers.gnss.EpochObservation.position_z', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_flag', full_name='apollo.drivers.gnss.EpochObservation.health_flag', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sat_obs_num', full_name='apollo.drivers.gnss.EpochObservation.sat_obs_num', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sat_obs', full_name='apollo.drivers.gnss.EpochObservation.sat_obs', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=848,
)


_KEPPLERORBIT = _descriptor.Descriptor(
  name='KepplerOrbit',
  full_name='apollo.drivers.gnss.KepplerOrbit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gnss_type', full_name='apollo.drivers.gnss.KepplerOrbit.gnss_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sat_prn', full_name='apollo.drivers.gnss.KepplerOrbit.sat_prn', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gnss_time_type', full_name='apollo.drivers.gnss.KepplerOrbit.gnss_time_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='year', full_name='apollo.drivers.gnss.KepplerOrbit.year', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='apollo.drivers.gnss.KepplerOrbit.month', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='apollo.drivers.gnss.KepplerOrbit.day', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hour', full_name='apollo.drivers.gnss.KepplerOrbit.hour', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minute', full_name='apollo.drivers.gnss.KepplerOrbit.minute', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second_s', full_name='apollo.drivers.gnss.KepplerOrbit.second_s', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='week_num', full_name='apollo.drivers.gnss.KepplerOrbit.week_num', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved', full_name='apollo.drivers.gnss.KepplerOrbit.reserved', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='af0', full_name='apollo.drivers.gnss.KepplerOrbit.af0', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='af1', full_name='apollo.drivers.gnss.KepplerOrbit.af1', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='af2', full_name='apollo.drivers.gnss.KepplerOrbit.af2', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iode', full_name='apollo.drivers.gnss.KepplerOrbit.iode', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deltan', full_name='apollo.drivers.gnss.KepplerOrbit.deltan', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m0', full_name='apollo.drivers.gnss.KepplerOrbit.m0', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='e', full_name='apollo.drivers.gnss.KepplerOrbit.e', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roota', full_name='apollo.drivers.gnss.KepplerOrbit.roota', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toe', full_name='apollo.drivers.gnss.KepplerOrbit.toe', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toc', full_name='apollo.drivers.gnss.KepplerOrbit.toc', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cic', full_name='apollo.drivers.gnss.KepplerOrbit.cic', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crc', full_name='apollo.drivers.gnss.KepplerOrbit.crc', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cis', full_name='apollo.drivers.gnss.KepplerOrbit.cis', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crs', full_name='apollo.drivers.gnss.KepplerOrbit.crs', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cuc', full_name='apollo.drivers.gnss.KepplerOrbit.cuc', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cus', full_name='apollo.drivers.gnss.KepplerOrbit.cus', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omega0', full_name='apollo.drivers.gnss.KepplerOrbit.omega0', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omega', full_name='apollo.drivers.gnss.KepplerOrbit.omega', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i0', full_name='apollo.drivers.gnss.KepplerOrbit.i0', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omegadot', full_name='apollo.drivers.gnss.KepplerOrbit.omegadot', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idot', full_name='apollo.drivers.gnss.KepplerOrbit.idot', index=31,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codesonL2channel', full_name='apollo.drivers.gnss.KepplerOrbit.codesonL2channel', index=32,
      number=33, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='L2Pdataflag', full_name='apollo.drivers.gnss.KepplerOrbit.L2Pdataflag', index=33,
      number=34, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='apollo.drivers.gnss.KepplerOrbit.accuracy', index=34,
      number=35, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health', full_name='apollo.drivers.gnss.KepplerOrbit.health', index=35,
      number=36, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tgd', full_name='apollo.drivers.gnss.KepplerOrbit.tgd', index=36,
      number=37, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iodc', full_name='apollo.drivers.gnss.KepplerOrbit.iodc', index=37,
      number=38, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=851,
  serialized_end=1530,
)


_GLONASSORBIT = _descriptor.Descriptor(
  name='GlonassOrbit',
  full_name='apollo.drivers.gnss.GlonassOrbit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gnss_type', full_name='apollo.drivers.gnss.GlonassOrbit.gnss_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slot_prn', full_name='apollo.drivers.gnss.GlonassOrbit.slot_prn', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gnss_time_type', full_name='apollo.drivers.gnss.GlonassOrbit.gnss_time_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toe', full_name='apollo.drivers.gnss.GlonassOrbit.toe', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='year', full_name='apollo.drivers.gnss.GlonassOrbit.year', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='apollo.drivers.gnss.GlonassOrbit.month', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='apollo.drivers.gnss.GlonassOrbit.day', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hour', full_name='apollo.drivers.gnss.GlonassOrbit.hour', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minute', full_name='apollo.drivers.gnss.GlonassOrbit.minute', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second_s', full_name='apollo.drivers.gnss.GlonassOrbit.second_s', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frequency_no', full_name='apollo.drivers.gnss.GlonassOrbit.frequency_no', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='week_num', full_name='apollo.drivers.gnss.GlonassOrbit.week_num', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='week_second_s', full_name='apollo.drivers.gnss.GlonassOrbit.week_second_s', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tk', full_name='apollo.drivers.gnss.GlonassOrbit.tk', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock_offset', full_name='apollo.drivers.gnss.GlonassOrbit.clock_offset', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock_drift', full_name='apollo.drivers.gnss.GlonassOrbit.clock_drift', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health', full_name='apollo.drivers.gnss.GlonassOrbit.health', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_x', full_name='apollo.drivers.gnss.GlonassOrbit.position_x', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_y', full_name='apollo.drivers.gnss.GlonassOrbit.position_y', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_z', full_name='apollo.drivers.gnss.GlonassOrbit.position_z', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_x', full_name='apollo.drivers.gnss.GlonassOrbit.velocity_x', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_y', full_name='apollo.drivers.gnss.GlonassOrbit.velocity_y', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_z', full_name='apollo.drivers.gnss.GlonassOrbit.velocity_z', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerate_x', full_name='apollo.drivers.gnss.GlonassOrbit.accelerate_x', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerate_y', full_name='apollo.drivers.gnss.GlonassOrbit.accelerate_y', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerate_z', full_name='apollo.drivers.gnss.GlonassOrbit.accelerate_z', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='infor_age', full_name='apollo.drivers.gnss.GlonassOrbit.infor_age', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sat_prn', full_name='apollo.drivers.gnss.GlonassOrbit.sat_prn', index=27,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1533,
  serialized_end=2152,
)


_GNSSEPHEMERIS = _descriptor.Descriptor(
  name='GnssEphemeris',
  full_name='apollo.drivers.gnss.GnssEphemeris',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gnss_type', full_name='apollo.drivers.gnss.GnssEphemeris.gnss_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keppler_orbit', full_name='apollo.drivers.gnss.GnssEphemeris.keppler_orbit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='glonass_orbit', full_name='apollo.drivers.gnss.GnssEphemeris.glonass_orbit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2155,
  serialized_end=2345,
)

_BANDOBSERVATION.fields_by_name['band_id'].enum_type = _GNSSBANDID
_BANDOBSERVATION.fields_by_name['pseudo_type'].enum_type = _PSEUDOTYPE
_SATELLITEOBSERVATION.fields_by_name['sat_sys'].enum_type = _GNSSTYPE
_SATELLITEOBSERVATION.fields_by_name['band_obs'].message_type = _BANDOBSERVATION
_EPOCHOBSERVATION.fields_by_name['gnss_time_type'].enum_type = _GNSSTIMETYPE
_EPOCHOBSERVATION.fields_by_name['sat_obs'].message_type = _SATELLITEOBSERVATION
_KEPPLERORBIT.fields_by_name['gnss_type'].enum_type = _GNSSTYPE
_KEPPLERORBIT.fields_by_name['gnss_time_type'].enum_type = _GNSSTIMETYPE
_GLONASSORBIT.fields_by_name['gnss_type'].enum_type = _GNSSTYPE
_GLONASSORBIT.fields_by_name['gnss_time_type'].enum_type = _GNSSTIMETYPE
_GNSSEPHEMERIS.fields_by_name['gnss_type'].enum_type = _GNSSTYPE
_GNSSEPHEMERIS.fields_by_name['keppler_orbit'].message_type = _KEPPLERORBIT
_GNSSEPHEMERIS.fields_by_name['glonass_orbit'].message_type = _GLONASSORBIT
DESCRIPTOR.message_types_by_name['BandObservation'] = _BANDOBSERVATION
DESCRIPTOR.message_types_by_name['SatelliteObservation'] = _SATELLITEOBSERVATION
DESCRIPTOR.message_types_by_name['EpochObservation'] = _EPOCHOBSERVATION
DESCRIPTOR.message_types_by_name['KepplerOrbit'] = _KEPPLERORBIT
DESCRIPTOR.message_types_by_name['GlonassOrbit'] = _GLONASSORBIT
DESCRIPTOR.message_types_by_name['GnssEphemeris'] = _GNSSEPHEMERIS
DESCRIPTOR.enum_types_by_name['GnssBandID'] = _GNSSBANDID
DESCRIPTOR.enum_types_by_name['GnssTimeType'] = _GNSSTIMETYPE
DESCRIPTOR.enum_types_by_name['GnssType'] = _GNSSTYPE
DESCRIPTOR.enum_types_by_name['PseudoType'] = _PSEUDOTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BandObservation = _reflection.GeneratedProtocolMessageType('BandObservation', (_message.Message,), {
  'DESCRIPTOR' : _BANDOBSERVATION,
  '__module__' : 'modules.drivers.gnss.proto.gnss_raw_observation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.BandObservation)
  })
_sym_db.RegisterMessage(BandObservation)

SatelliteObservation = _reflection.GeneratedProtocolMessageType('SatelliteObservation', (_message.Message,), {
  'DESCRIPTOR' : _SATELLITEOBSERVATION,
  '__module__' : 'modules.drivers.gnss.proto.gnss_raw_observation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.SatelliteObservation)
  })
_sym_db.RegisterMessage(SatelliteObservation)

EpochObservation = _reflection.GeneratedProtocolMessageType('EpochObservation', (_message.Message,), {
  'DESCRIPTOR' : _EPOCHOBSERVATION,
  '__module__' : 'modules.drivers.gnss.proto.gnss_raw_observation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.EpochObservation)
  })
_sym_db.RegisterMessage(EpochObservation)

KepplerOrbit = _reflection.GeneratedProtocolMessageType('KepplerOrbit', (_message.Message,), {
  'DESCRIPTOR' : _KEPPLERORBIT,
  '__module__' : 'modules.drivers.gnss.proto.gnss_raw_observation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.KepplerOrbit)
  })
_sym_db.RegisterMessage(KepplerOrbit)

GlonassOrbit = _reflection.GeneratedProtocolMessageType('GlonassOrbit', (_message.Message,), {
  'DESCRIPTOR' : _GLONASSORBIT,
  '__module__' : 'modules.drivers.gnss.proto.gnss_raw_observation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.GlonassOrbit)
  })
_sym_db.RegisterMessage(GlonassOrbit)

GnssEphemeris = _reflection.GeneratedProtocolMessageType('GnssEphemeris', (_message.Message,), {
  'DESCRIPTOR' : _GNSSEPHEMERIS,
  '__module__' : 'modules.drivers.gnss.proto.gnss_raw_observation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.GnssEphemeris)
  })
_sym_db.RegisterMessage(GnssEphemeris)


# @@protoc_insertion_point(module_scope)
