# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/lidar/app/proto/lidar_obstacle_segmentation_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/lidar/app/proto/lidar_obstacle_segmentation_config.proto',
  package='apollo.perception.lidar',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nKmodules/perception/lidar/app/proto/lidar_obstacle_segmentation_config.proto\x12\x17\x61pollo.perception.lidar\"\x8c\x01\n\x1fLidarObstacleSegmentationConfig\x12$\n\tsegmentor\x18\x01 \x01(\t:\x11\x44ummySegmentation\x12\x1d\n\x0fuse_map_manager\x18\x02 \x01(\x08:\x04true\x12$\n\x16use_object_filter_bank\x18\x03 \x01(\x08:\x04true'
)




_LIDAROBSTACLESEGMENTATIONCONFIG = _descriptor.Descriptor(
  name='LidarObstacleSegmentationConfig',
  full_name='apollo.perception.lidar.LidarObstacleSegmentationConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segmentor', full_name='apollo.perception.lidar.LidarObstacleSegmentationConfig.segmentor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"DummySegmentation".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_map_manager', full_name='apollo.perception.lidar.LidarObstacleSegmentationConfig.use_map_manager', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_object_filter_bank', full_name='apollo.perception.lidar.LidarObstacleSegmentationConfig.use_object_filter_bank', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=245,
)

DESCRIPTOR.message_types_by_name['LidarObstacleSegmentationConfig'] = _LIDAROBSTACLESEGMENTATIONCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LidarObstacleSegmentationConfig = _reflection.GeneratedProtocolMessageType('LidarObstacleSegmentationConfig', (_message.Message,), {
  'DESCRIPTOR' : _LIDAROBSTACLESEGMENTATIONCONFIG,
  '__module__' : 'modules.perception.lidar.app.proto.lidar_obstacle_segmentation_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.lidar.LidarObstacleSegmentationConfig)
  })
_sym_db.RegisterMessage(LidarObstacleSegmentationConfig)


# @@protoc_insertion_point(module_scope)
