# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/learning_data.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.canbus.proto import chassis_pb2 as modules_dot_canbus_dot_proto_dot_chassis__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2
from modules.map.proto import map_lane_pb2 as modules_dot_map_dot_proto_dot_map__lane__pb2
from modules.perception.proto import perception_obstacle_pb2 as modules_dot_perception_dot_proto_dot_perception__obstacle__pb2
from modules.prediction.proto import feature_pb2 as modules_dot_prediction_dot_proto_dot_feature__pb2
from modules.prediction.proto import prediction_obstacle_pb2 as modules_dot_prediction_dot_proto_dot_prediction__obstacle__pb2
from modules.perception.proto import traffic_light_detection_pb2 as modules_dot_perception_dot_proto_dot_traffic__light__detection__pb2
from modules.routing.proto import routing_pb2 as modules_dot_routing_dot_proto_dot_routing__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/learning_data.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*modules/planning/proto/learning_data.proto\x12\x0f\x61pollo.planning\x1a\"modules/canbus/proto/chassis.proto\x1a#modules/common/proto/geometry.proto\x1a!modules/common/proto/header.proto\x1a$modules/common/proto/pnc_point.proto\x1a modules/map/proto/map_lane.proto\x1a\x32modules/perception/proto/perception_obstacle.proto\x1a&modules/prediction/proto/feature.proto\x1a\x32modules/prediction/proto/prediction_obstacle.proto\x1a\x36modules/perception/proto/traffic_light_detection.proto\x1a#modules/routing/proto/routing.proto\".\n\x0eOverlapFeature\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x64istance\x18\x02 \x01(\x01\"\xf7\x02\n\x0bPlanningTag\x12.\n\tlane_turn\x18\x01 \x01(\x0e\x32\x1b.apollo.hdmap.Lane.LaneTurn\x12\x33\n\nclear_area\x18\x02 \x01(\x0b\x32\x1f.apollo.planning.OverlapFeature\x12\x32\n\tcrosswalk\x18\x03 \x01(\x0b\x32\x1f.apollo.planning.OverlapFeature\x12\x35\n\x0cpnc_junction\x18\x04 \x01(\x0b\x32\x1f.apollo.planning.OverlapFeature\x12/\n\x06signal\x18\x05 \x01(\x0b\x32\x1f.apollo.planning.OverlapFeature\x12\x32\n\tstop_sign\x18\x06 \x01(\x0b\x32\x1f.apollo.planning.OverlapFeature\x12\x33\n\nyield_sign\x18\x07 \x01(\x0b\x32\x1f.apollo.planning.OverlapFeature\"\xd2\x01\n\x0e\x43hassisFeature\x12\x1d\n\x15message_timestamp_sec\x18\x01 \x01(\x01\x12\x11\n\tspeed_mps\x18\x02 \x01(\x02\x12\x1b\n\x13throttle_percentage\x18\x03 \x01(\x02\x12\x18\n\x10\x62rake_percentage\x18\x04 \x01(\x02\x12\x1b\n\x13steering_percentage\x18\x05 \x01(\x02\x12:\n\rgear_location\x18\x06 \x01(\x0e\x32#.apollo.canbus.Chassis.GearPosition\"\x88\x02\n\x13LocalizationFeature\x12\x1d\n\x15message_timestamp_sec\x18\x01 \x01(\x01\x12)\n\x08position\x18\x02 \x01(\x0b\x32\x17.apollo.common.PointENU\x12\x0f\n\x07heading\x18\x03 \x01(\x01\x12/\n\x0flinear_velocity\x18\x04 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x33\n\x13linear_acceleration\x18\x05 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x30\n\x10\x61ngular_velocity\x18\x06 \x01(\x0b\x32\x16.apollo.common.Point3D\"d\n\x16\x43ommonPathPointFeature\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\x12\r\n\x05theta\x18\x04 \x01(\x01\x12\t\n\x01s\x18\x05 \x01(\x01\x12\x0f\n\x07lane_id\x18\x06 \x01(\t\"\xbc\x01\n\x1c\x43ommonTrajectoryPointFeature\x12;\n\npath_point\x18\x01 \x01(\x0b\x32\'.apollo.planning.CommonPathPointFeature\x12\t\n\x01v\x18\x02 \x01(\x01\x12\t\n\x01\x61\x18\x03 \x01(\x01\x12\x15\n\rrelative_time\x18\x04 \x01(\x01\x12\x32\n\rgaussian_info\x18\x05 \x01(\x0b\x32\x1b.apollo.common.GaussianInfo\"x\n\x16TrajectoryPointFeature\x12\x15\n\rtimestamp_sec\x18\x01 \x01(\x01\x12G\n\x10trajectory_point\x18\x02 \x01(\x0b\x32-.apollo.planning.CommonTrajectoryPointFeature\"\xf2\x01\n\x19PerceptionObstacleFeature\x12\x15\n\rtimestamp_sec\x18\x01 \x01(\x01\x12(\n\x08position\x18\x02 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\r\n\x05theta\x18\x03 \x01(\x01\x12(\n\x08velocity\x18\x04 \x01(\x0b\x32\x16.apollo.common.Point3D\x12,\n\x0c\x61\x63\x63\x65leration\x18\x05 \x01(\x0b\x32\x16.apollo.common.Point3D\x12-\n\rpolygon_point\x18\x06 \x03(\x0b\x32\x16.apollo.common.Point3D\"\xb9\x01\n\x19ObstacleTrajectoryFeature\x12O\n\x1bperception_obstacle_history\x18\x01 \x03(\x0b\x32*.apollo.planning.PerceptionObstacleFeature\x12K\n\x1a\x65valuated_trajectory_point\x18\x02 \x03(\x0b\x32\'.apollo.planning.TrajectoryPointFeature\"u\n\x1bPredictionTrajectoryFeature\x12\x13\n\x0bprobability\x18\x01 \x01(\x01\x12\x41\n\x10trajectory_point\x18\x02 \x03(\x0b\x32\'.apollo.planning.TrajectoryPointFeature\"\x92\x02\n\x19PredictionObstacleFeature\x12\x15\n\rtimestamp_sec\x18\x01 \x01(\x01\x12\x18\n\x10predicted_period\x18\x02 \x01(\x01\x12\x31\n\x06intent\x18\x03 \x01(\x0b\x32!.apollo.prediction.ObstacleIntent\x12\x35\n\x08priority\x18\x04 \x01(\x0b\x32#.apollo.prediction.ObstaclePriority\x12\x18\n\tis_static\x18\x05 \x01(\x08:\x05\x66\x61lse\x12@\n\ntrajectory\x18\x06 \x03(\x0b\x32,.apollo.planning.PredictionTrajectoryFeature\"\x98\x02\n\x0fObstacleFeature\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0e\n\x06length\x18\x02 \x01(\x01\x12\r\n\x05width\x18\x03 \x01(\x01\x12\x0e\n\x06height\x18\x04 \x01(\x01\x12\x38\n\x04type\x18\x05 \x01(\x0e\x32*.apollo.perception.PerceptionObstacle.Type\x12G\n\x13obstacle_trajectory\x18\x06 \x01(\x0b\x32*.apollo.planning.ObstacleTrajectoryFeature\x12G\n\x13obstacle_prediction\x18\x07 \x01(\x0b\x32*.apollo.planning.PredictionObstacleFeature\"u\n\x16RoutingResponseFeature\x12)\n\x04road\x18\x01 \x03(\x0b\x32\x1b.apollo.routing.RoadSegment\x12\x30\n\x0bmeasurement\x18\x02 \x01(\x0b\x32\x1b.apollo.routing.Measurement\"\xb2\x01\n\x0eRoutingFeature\x12\x41\n\x10routing_response\x18\x01 \x01(\x0b\x32\'.apollo.planning.RoutingResponseFeature\x12\x1d\n\x15local_routing_lane_id\x18\x02 \x03(\t\x12>\n\rlocal_routing\x18\x03 \x01(\x0b\x32\'.apollo.planning.RoutingResponseFeature\"\xac\x01\n\x13TrafficLightFeature\x12\x34\n\x05\x63olor\x18\x01 \x01(\x0e\x32%.apollo.perception.TrafficLight.Color\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\nconfidence\x18\x03 \x01(\x01:\x01\x31\x12\x15\n\rtracking_time\x18\x04 \x01(\x01\x12\r\n\x05\x62link\x18\x05 \x01(\x08\x12\x16\n\x0eremaining_time\x18\x06 \x01(\x01\"z\n\x1cTrafficLightDetectionFeature\x12\x1d\n\x15message_timestamp_sec\x18\x01 \x01(\x01\x12;\n\rtraffic_light\x18\x02 \x03(\x0b\x32$.apollo.planning.TrafficLightFeature\"\xa8\x01\n\x12\x41\x44\x43TrajectoryPoint\x12\x15\n\rtimestamp_sec\x18\x01 \x01(\x01\x12\x32\n\x0cplanning_tag\x18\x02 \x01(\x0b\x32\x1c.apollo.planning.PlanningTag\x12G\n\x10trajectory_point\x18\x03 \x01(\x0b\x32-.apollo.planning.CommonTrajectoryPointFeature\"^\n\x0eLearningOutput\x12L\n\x1b\x61\x64\x63_future_trajectory_point\x18\x01 \x03(\x0b\x32\'.apollo.planning.TrajectoryPointFeature\"\xa3\x04\n\x11LearningDataFrame\x12\x1d\n\x15message_timestamp_sec\x18\x01 \x01(\x01\x12\x11\n\tframe_num\x18\x02 \x01(\r\x12\x10\n\x08map_name\x18\x03 \x01(\t\x12\x32\n\x0cplanning_tag\x18\x04 \x01(\x0b\x32\x1c.apollo.planning.PlanningTag\x12\x30\n\x07\x63hassis\x18\x05 \x01(\x0b\x32\x1f.apollo.planning.ChassisFeature\x12:\n\x0clocalization\x18\x06 \x01(\x0b\x32$.apollo.planning.LocalizationFeature\x12\x32\n\x08obstacle\x18\x07 \x03(\x0b\x32 .apollo.planning.ObstacleFeature\x12\x30\n\x07routing\x18\x08 \x01(\x0b\x32\x1f.apollo.planning.RoutingFeature\x12N\n\x17traffic_light_detection\x18\t \x01(\x0b\x32-.apollo.planning.TrafficLightDetectionFeature\x12\x41\n\x14\x61\x64\x63_trajectory_point\x18\n \x03(\x0b\x32#.apollo.planning.ADCTrajectoryPoint\x12/\n\x06output\x18\x0b \x01(\x0b\x32\x1f.apollo.planning.LearningOutput\"O\n\x0cLearningData\x12?\n\x13learning_data_frame\x18\x01 \x03(\x0b\x32\".apollo.planning.LearningDataFrame\"~\n\x14PlanningLearningData\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12?\n\x13learning_data_frame\x18\x02 \x01(\x0b\x32\".apollo.planning.LearningDataFrame'
  ,
  dependencies=[modules_dot_canbus_dot_proto_dot_chassis__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__lane__pb2.DESCRIPTOR,modules_dot_perception_dot_proto_dot_perception__obstacle__pb2.DESCRIPTOR,modules_dot_prediction_dot_proto_dot_feature__pb2.DESCRIPTOR,modules_dot_prediction_dot_proto_dot_prediction__obstacle__pb2.DESCRIPTOR,modules_dot_perception_dot_proto_dot_traffic__light__detection__pb2.DESCRIPTOR,modules_dot_routing_dot_proto_dot_routing__pb2.DESCRIPTOR,])




_OVERLAPFEATURE = _descriptor.Descriptor(
  name='OverlapFeature',
  full_name='apollo.planning.OverlapFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.planning.OverlapFeature.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='apollo.planning.OverlapFeature.distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=526,
)


_PLANNINGTAG = _descriptor.Descriptor(
  name='PlanningTag',
  full_name='apollo.planning.PlanningTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_turn', full_name='apollo.planning.PlanningTag.lane_turn', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_area', full_name='apollo.planning.PlanningTag.clear_area', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalk', full_name='apollo.planning.PlanningTag.crosswalk', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pnc_junction', full_name='apollo.planning.PlanningTag.pnc_junction', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal', full_name='apollo.planning.PlanningTag.signal', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_sign', full_name='apollo.planning.PlanningTag.stop_sign', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield_sign', full_name='apollo.planning.PlanningTag.yield_sign', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=904,
)


_CHASSISFEATURE = _descriptor.Descriptor(
  name='ChassisFeature',
  full_name='apollo.planning.ChassisFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_timestamp_sec', full_name='apollo.planning.ChassisFeature.message_timestamp_sec', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_mps', full_name='apollo.planning.ChassisFeature.speed_mps', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_percentage', full_name='apollo.planning.ChassisFeature.throttle_percentage', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_percentage', full_name='apollo.planning.ChassisFeature.brake_percentage', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_percentage', full_name='apollo.planning.ChassisFeature.steering_percentage', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_location', full_name='apollo.planning.ChassisFeature.gear_location', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=1117,
)


_LOCALIZATIONFEATURE = _descriptor.Descriptor(
  name='LocalizationFeature',
  full_name='apollo.planning.LocalizationFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_timestamp_sec', full_name='apollo.planning.LocalizationFeature.message_timestamp_sec', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.planning.LocalizationFeature.position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.planning.LocalizationFeature.heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_velocity', full_name='apollo.planning.LocalizationFeature.linear_velocity', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_acceleration', full_name='apollo.planning.LocalizationFeature.linear_acceleration', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_velocity', full_name='apollo.planning.LocalizationFeature.angular_velocity', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1120,
  serialized_end=1384,
)


_COMMONPATHPOINTFEATURE = _descriptor.Descriptor(
  name='CommonPathPointFeature',
  full_name='apollo.planning.CommonPathPointFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.planning.CommonPathPointFeature.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.planning.CommonPathPointFeature.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='apollo.planning.CommonPathPointFeature.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='apollo.planning.CommonPathPointFeature.theta', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.planning.CommonPathPointFeature.s', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.planning.CommonPathPointFeature.lane_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1386,
  serialized_end=1486,
)


_COMMONTRAJECTORYPOINTFEATURE = _descriptor.Descriptor(
  name='CommonTrajectoryPointFeature',
  full_name='apollo.planning.CommonTrajectoryPointFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path_point', full_name='apollo.planning.CommonTrajectoryPointFeature.path_point', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v', full_name='apollo.planning.CommonTrajectoryPointFeature.v', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a', full_name='apollo.planning.CommonTrajectoryPointFeature.a', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_time', full_name='apollo.planning.CommonTrajectoryPointFeature.relative_time', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gaussian_info', full_name='apollo.planning.CommonTrajectoryPointFeature.gaussian_info', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1489,
  serialized_end=1677,
)


_TRAJECTORYPOINTFEATURE = _descriptor.Descriptor(
  name='TrajectoryPointFeature',
  full_name='apollo.planning.TrajectoryPointFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_sec', full_name='apollo.planning.TrajectoryPointFeature.timestamp_sec', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_point', full_name='apollo.planning.TrajectoryPointFeature.trajectory_point', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1679,
  serialized_end=1799,
)


_PERCEPTIONOBSTACLEFEATURE = _descriptor.Descriptor(
  name='PerceptionObstacleFeature',
  full_name='apollo.planning.PerceptionObstacleFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_sec', full_name='apollo.planning.PerceptionObstacleFeature.timestamp_sec', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.planning.PerceptionObstacleFeature.position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='apollo.planning.PerceptionObstacleFeature.theta', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='apollo.planning.PerceptionObstacleFeature.velocity', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='apollo.planning.PerceptionObstacleFeature.acceleration', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon_point', full_name='apollo.planning.PerceptionObstacleFeature.polygon_point', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1802,
  serialized_end=2044,
)


_OBSTACLETRAJECTORYFEATURE = _descriptor.Descriptor(
  name='ObstacleTrajectoryFeature',
  full_name='apollo.planning.ObstacleTrajectoryFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='perception_obstacle_history', full_name='apollo.planning.ObstacleTrajectoryFeature.perception_obstacle_history', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evaluated_trajectory_point', full_name='apollo.planning.ObstacleTrajectoryFeature.evaluated_trajectory_point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2047,
  serialized_end=2232,
)


_PREDICTIONTRAJECTORYFEATURE = _descriptor.Descriptor(
  name='PredictionTrajectoryFeature',
  full_name='apollo.planning.PredictionTrajectoryFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='probability', full_name='apollo.planning.PredictionTrajectoryFeature.probability', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_point', full_name='apollo.planning.PredictionTrajectoryFeature.trajectory_point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2234,
  serialized_end=2351,
)


_PREDICTIONOBSTACLEFEATURE = _descriptor.Descriptor(
  name='PredictionObstacleFeature',
  full_name='apollo.planning.PredictionObstacleFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_sec', full_name='apollo.planning.PredictionObstacleFeature.timestamp_sec', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predicted_period', full_name='apollo.planning.PredictionObstacleFeature.predicted_period', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intent', full_name='apollo.planning.PredictionObstacleFeature.intent', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='apollo.planning.PredictionObstacleFeature.priority', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_static', full_name='apollo.planning.PredictionObstacleFeature.is_static', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory', full_name='apollo.planning.PredictionObstacleFeature.trajectory', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2354,
  serialized_end=2628,
)


_OBSTACLEFEATURE = _descriptor.Descriptor(
  name='ObstacleFeature',
  full_name='apollo.planning.ObstacleFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.planning.ObstacleFeature.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.planning.ObstacleFeature.length', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.planning.ObstacleFeature.width', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.planning.ObstacleFeature.height', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.planning.ObstacleFeature.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_trajectory', full_name='apollo.planning.ObstacleFeature.obstacle_trajectory', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_prediction', full_name='apollo.planning.ObstacleFeature.obstacle_prediction', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2631,
  serialized_end=2911,
)


_ROUTINGRESPONSEFEATURE = _descriptor.Descriptor(
  name='RoutingResponseFeature',
  full_name='apollo.planning.RoutingResponseFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='road', full_name='apollo.planning.RoutingResponseFeature.road', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement', full_name='apollo.planning.RoutingResponseFeature.measurement', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2913,
  serialized_end=3030,
)


_ROUTINGFEATURE = _descriptor.Descriptor(
  name='RoutingFeature',
  full_name='apollo.planning.RoutingFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='routing_response', full_name='apollo.planning.RoutingFeature.routing_response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_routing_lane_id', full_name='apollo.planning.RoutingFeature.local_routing_lane_id', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_routing', full_name='apollo.planning.RoutingFeature.local_routing', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3033,
  serialized_end=3211,
)


_TRAFFICLIGHTFEATURE = _descriptor.Descriptor(
  name='TrafficLightFeature',
  full_name='apollo.planning.TrafficLightFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='apollo.planning.TrafficLightFeature.color', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.planning.TrafficLightFeature.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='apollo.planning.TrafficLightFeature.confidence', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracking_time', full_name='apollo.planning.TrafficLightFeature.tracking_time', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blink', full_name='apollo.planning.TrafficLightFeature.blink', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remaining_time', full_name='apollo.planning.TrafficLightFeature.remaining_time', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3214,
  serialized_end=3386,
)


_TRAFFICLIGHTDETECTIONFEATURE = _descriptor.Descriptor(
  name='TrafficLightDetectionFeature',
  full_name='apollo.planning.TrafficLightDetectionFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_timestamp_sec', full_name='apollo.planning.TrafficLightDetectionFeature.message_timestamp_sec', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light', full_name='apollo.planning.TrafficLightDetectionFeature.traffic_light', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3388,
  serialized_end=3510,
)


_ADCTRAJECTORYPOINT = _descriptor.Descriptor(
  name='ADCTrajectoryPoint',
  full_name='apollo.planning.ADCTrajectoryPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_sec', full_name='apollo.planning.ADCTrajectoryPoint.timestamp_sec', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='planning_tag', full_name='apollo.planning.ADCTrajectoryPoint.planning_tag', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_point', full_name='apollo.planning.ADCTrajectoryPoint.trajectory_point', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3513,
  serialized_end=3681,
)


_LEARNINGOUTPUT = _descriptor.Descriptor(
  name='LearningOutput',
  full_name='apollo.planning.LearningOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='adc_future_trajectory_point', full_name='apollo.planning.LearningOutput.adc_future_trajectory_point', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3683,
  serialized_end=3777,
)


_LEARNINGDATAFRAME = _descriptor.Descriptor(
  name='LearningDataFrame',
  full_name='apollo.planning.LearningDataFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_timestamp_sec', full_name='apollo.planning.LearningDataFrame.message_timestamp_sec', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_num', full_name='apollo.planning.LearningDataFrame.frame_num', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_name', full_name='apollo.planning.LearningDataFrame.map_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='planning_tag', full_name='apollo.planning.LearningDataFrame.planning_tag', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chassis', full_name='apollo.planning.LearningDataFrame.chassis', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localization', full_name='apollo.planning.LearningDataFrame.localization', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle', full_name='apollo.planning.LearningDataFrame.obstacle', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing', full_name='apollo.planning.LearningDataFrame.routing', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light_detection', full_name='apollo.planning.LearningDataFrame.traffic_light_detection', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_trajectory_point', full_name='apollo.planning.LearningDataFrame.adc_trajectory_point', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output', full_name='apollo.planning.LearningDataFrame.output', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3780,
  serialized_end=4327,
)


_LEARNINGDATA = _descriptor.Descriptor(
  name='LearningData',
  full_name='apollo.planning.LearningData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='learning_data_frame', full_name='apollo.planning.LearningData.learning_data_frame', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4329,
  serialized_end=4408,
)


_PLANNINGLEARNINGDATA = _descriptor.Descriptor(
  name='PlanningLearningData',
  full_name='apollo.planning.PlanningLearningData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.planning.PlanningLearningData.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='learning_data_frame', full_name='apollo.planning.PlanningLearningData.learning_data_frame', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4410,
  serialized_end=4536,
)

_PLANNINGTAG.fields_by_name['lane_turn'].enum_type = modules_dot_map_dot_proto_dot_map__lane__pb2._LANE_LANETURN
_PLANNINGTAG.fields_by_name['clear_area'].message_type = _OVERLAPFEATURE
_PLANNINGTAG.fields_by_name['crosswalk'].message_type = _OVERLAPFEATURE
_PLANNINGTAG.fields_by_name['pnc_junction'].message_type = _OVERLAPFEATURE
_PLANNINGTAG.fields_by_name['signal'].message_type = _OVERLAPFEATURE
_PLANNINGTAG.fields_by_name['stop_sign'].message_type = _OVERLAPFEATURE
_PLANNINGTAG.fields_by_name['yield_sign'].message_type = _OVERLAPFEATURE
_CHASSISFEATURE.fields_by_name['gear_location'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_GEARPOSITION
_LOCALIZATIONFEATURE.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_LOCALIZATIONFEATURE.fields_by_name['linear_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_LOCALIZATIONFEATURE.fields_by_name['linear_acceleration'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_LOCALIZATIONFEATURE.fields_by_name['angular_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_COMMONTRAJECTORYPOINTFEATURE.fields_by_name['path_point'].message_type = _COMMONPATHPOINTFEATURE
_COMMONTRAJECTORYPOINTFEATURE.fields_by_name['gaussian_info'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._GAUSSIANINFO
_TRAJECTORYPOINTFEATURE.fields_by_name['trajectory_point'].message_type = _COMMONTRAJECTORYPOINTFEATURE
_PERCEPTIONOBSTACLEFEATURE.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_PERCEPTIONOBSTACLEFEATURE.fields_by_name['velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_PERCEPTIONOBSTACLEFEATURE.fields_by_name['acceleration'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_PERCEPTIONOBSTACLEFEATURE.fields_by_name['polygon_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_OBSTACLETRAJECTORYFEATURE.fields_by_name['perception_obstacle_history'].message_type = _PERCEPTIONOBSTACLEFEATURE
_OBSTACLETRAJECTORYFEATURE.fields_by_name['evaluated_trajectory_point'].message_type = _TRAJECTORYPOINTFEATURE
_PREDICTIONTRAJECTORYFEATURE.fields_by_name['trajectory_point'].message_type = _TRAJECTORYPOINTFEATURE
_PREDICTIONOBSTACLEFEATURE.fields_by_name['intent'].message_type = modules_dot_prediction_dot_proto_dot_prediction__obstacle__pb2._OBSTACLEINTENT
_PREDICTIONOBSTACLEFEATURE.fields_by_name['priority'].message_type = modules_dot_prediction_dot_proto_dot_feature__pb2._OBSTACLEPRIORITY
_PREDICTIONOBSTACLEFEATURE.fields_by_name['trajectory'].message_type = _PREDICTIONTRAJECTORYFEATURE
_OBSTACLEFEATURE.fields_by_name['type'].enum_type = modules_dot_perception_dot_proto_dot_perception__obstacle__pb2._PERCEPTIONOBSTACLE_TYPE
_OBSTACLEFEATURE.fields_by_name['obstacle_trajectory'].message_type = _OBSTACLETRAJECTORYFEATURE
_OBSTACLEFEATURE.fields_by_name['obstacle_prediction'].message_type = _PREDICTIONOBSTACLEFEATURE
_ROUTINGRESPONSEFEATURE.fields_by_name['road'].message_type = modules_dot_routing_dot_proto_dot_routing__pb2._ROADSEGMENT
_ROUTINGRESPONSEFEATURE.fields_by_name['measurement'].message_type = modules_dot_routing_dot_proto_dot_routing__pb2._MEASUREMENT
_ROUTINGFEATURE.fields_by_name['routing_response'].message_type = _ROUTINGRESPONSEFEATURE
_ROUTINGFEATURE.fields_by_name['local_routing'].message_type = _ROUTINGRESPONSEFEATURE
_TRAFFICLIGHTFEATURE.fields_by_name['color'].enum_type = modules_dot_perception_dot_proto_dot_traffic__light__detection__pb2._TRAFFICLIGHT_COLOR
_TRAFFICLIGHTDETECTIONFEATURE.fields_by_name['traffic_light'].message_type = _TRAFFICLIGHTFEATURE
_ADCTRAJECTORYPOINT.fields_by_name['planning_tag'].message_type = _PLANNINGTAG
_ADCTRAJECTORYPOINT.fields_by_name['trajectory_point'].message_type = _COMMONTRAJECTORYPOINTFEATURE
_LEARNINGOUTPUT.fields_by_name['adc_future_trajectory_point'].message_type = _TRAJECTORYPOINTFEATURE
_LEARNINGDATAFRAME.fields_by_name['planning_tag'].message_type = _PLANNINGTAG
_LEARNINGDATAFRAME.fields_by_name['chassis'].message_type = _CHASSISFEATURE
_LEARNINGDATAFRAME.fields_by_name['localization'].message_type = _LOCALIZATIONFEATURE
_LEARNINGDATAFRAME.fields_by_name['obstacle'].message_type = _OBSTACLEFEATURE
_LEARNINGDATAFRAME.fields_by_name['routing'].message_type = _ROUTINGFEATURE
_LEARNINGDATAFRAME.fields_by_name['traffic_light_detection'].message_type = _TRAFFICLIGHTDETECTIONFEATURE
_LEARNINGDATAFRAME.fields_by_name['adc_trajectory_point'].message_type = _ADCTRAJECTORYPOINT
_LEARNINGDATAFRAME.fields_by_name['output'].message_type = _LEARNINGOUTPUT
_LEARNINGDATA.fields_by_name['learning_data_frame'].message_type = _LEARNINGDATAFRAME
_PLANNINGLEARNINGDATA.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_PLANNINGLEARNINGDATA.fields_by_name['learning_data_frame'].message_type = _LEARNINGDATAFRAME
DESCRIPTOR.message_types_by_name['OverlapFeature'] = _OVERLAPFEATURE
DESCRIPTOR.message_types_by_name['PlanningTag'] = _PLANNINGTAG
DESCRIPTOR.message_types_by_name['ChassisFeature'] = _CHASSISFEATURE
DESCRIPTOR.message_types_by_name['LocalizationFeature'] = _LOCALIZATIONFEATURE
DESCRIPTOR.message_types_by_name['CommonPathPointFeature'] = _COMMONPATHPOINTFEATURE
DESCRIPTOR.message_types_by_name['CommonTrajectoryPointFeature'] = _COMMONTRAJECTORYPOINTFEATURE
DESCRIPTOR.message_types_by_name['TrajectoryPointFeature'] = _TRAJECTORYPOINTFEATURE
DESCRIPTOR.message_types_by_name['PerceptionObstacleFeature'] = _PERCEPTIONOBSTACLEFEATURE
DESCRIPTOR.message_types_by_name['ObstacleTrajectoryFeature'] = _OBSTACLETRAJECTORYFEATURE
DESCRIPTOR.message_types_by_name['PredictionTrajectoryFeature'] = _PREDICTIONTRAJECTORYFEATURE
DESCRIPTOR.message_types_by_name['PredictionObstacleFeature'] = _PREDICTIONOBSTACLEFEATURE
DESCRIPTOR.message_types_by_name['ObstacleFeature'] = _OBSTACLEFEATURE
DESCRIPTOR.message_types_by_name['RoutingResponseFeature'] = _ROUTINGRESPONSEFEATURE
DESCRIPTOR.message_types_by_name['RoutingFeature'] = _ROUTINGFEATURE
DESCRIPTOR.message_types_by_name['TrafficLightFeature'] = _TRAFFICLIGHTFEATURE
DESCRIPTOR.message_types_by_name['TrafficLightDetectionFeature'] = _TRAFFICLIGHTDETECTIONFEATURE
DESCRIPTOR.message_types_by_name['ADCTrajectoryPoint'] = _ADCTRAJECTORYPOINT
DESCRIPTOR.message_types_by_name['LearningOutput'] = _LEARNINGOUTPUT
DESCRIPTOR.message_types_by_name['LearningDataFrame'] = _LEARNINGDATAFRAME
DESCRIPTOR.message_types_by_name['LearningData'] = _LEARNINGDATA
DESCRIPTOR.message_types_by_name['PlanningLearningData'] = _PLANNINGLEARNINGDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OverlapFeature = _reflection.GeneratedProtocolMessageType('OverlapFeature', (_message.Message,), {
  'DESCRIPTOR' : _OVERLAPFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OverlapFeature)
  })
_sym_db.RegisterMessage(OverlapFeature)

PlanningTag = _reflection.GeneratedProtocolMessageType('PlanningTag', (_message.Message,), {
  'DESCRIPTOR' : _PLANNINGTAG,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PlanningTag)
  })
_sym_db.RegisterMessage(PlanningTag)

ChassisFeature = _reflection.GeneratedProtocolMessageType('ChassisFeature', (_message.Message,), {
  'DESCRIPTOR' : _CHASSISFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ChassisFeature)
  })
_sym_db.RegisterMessage(ChassisFeature)

LocalizationFeature = _reflection.GeneratedProtocolMessageType('LocalizationFeature', (_message.Message,), {
  'DESCRIPTOR' : _LOCALIZATIONFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.LocalizationFeature)
  })
_sym_db.RegisterMessage(LocalizationFeature)

CommonPathPointFeature = _reflection.GeneratedProtocolMessageType('CommonPathPointFeature', (_message.Message,), {
  'DESCRIPTOR' : _COMMONPATHPOINTFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.CommonPathPointFeature)
  })
_sym_db.RegisterMessage(CommonPathPointFeature)

CommonTrajectoryPointFeature = _reflection.GeneratedProtocolMessageType('CommonTrajectoryPointFeature', (_message.Message,), {
  'DESCRIPTOR' : _COMMONTRAJECTORYPOINTFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.CommonTrajectoryPointFeature)
  })
_sym_db.RegisterMessage(CommonTrajectoryPointFeature)

TrajectoryPointFeature = _reflection.GeneratedProtocolMessageType('TrajectoryPointFeature', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORYPOINTFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.TrajectoryPointFeature)
  })
_sym_db.RegisterMessage(TrajectoryPointFeature)

PerceptionObstacleFeature = _reflection.GeneratedProtocolMessageType('PerceptionObstacleFeature', (_message.Message,), {
  'DESCRIPTOR' : _PERCEPTIONOBSTACLEFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PerceptionObstacleFeature)
  })
_sym_db.RegisterMessage(PerceptionObstacleFeature)

ObstacleTrajectoryFeature = _reflection.GeneratedProtocolMessageType('ObstacleTrajectoryFeature', (_message.Message,), {
  'DESCRIPTOR' : _OBSTACLETRAJECTORYFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObstacleTrajectoryFeature)
  })
_sym_db.RegisterMessage(ObstacleTrajectoryFeature)

PredictionTrajectoryFeature = _reflection.GeneratedProtocolMessageType('PredictionTrajectoryFeature', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTIONTRAJECTORYFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PredictionTrajectoryFeature)
  })
_sym_db.RegisterMessage(PredictionTrajectoryFeature)

PredictionObstacleFeature = _reflection.GeneratedProtocolMessageType('PredictionObstacleFeature', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTIONOBSTACLEFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PredictionObstacleFeature)
  })
_sym_db.RegisterMessage(PredictionObstacleFeature)

ObstacleFeature = _reflection.GeneratedProtocolMessageType('ObstacleFeature', (_message.Message,), {
  'DESCRIPTOR' : _OBSTACLEFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObstacleFeature)
  })
_sym_db.RegisterMessage(ObstacleFeature)

RoutingResponseFeature = _reflection.GeneratedProtocolMessageType('RoutingResponseFeature', (_message.Message,), {
  'DESCRIPTOR' : _ROUTINGRESPONSEFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.RoutingResponseFeature)
  })
_sym_db.RegisterMessage(RoutingResponseFeature)

RoutingFeature = _reflection.GeneratedProtocolMessageType('RoutingFeature', (_message.Message,), {
  'DESCRIPTOR' : _ROUTINGFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.RoutingFeature)
  })
_sym_db.RegisterMessage(RoutingFeature)

TrafficLightFeature = _reflection.GeneratedProtocolMessageType('TrafficLightFeature', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICLIGHTFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.TrafficLightFeature)
  })
_sym_db.RegisterMessage(TrafficLightFeature)

TrafficLightDetectionFeature = _reflection.GeneratedProtocolMessageType('TrafficLightDetectionFeature', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICLIGHTDETECTIONFEATURE,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.TrafficLightDetectionFeature)
  })
_sym_db.RegisterMessage(TrafficLightDetectionFeature)

ADCTrajectoryPoint = _reflection.GeneratedProtocolMessageType('ADCTrajectoryPoint', (_message.Message,), {
  'DESCRIPTOR' : _ADCTRAJECTORYPOINT,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ADCTrajectoryPoint)
  })
_sym_db.RegisterMessage(ADCTrajectoryPoint)

LearningOutput = _reflection.GeneratedProtocolMessageType('LearningOutput', (_message.Message,), {
  'DESCRIPTOR' : _LEARNINGOUTPUT,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.LearningOutput)
  })
_sym_db.RegisterMessage(LearningOutput)

LearningDataFrame = _reflection.GeneratedProtocolMessageType('LearningDataFrame', (_message.Message,), {
  'DESCRIPTOR' : _LEARNINGDATAFRAME,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.LearningDataFrame)
  })
_sym_db.RegisterMessage(LearningDataFrame)

LearningData = _reflection.GeneratedProtocolMessageType('LearningData', (_message.Message,), {
  'DESCRIPTOR' : _LEARNINGDATA,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.LearningData)
  })
_sym_db.RegisterMessage(LearningData)

PlanningLearningData = _reflection.GeneratedProtocolMessageType('PlanningLearningData', (_message.Message,), {
  'DESCRIPTOR' : _PLANNINGLEARNINGDATA,
  '__module__' : 'modules.planning.proto.learning_data_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PlanningLearningData)
  })
_sym_db.RegisterMessage(PlanningLearningData)


# @@protoc_insertion_point(module_scope)
