# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/math/cos_theta_smoother_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/math/cos_theta_smoother_config.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;modules/planning/proto/math/cos_theta_smoother_config.proto\x12\x0f\x61pollo.planning\"\xc8\x02\n\x16\x43osThetaSmootherConfig\x12(\n\x19weight_cos_included_angle\x18\x01 \x01(\x01:\x05\x31\x30\x30\x30\x30\x12\x1f\n\x14weight_anchor_points\x18\x02 \x01(\x01:\x01\x31\x12\x18\n\rweight_length\x18\x03 \x01(\x01:\x01\x31\x12\x16\n\x0bprint_level\x18\x04 \x01(\x05:\x01\x30\x12\"\n\x15max_num_of_iterations\x18\x05 \x01(\x05:\x03\x35\x30\x30\x12(\n\x1c\x61\x63\x63\x65ptable_num_of_iterations\x18\x06 \x01(\x05:\x02\x31\x35\x12\x12\n\x03tol\x18\x07 \x01(\x01:\x05\x31\x65-08\x12\x1b\n\x0e\x61\x63\x63\x65ptable_tol\x18\x08 \x01(\x01:\x03\x30.1\x12\x32\n#ipopt_use_automatic_differentiation\x18\t \x01(\x08:\x05\x66\x61lse'
)




_COSTHETASMOOTHERCONFIG = _descriptor.Descriptor(
  name='CosThetaSmootherConfig',
  full_name='apollo.planning.CosThetaSmootherConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight_cos_included_angle', full_name='apollo.planning.CosThetaSmootherConfig.weight_cos_included_angle', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10000),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_anchor_points', full_name='apollo.planning.CosThetaSmootherConfig.weight_anchor_points', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_length', full_name='apollo.planning.CosThetaSmootherConfig.weight_length', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='print_level', full_name='apollo.planning.CosThetaSmootherConfig.print_level', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_num_of_iterations', full_name='apollo.planning.CosThetaSmootherConfig.max_num_of_iterations', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=500,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceptable_num_of_iterations', full_name='apollo.planning.CosThetaSmootherConfig.acceptable_num_of_iterations', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=15,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tol', full_name='apollo.planning.CosThetaSmootherConfig.tol', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1e-08),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceptable_tol', full_name='apollo.planning.CosThetaSmootherConfig.acceptable_tol', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_use_automatic_differentiation', full_name='apollo.planning.CosThetaSmootherConfig.ipopt_use_automatic_differentiation', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=409,
)

DESCRIPTOR.message_types_by_name['CosThetaSmootherConfig'] = _COSTHETASMOOTHERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CosThetaSmootherConfig = _reflection.GeneratedProtocolMessageType('CosThetaSmootherConfig', (_message.Message,), {
  'DESCRIPTOR' : _COSTHETASMOOTHERCONFIG,
  '__module__' : 'modules.planning.proto.math.cos_theta_smoother_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.CosThetaSmootherConfig)
  })
_sym_db.RegisterMessage(CosThetaSmootherConfig)


# @@protoc_insertion_point(module_scope)
