# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/pbf_tracker_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/pbf_tracker_config.proto',
  package='apollo.perception.fusion',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1modules/perception/proto/pbf_tracker_config.proto\x12\x18\x61pollo.perception.fusion\"\xd1\x01\n\x10PbfTrackerConfig\x12)\n\x12type_fusion_method\x18\x01 \x01(\t:\rDstTypeFusion\x12\x30\n\x14motion_fusion_method\x18\x02 \x01(\t:\x12KalmanMotionFusion\x12+\n\x13shape_fusion_method\x18\x03 \x01(\t:\x0ePbfShapeFusion\x12\x33\n\x17\x65xistence_fusion_method\x18\x04 \x01(\t:\x12\x44stExistenceFusion'
)




_PBFTRACKERCONFIG = _descriptor.Descriptor(
  name='PbfTrackerConfig',
  full_name='apollo.perception.fusion.PbfTrackerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_fusion_method', full_name='apollo.perception.fusion.PbfTrackerConfig.type_fusion_method', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"DstTypeFusion".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motion_fusion_method', full_name='apollo.perception.fusion.PbfTrackerConfig.motion_fusion_method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"KalmanMotionFusion".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape_fusion_method', full_name='apollo.perception.fusion.PbfTrackerConfig.shape_fusion_method', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"PbfShapeFusion".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='existence_fusion_method', full_name='apollo.perception.fusion.PbfTrackerConfig.existence_fusion_method', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"DstExistenceFusion".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=289,
)

DESCRIPTOR.message_types_by_name['PbfTrackerConfig'] = _PBFTRACKERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PbfTrackerConfig = _reflection.GeneratedProtocolMessageType('PbfTrackerConfig', (_message.Message,), {
  'DESCRIPTOR' : _PBFTRACKERCONFIG,
  '__module__' : 'modules.perception.proto.pbf_tracker_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.fusion.PbfTrackerConfig)
  })
_sym_db.RegisterMessage(PbfTrackerConfig)


# @@protoc_insertion_point(module_scope)
