# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/velodyne/proto/config.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.drivers.velodyne.proto import velodyne_pb2 as modules_dot_drivers_dot_velodyne_dot_proto_dot_velodyne__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/velodyne/proto/config.proto',
  package='apollo.drivers.velodyne',
  syntax='proto2',
  serialized_pb=_b('\n+modules/drivers/velodyne/proto/config.proto\x12\x17\x61pollo.drivers.velodyne\x1a-modules/drivers/velodyne/proto/velodyne.proto\"\xc9\x04\n\x06\x43onfig\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\x12\x14\n\x0cscan_channel\x18\x02 \x01(\t\x12\x10\n\x03rpm\x18\x03 \x01(\x01:\x03\x36\x30\x30\x12-\n\x05model\x18\x04 \x01(\x0e\x32\x1e.apollo.drivers.velodyne.Model\x12+\n\x04mode\x18\x15 \x01(\x0e\x32\x1d.apollo.drivers.velodyne.Mode\x12\x0c\n\x04pcap\x18\x05 \x01(\t\x12\x14\n\x0cprefix_angle\x18\x06 \x01(\x05\x12\x18\n\x10\x66iring_data_port\x18\x07 \x01(\x05\x12\x1d\n\x15positioning_data_port\x18\x08 \x01(\x05\x12\x17\n\x0fuse_sensor_sync\x18\t \x01(\x08\x12\x11\n\tmax_range\x18\n \x01(\x01\x12\x11\n\tmin_range\x18\x0b \x01(\x01\x12\x11\n\tmax_angle\x18\x0c \x01(\x01\x12\x11\n\tmin_angle\x18\r \x01(\x01\x12\x16\n\x0eview_direction\x18\x0e \x01(\x01\x12\x12\n\nview_width\x18\x0f \x01(\x01\x12\x1a\n\x12\x63\x61libration_online\x18\x10 \x01(\x08\x12\x18\n\x10\x63\x61libration_file\x18\x11 \x01(\t\x12\x11\n\torganized\x18\x12 \x01(\x08\x12\x1c\n\x14\x63onvert_channel_name\x18\x13 \x01(\t\x12\x10\n\x08npackets\x18\x14 \x01(\x05\x12\x14\n\x0cuse_gps_time\x18\x17 \x01(\x08\x12\x15\n\ruse_poll_sync\x18\x18 \x01(\x08\x12\x15\n\ris_main_frame\x18\x19 \x01(\x08\"\x86\x01\n\x0c\x46usionConfig\x12\x17\n\x0fmax_interval_ms\x18\x01 \x01(\r\x12\x19\n\x11\x64rop_expired_data\x18\x02 \x01(\x08\x12\x16\n\x0e\x66usion_channel\x18\x03 \x01(\t\x12\x15\n\rinput_channel\x18\x04 \x03(\t\x12\x13\n\x0bwait_time_s\x18\x05 \x01(\x02\"\xa4\x01\n\x11\x43ompensatorConfig\x12\x16\n\x0eoutput_channel\x18\x01 \x01(\t\x12%\n\x17transform_query_timeout\x18\x02 \x01(\x02:\x04\x30.02\x12\x1d\n\x0eworld_frame_id\x18\x03 \x01(\t:\x05world\x12\x17\n\x0ftarget_frame_id\x18\x04 \x01(\t\x12\x18\n\x10point_cloud_size\x18\x05 \x01(\r')
  ,
  dependencies=[modules_dot_drivers_dot_velodyne_dot_proto_dot_velodyne__pb2.DESCRIPTOR,])




_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='apollo.drivers.velodyne.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.drivers.velodyne.Config.frame_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scan_channel', full_name='apollo.drivers.velodyne.Config.scan_channel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpm', full_name='apollo.drivers.velodyne.Config.rpm', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(600),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='model', full_name='apollo.drivers.velodyne.Config.model', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mode', full_name='apollo.drivers.velodyne.Config.mode', index=4,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pcap', full_name='apollo.drivers.velodyne.Config.pcap', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prefix_angle', full_name='apollo.drivers.velodyne.Config.prefix_angle', index=6,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='firing_data_port', full_name='apollo.drivers.velodyne.Config.firing_data_port', index=7,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='positioning_data_port', full_name='apollo.drivers.velodyne.Config.positioning_data_port', index=8,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_sensor_sync', full_name='apollo.drivers.velodyne.Config.use_sensor_sync', index=9,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_range', full_name='apollo.drivers.velodyne.Config.max_range', index=10,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_range', full_name='apollo.drivers.velodyne.Config.min_range', index=11,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_angle', full_name='apollo.drivers.velodyne.Config.max_angle', index=12,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_angle', full_name='apollo.drivers.velodyne.Config.min_angle', index=13,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='view_direction', full_name='apollo.drivers.velodyne.Config.view_direction', index=14,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='view_width', full_name='apollo.drivers.velodyne.Config.view_width', index=15,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calibration_online', full_name='apollo.drivers.velodyne.Config.calibration_online', index=16,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calibration_file', full_name='apollo.drivers.velodyne.Config.calibration_file', index=17,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='organized', full_name='apollo.drivers.velodyne.Config.organized', index=18,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='convert_channel_name', full_name='apollo.drivers.velodyne.Config.convert_channel_name', index=19,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='npackets', full_name='apollo.drivers.velodyne.Config.npackets', index=20,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_gps_time', full_name='apollo.drivers.velodyne.Config.use_gps_time', index=21,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_poll_sync', full_name='apollo.drivers.velodyne.Config.use_poll_sync', index=22,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_main_frame', full_name='apollo.drivers.velodyne.Config.is_main_frame', index=23,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=705,
)


_FUSIONCONFIG = _descriptor.Descriptor(
  name='FusionConfig',
  full_name='apollo.drivers.velodyne.FusionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_interval_ms', full_name='apollo.drivers.velodyne.FusionConfig.max_interval_ms', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='drop_expired_data', full_name='apollo.drivers.velodyne.FusionConfig.drop_expired_data', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fusion_channel', full_name='apollo.drivers.velodyne.FusionConfig.fusion_channel', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='input_channel', full_name='apollo.drivers.velodyne.FusionConfig.input_channel', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wait_time_s', full_name='apollo.drivers.velodyne.FusionConfig.wait_time_s', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=842,
)


_COMPENSATORCONFIG = _descriptor.Descriptor(
  name='CompensatorConfig',
  full_name='apollo.drivers.velodyne.CompensatorConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_channel', full_name='apollo.drivers.velodyne.CompensatorConfig.output_channel', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='transform_query_timeout', full_name='apollo.drivers.velodyne.CompensatorConfig.transform_query_timeout', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.02),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='world_frame_id', full_name='apollo.drivers.velodyne.CompensatorConfig.world_frame_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("world").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_frame_id', full_name='apollo.drivers.velodyne.CompensatorConfig.target_frame_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='point_cloud_size', full_name='apollo.drivers.velodyne.CompensatorConfig.point_cloud_size', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=1009,
)

_CONFIG.fields_by_name['model'].enum_type = modules_dot_drivers_dot_velodyne_dot_proto_dot_velodyne__pb2._MODEL
_CONFIG.fields_by_name['mode'].enum_type = modules_dot_drivers_dot_velodyne_dot_proto_dot_velodyne__pb2._MODE
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.message_types_by_name['FusionConfig'] = _FUSIONCONFIG
DESCRIPTOR.message_types_by_name['CompensatorConfig'] = _COMPENSATORCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), dict(
  DESCRIPTOR = _CONFIG,
  __module__ = 'modules.drivers.velodyne.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.velodyne.Config)
  ))
_sym_db.RegisterMessage(Config)

FusionConfig = _reflection.GeneratedProtocolMessageType('FusionConfig', (_message.Message,), dict(
  DESCRIPTOR = _FUSIONCONFIG,
  __module__ = 'modules.drivers.velodyne.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.velodyne.FusionConfig)
  ))
_sym_db.RegisterMessage(FusionConfig)

CompensatorConfig = _reflection.GeneratedProtocolMessageType('CompensatorConfig', (_message.Message,), dict(
  DESCRIPTOR = _COMPENSATORCONFIG,
  __module__ = 'modules.drivers.velodyne.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.velodyne.CompensatorConfig)
  ))
_sym_db.RegisterMessage(CompensatorConfig)


# @@protoc_insertion_point(module_scope)
