# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/transform/proto/static_transform_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/transform/proto/static_transform_conf.proto',
  package='apollo.static_transform',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3modules/transform/proto/static_transform_conf.proto\x12\x17\x61pollo.static_transform\"\\\n\rExtrinsicFile\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63hild_frame_id\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t\x12\x0e\n\x06\x65nable\x18\x04 \x01(\x08\"F\n\x04\x43onf\x12>\n\x0e\x65xtrinsic_file\x18\x01 \x03(\x0b\x32&.apollo.static_transform.ExtrinsicFile'
)




_EXTRINSICFILE = _descriptor.Descriptor(
  name='ExtrinsicFile',
  full_name='apollo.static_transform.ExtrinsicFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.static_transform.ExtrinsicFile.frame_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_frame_id', full_name='apollo.static_transform.ExtrinsicFile.child_frame_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_path', full_name='apollo.static_transform.ExtrinsicFile.file_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.static_transform.ExtrinsicFile.enable', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=172,
)


_CONF = _descriptor.Descriptor(
  name='Conf',
  full_name='apollo.static_transform.Conf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extrinsic_file', full_name='apollo.static_transform.Conf.extrinsic_file', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=244,
)

_CONF.fields_by_name['extrinsic_file'].message_type = _EXTRINSICFILE
DESCRIPTOR.message_types_by_name['ExtrinsicFile'] = _EXTRINSICFILE
DESCRIPTOR.message_types_by_name['Conf'] = _CONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExtrinsicFile = _reflection.GeneratedProtocolMessageType('ExtrinsicFile', (_message.Message,), {
  'DESCRIPTOR' : _EXTRINSICFILE,
  '__module__' : 'modules.transform.proto.static_transform_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.static_transform.ExtrinsicFile)
  })
_sym_db.RegisterMessage(ExtrinsicFile)

Conf = _reflection.GeneratedProtocolMessageType('Conf', (_message.Message,), {
  'DESCRIPTOR' : _CONF,
  '__module__' : 'modules.transform.proto.static_transform_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.static_transform.Conf)
  })
_sym_db.RegisterMessage(Conf)


# @@protoc_insertion_point(module_scope)
