# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/scheduler_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cyber.proto import classic_conf_pb2 as cyber_dot_proto_dot_classic__conf__pb2
from cyber.proto import choreography_conf_pb2 as cyber_dot_proto_dot_choreography__conf__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/scheduler_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n cyber/proto/scheduler_conf.proto\x12\x12\x61pollo.cyber.proto\x1a\x1e\x63yber/proto/classic_conf.proto\x1a#cyber/proto/choreography_conf.proto\"L\n\x0bInnerThread\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x63puset\x18\x02 \x01(\t\x12\x0e\n\x06policy\x18\x03 \x01(\t\x12\x0f\n\x04prio\x18\x04 \x01(\r:\x01\x31\"\x96\x02\n\rSchedulerConf\x12\x0e\n\x06policy\x18\x01 \x01(\t\x12\x13\n\x0broutine_num\x18\x02 \x01(\r\x12\x18\n\x10\x64\x65\x66\x61ult_proc_num\x18\x03 \x01(\r\x12\x1c\n\x14process_level_cpuset\x18\x04 \x01(\t\x12\x30\n\x07threads\x18\x05 \x03(\x0b\x32\x1f.apollo.cyber.proto.InnerThread\x12\x35\n\x0c\x63lassic_conf\x18\x06 \x01(\x0b\x32\x1f.apollo.cyber.proto.ClassicConf\x12?\n\x11\x63horeography_conf\x18\x07 \x01(\x0b\x32$.apollo.cyber.proto.ChoreographyConf'
  ,
  dependencies=[cyber_dot_proto_dot_classic__conf__pb2.DESCRIPTOR,cyber_dot_proto_dot_choreography__conf__pb2.DESCRIPTOR,])




_INNERTHREAD = _descriptor.Descriptor(
  name='InnerThread',
  full_name='apollo.cyber.proto.InnerThread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.InnerThread.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpuset', full_name='apollo.cyber.proto.InnerThread.cpuset', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy', full_name='apollo.cyber.proto.InnerThread.policy', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prio', full_name='apollo.cyber.proto.InnerThread.prio', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=201,
)


_SCHEDULERCONF = _descriptor.Descriptor(
  name='SchedulerConf',
  full_name='apollo.cyber.proto.SchedulerConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='policy', full_name='apollo.cyber.proto.SchedulerConf.policy', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routine_num', full_name='apollo.cyber.proto.SchedulerConf.routine_num', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_proc_num', full_name='apollo.cyber.proto.SchedulerConf.default_proc_num', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_level_cpuset', full_name='apollo.cyber.proto.SchedulerConf.process_level_cpuset', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threads', full_name='apollo.cyber.proto.SchedulerConf.threads', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classic_conf', full_name='apollo.cyber.proto.SchedulerConf.classic_conf', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choreography_conf', full_name='apollo.cyber.proto.SchedulerConf.choreography_conf', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=482,
)

_SCHEDULERCONF.fields_by_name['threads'].message_type = _INNERTHREAD
_SCHEDULERCONF.fields_by_name['classic_conf'].message_type = cyber_dot_proto_dot_classic__conf__pb2._CLASSICCONF
_SCHEDULERCONF.fields_by_name['choreography_conf'].message_type = cyber_dot_proto_dot_choreography__conf__pb2._CHOREOGRAPHYCONF
DESCRIPTOR.message_types_by_name['InnerThread'] = _INNERTHREAD
DESCRIPTOR.message_types_by_name['SchedulerConf'] = _SCHEDULERCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InnerThread = _reflection.GeneratedProtocolMessageType('InnerThread', (_message.Message,), {
  'DESCRIPTOR' : _INNERTHREAD,
  '__module__' : 'cyber.proto.scheduler_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.InnerThread)
  })
_sym_db.RegisterMessage(InnerThread)

SchedulerConf = _reflection.GeneratedProtocolMessageType('SchedulerConf', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULERCONF,
  '__module__' : 'cyber.proto.scheduler_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.SchedulerConf)
  })
_sym_db.RegisterMessage(SchedulerConf)


# @@protoc_insertion_point(module_scope)
