# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/dreamview/proto/preprocess_table.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/dreamview/proto/preprocess_table.proto',
  package='apollo.dreamview',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.modules/dreamview/proto/preprocess_table.proto\x12\x10\x61pollo.dreamview\".\n\x0bTranslation\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"V\n\x0bLidarConfig\x12\x13\n\x0bsensor_name\x18\x01 \x01(\t\x12\x32\n\x0btranslation\x18\x02 \x01(\x0b\x32\x1d.apollo.dreamview.Translation\"X\n\x0c\x43\x61meraConfig\x12\x32\n\x0btranslation\x18\x01 \x01(\x0b\x32\x1d.apollo.dreamview.Translation\x12\t\n\x01\x44\x18\x02 \x03(\x02\x12\t\n\x01K\x18\x03 \x03(\x02\"\\\n\x08Progress\x12\x12\n\npercentage\x18\x01 \x01(\x02\x12\x12\n\nlog_string\x18\x02 \x01(\t\x12(\n\x06status\x18\x03 \x01(\x0e\x32\x18.apollo.dreamview.Status\"\xc0\x01\n\x0fPreprocessTable\x12\x33\n\x0clidar_config\x18\x01 \x03(\x0b\x32\x1d.apollo.dreamview.LidarConfig\x12\x35\n\rcamera_config\x18\x02 \x01(\x0b\x32\x1e.apollo.dreamview.CameraConfig\x12\x13\n\x0bmain_sensor\x18\x03 \x01(\t\x12,\n\x08progress\x18\x04 \x01(\x0b\x32\x1a.apollo.dreamview.Progress*,\n\x06Status\x12\x0b\n\x07SUCCESS\x10\x00\x12\x08\n\x04\x46\x41IL\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02'
)

_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='apollo.dreamview.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=583,
  serialized_end=627,
)
_sym_db.RegisterEnumDescriptor(_STATUS)

Status = enum_type_wrapper.EnumTypeWrapper(_STATUS)
SUCCESS = 0
FAIL = 1
UNKNOWN = 2



_TRANSLATION = _descriptor.Descriptor(
  name='Translation',
  full_name='apollo.dreamview.Translation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.dreamview.Translation.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.dreamview.Translation.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='apollo.dreamview.Translation.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=114,
)


_LIDARCONFIG = _descriptor.Descriptor(
  name='LidarConfig',
  full_name='apollo.dreamview.LidarConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_name', full_name='apollo.dreamview.LidarConfig.sensor_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='translation', full_name='apollo.dreamview.LidarConfig.translation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=202,
)


_CAMERACONFIG = _descriptor.Descriptor(
  name='CameraConfig',
  full_name='apollo.dreamview.CameraConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='translation', full_name='apollo.dreamview.CameraConfig.translation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='D', full_name='apollo.dreamview.CameraConfig.D', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='K', full_name='apollo.dreamview.CameraConfig.K', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=292,
)


_PROGRESS = _descriptor.Descriptor(
  name='Progress',
  full_name='apollo.dreamview.Progress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentage', full_name='apollo.dreamview.Progress.percentage', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_string', full_name='apollo.dreamview.Progress.log_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='apollo.dreamview.Progress.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=386,
)


_PREPROCESSTABLE = _descriptor.Descriptor(
  name='PreprocessTable',
  full_name='apollo.dreamview.PreprocessTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lidar_config', full_name='apollo.dreamview.PreprocessTable.lidar_config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_config', full_name='apollo.dreamview.PreprocessTable.camera_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_sensor', full_name='apollo.dreamview.PreprocessTable.main_sensor', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress', full_name='apollo.dreamview.PreprocessTable.progress', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=581,
)

_LIDARCONFIG.fields_by_name['translation'].message_type = _TRANSLATION
_CAMERACONFIG.fields_by_name['translation'].message_type = _TRANSLATION
_PROGRESS.fields_by_name['status'].enum_type = _STATUS
_PREPROCESSTABLE.fields_by_name['lidar_config'].message_type = _LIDARCONFIG
_PREPROCESSTABLE.fields_by_name['camera_config'].message_type = _CAMERACONFIG
_PREPROCESSTABLE.fields_by_name['progress'].message_type = _PROGRESS
DESCRIPTOR.message_types_by_name['Translation'] = _TRANSLATION
DESCRIPTOR.message_types_by_name['LidarConfig'] = _LIDARCONFIG
DESCRIPTOR.message_types_by_name['CameraConfig'] = _CAMERACONFIG
DESCRIPTOR.message_types_by_name['Progress'] = _PROGRESS
DESCRIPTOR.message_types_by_name['PreprocessTable'] = _PREPROCESSTABLE
DESCRIPTOR.enum_types_by_name['Status'] = _STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Translation = _reflection.GeneratedProtocolMessageType('Translation', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATION,
  '__module__' : 'modules.dreamview.proto.preprocess_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Translation)
  })
_sym_db.RegisterMessage(Translation)

LidarConfig = _reflection.GeneratedProtocolMessageType('LidarConfig', (_message.Message,), {
  'DESCRIPTOR' : _LIDARCONFIG,
  '__module__' : 'modules.dreamview.proto.preprocess_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.LidarConfig)
  })
_sym_db.RegisterMessage(LidarConfig)

CameraConfig = _reflection.GeneratedProtocolMessageType('CameraConfig', (_message.Message,), {
  'DESCRIPTOR' : _CAMERACONFIG,
  '__module__' : 'modules.dreamview.proto.preprocess_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.CameraConfig)
  })
_sym_db.RegisterMessage(CameraConfig)

Progress = _reflection.GeneratedProtocolMessageType('Progress', (_message.Message,), {
  'DESCRIPTOR' : _PROGRESS,
  '__module__' : 'modules.dreamview.proto.preprocess_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Progress)
  })
_sym_db.RegisterMessage(Progress)

PreprocessTable = _reflection.GeneratedProtocolMessageType('PreprocessTable', (_message.Message,), {
  'DESCRIPTOR' : _PREPROCESSTABLE,
  '__module__' : 'modules.dreamview.proto.preprocess_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.PreprocessTable)
  })
_sym_db.RegisterMessage(PreprocessTable)


# @@protoc_insertion_point(module_scope)
