# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/prediction/proto/network_layers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/prediction/proto/network_layers.proto',
  package='apollo.prediction',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-modules/prediction/proto/network_layers.proto\x12\x11\x61pollo.prediction\"2\n\x0fTensorParameter\x12\x10\n\x04\x64\x61ta\x18\x01 \x03(\x02\x42\x02\x10\x01\x12\r\n\x05shape\x18\x02 \x03(\x05\"D\n\x0eInputParameter\x12\x13\n\x0binput_shape\x18\x01 \x03(\x05\x12\r\n\x05\x64type\x18\x02 \x01(\t\x12\x0e\n\x06sparse\x18\x03 \x01(\x08\"\xac\x01\n\x0e\x44\x65nseParameter\x12\r\n\x05units\x18\x01 \x01(\x05\x12\x12\n\nactivation\x18\x02 \x01(\t\x12\x10\n\x08use_bias\x18\x03 \x01(\x08\x12\x33\n\x07weights\x18\x04 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x30\n\x04\x62ias\x18\x05 \x01(\x0b\x32\".apollo.prediction.TensorParameter\"\xa8\x01\n\x0f\x43onv1dParameter\x12\r\n\x05shape\x18\x01 \x03(\x05\x12\x10\n\x08use_bias\x18\x02 \x01(\x08\x12\x32\n\x06kernel\x18\x03 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x30\n\x04\x62ias\x18\x04 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x0e\n\x06stride\x18\x05 \x01(\x05\"9\n\x12MaxPool1dParameter\x12\x13\n\x0bkernel_size\x18\x01 \x01(\x05\x12\x0e\n\x06stride\x18\x02 \x01(\x05\"9\n\x12\x41vgPool1dParameter\x12\x13\n\x0bkernel_size\x18\x01 \x01(\x05\x12\x0e\n\x06stride\x18\x02 \x01(\x05\"\xbc\x02\n\x1b\x42\x61tchNormalizationParameter\x12\x16\n\x07\x65psilon\x18\x01 \x01(\x01:\x05\x31\x65-05\x12\x0c\n\x04\x61xis\x18\x02 \x01(\x05\x12\x0e\n\x06\x63\x65nter\x18\x03 \x01(\x08\x12\r\n\x05scale\x18\x04 \x01(\x08\x12\x10\n\x08momentum\x18\x05 \x01(\x02\x12.\n\x02mu\x18\x06 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x31\n\x05sigma\x18\x07 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x31\n\x05gamma\x18\x08 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x30\n\x04\x62\x65ta\x18\t \x01(\x0b\x32\".apollo.prediction.TensorParameter\"\xe0\x07\n\rLSTMParameter\x12\r\n\x05units\x18\x01 \x01(\x05\x12\x18\n\x10return_sequences\x18\x02 \x01(\x08\x12\x10\n\x08stateful\x18\x03 \x01(\x08\x12\x12\n\nactivation\x18\x04 \x01(\t\x12\x1c\n\x14recurrent_activation\x18\x05 \x01(\t\x12\x10\n\x08use_bias\x18\x06 \x01(\x08\x12\x1e\n\x10unit_forget_bias\x18\x07 \x01(\x08:\x04true\x12\x1b\n\x0cgo_backwards\x18\x08 \x01(\x08:\x05\x66\x61lse\x12\x15\n\x06unroll\x18\t \x01(\x08:\x05\x66\x61lse\x12\x19\n\x0eimplementation\x18\n \x01(\x05:\x01\x30\x12\x39\n\rweights_input\x18\x0f \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12:\n\x0eweights_forget\x18\x10 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x38\n\x0cweights_cell\x18\x11 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12:\n\x0eweights_output\x18\x12 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x36\n\nbias_input\x18\x13 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x37\n\x0b\x62ias_forget\x18\x14 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x35\n\tbias_cell\x18\x15 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x37\n\x0b\x62ias_output\x18\x16 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x43\n\x17recurrent_weights_input\x18\x19 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x44\n\x18recurrent_weights_forget\x18\x1a \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x42\n\x16recurrent_weights_cell\x18\x1b \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x44\n\x18recurrent_weights_output\x18\x1c \x01(\x0b\x32\".apollo.prediction.TensorParameter\")\n\x13\x41\x63tivationParameter\x12\x12\n\nactivation\x18\x01 \x01(\t\"\x12\n\x10\x46lattenParameter\"$\n\x14\x43oncatenateParameter\x12\x0c\n\x04\x61xis\x18\x01 \x01(\x05\"\x9f\x05\n\x0eLayerParameter\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0corder_number\x18\x03 \x01(\x05\x12\x32\n\x05input\x18\x04 \x01(\x0b\x32!.apollo.prediction.InputParameterH\x00\x12<\n\nactivation\x18\x05 \x01(\x0b\x32&.apollo.prediction.ActivationParameterH\x00\x12\x32\n\x05\x64\x65nse\x18\x06 \x01(\x0b\x32!.apollo.prediction.DenseParameterH\x00\x12M\n\x13\x62\x61tch_normalization\x18\x07 \x01(\x0b\x32..apollo.prediction.BatchNormalizationParameterH\x00\x12\x30\n\x04lstm\x18\x08 \x01(\x0b\x32 .apollo.prediction.LSTMParameterH\x00\x12\x36\n\x07\x66latten\x18\t \x01(\x0b\x32#.apollo.prediction.FlattenParameterH\x00\x12>\n\x0b\x63oncatenate\x18\n \x01(\x0b\x32\'.apollo.prediction.ConcatenateParameterH\x00\x12\x34\n\x06\x63onv1d\x18\x0b \x01(\x0b\x32\".apollo.prediction.Conv1dParameterH\x00\x12:\n\tmaxpool1d\x18\x0c \x01(\x0b\x32%.apollo.prediction.MaxPool1dParameterH\x00\x12:\n\tavgpool1d\x18\r \x01(\x0b\x32%.apollo.prediction.AvgPool1dParameterH\x00\x42\x0e\n\x0coneof_layers'
)




_TENSORPARAMETER = _descriptor.Descriptor(
  name='TensorParameter',
  full_name='apollo.prediction.TensorParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='apollo.prediction.TensorParameter.data', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='apollo.prediction.TensorParameter.shape', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=118,
)


_INPUTPARAMETER = _descriptor.Descriptor(
  name='InputParameter',
  full_name='apollo.prediction.InputParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_shape', full_name='apollo.prediction.InputParameter.input_shape', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dtype', full_name='apollo.prediction.InputParameter.dtype', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sparse', full_name='apollo.prediction.InputParameter.sparse', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=188,
)


_DENSEPARAMETER = _descriptor.Descriptor(
  name='DenseParameter',
  full_name='apollo.prediction.DenseParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='units', full_name='apollo.prediction.DenseParameter.units', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation', full_name='apollo.prediction.DenseParameter.activation', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_bias', full_name='apollo.prediction.DenseParameter.use_bias', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights', full_name='apollo.prediction.DenseParameter.weights', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias', full_name='apollo.prediction.DenseParameter.bias', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=363,
)


_CONV1DPARAMETER = _descriptor.Descriptor(
  name='Conv1dParameter',
  full_name='apollo.prediction.Conv1dParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shape', full_name='apollo.prediction.Conv1dParameter.shape', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_bias', full_name='apollo.prediction.Conv1dParameter.use_bias', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kernel', full_name='apollo.prediction.Conv1dParameter.kernel', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias', full_name='apollo.prediction.Conv1dParameter.bias', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stride', full_name='apollo.prediction.Conv1dParameter.stride', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=534,
)


_MAXPOOL1DPARAMETER = _descriptor.Descriptor(
  name='MaxPool1dParameter',
  full_name='apollo.prediction.MaxPool1dParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kernel_size', full_name='apollo.prediction.MaxPool1dParameter.kernel_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stride', full_name='apollo.prediction.MaxPool1dParameter.stride', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=593,
)


_AVGPOOL1DPARAMETER = _descriptor.Descriptor(
  name='AvgPool1dParameter',
  full_name='apollo.prediction.AvgPool1dParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kernel_size', full_name='apollo.prediction.AvgPool1dParameter.kernel_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stride', full_name='apollo.prediction.AvgPool1dParameter.stride', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=652,
)


_BATCHNORMALIZATIONPARAMETER = _descriptor.Descriptor(
  name='BatchNormalizationParameter',
  full_name='apollo.prediction.BatchNormalizationParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='epsilon', full_name='apollo.prediction.BatchNormalizationParameter.epsilon', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1e-05),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='apollo.prediction.BatchNormalizationParameter.axis', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center', full_name='apollo.prediction.BatchNormalizationParameter.center', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale', full_name='apollo.prediction.BatchNormalizationParameter.scale', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='momentum', full_name='apollo.prediction.BatchNormalizationParameter.momentum', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mu', full_name='apollo.prediction.BatchNormalizationParameter.mu', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sigma', full_name='apollo.prediction.BatchNormalizationParameter.sigma', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gamma', full_name='apollo.prediction.BatchNormalizationParameter.gamma', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beta', full_name='apollo.prediction.BatchNormalizationParameter.beta', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=655,
  serialized_end=971,
)


_LSTMPARAMETER = _descriptor.Descriptor(
  name='LSTMParameter',
  full_name='apollo.prediction.LSTMParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='units', full_name='apollo.prediction.LSTMParameter.units', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_sequences', full_name='apollo.prediction.LSTMParameter.return_sequences', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stateful', full_name='apollo.prediction.LSTMParameter.stateful', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation', full_name='apollo.prediction.LSTMParameter.activation', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recurrent_activation', full_name='apollo.prediction.LSTMParameter.recurrent_activation', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_bias', full_name='apollo.prediction.LSTMParameter.use_bias', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_forget_bias', full_name='apollo.prediction.LSTMParameter.unit_forget_bias', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='go_backwards', full_name='apollo.prediction.LSTMParameter.go_backwards', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unroll', full_name='apollo.prediction.LSTMParameter.unroll', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='implementation', full_name='apollo.prediction.LSTMParameter.implementation', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights_input', full_name='apollo.prediction.LSTMParameter.weights_input', index=10,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights_forget', full_name='apollo.prediction.LSTMParameter.weights_forget', index=11,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights_cell', full_name='apollo.prediction.LSTMParameter.weights_cell', index=12,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights_output', full_name='apollo.prediction.LSTMParameter.weights_output', index=13,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias_input', full_name='apollo.prediction.LSTMParameter.bias_input', index=14,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias_forget', full_name='apollo.prediction.LSTMParameter.bias_forget', index=15,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias_cell', full_name='apollo.prediction.LSTMParameter.bias_cell', index=16,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias_output', full_name='apollo.prediction.LSTMParameter.bias_output', index=17,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recurrent_weights_input', full_name='apollo.prediction.LSTMParameter.recurrent_weights_input', index=18,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recurrent_weights_forget', full_name='apollo.prediction.LSTMParameter.recurrent_weights_forget', index=19,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recurrent_weights_cell', full_name='apollo.prediction.LSTMParameter.recurrent_weights_cell', index=20,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recurrent_weights_output', full_name='apollo.prediction.LSTMParameter.recurrent_weights_output', index=21,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=974,
  serialized_end=1966,
)


_ACTIVATIONPARAMETER = _descriptor.Descriptor(
  name='ActivationParameter',
  full_name='apollo.prediction.ActivationParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='activation', full_name='apollo.prediction.ActivationParameter.activation', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1968,
  serialized_end=2009,
)


_FLATTENPARAMETER = _descriptor.Descriptor(
  name='FlattenParameter',
  full_name='apollo.prediction.FlattenParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2011,
  serialized_end=2029,
)


_CONCATENATEPARAMETER = _descriptor.Descriptor(
  name='ConcatenateParameter',
  full_name='apollo.prediction.ConcatenateParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='axis', full_name='apollo.prediction.ConcatenateParameter.axis', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2031,
  serialized_end=2067,
)


_LAYERPARAMETER = _descriptor.Descriptor(
  name='LayerParameter',
  full_name='apollo.prediction.LayerParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.prediction.LayerParameter.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.prediction.LayerParameter.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_number', full_name='apollo.prediction.LayerParameter.order_number', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input', full_name='apollo.prediction.LayerParameter.input', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation', full_name='apollo.prediction.LayerParameter.activation', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dense', full_name='apollo.prediction.LayerParameter.dense', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_normalization', full_name='apollo.prediction.LayerParameter.batch_normalization', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lstm', full_name='apollo.prediction.LayerParameter.lstm', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flatten', full_name='apollo.prediction.LayerParameter.flatten', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='concatenate', full_name='apollo.prediction.LayerParameter.concatenate', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conv1d', full_name='apollo.prediction.LayerParameter.conv1d', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxpool1d', full_name='apollo.prediction.LayerParameter.maxpool1d', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avgpool1d', full_name='apollo.prediction.LayerParameter.avgpool1d', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_layers', full_name='apollo.prediction.LayerParameter.oneof_layers',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2070,
  serialized_end=2741,
)

_DENSEPARAMETER.fields_by_name['weights'].message_type = _TENSORPARAMETER
_DENSEPARAMETER.fields_by_name['bias'].message_type = _TENSORPARAMETER
_CONV1DPARAMETER.fields_by_name['kernel'].message_type = _TENSORPARAMETER
_CONV1DPARAMETER.fields_by_name['bias'].message_type = _TENSORPARAMETER
_BATCHNORMALIZATIONPARAMETER.fields_by_name['mu'].message_type = _TENSORPARAMETER
_BATCHNORMALIZATIONPARAMETER.fields_by_name['sigma'].message_type = _TENSORPARAMETER
_BATCHNORMALIZATIONPARAMETER.fields_by_name['gamma'].message_type = _TENSORPARAMETER
_BATCHNORMALIZATIONPARAMETER.fields_by_name['beta'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['weights_input'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['weights_forget'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['weights_cell'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['weights_output'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['bias_input'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['bias_forget'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['bias_cell'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['bias_output'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['recurrent_weights_input'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['recurrent_weights_forget'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['recurrent_weights_cell'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['recurrent_weights_output'].message_type = _TENSORPARAMETER
_LAYERPARAMETER.fields_by_name['input'].message_type = _INPUTPARAMETER
_LAYERPARAMETER.fields_by_name['activation'].message_type = _ACTIVATIONPARAMETER
_LAYERPARAMETER.fields_by_name['dense'].message_type = _DENSEPARAMETER
_LAYERPARAMETER.fields_by_name['batch_normalization'].message_type = _BATCHNORMALIZATIONPARAMETER
_LAYERPARAMETER.fields_by_name['lstm'].message_type = _LSTMPARAMETER
_LAYERPARAMETER.fields_by_name['flatten'].message_type = _FLATTENPARAMETER
_LAYERPARAMETER.fields_by_name['concatenate'].message_type = _CONCATENATEPARAMETER
_LAYERPARAMETER.fields_by_name['conv1d'].message_type = _CONV1DPARAMETER
_LAYERPARAMETER.fields_by_name['maxpool1d'].message_type = _MAXPOOL1DPARAMETER
_LAYERPARAMETER.fields_by_name['avgpool1d'].message_type = _AVGPOOL1DPARAMETER
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['input'])
_LAYERPARAMETER.fields_by_name['input'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['activation'])
_LAYERPARAMETER.fields_by_name['activation'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['dense'])
_LAYERPARAMETER.fields_by_name['dense'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['batch_normalization'])
_LAYERPARAMETER.fields_by_name['batch_normalization'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['lstm'])
_LAYERPARAMETER.fields_by_name['lstm'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['flatten'])
_LAYERPARAMETER.fields_by_name['flatten'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['concatenate'])
_LAYERPARAMETER.fields_by_name['concatenate'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['conv1d'])
_LAYERPARAMETER.fields_by_name['conv1d'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['maxpool1d'])
_LAYERPARAMETER.fields_by_name['maxpool1d'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['avgpool1d'])
_LAYERPARAMETER.fields_by_name['avgpool1d'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
DESCRIPTOR.message_types_by_name['TensorParameter'] = _TENSORPARAMETER
DESCRIPTOR.message_types_by_name['InputParameter'] = _INPUTPARAMETER
DESCRIPTOR.message_types_by_name['DenseParameter'] = _DENSEPARAMETER
DESCRIPTOR.message_types_by_name['Conv1dParameter'] = _CONV1DPARAMETER
DESCRIPTOR.message_types_by_name['MaxPool1dParameter'] = _MAXPOOL1DPARAMETER
DESCRIPTOR.message_types_by_name['AvgPool1dParameter'] = _AVGPOOL1DPARAMETER
DESCRIPTOR.message_types_by_name['BatchNormalizationParameter'] = _BATCHNORMALIZATIONPARAMETER
DESCRIPTOR.message_types_by_name['LSTMParameter'] = _LSTMPARAMETER
DESCRIPTOR.message_types_by_name['ActivationParameter'] = _ACTIVATIONPARAMETER
DESCRIPTOR.message_types_by_name['FlattenParameter'] = _FLATTENPARAMETER
DESCRIPTOR.message_types_by_name['ConcatenateParameter'] = _CONCATENATEPARAMETER
DESCRIPTOR.message_types_by_name['LayerParameter'] = _LAYERPARAMETER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TensorParameter = _reflection.GeneratedProtocolMessageType('TensorParameter', (_message.Message,), {
  'DESCRIPTOR' : _TENSORPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.TensorParameter)
  })
_sym_db.RegisterMessage(TensorParameter)

InputParameter = _reflection.GeneratedProtocolMessageType('InputParameter', (_message.Message,), {
  'DESCRIPTOR' : _INPUTPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.InputParameter)
  })
_sym_db.RegisterMessage(InputParameter)

DenseParameter = _reflection.GeneratedProtocolMessageType('DenseParameter', (_message.Message,), {
  'DESCRIPTOR' : _DENSEPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.DenseParameter)
  })
_sym_db.RegisterMessage(DenseParameter)

Conv1dParameter = _reflection.GeneratedProtocolMessageType('Conv1dParameter', (_message.Message,), {
  'DESCRIPTOR' : _CONV1DPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Conv1dParameter)
  })
_sym_db.RegisterMessage(Conv1dParameter)

MaxPool1dParameter = _reflection.GeneratedProtocolMessageType('MaxPool1dParameter', (_message.Message,), {
  'DESCRIPTOR' : _MAXPOOL1DPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.MaxPool1dParameter)
  })
_sym_db.RegisterMessage(MaxPool1dParameter)

AvgPool1dParameter = _reflection.GeneratedProtocolMessageType('AvgPool1dParameter', (_message.Message,), {
  'DESCRIPTOR' : _AVGPOOL1DPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.AvgPool1dParameter)
  })
_sym_db.RegisterMessage(AvgPool1dParameter)

BatchNormalizationParameter = _reflection.GeneratedProtocolMessageType('BatchNormalizationParameter', (_message.Message,), {
  'DESCRIPTOR' : _BATCHNORMALIZATIONPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.BatchNormalizationParameter)
  })
_sym_db.RegisterMessage(BatchNormalizationParameter)

LSTMParameter = _reflection.GeneratedProtocolMessageType('LSTMParameter', (_message.Message,), {
  'DESCRIPTOR' : _LSTMPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.LSTMParameter)
  })
_sym_db.RegisterMessage(LSTMParameter)

ActivationParameter = _reflection.GeneratedProtocolMessageType('ActivationParameter', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATIONPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ActivationParameter)
  })
_sym_db.RegisterMessage(ActivationParameter)

FlattenParameter = _reflection.GeneratedProtocolMessageType('FlattenParameter', (_message.Message,), {
  'DESCRIPTOR' : _FLATTENPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.FlattenParameter)
  })
_sym_db.RegisterMessage(FlattenParameter)

ConcatenateParameter = _reflection.GeneratedProtocolMessageType('ConcatenateParameter', (_message.Message,), {
  'DESCRIPTOR' : _CONCATENATEPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ConcatenateParameter)
  })
_sym_db.RegisterMessage(ConcatenateParameter)

LayerParameter = _reflection.GeneratedProtocolMessageType('LayerParameter', (_message.Message,), {
  'DESCRIPTOR' : _LAYERPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.LayerParameter)
  })
_sym_db.RegisterMessage(LayerParameter)


_TENSORPARAMETER.fields_by_name['data']._options = None
# @@protoc_insertion_point(module_scope)
