# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/reference_line_smoother_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.planning.proto.math import cos_theta_smoother_config_pb2 as modules_dot_planning_dot_proto_dot_math_dot_cos__theta__smoother__config__pb2
from modules.planning.proto.math import fem_pos_deviation_smoother_config_pb2 as modules_dot_planning_dot_proto_dot_math_dot_fem__pos__deviation__smoother__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/reference_line_smoother_config.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;modules/planning/proto/reference_line_smoother_config.proto\x12\x0f\x61pollo.planning\x1a;modules/planning/proto/math/cos_theta_smoother_config.proto\x1a\x43modules/planning/proto/math/fem_pos_deviation_smoother_config.proto\"\xbf\x01\n\x16QpSplineSmootherConfig\x12\x17\n\x0cspline_order\x18\x01 \x01(\r:\x01\x35\x12\x1d\n\x11max_spline_length\x18\x02 \x01(\x01:\x02\x32\x35\x12\"\n\x15regularization_weight\x18\x03 \x01(\x01:\x03\x30.1\x12#\n\x18second_derivative_weight\x18\x04 \x01(\x01:\x01\x30\x12$\n\x17third_derivative_weight\x18\x05 \x01(\x01:\x03\x31\x30\x30\"\xa3\x02\n\x14SpiralSmootherConfig\x12\x1a\n\rmax_deviation\x18\x01 \x01(\x01:\x03\x30.1\x12\x1c\n\x10piecewise_length\x18\x02 \x01(\x01:\x02\x31\x30\x12\x1b\n\rmax_iteration\x18\x03 \x01(\r:\x04\x31\x30\x30\x30\x12\x16\n\x07opt_tol\x18\x04 \x01(\x01:\x05\x31\x65-08\x12!\n\x12opt_acceptable_tol\x18\x05 \x01(\x01:\x05\x31\x65-06\x12$\n\x18opt_acceptable_iteration\x18\x06 \x01(\r:\x02\x31\x35\x12\x1e\n\x13weight_curve_length\x18\x07 \x01(\x01:\x01\x31\x12\x17\n\x0cweight_kappa\x18\x08 \x01(\x01:\x01\x31\x12\x1a\n\rweight_dkappa\x18\t \x01(\x01:\x03\x31\x30\x30\"\xa3\x03\n\x1c\x44iscretePointsSmootherConfig\x12t\n\x10smoothing_method\x18\x03 \x01(\x0e\x32=.apollo.planning.DiscretePointsSmootherConfig.SmoothingMethod:\x1b\x46\x45M_POS_DEVIATION_SMOOTHING\x12\x46\n\x13\x63os_theta_smoothing\x18\x04 \x01(\x0b\x32\'.apollo.planning.CosThetaSmootherConfigH\x00\x12U\n\x1b\x66\x65m_pos_deviation_smoothing\x18\x05 \x01(\x0b\x32..apollo.planning.FemPosDeviationSmootherConfigH\x00\"\\\n\x0fSmoothingMethod\x12\x0f\n\x0bNOT_DEFINED\x10\x00\x12\x17\n\x13\x43OS_THETA_SMOOTHING\x10\x01\x12\x1f\n\x1b\x46\x45M_POS_DEVIATION_SMOOTHING\x10\x02\x42\x10\n\x0eSmootherConfig\"\x80\x04\n\x1bReferenceLineSmootherConfig\x12\"\n\x17max_constraint_interval\x18\x01 \x01(\x01:\x01\x35\x12&\n\x1blongitudinal_boundary_bound\x18\x02 \x01(\x01:\x01\x31\x12\'\n\x1amax_lateral_boundary_bound\x18\x03 \x01(\x01:\x03\x30.5\x12\'\n\x1amin_lateral_boundary_bound\x18\x04 \x01(\x01:\x03\x30.2\x12 \n\x13num_of_total_points\x18\x05 \x01(\r:\x03\x35\x30\x30\x12\x17\n\ncurb_shift\x18\x06 \x01(\x01:\x03\x30.2\x12\x1b\n\x0elateral_buffer\x18\x07 \x01(\x01:\x03\x30.2\x12\x18\n\nresolution\x18\x08 \x01(\x01:\x04\x30.02\x12<\n\tqp_spline\x18\x14 \x01(\x0b\x32\'.apollo.planning.QpSplineSmootherConfigH\x00\x12\x37\n\x06spiral\x18\x15 \x01(\x0b\x32%.apollo.planning.SpiralSmootherConfigH\x00\x12H\n\x0f\x64iscrete_points\x18\x16 \x01(\x0b\x32-.apollo.planning.DiscretePointsSmootherConfigH\x00\x42\x10\n\x0eSmootherConfig'
  ,
  dependencies=[modules_dot_planning_dot_proto_dot_math_dot_cos__theta__smoother__config__pb2.DESCRIPTOR,modules_dot_planning_dot_proto_dot_math_dot_fem__pos__deviation__smoother__config__pb2.DESCRIPTOR,])



_DISCRETEPOINTSSMOOTHERCONFIG_SMOOTHINGMETHOD = _descriptor.EnumDescriptor(
  name='SmoothingMethod',
  full_name='apollo.planning.DiscretePointsSmootherConfig.SmoothingMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_DEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COS_THETA_SMOOTHING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEM_POS_DEVIATION_SMOOTHING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1008,
  serialized_end=1100,
)
_sym_db.RegisterEnumDescriptor(_DISCRETEPOINTSSMOOTHERCONFIG_SMOOTHINGMETHOD)


_QPSPLINESMOOTHERCONFIG = _descriptor.Descriptor(
  name='QpSplineSmootherConfig',
  full_name='apollo.planning.QpSplineSmootherConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spline_order', full_name='apollo.planning.QpSplineSmootherConfig.spline_order', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=5,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_spline_length', full_name='apollo.planning.QpSplineSmootherConfig.max_spline_length', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(25),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regularization_weight', full_name='apollo.planning.QpSplineSmootherConfig.regularization_weight', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second_derivative_weight', full_name='apollo.planning.QpSplineSmootherConfig.second_derivative_weight', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='third_derivative_weight', full_name='apollo.planning.QpSplineSmootherConfig.third_derivative_weight', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(100),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=402,
)


_SPIRALSMOOTHERCONFIG = _descriptor.Descriptor(
  name='SpiralSmootherConfig',
  full_name='apollo.planning.SpiralSmootherConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_deviation', full_name='apollo.planning.SpiralSmootherConfig.max_deviation', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='piecewise_length', full_name='apollo.planning.SpiralSmootherConfig.piecewise_length', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_iteration', full_name='apollo.planning.SpiralSmootherConfig.max_iteration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opt_tol', full_name='apollo.planning.SpiralSmootherConfig.opt_tol', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1e-08),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opt_acceptable_tol', full_name='apollo.planning.SpiralSmootherConfig.opt_acceptable_tol', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1e-06),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opt_acceptable_iteration', full_name='apollo.planning.SpiralSmootherConfig.opt_acceptable_iteration', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=15,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_curve_length', full_name='apollo.planning.SpiralSmootherConfig.weight_curve_length', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_kappa', full_name='apollo.planning.SpiralSmootherConfig.weight_kappa', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_dkappa', full_name='apollo.planning.SpiralSmootherConfig.weight_dkappa', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(100),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=405,
  serialized_end=696,
)


_DISCRETEPOINTSSMOOTHERCONFIG = _descriptor.Descriptor(
  name='DiscretePointsSmootherConfig',
  full_name='apollo.planning.DiscretePointsSmootherConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='smoothing_method', full_name='apollo.planning.DiscretePointsSmootherConfig.smoothing_method', index=0,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cos_theta_smoothing', full_name='apollo.planning.DiscretePointsSmootherConfig.cos_theta_smoothing', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fem_pos_deviation_smoothing', full_name='apollo.planning.DiscretePointsSmootherConfig.fem_pos_deviation_smoothing', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DISCRETEPOINTSSMOOTHERCONFIG_SMOOTHINGMETHOD,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='SmootherConfig', full_name='apollo.planning.DiscretePointsSmootherConfig.SmootherConfig',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=699,
  serialized_end=1118,
)


_REFERENCELINESMOOTHERCONFIG = _descriptor.Descriptor(
  name='ReferenceLineSmootherConfig',
  full_name='apollo.planning.ReferenceLineSmootherConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_constraint_interval', full_name='apollo.planning.ReferenceLineSmootherConfig.max_constraint_interval', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitudinal_boundary_bound', full_name='apollo.planning.ReferenceLineSmootherConfig.longitudinal_boundary_bound', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_lateral_boundary_bound', full_name='apollo.planning.ReferenceLineSmootherConfig.max_lateral_boundary_bound', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_lateral_boundary_bound', full_name='apollo.planning.ReferenceLineSmootherConfig.min_lateral_boundary_bound', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_of_total_points', full_name='apollo.planning.ReferenceLineSmootherConfig.num_of_total_points', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=500,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curb_shift', full_name='apollo.planning.ReferenceLineSmootherConfig.curb_shift', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_buffer', full_name='apollo.planning.ReferenceLineSmootherConfig.lateral_buffer', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolution', full_name='apollo.planning.ReferenceLineSmootherConfig.resolution', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.02),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qp_spline', full_name='apollo.planning.ReferenceLineSmootherConfig.qp_spline', index=8,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spiral', full_name='apollo.planning.ReferenceLineSmootherConfig.spiral', index=9,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discrete_points', full_name='apollo.planning.ReferenceLineSmootherConfig.discrete_points', index=10,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='SmootherConfig', full_name='apollo.planning.ReferenceLineSmootherConfig.SmootherConfig',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1121,
  serialized_end=1633,
)

_DISCRETEPOINTSSMOOTHERCONFIG.fields_by_name['smoothing_method'].enum_type = _DISCRETEPOINTSSMOOTHERCONFIG_SMOOTHINGMETHOD
_DISCRETEPOINTSSMOOTHERCONFIG.fields_by_name['cos_theta_smoothing'].message_type = modules_dot_planning_dot_proto_dot_math_dot_cos__theta__smoother__config__pb2._COSTHETASMOOTHERCONFIG
_DISCRETEPOINTSSMOOTHERCONFIG.fields_by_name['fem_pos_deviation_smoothing'].message_type = modules_dot_planning_dot_proto_dot_math_dot_fem__pos__deviation__smoother__config__pb2._FEMPOSDEVIATIONSMOOTHERCONFIG
_DISCRETEPOINTSSMOOTHERCONFIG_SMOOTHINGMETHOD.containing_type = _DISCRETEPOINTSSMOOTHERCONFIG
_DISCRETEPOINTSSMOOTHERCONFIG.oneofs_by_name['SmootherConfig'].fields.append(
  _DISCRETEPOINTSSMOOTHERCONFIG.fields_by_name['cos_theta_smoothing'])
_DISCRETEPOINTSSMOOTHERCONFIG.fields_by_name['cos_theta_smoothing'].containing_oneof = _DISCRETEPOINTSSMOOTHERCONFIG.oneofs_by_name['SmootherConfig']
_DISCRETEPOINTSSMOOTHERCONFIG.oneofs_by_name['SmootherConfig'].fields.append(
  _DISCRETEPOINTSSMOOTHERCONFIG.fields_by_name['fem_pos_deviation_smoothing'])
_DISCRETEPOINTSSMOOTHERCONFIG.fields_by_name['fem_pos_deviation_smoothing'].containing_oneof = _DISCRETEPOINTSSMOOTHERCONFIG.oneofs_by_name['SmootherConfig']
_REFERENCELINESMOOTHERCONFIG.fields_by_name['qp_spline'].message_type = _QPSPLINESMOOTHERCONFIG
_REFERENCELINESMOOTHERCONFIG.fields_by_name['spiral'].message_type = _SPIRALSMOOTHERCONFIG
_REFERENCELINESMOOTHERCONFIG.fields_by_name['discrete_points'].message_type = _DISCRETEPOINTSSMOOTHERCONFIG
_REFERENCELINESMOOTHERCONFIG.oneofs_by_name['SmootherConfig'].fields.append(
  _REFERENCELINESMOOTHERCONFIG.fields_by_name['qp_spline'])
_REFERENCELINESMOOTHERCONFIG.fields_by_name['qp_spline'].containing_oneof = _REFERENCELINESMOOTHERCONFIG.oneofs_by_name['SmootherConfig']
_REFERENCELINESMOOTHERCONFIG.oneofs_by_name['SmootherConfig'].fields.append(
  _REFERENCELINESMOOTHERCONFIG.fields_by_name['spiral'])
_REFERENCELINESMOOTHERCONFIG.fields_by_name['spiral'].containing_oneof = _REFERENCELINESMOOTHERCONFIG.oneofs_by_name['SmootherConfig']
_REFERENCELINESMOOTHERCONFIG.oneofs_by_name['SmootherConfig'].fields.append(
  _REFERENCELINESMOOTHERCONFIG.fields_by_name['discrete_points'])
_REFERENCELINESMOOTHERCONFIG.fields_by_name['discrete_points'].containing_oneof = _REFERENCELINESMOOTHERCONFIG.oneofs_by_name['SmootherConfig']
DESCRIPTOR.message_types_by_name['QpSplineSmootherConfig'] = _QPSPLINESMOOTHERCONFIG
DESCRIPTOR.message_types_by_name['SpiralSmootherConfig'] = _SPIRALSMOOTHERCONFIG
DESCRIPTOR.message_types_by_name['DiscretePointsSmootherConfig'] = _DISCRETEPOINTSSMOOTHERCONFIG
DESCRIPTOR.message_types_by_name['ReferenceLineSmootherConfig'] = _REFERENCELINESMOOTHERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QpSplineSmootherConfig = _reflection.GeneratedProtocolMessageType('QpSplineSmootherConfig', (_message.Message,), {
  'DESCRIPTOR' : _QPSPLINESMOOTHERCONFIG,
  '__module__' : 'modules.planning.proto.reference_line_smoother_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.QpSplineSmootherConfig)
  })
_sym_db.RegisterMessage(QpSplineSmootherConfig)

SpiralSmootherConfig = _reflection.GeneratedProtocolMessageType('SpiralSmootherConfig', (_message.Message,), {
  'DESCRIPTOR' : _SPIRALSMOOTHERCONFIG,
  '__module__' : 'modules.planning.proto.reference_line_smoother_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.SpiralSmootherConfig)
  })
_sym_db.RegisterMessage(SpiralSmootherConfig)

DiscretePointsSmootherConfig = _reflection.GeneratedProtocolMessageType('DiscretePointsSmootherConfig', (_message.Message,), {
  'DESCRIPTOR' : _DISCRETEPOINTSSMOOTHERCONFIG,
  '__module__' : 'modules.planning.proto.reference_line_smoother_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.DiscretePointsSmootherConfig)
  })
_sym_db.RegisterMessage(DiscretePointsSmootherConfig)

ReferenceLineSmootherConfig = _reflection.GeneratedProtocolMessageType('ReferenceLineSmootherConfig', (_message.Message,), {
  'DESCRIPTOR' : _REFERENCELINESMOOTHERCONFIG,
  '__module__' : 'modules.planning.proto.reference_line_smoother_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ReferenceLineSmootherConfig)
  })
_sym_db.RegisterMessage(ReferenceLineSmootherConfig)


# @@protoc_insertion_point(module_scope)
