# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/onboard/proto/fusion_component_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/onboard/proto/fusion_component_config.proto',
  package='apollo.perception.onboard',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n>modules/perception/onboard/proto/fusion_component_config.proto\x12\x19\x61pollo.perception.onboard\"\xb0\x02\n\x15\x46usionComponentConfig\x12\x15\n\rfusion_method\x18\x01 \x01(\t\x12\x1b\n\x13\x66usion_main_sensors\x18\x02 \x03(\t\x12\x1b\n\x13object_in_roi_check\x18\x03 \x01(\x08\x12#\n\x1bradius_for_roi_object_check\x18\x04 \x01(\x01\x12\x44\n\x1doutput_obstacles_channel_name\x18\x05 \x01(\t:\x1d/perception/vehicle/obstacles\x12[\n%output_viz_fused_content_channel_name\x18\x06 \x01(\t:,/perception/inner/visualization/FusedObjects'
)




_FUSIONCOMPONENTCONFIG = _descriptor.Descriptor(
  name='FusionComponentConfig',
  full_name='apollo.perception.onboard.FusionComponentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fusion_method', full_name='apollo.perception.onboard.FusionComponentConfig.fusion_method', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fusion_main_sensors', full_name='apollo.perception.onboard.FusionComponentConfig.fusion_main_sensors', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_in_roi_check', full_name='apollo.perception.onboard.FusionComponentConfig.object_in_roi_check', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius_for_roi_object_check', full_name='apollo.perception.onboard.FusionComponentConfig.radius_for_roi_object_check', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_obstacles_channel_name', full_name='apollo.perception.onboard.FusionComponentConfig.output_obstacles_channel_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/perception/vehicle/obstacles".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_viz_fused_content_channel_name', full_name='apollo.perception.onboard.FusionComponentConfig.output_viz_fused_content_channel_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/perception/inner/visualization/FusedObjects".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=398,
)

DESCRIPTOR.message_types_by_name['FusionComponentConfig'] = _FUSIONCOMPONENTCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FusionComponentConfig = _reflection.GeneratedProtocolMessageType('FusionComponentConfig', (_message.Message,), {
  'DESCRIPTOR' : _FUSIONCOMPONENTCONFIG,
  '__module__' : 'modules.perception.onboard.proto.fusion_component_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.onboard.FusionComponentConfig)
  })
_sym_db.RegisterMessage(FusionComponentConfig)


# @@protoc_insertion_point(module_scope)
