# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/planning_status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.planning.proto import planning_config_pb2 as modules_dot_planning_dot_proto_dot_planning__config__pb2
from modules.routing.proto import routing_pb2 as modules_dot_routing_dot_proto_dot_routing__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/planning_status.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,modules/planning/proto/planning_status.proto\x12\x0f\x61pollo.planning\x1a#modules/common/proto/geometry.proto\x1a,modules/planning/proto/planning_config.proto\x1a#modules/routing/proto/routing.proto\"~\n\x16\x42\x61reIntersectionStatus\x12\'\n\x1f\x63urrent_pnc_junction_overlap_id\x18\x01 \x01(\t\x12$\n\x1c\x64one_pnc_junction_overlap_id\x18\x02 \x01(\t\x12\x15\n\rclear_counter\x18\x03 \x01(\r\"\x9c\x03\n\x10\x43hangeLaneStatus\x12\x38\n\x06status\x18\x01 \x01(\x0e\x32(.apollo.planning.ChangeLaneStatus.Status\x12\x0f\n\x07path_id\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x01\x12/\n exist_lane_change_start_position\x18\x04 \x01(\x08:\x05\x66\x61lse\x12:\n\x1alane_change_start_position\x18\x05 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x1e\n\x16last_succeed_timestamp\x18\x06 \x01(\x01\x12%\n\x16is_current_opt_succeed\x18\x07 \x01(\x08:\x05\x66\x61lse\x12&\n\x17is_clear_to_change_lane\x18\x08 \x01(\x08:\x05\x66\x61lse\"N\n\x06Status\x12\x12\n\x0eIN_CHANGE_LANE\x10\x01\x12\x16\n\x12\x43HANGE_LANE_FAILED\x10\x02\x12\x18\n\x14\x43HANGE_LANE_FINISHED\x10\x03\"1\n\x12\x43reepDeciderStatus\x12\x1b\n\x13\x63reep_clear_counter\x18\x01 \x01(\r\";\n\x08StopTime\x12\x13\n\x0bobstacle_id\x18\x01 \x01(\t\x12\x1a\n\x12stop_timestamp_sec\x18\x02 \x01(\x01\"q\n\x0f\x43rosswalkStatus\x12\x14\n\x0c\x63rosswalk_id\x18\x01 \x01(\t\x12,\n\tstop_time\x18\x02 \x03(\x0b\x32\x19.apollo.planning.StopTime\x12\x1a\n\x12\x66inished_crosswalk\x18\x03 \x03(\t\":\n\x11\x44\x65stinationStatus\x12%\n\x16has_passed_destination\x18\x01 \x01(\x08:\x05\x66\x61lse\"H\n\x13\x45mergencyStopStatus\x12\x31\n\x10stop_fence_point\x18\x01 \x01(\x0b\x32\x17.apollo.common.PointENU\"_\n\x0fOpenSpaceStatus\x12.\n&partitioned_trajectories_index_history\x18\x01 \x03(\t\x12\x1c\n\rposition_init\x18\x02 \x01(\x08:\x05\x66\x61lse\"\xad\x01\n\x0fParkAndGoStatus\x12\x32\n\x11\x61\x64\x63_init_position\x18\x01 \x01(\x0b\x32\x17.apollo.common.PointENU\x12\x18\n\x10\x61\x64\x63_init_heading\x18\x02 \x01(\x01\x12\x16\n\x0ein_check_stage\x18\x03 \x01(\x08\x12\x34\n\x13\x61\x64\x63_adjust_end_pose\x18\x04 \x01(\x0b\x32\x17.apollo.common.PointENU\"\xd8\x02\n\x11PathDeciderStatus\x12.\n#front_static_obstacle_cycle_counter\x18\x01 \x01(\x05:\x01\x30\x12(\n\x1d\x61\x62le_to_use_self_lane_counter\x18\x02 \x01(\x05:\x01\x30\x12.\n\x1fis_in_path_lane_borrow_scenario\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\"\n\x18\x66ront_static_obstacle_id\x18\x04 \x01(\t:\x00\x12[\n\x1b\x64\x65\x63ided_side_pass_direction\x18\x05 \x03(\x0e\x32\x36.apollo.planning.PathDeciderStatus.LaneBorrowDirection\"8\n\x13LaneBorrowDirection\x12\x0f\n\x0bLEFT_BORROW\x10\x01\x12\x10\n\x0cRIGHT_BORROW\x10\x02\"\xc0\x02\n\x0ePullOverStatus\x12\x44\n\x0epull_over_type\x18\x01 \x01(\x0e\x32,.apollo.planning.PullOverStatus.PullOverType\x12\"\n\x13plan_pull_over_path\x18\x02 \x01(\x08:\x05\x66\x61lse\x12)\n\x08position\x18\x03 \x01(\x0b\x32\x17.apollo.common.PointENU\x12\r\n\x05theta\x18\x04 \x01(\x01\x12\x14\n\x0clength_front\x18\x05 \x01(\x01\x12\x13\n\x0blength_back\x18\x06 \x01(\x01\x12\x12\n\nwidth_left\x18\x07 \x01(\x01\x12\x13\n\x0bwidth_right\x18\x08 \x01(\x01\"6\n\x0cPullOverType\x12\r\n\tPULL_OVER\x10\x01\x12\x17\n\x13\x45MERGENCY_PULL_OVER\x10\x02\"\x86\x01\n\x0fReroutingStatus\x12\x1b\n\x13last_rerouting_time\x18\x01 \x01(\x01\x12\x1d\n\x0eneed_rerouting\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x37\n\x0frouting_request\x18\x03 \x01(\x0b\x32\x1e.apollo.routing.RoutingRequest\"M\n\x12SpeedDeciderStatus\x12\x37\n\x14pedestrian_stop_time\x18\x01 \x03(\x0b\x32\x19.apollo.planning.StopTime\"\x94\x01\n\x0eScenarioStatus\x12\x43\n\rscenario_type\x18\x01 \x01(\x0e\x32,.apollo.planning.ScenarioConfig.ScenarioType\x12=\n\nstage_type\x18\x02 \x01(\x0e\x32).apollo.planning.ScenarioConfig.StageType\"w\n\x0eStopSignStatus\x12$\n\x1c\x63urrent_stop_sign_overlap_id\x18\x01 \x01(\t\x12!\n\x19\x64one_stop_sign_overlap_id\x18\x02 \x01(\t\x12\x1c\n\x14wait_for_obstacle_id\x18\x03 \x03(\t\"e\n\x12TrafficLightStatus\x12(\n current_traffic_light_overlap_id\x18\x01 \x03(\t\x12%\n\x1d\x64one_traffic_light_overlap_id\x18\x02 \x03(\t\"z\n\x0fYieldSignStatus\x12%\n\x1d\x63urrent_yield_sign_overlap_id\x18\x01 \x03(\t\x12\"\n\x1a\x64one_yield_sign_overlap_id\x18\x02 \x03(\t\x12\x1c\n\x14wait_for_obstacle_id\x18\x03 \x03(\t\"\x99\x07\n\x0ePlanningStatus\x12\x42\n\x11\x62\x61re_intersection\x18\x01 \x01(\x0b\x32\'.apollo.planning.BareIntersectionStatus\x12\x36\n\x0b\x63hange_lane\x18\x02 \x01(\x0b\x32!.apollo.planning.ChangeLaneStatus\x12:\n\rcreep_decider\x18\x03 \x01(\x0b\x32#.apollo.planning.CreepDeciderStatus\x12\x33\n\tcrosswalk\x18\x04 \x01(\x0b\x32 .apollo.planning.CrosswalkStatus\x12\x37\n\x0b\x64\x65stination\x18\x05 \x01(\x0b\x32\".apollo.planning.DestinationStatus\x12<\n\x0e\x65mergency_stop\x18\x06 \x01(\x0b\x32$.apollo.planning.EmergencyStopStatus\x12\x34\n\nopen_space\x18\x07 \x01(\x0b\x32 .apollo.planning.OpenSpaceStatus\x12\x35\n\x0bpark_and_go\x18\x08 \x01(\x0b\x32 .apollo.planning.ParkAndGoStatus\x12\x38\n\x0cpath_decider\x18\t \x01(\x0b\x32\".apollo.planning.PathDeciderStatus\x12\x32\n\tpull_over\x18\n \x01(\x0b\x32\x1f.apollo.planning.PullOverStatus\x12\x33\n\trerouting\x18\x0b \x01(\x0b\x32 .apollo.planning.ReroutingStatus\x12\x31\n\x08scenario\x18\x0c \x01(\x0b\x32\x1f.apollo.planning.ScenarioStatus\x12:\n\rspeed_decider\x18\r \x01(\x0b\x32#.apollo.planning.SpeedDeciderStatus\x12\x32\n\tstop_sign\x18\x0e \x01(\x0b\x32\x1f.apollo.planning.StopSignStatus\x12:\n\rtraffic_light\x18\x0f \x01(\x0b\x32#.apollo.planning.TrafficLightStatus\x12\x34\n\nyield_sign\x18\x10 \x01(\x0b\x32 .apollo.planning.YieldSignStatus'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_planning_dot_proto_dot_planning__config__pb2.DESCRIPTOR,modules_dot_routing_dot_proto_dot_routing__pb2.DESCRIPTOR,])



_CHANGELANESTATUS_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='apollo.planning.ChangeLaneStatus.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IN_CHANGE_LANE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_LANE_FAILED', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_LANE_FINISHED', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=648,
  serialized_end=726,
)
_sym_db.RegisterEnumDescriptor(_CHANGELANESTATUS_STATUS)

_PATHDECIDERSTATUS_LANEBORROWDIRECTION = _descriptor.EnumDescriptor(
  name='LaneBorrowDirection',
  full_name='apollo.planning.PathDeciderStatus.LaneBorrowDirection',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEFT_BORROW', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_BORROW', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1651,
  serialized_end=1707,
)
_sym_db.RegisterEnumDescriptor(_PATHDECIDERSTATUS_LANEBORROWDIRECTION)

_PULLOVERSTATUS_PULLOVERTYPE = _descriptor.EnumDescriptor(
  name='PullOverType',
  full_name='apollo.planning.PullOverStatus.PullOverType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PULL_OVER', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_PULL_OVER', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1976,
  serialized_end=2030,
)
_sym_db.RegisterEnumDescriptor(_PULLOVERSTATUS_PULLOVERTYPE)


_BAREINTERSECTIONSTATUS = _descriptor.Descriptor(
  name='BareIntersectionStatus',
  full_name='apollo.planning.BareIntersectionStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_pnc_junction_overlap_id', full_name='apollo.planning.BareIntersectionStatus.current_pnc_junction_overlap_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='done_pnc_junction_overlap_id', full_name='apollo.planning.BareIntersectionStatus.done_pnc_junction_overlap_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_counter', full_name='apollo.planning.BareIntersectionStatus.clear_counter', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=311,
)


_CHANGELANESTATUS = _descriptor.Descriptor(
  name='ChangeLaneStatus',
  full_name='apollo.planning.ChangeLaneStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='apollo.planning.ChangeLaneStatus.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_id', full_name='apollo.planning.ChangeLaneStatus.path_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.planning.ChangeLaneStatus.timestamp', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exist_lane_change_start_position', full_name='apollo.planning.ChangeLaneStatus.exist_lane_change_start_position', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_change_start_position', full_name='apollo.planning.ChangeLaneStatus.lane_change_start_position', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_succeed_timestamp', full_name='apollo.planning.ChangeLaneStatus.last_succeed_timestamp', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_current_opt_succeed', full_name='apollo.planning.ChangeLaneStatus.is_current_opt_succeed', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_clear_to_change_lane', full_name='apollo.planning.ChangeLaneStatus.is_clear_to_change_lane', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANGELANESTATUS_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=726,
)


_CREEPDECIDERSTATUS = _descriptor.Descriptor(
  name='CreepDeciderStatus',
  full_name='apollo.planning.CreepDeciderStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='creep_clear_counter', full_name='apollo.planning.CreepDeciderStatus.creep_clear_counter', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=728,
  serialized_end=777,
)


_STOPTIME = _descriptor.Descriptor(
  name='StopTime',
  full_name='apollo.planning.StopTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obstacle_id', full_name='apollo.planning.StopTime.obstacle_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_timestamp_sec', full_name='apollo.planning.StopTime.stop_timestamp_sec', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=838,
)


_CROSSWALKSTATUS = _descriptor.Descriptor(
  name='CrosswalkStatus',
  full_name='apollo.planning.CrosswalkStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='crosswalk_id', full_name='apollo.planning.CrosswalkStatus.crosswalk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_time', full_name='apollo.planning.CrosswalkStatus.stop_time', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finished_crosswalk', full_name='apollo.planning.CrosswalkStatus.finished_crosswalk', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=840,
  serialized_end=953,
)


_DESTINATIONSTATUS = _descriptor.Descriptor(
  name='DestinationStatus',
  full_name='apollo.planning.DestinationStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_passed_destination', full_name='apollo.planning.DestinationStatus.has_passed_destination', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=955,
  serialized_end=1013,
)


_EMERGENCYSTOPSTATUS = _descriptor.Descriptor(
  name='EmergencyStopStatus',
  full_name='apollo.planning.EmergencyStopStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_fence_point', full_name='apollo.planning.EmergencyStopStatus.stop_fence_point', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1015,
  serialized_end=1087,
)


_OPENSPACESTATUS = _descriptor.Descriptor(
  name='OpenSpaceStatus',
  full_name='apollo.planning.OpenSpaceStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partitioned_trajectories_index_history', full_name='apollo.planning.OpenSpaceStatus.partitioned_trajectories_index_history', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_init', full_name='apollo.planning.OpenSpaceStatus.position_init', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1089,
  serialized_end=1184,
)


_PARKANDGOSTATUS = _descriptor.Descriptor(
  name='ParkAndGoStatus',
  full_name='apollo.planning.ParkAndGoStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='adc_init_position', full_name='apollo.planning.ParkAndGoStatus.adc_init_position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_init_heading', full_name='apollo.planning.ParkAndGoStatus.adc_init_heading', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_check_stage', full_name='apollo.planning.ParkAndGoStatus.in_check_stage', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_adjust_end_pose', full_name='apollo.planning.ParkAndGoStatus.adc_adjust_end_pose', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1187,
  serialized_end=1360,
)


_PATHDECIDERSTATUS = _descriptor.Descriptor(
  name='PathDeciderStatus',
  full_name='apollo.planning.PathDeciderStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='front_static_obstacle_cycle_counter', full_name='apollo.planning.PathDeciderStatus.front_static_obstacle_cycle_counter', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='able_to_use_self_lane_counter', full_name='apollo.planning.PathDeciderStatus.able_to_use_self_lane_counter', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_in_path_lane_borrow_scenario', full_name='apollo.planning.PathDeciderStatus.is_in_path_lane_borrow_scenario', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_static_obstacle_id', full_name='apollo.planning.PathDeciderStatus.front_static_obstacle_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decided_side_pass_direction', full_name='apollo.planning.PathDeciderStatus.decided_side_pass_direction', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PATHDECIDERSTATUS_LANEBORROWDIRECTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1363,
  serialized_end=1707,
)


_PULLOVERSTATUS = _descriptor.Descriptor(
  name='PullOverStatus',
  full_name='apollo.planning.PullOverStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pull_over_type', full_name='apollo.planning.PullOverStatus.pull_over_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan_pull_over_path', full_name='apollo.planning.PullOverStatus.plan_pull_over_path', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.planning.PullOverStatus.position', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='apollo.planning.PullOverStatus.theta', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length_front', full_name='apollo.planning.PullOverStatus.length_front', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length_back', full_name='apollo.planning.PullOverStatus.length_back', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width_left', full_name='apollo.planning.PullOverStatus.width_left', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width_right', full_name='apollo.planning.PullOverStatus.width_right', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PULLOVERSTATUS_PULLOVERTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1710,
  serialized_end=2030,
)


_REROUTINGSTATUS = _descriptor.Descriptor(
  name='ReroutingStatus',
  full_name='apollo.planning.ReroutingStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_rerouting_time', full_name='apollo.planning.ReroutingStatus.last_rerouting_time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_rerouting', full_name='apollo.planning.ReroutingStatus.need_rerouting', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_request', full_name='apollo.planning.ReroutingStatus.routing_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2033,
  serialized_end=2167,
)


_SPEEDDECIDERSTATUS = _descriptor.Descriptor(
  name='SpeedDeciderStatus',
  full_name='apollo.planning.SpeedDeciderStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pedestrian_stop_time', full_name='apollo.planning.SpeedDeciderStatus.pedestrian_stop_time', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2169,
  serialized_end=2246,
)


_SCENARIOSTATUS = _descriptor.Descriptor(
  name='ScenarioStatus',
  full_name='apollo.planning.ScenarioStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scenario_type', full_name='apollo.planning.ScenarioStatus.scenario_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage_type', full_name='apollo.planning.ScenarioStatus.stage_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2249,
  serialized_end=2397,
)


_STOPSIGNSTATUS = _descriptor.Descriptor(
  name='StopSignStatus',
  full_name='apollo.planning.StopSignStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_stop_sign_overlap_id', full_name='apollo.planning.StopSignStatus.current_stop_sign_overlap_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='done_stop_sign_overlap_id', full_name='apollo.planning.StopSignStatus.done_stop_sign_overlap_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_for_obstacle_id', full_name='apollo.planning.StopSignStatus.wait_for_obstacle_id', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2399,
  serialized_end=2518,
)


_TRAFFICLIGHTSTATUS = _descriptor.Descriptor(
  name='TrafficLightStatus',
  full_name='apollo.planning.TrafficLightStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_traffic_light_overlap_id', full_name='apollo.planning.TrafficLightStatus.current_traffic_light_overlap_id', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='done_traffic_light_overlap_id', full_name='apollo.planning.TrafficLightStatus.done_traffic_light_overlap_id', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2520,
  serialized_end=2621,
)


_YIELDSIGNSTATUS = _descriptor.Descriptor(
  name='YieldSignStatus',
  full_name='apollo.planning.YieldSignStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_yield_sign_overlap_id', full_name='apollo.planning.YieldSignStatus.current_yield_sign_overlap_id', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='done_yield_sign_overlap_id', full_name='apollo.planning.YieldSignStatus.done_yield_sign_overlap_id', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_for_obstacle_id', full_name='apollo.planning.YieldSignStatus.wait_for_obstacle_id', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2623,
  serialized_end=2745,
)


_PLANNINGSTATUS = _descriptor.Descriptor(
  name='PlanningStatus',
  full_name='apollo.planning.PlanningStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bare_intersection', full_name='apollo.planning.PlanningStatus.bare_intersection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change_lane', full_name='apollo.planning.PlanningStatus.change_lane', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creep_decider', full_name='apollo.planning.PlanningStatus.creep_decider', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalk', full_name='apollo.planning.PlanningStatus.crosswalk', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination', full_name='apollo.planning.PlanningStatus.destination', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emergency_stop', full_name='apollo.planning.PlanningStatus.emergency_stop', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_space', full_name='apollo.planning.PlanningStatus.open_space', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='park_and_go', full_name='apollo.planning.PlanningStatus.park_and_go', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_decider', full_name='apollo.planning.PlanningStatus.path_decider', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over', full_name='apollo.planning.PlanningStatus.pull_over', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rerouting', full_name='apollo.planning.PlanningStatus.rerouting', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scenario', full_name='apollo.planning.PlanningStatus.scenario', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_decider', full_name='apollo.planning.PlanningStatus.speed_decider', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_sign', full_name='apollo.planning.PlanningStatus.stop_sign', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light', full_name='apollo.planning.PlanningStatus.traffic_light', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield_sign', full_name='apollo.planning.PlanningStatus.yield_sign', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2748,
  serialized_end=3669,
)

_CHANGELANESTATUS.fields_by_name['status'].enum_type = _CHANGELANESTATUS_STATUS
_CHANGELANESTATUS.fields_by_name['lane_change_start_position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_CHANGELANESTATUS_STATUS.containing_type = _CHANGELANESTATUS
_CROSSWALKSTATUS.fields_by_name['stop_time'].message_type = _STOPTIME
_EMERGENCYSTOPSTATUS.fields_by_name['stop_fence_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_PARKANDGOSTATUS.fields_by_name['adc_init_position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_PARKANDGOSTATUS.fields_by_name['adc_adjust_end_pose'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_PATHDECIDERSTATUS.fields_by_name['decided_side_pass_direction'].enum_type = _PATHDECIDERSTATUS_LANEBORROWDIRECTION
_PATHDECIDERSTATUS_LANEBORROWDIRECTION.containing_type = _PATHDECIDERSTATUS
_PULLOVERSTATUS.fields_by_name['pull_over_type'].enum_type = _PULLOVERSTATUS_PULLOVERTYPE
_PULLOVERSTATUS.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_PULLOVERSTATUS_PULLOVERTYPE.containing_type = _PULLOVERSTATUS
_REROUTINGSTATUS.fields_by_name['routing_request'].message_type = modules_dot_routing_dot_proto_dot_routing__pb2._ROUTINGREQUEST
_SPEEDDECIDERSTATUS.fields_by_name['pedestrian_stop_time'].message_type = _STOPTIME
_SCENARIOSTATUS.fields_by_name['scenario_type'].enum_type = modules_dot_planning_dot_proto_dot_planning__config__pb2._SCENARIOCONFIG_SCENARIOTYPE
_SCENARIOSTATUS.fields_by_name['stage_type'].enum_type = modules_dot_planning_dot_proto_dot_planning__config__pb2._SCENARIOCONFIG_STAGETYPE
_PLANNINGSTATUS.fields_by_name['bare_intersection'].message_type = _BAREINTERSECTIONSTATUS
_PLANNINGSTATUS.fields_by_name['change_lane'].message_type = _CHANGELANESTATUS
_PLANNINGSTATUS.fields_by_name['creep_decider'].message_type = _CREEPDECIDERSTATUS
_PLANNINGSTATUS.fields_by_name['crosswalk'].message_type = _CROSSWALKSTATUS
_PLANNINGSTATUS.fields_by_name['destination'].message_type = _DESTINATIONSTATUS
_PLANNINGSTATUS.fields_by_name['emergency_stop'].message_type = _EMERGENCYSTOPSTATUS
_PLANNINGSTATUS.fields_by_name['open_space'].message_type = _OPENSPACESTATUS
_PLANNINGSTATUS.fields_by_name['park_and_go'].message_type = _PARKANDGOSTATUS
_PLANNINGSTATUS.fields_by_name['path_decider'].message_type = _PATHDECIDERSTATUS
_PLANNINGSTATUS.fields_by_name['pull_over'].message_type = _PULLOVERSTATUS
_PLANNINGSTATUS.fields_by_name['rerouting'].message_type = _REROUTINGSTATUS
_PLANNINGSTATUS.fields_by_name['scenario'].message_type = _SCENARIOSTATUS
_PLANNINGSTATUS.fields_by_name['speed_decider'].message_type = _SPEEDDECIDERSTATUS
_PLANNINGSTATUS.fields_by_name['stop_sign'].message_type = _STOPSIGNSTATUS
_PLANNINGSTATUS.fields_by_name['traffic_light'].message_type = _TRAFFICLIGHTSTATUS
_PLANNINGSTATUS.fields_by_name['yield_sign'].message_type = _YIELDSIGNSTATUS
DESCRIPTOR.message_types_by_name['BareIntersectionStatus'] = _BAREINTERSECTIONSTATUS
DESCRIPTOR.message_types_by_name['ChangeLaneStatus'] = _CHANGELANESTATUS
DESCRIPTOR.message_types_by_name['CreepDeciderStatus'] = _CREEPDECIDERSTATUS
DESCRIPTOR.message_types_by_name['StopTime'] = _STOPTIME
DESCRIPTOR.message_types_by_name['CrosswalkStatus'] = _CROSSWALKSTATUS
DESCRIPTOR.message_types_by_name['DestinationStatus'] = _DESTINATIONSTATUS
DESCRIPTOR.message_types_by_name['EmergencyStopStatus'] = _EMERGENCYSTOPSTATUS
DESCRIPTOR.message_types_by_name['OpenSpaceStatus'] = _OPENSPACESTATUS
DESCRIPTOR.message_types_by_name['ParkAndGoStatus'] = _PARKANDGOSTATUS
DESCRIPTOR.message_types_by_name['PathDeciderStatus'] = _PATHDECIDERSTATUS
DESCRIPTOR.message_types_by_name['PullOverStatus'] = _PULLOVERSTATUS
DESCRIPTOR.message_types_by_name['ReroutingStatus'] = _REROUTINGSTATUS
DESCRIPTOR.message_types_by_name['SpeedDeciderStatus'] = _SPEEDDECIDERSTATUS
DESCRIPTOR.message_types_by_name['ScenarioStatus'] = _SCENARIOSTATUS
DESCRIPTOR.message_types_by_name['StopSignStatus'] = _STOPSIGNSTATUS
DESCRIPTOR.message_types_by_name['TrafficLightStatus'] = _TRAFFICLIGHTSTATUS
DESCRIPTOR.message_types_by_name['YieldSignStatus'] = _YIELDSIGNSTATUS
DESCRIPTOR.message_types_by_name['PlanningStatus'] = _PLANNINGSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BareIntersectionStatus = _reflection.GeneratedProtocolMessageType('BareIntersectionStatus', (_message.Message,), {
  'DESCRIPTOR' : _BAREINTERSECTIONSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.BareIntersectionStatus)
  })
_sym_db.RegisterMessage(BareIntersectionStatus)

ChangeLaneStatus = _reflection.GeneratedProtocolMessageType('ChangeLaneStatus', (_message.Message,), {
  'DESCRIPTOR' : _CHANGELANESTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ChangeLaneStatus)
  })
_sym_db.RegisterMessage(ChangeLaneStatus)

CreepDeciderStatus = _reflection.GeneratedProtocolMessageType('CreepDeciderStatus', (_message.Message,), {
  'DESCRIPTOR' : _CREEPDECIDERSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.CreepDeciderStatus)
  })
_sym_db.RegisterMessage(CreepDeciderStatus)

StopTime = _reflection.GeneratedProtocolMessageType('StopTime', (_message.Message,), {
  'DESCRIPTOR' : _STOPTIME,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.StopTime)
  })
_sym_db.RegisterMessage(StopTime)

CrosswalkStatus = _reflection.GeneratedProtocolMessageType('CrosswalkStatus', (_message.Message,), {
  'DESCRIPTOR' : _CROSSWALKSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.CrosswalkStatus)
  })
_sym_db.RegisterMessage(CrosswalkStatus)

DestinationStatus = _reflection.GeneratedProtocolMessageType('DestinationStatus', (_message.Message,), {
  'DESCRIPTOR' : _DESTINATIONSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.DestinationStatus)
  })
_sym_db.RegisterMessage(DestinationStatus)

EmergencyStopStatus = _reflection.GeneratedProtocolMessageType('EmergencyStopStatus', (_message.Message,), {
  'DESCRIPTOR' : _EMERGENCYSTOPSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.EmergencyStopStatus)
  })
_sym_db.RegisterMessage(EmergencyStopStatus)

OpenSpaceStatus = _reflection.GeneratedProtocolMessageType('OpenSpaceStatus', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACESTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OpenSpaceStatus)
  })
_sym_db.RegisterMessage(OpenSpaceStatus)

ParkAndGoStatus = _reflection.GeneratedProtocolMessageType('ParkAndGoStatus', (_message.Message,), {
  'DESCRIPTOR' : _PARKANDGOSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ParkAndGoStatus)
  })
_sym_db.RegisterMessage(ParkAndGoStatus)

PathDeciderStatus = _reflection.GeneratedProtocolMessageType('PathDeciderStatus', (_message.Message,), {
  'DESCRIPTOR' : _PATHDECIDERSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PathDeciderStatus)
  })
_sym_db.RegisterMessage(PathDeciderStatus)

PullOverStatus = _reflection.GeneratedProtocolMessageType('PullOverStatus', (_message.Message,), {
  'DESCRIPTOR' : _PULLOVERSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PullOverStatus)
  })
_sym_db.RegisterMessage(PullOverStatus)

ReroutingStatus = _reflection.GeneratedProtocolMessageType('ReroutingStatus', (_message.Message,), {
  'DESCRIPTOR' : _REROUTINGSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ReroutingStatus)
  })
_sym_db.RegisterMessage(ReroutingStatus)

SpeedDeciderStatus = _reflection.GeneratedProtocolMessageType('SpeedDeciderStatus', (_message.Message,), {
  'DESCRIPTOR' : _SPEEDDECIDERSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.SpeedDeciderStatus)
  })
_sym_db.RegisterMessage(SpeedDeciderStatus)

ScenarioStatus = _reflection.GeneratedProtocolMessageType('ScenarioStatus', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioStatus)
  })
_sym_db.RegisterMessage(ScenarioStatus)

StopSignStatus = _reflection.GeneratedProtocolMessageType('StopSignStatus', (_message.Message,), {
  'DESCRIPTOR' : _STOPSIGNSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.StopSignStatus)
  })
_sym_db.RegisterMessage(StopSignStatus)

TrafficLightStatus = _reflection.GeneratedProtocolMessageType('TrafficLightStatus', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICLIGHTSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.TrafficLightStatus)
  })
_sym_db.RegisterMessage(TrafficLightStatus)

YieldSignStatus = _reflection.GeneratedProtocolMessageType('YieldSignStatus', (_message.Message,), {
  'DESCRIPTOR' : _YIELDSIGNSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.YieldSignStatus)
  })
_sym_db.RegisterMessage(YieldSignStatus)

PlanningStatus = _reflection.GeneratedProtocolMessageType('PlanningStatus', (_message.Message,), {
  'DESCRIPTOR' : _PLANNINGSTATUS,
  '__module__' : 'modules.planning.proto.planning_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PlanningStatus)
  })
_sym_db.RegisterMessage(PlanningStatus)


# @@protoc_insertion_point(module_scope)
