# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/canbus/proto/zhongyun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/canbus/proto/zhongyun.proto',
  package='apollo.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#modules/canbus/proto/zhongyun.proto\x12\rapollo.canbus\"\xc5\x03\n\x0fGear_control_a1\x12O\n\x11gear_state_target\x18\x01 \x01(\x0e\x32\x34.apollo.canbus.Gear_control_a1.Gear_state_targetType\x12S\n\x13gear_enable_control\x18\x02 \x01(\x0e\x32\x36.apollo.canbus.Gear_control_a1.Gear_enable_controlType\"\x9a\x01\n\x15Gear_state_targetType\x12\x17\n\x13GEAR_STATE_TARGET_P\x10\x01\x12\x17\n\x13GEAR_STATE_TARGET_N\x10\x02\x12\x17\n\x13GEAR_STATE_TARGET_D\x10\x03\x12\x17\n\x13GEAR_STATE_TARGET_R\x10\x04\x12\x1d\n\x19GEAR_STATE_TARGET_INVALID\x10\x05\"o\n\x17Gear_enable_controlType\x12*\n&GEAR_ENABLE_CONTROL_GEAR_MANUALCONTROL\x10\x00\x12(\n$GEAR_ENABLE_CONTROL_GEAR_AUTOCONTROL\x10\x01\"\xf0\x01\n\x11Torque_control_a3\x12\x15\n\rdriven_torque\x18\x01 \x01(\x01\x12Y\n\x15\x64riven_enable_control\x18\x02 \x01(\x0e\x32:.apollo.canbus.Torque_control_a3.Driven_enable_controlType\"i\n\x19\x44riven_enable_controlType\x12&\n\"DRIVEN_ENABLE_CONTROL_DRIVE_MANUAL\x10\x00\x12$\n DRIVEN_ENABLE_CONTROL_DRIVE_AUTO\x10\x01\"\x95\x02\n\x13Steering_control_a2\x12\x17\n\x0fsteering_target\x18\x01 \x01(\x01\x12_\n\x17steering_enable_control\x18\x02 \x01(\x0e\x32>.apollo.canbus.Steering_control_a2.Steering_enable_controlType\"\x83\x01\n\x1bSteering_enable_controlType\x12\x32\n.STEERING_ENABLE_CONTROL_STEERING_MANUALCONTROL\x10\x00\x12\x30\n,STEERING_ENABLE_CONTROL_STEERING_AUTOCONTROL\x10\x01\"\x96\x03\n\x12Parking_control_a5\x12L\n\x0eparking_target\x18\x01 \x01(\x0e\x32\x34.apollo.canbus.Parking_control_a5.Parking_targetType\x12\\\n\x16parking_enable_control\x18\x02 \x01(\x0e\x32<.apollo.canbus.Parking_control_a5.Parking_enable_controlType\"T\n\x12Parking_targetType\x12\x1a\n\x16PARKING_TARGET_RELEASE\x10\x00\x12\"\n\x1ePARKING_TARGET_PARKING_TRIGGER\x10\x01\"~\n\x1aParking_enable_controlType\x12\x30\n,PARKING_ENABLE_CONTROL_PARKING_MANUALCONTROL\x10\x00\x12.\n*PARKING_ENABLE_CONTROL_PARKING_AUTOCONTROL\x10\x01\"\xe8\x01\n\x10\x42rake_control_a4\x12\x14\n\x0c\x62rake_torque\x18\x01 \x01(\x01\x12V\n\x14\x62rake_enable_control\x18\x02 \x01(\x0e\x32\x38.apollo.canbus.Brake_control_a4.Brake_enable_controlType\"f\n\x18\x42rake_enable_controlType\x12%\n!BRAKE_ENABLE_CONTROL_BRAKE_MANUAL\x10\x00\x12#\n\x1f\x42RAKE_ENABLE_CONTROL_BRAKE_AUTO\x10\x01\"\x80\n\n\x18\x45nable_state_feedback_c3\x12^\n\x14parking_enable_state\x18\x01 \x01(\x0e\x32@.apollo.canbus.Enable_state_feedback_c3.Parking_enable_stateType\x12`\n\x15steering_enable_state\x18\x02 \x01(\x0e\x32\x41.apollo.canbus.Enable_state_feedback_c3.Steering_enable_stateType\x12Z\n\x12gear_enable_actual\x18\x03 \x01(\x0e\x32>.apollo.canbus.Enable_state_feedback_c3.Gear_enable_actualType\x12\\\n\x13\x64riven_enable_state\x18\x04 \x01(\x0e\x32?.apollo.canbus.Enable_state_feedback_c3.Driven_enable_stateType\x12Z\n\x12\x62rake_enable_state\x18\x05 \x01(\x0e\x32>.apollo.canbus.Enable_state_feedback_c3.Brake_enable_stateType\"\xa3\x01\n\x18Parking_enable_stateType\x12.\n*PARKING_ENABLE_STATE_PARKING_MANUALCONTROL\x10\x00\x12,\n(PARKING_ENABLE_STATE_PARKING_AUTOCONTROL\x10\x01\x12)\n%PARKING_ENABLE_STATE_PARKING_TAKEOVER\x10\x02\"\xb1\x01\n\x19Steering_enable_stateType\x12\x30\n,STEERING_ENABLE_STATE_STEERING_MANUALCONTROL\x10\x00\x12.\n*STEERING_ENABLE_STATE_STEERING_AUTOCONTROL\x10\x01\x12\x32\n.STEERING_ENABLE_STATE_STEERING_MANUAL_TAKEOVER\x10\x02\"\x99\x01\n\x16Gear_enable_actualType\x12)\n%GEAR_ENABLE_ACTUAL_GEAR_MANUALCONTROL\x10\x00\x12\'\n#GEAR_ENABLE_ACTUAL_GEAR_AUTOCONTROL\x10\x01\x12+\n\'GEAR_ENABLE_ACTUAL_GEAR_MANUAL_TAKEOVER\x10\x02\"\x8b\x01\n\x17\x44riven_enable_stateType\x12$\n DRIVEN_ENABLE_STATE_DRIVE_MANUAL\x10\x00\x12\"\n\x1e\x44RIVEN_ENABLE_STATE_DRIVE_AUTO\x10\x01\x12&\n\"DRIVEN_ENABLE_STATE_DRIVE_TAKEOVER\x10\x02\"\x87\x01\n\x16\x42rake_enable_stateType\x12#\n\x1f\x42RAKE_ENABLE_STATE_BRAKE_MANUAL\x10\x00\x12!\n\x1d\x42RAKE_ENABLE_STATE_BRAKE_AUTO\x10\x01\x12%\n!BRAKE_ENABLE_STATE_BRAKE_TAKEOVER\x10\x02\"\x85\x04\n\x19Vehicle_state_feedback_c1\x12S\n\x0eparking_actual\x18\x01 \x01(\x0e\x32;.apollo.canbus.Vehicle_state_feedback_c1.Parking_actualType\x12\x1d\n\x15\x62rake_torque_feedback\x18\x02 \x01(\x01\x12Y\n\x11gear_state_actual\x18\x03 \x01(\x0e\x32>.apollo.canbus.Vehicle_state_feedback_c1.Gear_state_actualType\x12\x17\n\x0fsteering_actual\x18\x04 \x01(\x01\x12\r\n\x05speed\x18\x05 \x01(\x01\"T\n\x12Parking_actualType\x12\x1a\n\x16PARKING_ACTUAL_RELEASE\x10\x00\x12\"\n\x1ePARKING_ACTUAL_PARKING_TRIGGER\x10\x01\"\x9a\x01\n\x15Gear_state_actualType\x12\x17\n\x13GEAR_STATE_ACTUAL_P\x10\x01\x12\x17\n\x13GEAR_STATE_ACTUAL_N\x10\x02\x12\x17\n\x13GEAR_STATE_ACTUAL_D\x10\x03\x12\x17\n\x13GEAR_STATE_ACTUAL_R\x10\x04\x12\x1d\n\x19GEAR_STATE_ACTUAL_INVALID\x10\x05\"\xc9\x06\n\x0e\x45rror_state_e1\x12L\n\x10\x62rake_error_code\x18\x01 \x01(\x0e\x32\x32.apollo.canbus.Error_state_e1.Brake_error_codeType\x12N\n\x11\x64riven_error_code\x18\x02 \x01(\x0e\x32\x33.apollo.canbus.Error_state_e1.Driven_error_codeType\x12R\n\x13steering_error_code\x18\x03 \x01(\x0e\x32\x35.apollo.canbus.Error_state_e1.Steering_error_codeType\x12P\n\x12parking_error_code\x18\x04 \x01(\x0e\x32\x34.apollo.canbus.Error_state_e1.Parking_error_codeType\x12H\n\x0egear_error_msg\x18\x05 \x01(\x0e\x32\x30.apollo.canbus.Error_state_e1.Gear_error_msgType\"Q\n\x14\x42rake_error_codeType\x12\x1d\n\x19\x42RAKE_ERROR_CODE_NO_ERROR\x10\x00\x12\x1a\n\x16\x42RAKE_ERROR_CODE_ERROR\x10\x01\"T\n\x15\x44riven_error_codeType\x12\x1e\n\x1a\x44RIVEN_ERROR_CODE_NO_ERROR\x10\x00\x12\x1b\n\x17\x44RIVEN_ERROR_CODE_ERROR\x10\x01\"Z\n\x17Steering_error_codeType\x12 \n\x1cSTEERING_ERROR_CODE_NO_ERROR\x10\x00\x12\x1d\n\x19STEERING_ERROR_CODE_ERROR\x10\x01\"W\n\x16Parking_error_codeType\x12\x1f\n\x1bPARKING_ERROR_CODE_NO_ERROR\x10\x00\x12\x1c\n\x18PARKING_ERROR_CODE_ERROR\x10\x01\"K\n\x12Gear_error_msgType\x12\x1b\n\x17GEAR_ERROR_MSG_NO_ERROR\x10\x00\x12\x18\n\x14GEAR_ERROR_MSG_ERROR\x10\x01\"R\n\x1bVehicle_state_feedback_2_c4\x12\x13\n\x0bmotor_speed\x18\x01 \x01(\x05\x12\x1e\n\x16\x64riven_torque_feedback\x18\x02 \x01(\x01\"\xdb\x04\n\x08Zhongyun\x12\x37\n\x0fgear_control_a1\x18\x01 \x01(\x0b\x32\x1e.apollo.canbus.Gear_control_a1\x12;\n\x11torque_control_a3\x18\x02 \x01(\x0b\x32 .apollo.canbus.Torque_control_a3\x12?\n\x13steering_control_a2\x18\x03 \x01(\x0b\x32\".apollo.canbus.Steering_control_a2\x12=\n\x12parking_control_a5\x18\x04 \x01(\x0b\x32!.apollo.canbus.Parking_control_a5\x12\x39\n\x10\x62rake_control_a4\x18\x05 \x01(\x0b\x32\x1f.apollo.canbus.Brake_control_a4\x12I\n\x18\x65nable_state_feedback_c3\x18\x06 \x01(\x0b\x32\'.apollo.canbus.Enable_state_feedback_c3\x12K\n\x19vehicle_state_feedback_c1\x18\x07 \x01(\x0b\x32(.apollo.canbus.Vehicle_state_feedback_c1\x12\x35\n\x0e\x65rror_state_e1\x18\x08 \x01(\x0b\x32\x1d.apollo.canbus.Error_state_e1\x12O\n\x1bvehicle_state_feedback_2_c4\x18\t \x01(\x0b\x32*.apollo.canbus.Vehicle_state_feedback_2_c4'
)



_GEAR_CONTROL_A1_GEAR_STATE_TARGETTYPE = _descriptor.EnumDescriptor(
  name='Gear_state_targetType',
  full_name='apollo.canbus.Gear_control_a1.Gear_state_targetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_TARGET_P', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_TARGET_N', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_TARGET_D', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_TARGET_R', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_TARGET_INVALID', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=241,
  serialized_end=395,
)
_sym_db.RegisterEnumDescriptor(_GEAR_CONTROL_A1_GEAR_STATE_TARGETTYPE)

_GEAR_CONTROL_A1_GEAR_ENABLE_CONTROLTYPE = _descriptor.EnumDescriptor(
  name='Gear_enable_controlType',
  full_name='apollo.canbus.Gear_control_a1.Gear_enable_controlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_ENABLE_CONTROL_GEAR_MANUALCONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_ENABLE_CONTROL_GEAR_AUTOCONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=397,
  serialized_end=508,
)
_sym_db.RegisterEnumDescriptor(_GEAR_CONTROL_A1_GEAR_ENABLE_CONTROLTYPE)

_TORQUE_CONTROL_A3_DRIVEN_ENABLE_CONTROLTYPE = _descriptor.EnumDescriptor(
  name='Driven_enable_controlType',
  full_name='apollo.canbus.Torque_control_a3.Driven_enable_controlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ENABLE_CONTROL_DRIVE_MANUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ENABLE_CONTROL_DRIVE_AUTO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=646,
  serialized_end=751,
)
_sym_db.RegisterEnumDescriptor(_TORQUE_CONTROL_A3_DRIVEN_ENABLE_CONTROLTYPE)

_STEERING_CONTROL_A2_STEERING_ENABLE_CONTROLTYPE = _descriptor.EnumDescriptor(
  name='Steering_enable_controlType',
  full_name='apollo.canbus.Steering_control_a2.Steering_enable_controlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEERING_ENABLE_CONTROL_STEERING_MANUALCONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEERING_ENABLE_CONTROL_STEERING_AUTOCONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=900,
  serialized_end=1031,
)
_sym_db.RegisterEnumDescriptor(_STEERING_CONTROL_A2_STEERING_ENABLE_CONTROLTYPE)

_PARKING_CONTROL_A5_PARKING_TARGETTYPE = _descriptor.EnumDescriptor(
  name='Parking_targetType',
  full_name='apollo.canbus.Parking_control_a5.Parking_targetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARKING_TARGET_RELEASE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_TARGET_PARKING_TRIGGER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1228,
  serialized_end=1312,
)
_sym_db.RegisterEnumDescriptor(_PARKING_CONTROL_A5_PARKING_TARGETTYPE)

_PARKING_CONTROL_A5_PARKING_ENABLE_CONTROLTYPE = _descriptor.EnumDescriptor(
  name='Parking_enable_controlType',
  full_name='apollo.canbus.Parking_control_a5.Parking_enable_controlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARKING_ENABLE_CONTROL_PARKING_MANUALCONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_ENABLE_CONTROL_PARKING_AUTOCONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1314,
  serialized_end=1440,
)
_sym_db.RegisterEnumDescriptor(_PARKING_CONTROL_A5_PARKING_ENABLE_CONTROLTYPE)

_BRAKE_CONTROL_A4_BRAKE_ENABLE_CONTROLTYPE = _descriptor.EnumDescriptor(
  name='Brake_enable_controlType',
  full_name='apollo.canbus.Brake_control_a4.Brake_enable_controlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ENABLE_CONTROL_BRAKE_MANUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ENABLE_CONTROL_BRAKE_AUTO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1573,
  serialized_end=1675,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_CONTROL_A4_BRAKE_ENABLE_CONTROLTYPE)

_ENABLE_STATE_FEEDBACK_C3_PARKING_ENABLE_STATETYPE = _descriptor.EnumDescriptor(
  name='Parking_enable_stateType',
  full_name='apollo.canbus.Enable_state_feedback_c3.Parking_enable_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARKING_ENABLE_STATE_PARKING_MANUALCONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_ENABLE_STATE_PARKING_AUTOCONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_ENABLE_STATE_PARKING_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2179,
  serialized_end=2342,
)
_sym_db.RegisterEnumDescriptor(_ENABLE_STATE_FEEDBACK_C3_PARKING_ENABLE_STATETYPE)

_ENABLE_STATE_FEEDBACK_C3_STEERING_ENABLE_STATETYPE = _descriptor.EnumDescriptor(
  name='Steering_enable_stateType',
  full_name='apollo.canbus.Enable_state_feedback_c3.Steering_enable_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEERING_ENABLE_STATE_STEERING_MANUALCONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEERING_ENABLE_STATE_STEERING_AUTOCONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEERING_ENABLE_STATE_STEERING_MANUAL_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2345,
  serialized_end=2522,
)
_sym_db.RegisterEnumDescriptor(_ENABLE_STATE_FEEDBACK_C3_STEERING_ENABLE_STATETYPE)

_ENABLE_STATE_FEEDBACK_C3_GEAR_ENABLE_ACTUALTYPE = _descriptor.EnumDescriptor(
  name='Gear_enable_actualType',
  full_name='apollo.canbus.Enable_state_feedback_c3.Gear_enable_actualType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_ENABLE_ACTUAL_GEAR_MANUALCONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_ENABLE_ACTUAL_GEAR_AUTOCONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_ENABLE_ACTUAL_GEAR_MANUAL_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2525,
  serialized_end=2678,
)
_sym_db.RegisterEnumDescriptor(_ENABLE_STATE_FEEDBACK_C3_GEAR_ENABLE_ACTUALTYPE)

_ENABLE_STATE_FEEDBACK_C3_DRIVEN_ENABLE_STATETYPE = _descriptor.EnumDescriptor(
  name='Driven_enable_stateType',
  full_name='apollo.canbus.Enable_state_feedback_c3.Driven_enable_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ENABLE_STATE_DRIVE_MANUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ENABLE_STATE_DRIVE_AUTO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ENABLE_STATE_DRIVE_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2681,
  serialized_end=2820,
)
_sym_db.RegisterEnumDescriptor(_ENABLE_STATE_FEEDBACK_C3_DRIVEN_ENABLE_STATETYPE)

_ENABLE_STATE_FEEDBACK_C3_BRAKE_ENABLE_STATETYPE = _descriptor.EnumDescriptor(
  name='Brake_enable_stateType',
  full_name='apollo.canbus.Enable_state_feedback_c3.Brake_enable_stateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ENABLE_STATE_BRAKE_MANUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ENABLE_STATE_BRAKE_AUTO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ENABLE_STATE_BRAKE_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2823,
  serialized_end=2958,
)
_sym_db.RegisterEnumDescriptor(_ENABLE_STATE_FEEDBACK_C3_BRAKE_ENABLE_STATETYPE)

_VEHICLE_STATE_FEEDBACK_C1_PARKING_ACTUALTYPE = _descriptor.EnumDescriptor(
  name='Parking_actualType',
  full_name='apollo.canbus.Vehicle_state_feedback_c1.Parking_actualType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARKING_ACTUAL_RELEASE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_ACTUAL_PARKING_TRIGGER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3237,
  serialized_end=3321,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE_STATE_FEEDBACK_C1_PARKING_ACTUALTYPE)

_VEHICLE_STATE_FEEDBACK_C1_GEAR_STATE_ACTUALTYPE = _descriptor.EnumDescriptor(
  name='Gear_state_actualType',
  full_name='apollo.canbus.Vehicle_state_feedback_c1.Gear_state_actualType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_ACTUAL_P', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_ACTUAL_N', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_ACTUAL_D', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_ACTUAL_R', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STATE_ACTUAL_INVALID', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3324,
  serialized_end=3478,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE_STATE_FEEDBACK_C1_GEAR_STATE_ACTUALTYPE)

_ERROR_STATE_E1_BRAKE_ERROR_CODETYPE = _descriptor.EnumDescriptor(
  name='Brake_error_codeType',
  full_name='apollo.canbus.Error_state_e1.Brake_error_codeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ERROR_CODE_NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ERROR_CODE_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3897,
  serialized_end=3978,
)
_sym_db.RegisterEnumDescriptor(_ERROR_STATE_E1_BRAKE_ERROR_CODETYPE)

_ERROR_STATE_E1_DRIVEN_ERROR_CODETYPE = _descriptor.EnumDescriptor(
  name='Driven_error_codeType',
  full_name='apollo.canbus.Error_state_e1.Driven_error_codeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ERROR_CODE_NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVEN_ERROR_CODE_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3980,
  serialized_end=4064,
)
_sym_db.RegisterEnumDescriptor(_ERROR_STATE_E1_DRIVEN_ERROR_CODETYPE)

_ERROR_STATE_E1_STEERING_ERROR_CODETYPE = _descriptor.EnumDescriptor(
  name='Steering_error_codeType',
  full_name='apollo.canbus.Error_state_e1.Steering_error_codeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEERING_ERROR_CODE_NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEERING_ERROR_CODE_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4066,
  serialized_end=4156,
)
_sym_db.RegisterEnumDescriptor(_ERROR_STATE_E1_STEERING_ERROR_CODETYPE)

_ERROR_STATE_E1_PARKING_ERROR_CODETYPE = _descriptor.EnumDescriptor(
  name='Parking_error_codeType',
  full_name='apollo.canbus.Error_state_e1.Parking_error_codeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARKING_ERROR_CODE_NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_ERROR_CODE_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4158,
  serialized_end=4245,
)
_sym_db.RegisterEnumDescriptor(_ERROR_STATE_E1_PARKING_ERROR_CODETYPE)

_ERROR_STATE_E1_GEAR_ERROR_MSGTYPE = _descriptor.EnumDescriptor(
  name='Gear_error_msgType',
  full_name='apollo.canbus.Error_state_e1.Gear_error_msgType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_ERROR_MSG_NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_ERROR_MSG_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4247,
  serialized_end=4322,
)
_sym_db.RegisterEnumDescriptor(_ERROR_STATE_E1_GEAR_ERROR_MSGTYPE)


_GEAR_CONTROL_A1 = _descriptor.Descriptor(
  name='Gear_control_a1',
  full_name='apollo.canbus.Gear_control_a1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gear_state_target', full_name='apollo.canbus.Gear_control_a1.gear_state_target', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_enable_control', full_name='apollo.canbus.Gear_control_a1.gear_enable_control', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GEAR_CONTROL_A1_GEAR_STATE_TARGETTYPE,
    _GEAR_CONTROL_A1_GEAR_ENABLE_CONTROLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=508,
)


_TORQUE_CONTROL_A3 = _descriptor.Descriptor(
  name='Torque_control_a3',
  full_name='apollo.canbus.Torque_control_a3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='driven_torque', full_name='apollo.canbus.Torque_control_a3.driven_torque', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driven_enable_control', full_name='apollo.canbus.Torque_control_a3.driven_enable_control', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TORQUE_CONTROL_A3_DRIVEN_ENABLE_CONTROLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=511,
  serialized_end=751,
)


_STEERING_CONTROL_A2 = _descriptor.Descriptor(
  name='Steering_control_a2',
  full_name='apollo.canbus.Steering_control_a2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steering_target', full_name='apollo.canbus.Steering_control_a2.steering_target', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_enable_control', full_name='apollo.canbus.Steering_control_a2.steering_enable_control', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STEERING_CONTROL_A2_STEERING_ENABLE_CONTROLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=754,
  serialized_end=1031,
)


_PARKING_CONTROL_A5 = _descriptor.Descriptor(
  name='Parking_control_a5',
  full_name='apollo.canbus.Parking_control_a5',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parking_target', full_name='apollo.canbus.Parking_control_a5.parking_target', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_enable_control', full_name='apollo.canbus.Parking_control_a5.parking_enable_control', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PARKING_CONTROL_A5_PARKING_TARGETTYPE,
    _PARKING_CONTROL_A5_PARKING_ENABLE_CONTROLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1440,
)


_BRAKE_CONTROL_A4 = _descriptor.Descriptor(
  name='Brake_control_a4',
  full_name='apollo.canbus.Brake_control_a4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brake_torque', full_name='apollo.canbus.Brake_control_a4.brake_torque', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_enable_control', full_name='apollo.canbus.Brake_control_a4.brake_enable_control', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BRAKE_CONTROL_A4_BRAKE_ENABLE_CONTROLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1675,
)


_ENABLE_STATE_FEEDBACK_C3 = _descriptor.Descriptor(
  name='Enable_state_feedback_c3',
  full_name='apollo.canbus.Enable_state_feedback_c3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parking_enable_state', full_name='apollo.canbus.Enable_state_feedback_c3.parking_enable_state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_enable_state', full_name='apollo.canbus.Enable_state_feedback_c3.steering_enable_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_enable_actual', full_name='apollo.canbus.Enable_state_feedback_c3.gear_enable_actual', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driven_enable_state', full_name='apollo.canbus.Enable_state_feedback_c3.driven_enable_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_enable_state', full_name='apollo.canbus.Enable_state_feedback_c3.brake_enable_state', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ENABLE_STATE_FEEDBACK_C3_PARKING_ENABLE_STATETYPE,
    _ENABLE_STATE_FEEDBACK_C3_STEERING_ENABLE_STATETYPE,
    _ENABLE_STATE_FEEDBACK_C3_GEAR_ENABLE_ACTUALTYPE,
    _ENABLE_STATE_FEEDBACK_C3_DRIVEN_ENABLE_STATETYPE,
    _ENABLE_STATE_FEEDBACK_C3_BRAKE_ENABLE_STATETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1678,
  serialized_end=2958,
)


_VEHICLE_STATE_FEEDBACK_C1 = _descriptor.Descriptor(
  name='Vehicle_state_feedback_c1',
  full_name='apollo.canbus.Vehicle_state_feedback_c1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parking_actual', full_name='apollo.canbus.Vehicle_state_feedback_c1.parking_actual', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_torque_feedback', full_name='apollo.canbus.Vehicle_state_feedback_c1.brake_torque_feedback', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_state_actual', full_name='apollo.canbus.Vehicle_state_feedback_c1.gear_state_actual', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_actual', full_name='apollo.canbus.Vehicle_state_feedback_c1.steering_actual', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.canbus.Vehicle_state_feedback_c1.speed', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VEHICLE_STATE_FEEDBACK_C1_PARKING_ACTUALTYPE,
    _VEHICLE_STATE_FEEDBACK_C1_GEAR_STATE_ACTUALTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2961,
  serialized_end=3478,
)


_ERROR_STATE_E1 = _descriptor.Descriptor(
  name='Error_state_e1',
  full_name='apollo.canbus.Error_state_e1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brake_error_code', full_name='apollo.canbus.Error_state_e1.brake_error_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driven_error_code', full_name='apollo.canbus.Error_state_e1.driven_error_code', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_error_code', full_name='apollo.canbus.Error_state_e1.steering_error_code', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_error_code', full_name='apollo.canbus.Error_state_e1.parking_error_code', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_error_msg', full_name='apollo.canbus.Error_state_e1.gear_error_msg', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ERROR_STATE_E1_BRAKE_ERROR_CODETYPE,
    _ERROR_STATE_E1_DRIVEN_ERROR_CODETYPE,
    _ERROR_STATE_E1_STEERING_ERROR_CODETYPE,
    _ERROR_STATE_E1_PARKING_ERROR_CODETYPE,
    _ERROR_STATE_E1_GEAR_ERROR_MSGTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3481,
  serialized_end=4322,
)


_VEHICLE_STATE_FEEDBACK_2_C4 = _descriptor.Descriptor(
  name='Vehicle_state_feedback_2_c4',
  full_name='apollo.canbus.Vehicle_state_feedback_2_c4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='motor_speed', full_name='apollo.canbus.Vehicle_state_feedback_2_c4.motor_speed', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driven_torque_feedback', full_name='apollo.canbus.Vehicle_state_feedback_2_c4.driven_torque_feedback', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4324,
  serialized_end=4406,
)


_ZHONGYUN = _descriptor.Descriptor(
  name='Zhongyun',
  full_name='apollo.canbus.Zhongyun',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gear_control_a1', full_name='apollo.canbus.Zhongyun.gear_control_a1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='torque_control_a3', full_name='apollo.canbus.Zhongyun.torque_control_a3', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_control_a2', full_name='apollo.canbus.Zhongyun.steering_control_a2', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_control_a5', full_name='apollo.canbus.Zhongyun.parking_control_a5', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_control_a4', full_name='apollo.canbus.Zhongyun.brake_control_a4', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_state_feedback_c3', full_name='apollo.canbus.Zhongyun.enable_state_feedback_c3', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_state_feedback_c1', full_name='apollo.canbus.Zhongyun.vehicle_state_feedback_c1', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_state_e1', full_name='apollo.canbus.Zhongyun.error_state_e1', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_state_feedback_2_c4', full_name='apollo.canbus.Zhongyun.vehicle_state_feedback_2_c4', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4409,
  serialized_end=5012,
)

_GEAR_CONTROL_A1.fields_by_name['gear_state_target'].enum_type = _GEAR_CONTROL_A1_GEAR_STATE_TARGETTYPE
_GEAR_CONTROL_A1.fields_by_name['gear_enable_control'].enum_type = _GEAR_CONTROL_A1_GEAR_ENABLE_CONTROLTYPE
_GEAR_CONTROL_A1_GEAR_STATE_TARGETTYPE.containing_type = _GEAR_CONTROL_A1
_GEAR_CONTROL_A1_GEAR_ENABLE_CONTROLTYPE.containing_type = _GEAR_CONTROL_A1
_TORQUE_CONTROL_A3.fields_by_name['driven_enable_control'].enum_type = _TORQUE_CONTROL_A3_DRIVEN_ENABLE_CONTROLTYPE
_TORQUE_CONTROL_A3_DRIVEN_ENABLE_CONTROLTYPE.containing_type = _TORQUE_CONTROL_A3
_STEERING_CONTROL_A2.fields_by_name['steering_enable_control'].enum_type = _STEERING_CONTROL_A2_STEERING_ENABLE_CONTROLTYPE
_STEERING_CONTROL_A2_STEERING_ENABLE_CONTROLTYPE.containing_type = _STEERING_CONTROL_A2
_PARKING_CONTROL_A5.fields_by_name['parking_target'].enum_type = _PARKING_CONTROL_A5_PARKING_TARGETTYPE
_PARKING_CONTROL_A5.fields_by_name['parking_enable_control'].enum_type = _PARKING_CONTROL_A5_PARKING_ENABLE_CONTROLTYPE
_PARKING_CONTROL_A5_PARKING_TARGETTYPE.containing_type = _PARKING_CONTROL_A5
_PARKING_CONTROL_A5_PARKING_ENABLE_CONTROLTYPE.containing_type = _PARKING_CONTROL_A5
_BRAKE_CONTROL_A4.fields_by_name['brake_enable_control'].enum_type = _BRAKE_CONTROL_A4_BRAKE_ENABLE_CONTROLTYPE
_BRAKE_CONTROL_A4_BRAKE_ENABLE_CONTROLTYPE.containing_type = _BRAKE_CONTROL_A4
_ENABLE_STATE_FEEDBACK_C3.fields_by_name['parking_enable_state'].enum_type = _ENABLE_STATE_FEEDBACK_C3_PARKING_ENABLE_STATETYPE
_ENABLE_STATE_FEEDBACK_C3.fields_by_name['steering_enable_state'].enum_type = _ENABLE_STATE_FEEDBACK_C3_STEERING_ENABLE_STATETYPE
_ENABLE_STATE_FEEDBACK_C3.fields_by_name['gear_enable_actual'].enum_type = _ENABLE_STATE_FEEDBACK_C3_GEAR_ENABLE_ACTUALTYPE
_ENABLE_STATE_FEEDBACK_C3.fields_by_name['driven_enable_state'].enum_type = _ENABLE_STATE_FEEDBACK_C3_DRIVEN_ENABLE_STATETYPE
_ENABLE_STATE_FEEDBACK_C3.fields_by_name['brake_enable_state'].enum_type = _ENABLE_STATE_FEEDBACK_C3_BRAKE_ENABLE_STATETYPE
_ENABLE_STATE_FEEDBACK_C3_PARKING_ENABLE_STATETYPE.containing_type = _ENABLE_STATE_FEEDBACK_C3
_ENABLE_STATE_FEEDBACK_C3_STEERING_ENABLE_STATETYPE.containing_type = _ENABLE_STATE_FEEDBACK_C3
_ENABLE_STATE_FEEDBACK_C3_GEAR_ENABLE_ACTUALTYPE.containing_type = _ENABLE_STATE_FEEDBACK_C3
_ENABLE_STATE_FEEDBACK_C3_DRIVEN_ENABLE_STATETYPE.containing_type = _ENABLE_STATE_FEEDBACK_C3
_ENABLE_STATE_FEEDBACK_C3_BRAKE_ENABLE_STATETYPE.containing_type = _ENABLE_STATE_FEEDBACK_C3
_VEHICLE_STATE_FEEDBACK_C1.fields_by_name['parking_actual'].enum_type = _VEHICLE_STATE_FEEDBACK_C1_PARKING_ACTUALTYPE
_VEHICLE_STATE_FEEDBACK_C1.fields_by_name['gear_state_actual'].enum_type = _VEHICLE_STATE_FEEDBACK_C1_GEAR_STATE_ACTUALTYPE
_VEHICLE_STATE_FEEDBACK_C1_PARKING_ACTUALTYPE.containing_type = _VEHICLE_STATE_FEEDBACK_C1
_VEHICLE_STATE_FEEDBACK_C1_GEAR_STATE_ACTUALTYPE.containing_type = _VEHICLE_STATE_FEEDBACK_C1
_ERROR_STATE_E1.fields_by_name['brake_error_code'].enum_type = _ERROR_STATE_E1_BRAKE_ERROR_CODETYPE
_ERROR_STATE_E1.fields_by_name['driven_error_code'].enum_type = _ERROR_STATE_E1_DRIVEN_ERROR_CODETYPE
_ERROR_STATE_E1.fields_by_name['steering_error_code'].enum_type = _ERROR_STATE_E1_STEERING_ERROR_CODETYPE
_ERROR_STATE_E1.fields_by_name['parking_error_code'].enum_type = _ERROR_STATE_E1_PARKING_ERROR_CODETYPE
_ERROR_STATE_E1.fields_by_name['gear_error_msg'].enum_type = _ERROR_STATE_E1_GEAR_ERROR_MSGTYPE
_ERROR_STATE_E1_BRAKE_ERROR_CODETYPE.containing_type = _ERROR_STATE_E1
_ERROR_STATE_E1_DRIVEN_ERROR_CODETYPE.containing_type = _ERROR_STATE_E1
_ERROR_STATE_E1_STEERING_ERROR_CODETYPE.containing_type = _ERROR_STATE_E1
_ERROR_STATE_E1_PARKING_ERROR_CODETYPE.containing_type = _ERROR_STATE_E1
_ERROR_STATE_E1_GEAR_ERROR_MSGTYPE.containing_type = _ERROR_STATE_E1
_ZHONGYUN.fields_by_name['gear_control_a1'].message_type = _GEAR_CONTROL_A1
_ZHONGYUN.fields_by_name['torque_control_a3'].message_type = _TORQUE_CONTROL_A3
_ZHONGYUN.fields_by_name['steering_control_a2'].message_type = _STEERING_CONTROL_A2
_ZHONGYUN.fields_by_name['parking_control_a5'].message_type = _PARKING_CONTROL_A5
_ZHONGYUN.fields_by_name['brake_control_a4'].message_type = _BRAKE_CONTROL_A4
_ZHONGYUN.fields_by_name['enable_state_feedback_c3'].message_type = _ENABLE_STATE_FEEDBACK_C3
_ZHONGYUN.fields_by_name['vehicle_state_feedback_c1'].message_type = _VEHICLE_STATE_FEEDBACK_C1
_ZHONGYUN.fields_by_name['error_state_e1'].message_type = _ERROR_STATE_E1
_ZHONGYUN.fields_by_name['vehicle_state_feedback_2_c4'].message_type = _VEHICLE_STATE_FEEDBACK_2_C4
DESCRIPTOR.message_types_by_name['Gear_control_a1'] = _GEAR_CONTROL_A1
DESCRIPTOR.message_types_by_name['Torque_control_a3'] = _TORQUE_CONTROL_A3
DESCRIPTOR.message_types_by_name['Steering_control_a2'] = _STEERING_CONTROL_A2
DESCRIPTOR.message_types_by_name['Parking_control_a5'] = _PARKING_CONTROL_A5
DESCRIPTOR.message_types_by_name['Brake_control_a4'] = _BRAKE_CONTROL_A4
DESCRIPTOR.message_types_by_name['Enable_state_feedback_c3'] = _ENABLE_STATE_FEEDBACK_C3
DESCRIPTOR.message_types_by_name['Vehicle_state_feedback_c1'] = _VEHICLE_STATE_FEEDBACK_C1
DESCRIPTOR.message_types_by_name['Error_state_e1'] = _ERROR_STATE_E1
DESCRIPTOR.message_types_by_name['Vehicle_state_feedback_2_c4'] = _VEHICLE_STATE_FEEDBACK_2_C4
DESCRIPTOR.message_types_by_name['Zhongyun'] = _ZHONGYUN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Gear_control_a1 = _reflection.GeneratedProtocolMessageType('Gear_control_a1', (_message.Message,), {
  'DESCRIPTOR' : _GEAR_CONTROL_A1,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Gear_control_a1)
  })
_sym_db.RegisterMessage(Gear_control_a1)

Torque_control_a3 = _reflection.GeneratedProtocolMessageType('Torque_control_a3', (_message.Message,), {
  'DESCRIPTOR' : _TORQUE_CONTROL_A3,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Torque_control_a3)
  })
_sym_db.RegisterMessage(Torque_control_a3)

Steering_control_a2 = _reflection.GeneratedProtocolMessageType('Steering_control_a2', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_CONTROL_A2,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_control_a2)
  })
_sym_db.RegisterMessage(Steering_control_a2)

Parking_control_a5 = _reflection.GeneratedProtocolMessageType('Parking_control_a5', (_message.Message,), {
  'DESCRIPTOR' : _PARKING_CONTROL_A5,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Parking_control_a5)
  })
_sym_db.RegisterMessage(Parking_control_a5)

Brake_control_a4 = _reflection.GeneratedProtocolMessageType('Brake_control_a4', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_CONTROL_A4,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_control_a4)
  })
_sym_db.RegisterMessage(Brake_control_a4)

Enable_state_feedback_c3 = _reflection.GeneratedProtocolMessageType('Enable_state_feedback_c3', (_message.Message,), {
  'DESCRIPTOR' : _ENABLE_STATE_FEEDBACK_C3,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Enable_state_feedback_c3)
  })
_sym_db.RegisterMessage(Enable_state_feedback_c3)

Vehicle_state_feedback_c1 = _reflection.GeneratedProtocolMessageType('Vehicle_state_feedback_c1', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLE_STATE_FEEDBACK_C1,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vehicle_state_feedback_c1)
  })
_sym_db.RegisterMessage(Vehicle_state_feedback_c1)

Error_state_e1 = _reflection.GeneratedProtocolMessageType('Error_state_e1', (_message.Message,), {
  'DESCRIPTOR' : _ERROR_STATE_E1,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Error_state_e1)
  })
_sym_db.RegisterMessage(Error_state_e1)

Vehicle_state_feedback_2_c4 = _reflection.GeneratedProtocolMessageType('Vehicle_state_feedback_2_c4', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLE_STATE_FEEDBACK_2_C4,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vehicle_state_feedback_2_c4)
  })
_sym_db.RegisterMessage(Vehicle_state_feedback_2_c4)

Zhongyun = _reflection.GeneratedProtocolMessageType('Zhongyun', (_message.Message,), {
  'DESCRIPTOR' : _ZHONGYUN,
  '__module__' : 'modules.canbus.proto.zhongyun_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Zhongyun)
  })
_sym_db.RegisterMessage(Zhongyun)


# @@protoc_insertion_point(module_scope)
