# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/choreography_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/choreography_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#cyber/proto/choreography_conf.proto\x12\x12\x61pollo.cyber.proto\"D\n\x10\x43horeographyTask\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\x05\x12\x0f\n\x04prio\x18\x03 \x01(\r:\x01\x31\"\xf7\x02\n\x10\x43horeographyConf\x12\"\n\x1a\x63horeography_processor_num\x18\x01 \x01(\r\x12\x1d\n\x15\x63horeography_affinity\x18\x02 \x01(\t\x12%\n\x1d\x63horeography_processor_policy\x18\x03 \x01(\t\x12#\n\x1b\x63horeography_processor_prio\x18\x04 \x01(\x05\x12\x1b\n\x13\x63horeography_cpuset\x18\x05 \x01(\t\x12\x1a\n\x12pool_processor_num\x18\x06 \x01(\r\x12\x15\n\rpool_affinity\x18\x07 \x01(\t\x12\x1d\n\x15pool_processor_policy\x18\x08 \x01(\t\x12\x1b\n\x13pool_processor_prio\x18\t \x01(\x05\x12\x13\n\x0bpool_cpuset\x18\n \x01(\t\x12\x33\n\x05tasks\x18\x0b \x03(\x0b\x32$.apollo.cyber.proto.ChoreographyTask'
)




_CHOREOGRAPHYTASK = _descriptor.Descriptor(
  name='ChoreographyTask',
  full_name='apollo.cyber.proto.ChoreographyTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.ChoreographyTask.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processor', full_name='apollo.cyber.proto.ChoreographyTask.processor', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prio', full_name='apollo.cyber.proto.ChoreographyTask.prio', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=127,
)


_CHOREOGRAPHYCONF = _descriptor.Descriptor(
  name='ChoreographyConf',
  full_name='apollo.cyber.proto.ChoreographyConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choreography_processor_num', full_name='apollo.cyber.proto.ChoreographyConf.choreography_processor_num', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choreography_affinity', full_name='apollo.cyber.proto.ChoreographyConf.choreography_affinity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choreography_processor_policy', full_name='apollo.cyber.proto.ChoreographyConf.choreography_processor_policy', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choreography_processor_prio', full_name='apollo.cyber.proto.ChoreographyConf.choreography_processor_prio', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choreography_cpuset', full_name='apollo.cyber.proto.ChoreographyConf.choreography_cpuset', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_processor_num', full_name='apollo.cyber.proto.ChoreographyConf.pool_processor_num', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_affinity', full_name='apollo.cyber.proto.ChoreographyConf.pool_affinity', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_processor_policy', full_name='apollo.cyber.proto.ChoreographyConf.pool_processor_policy', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_processor_prio', full_name='apollo.cyber.proto.ChoreographyConf.pool_processor_prio', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_cpuset', full_name='apollo.cyber.proto.ChoreographyConf.pool_cpuset', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='apollo.cyber.proto.ChoreographyConf.tasks', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=505,
)

_CHOREOGRAPHYCONF.fields_by_name['tasks'].message_type = _CHOREOGRAPHYTASK
DESCRIPTOR.message_types_by_name['ChoreographyTask'] = _CHOREOGRAPHYTASK
DESCRIPTOR.message_types_by_name['ChoreographyConf'] = _CHOREOGRAPHYCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChoreographyTask = _reflection.GeneratedProtocolMessageType('ChoreographyTask', (_message.Message,), {
  'DESCRIPTOR' : _CHOREOGRAPHYTASK,
  '__module__' : 'cyber.proto.choreography_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ChoreographyTask)
  })
_sym_db.RegisterMessage(ChoreographyTask)

ChoreographyConf = _reflection.GeneratedProtocolMessageType('ChoreographyConf', (_message.Message,), {
  'DESCRIPTOR' : _CHOREOGRAPHYCONF,
  '__module__' : 'cyber.proto.choreography_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ChoreographyConf)
  })
_sym_db.RegisterMessage(ChoreographyConf)


# @@protoc_insertion_point(module_scope)
