# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/task_manager/proto/task_manager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.routing.proto import routing_pb2 as modules_dot_routing_dot_proto_dot_routing__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/task_manager/proto/task_manager.proto',
  package='apollo.task_manager',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-modules/task_manager/proto/task_manager.proto\x12\x13\x61pollo.task_manager\x1a!modules/common/proto/header.proto\x1a#modules/routing/proto/routing.proto\"^\n\x10\x43ycleRoutingTask\x12\x11\n\tcycle_num\x18\x01 \x01(\x05\x12\x37\n\x0frouting_request\x18\x02 \x01(\x0b\x32\x1e.apollo.routing.RoutingRequest\"\xb5\x01\n\x04Task\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x11\n\ttask_name\x18\x02 \x01(\t\x12\x30\n\ttask_type\x18\x03 \x01(\x0e\x32\x1d.apollo.task_manager.TaskType\x12\x41\n\x12\x63ycle_routing_task\x18\x04 \x01(\x0b\x32%.apollo.task_manager.CycleRoutingTask*\x1d\n\x08TaskType\x12\x11\n\rCYCLE_ROUTING\x10\x00'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_routing_dot_proto_dot_routing__pb2.DESCRIPTOR,])

_TASKTYPE = _descriptor.EnumDescriptor(
  name='TaskType',
  full_name='apollo.task_manager.TaskType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CYCLE_ROUTING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=422,
  serialized_end=451,
)
_sym_db.RegisterEnumDescriptor(_TASKTYPE)

TaskType = enum_type_wrapper.EnumTypeWrapper(_TASKTYPE)
CYCLE_ROUTING = 0



_CYCLEROUTINGTASK = _descriptor.Descriptor(
  name='CycleRoutingTask',
  full_name='apollo.task_manager.CycleRoutingTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cycle_num', full_name='apollo.task_manager.CycleRoutingTask.cycle_num', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_request', full_name='apollo.task_manager.CycleRoutingTask.routing_request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=236,
)


_TASK = _descriptor.Descriptor(
  name='Task',
  full_name='apollo.task_manager.Task',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.task_manager.Task.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_name', full_name='apollo.task_manager.Task.task_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_type', full_name='apollo.task_manager.Task.task_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cycle_routing_task', full_name='apollo.task_manager.Task.cycle_routing_task', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=420,
)

_CYCLEROUTINGTASK.fields_by_name['routing_request'].message_type = modules_dot_routing_dot_proto_dot_routing__pb2._ROUTINGREQUEST
_TASK.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_TASK.fields_by_name['task_type'].enum_type = _TASKTYPE
_TASK.fields_by_name['cycle_routing_task'].message_type = _CYCLEROUTINGTASK
DESCRIPTOR.message_types_by_name['CycleRoutingTask'] = _CYCLEROUTINGTASK
DESCRIPTOR.message_types_by_name['Task'] = _TASK
DESCRIPTOR.enum_types_by_name['TaskType'] = _TASKTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CycleRoutingTask = _reflection.GeneratedProtocolMessageType('CycleRoutingTask', (_message.Message,), {
  'DESCRIPTOR' : _CYCLEROUTINGTASK,
  '__module__' : 'modules.task_manager.proto.task_manager_pb2'
  # @@protoc_insertion_point(class_scope:apollo.task_manager.CycleRoutingTask)
  })
_sym_db.RegisterMessage(CycleRoutingTask)

Task = _reflection.GeneratedProtocolMessageType('Task', (_message.Message,), {
  'DESCRIPTOR' : _TASK,
  '__module__' : 'modules.task_manager.proto.task_manager_pb2'
  # @@protoc_insertion_point(class_scope:apollo.task_manager.Task)
  })
_sym_db.RegisterMessage(Task)


# @@protoc_insertion_point(module_scope)
