# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/open_space_task_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.planning.proto import planner_open_space_config_pb2 as modules_dot_planning_dot_proto_dot_planner__open__space__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/open_space_task_config.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3modules/planning/proto/open_space_task_config.proto\x12\x0f\x61pollo.planning\x1a\x36modules/planning/proto/planner_open_space_config.proto\"\xe6\x01\n\x1eOpenSpaceFallBackDeciderConfig\x12,\n!open_space_prediction_time_period\x18\x01 \x01(\x01:\x01\x35\x12\x31\n&open_space_fallback_collision_distance\x18\x02 \x01(\x01:\x01\x35\x12,\n!open_space_fallback_stop_distance\x18\x03 \x01(\x01:\x01\x32\x12\x35\n)open_space_fallback_collision_time_buffer\x18\x04 \x01(\x01:\x02\x31\x30\"\x86\x02\n\x1dOpenSpacePreStopDeciderConfig\x12J\n\tstop_type\x18\x01 \x01(\x0e\x32\x37.apollo.planning.OpenSpacePreStopDeciderConfig.StopType\x12\"\n\x17rightaway_stop_distance\x18\x02 \x01(\x01:\x01\x32\x12\"\n\x17stop_distance_to_target\x18\x03 \x01(\x01:\x01\x35\"Q\n\x08StopType\x12\x0f\n\x0bNOT_DEFINED\x10\x00\x12\x0b\n\x07PARKING\x10\x01\x12\r\n\tPULL_OVER\x10\x02\x12\x18\n\x14NARROW_STREET_U_TURN\x10\x03\"\xc8\x05\n\x19OpenSpaceRoiDeciderConfig\x12\x44\n\x08roi_type\x18\x01 \x01(\x0e\x32\x32.apollo.planning.OpenSpaceRoiDeciderConfig.RoiType\x12(\n\x1croi_longitudinal_range_start\x18\x02 \x01(\x01:\x02\x31\x30\x12&\n\x1aroi_longitudinal_range_end\x18\x03 \x01(\x01:\x02\x31\x30\x12\x1e\n\x13parking_start_range\x18\x04 \x01(\x01:\x01\x37\x12\x1e\n\x0fparking_inwards\x18\x05 \x01(\x08:\x05\x66\x61lse\x12#\n\x1b\x65nable_perception_obstacles\x18\x06 \x01(\x08\x12!\n\x14parking_depth_buffer\x18\x07 \x01(\x01:\x03\x30.1\x12\'\n\x1aroi_line_segment_min_angle\x18\x08 \x01(\x01:\x03\x30.3\x12\"\n\x17roi_line_segment_length\x18\t \x01(\x01:\x01\x31\x12,\n roi_line_segment_length_from_map\x18\n \x01(\x01:\x02\x31\x30\x12\x34\n&perception_obstacle_filtering_distance\x18\x0b \x01(\x01:\x04\x31\x30\x30\x30\x12\"\n\x1aperception_obstacle_buffer\x18\x0c \x01(\x01\x12\x32\n\'curb_heading_tangent_change_upper_limit\x18\r \x01(\x01:\x01\x31\x12\x1f\n\x13\x65nd_pose_s_distance\x18\x0e \x01(\x01:\x02\x31\x30\"a\n\x07RoiType\x12\x0f\n\x0bNOT_DEFINED\x10\x00\x12\x0b\n\x07PARKING\x10\x01\x12\r\n\tPULL_OVER\x10\x02\x12\x0f\n\x0bPARK_AND_GO\x10\x03\x12\x18\n\x14NARROW_STREET_U_TURN\x10\x04\"\x82\x04\n\"OpenSpaceTrajectoryPartitionConfig\x12\x18\n\x10gear_shift_max_t\x18\x01 \x01(\x01\x12\x19\n\x11gear_shift_unit_t\x18\x02 \x01(\x01\x12\"\n\x1agear_shift_period_duration\x18\x03 \x01(\x01\x12\x1f\n\x17interpolated_pieces_num\x18\x04 \x01(\x04\x12\"\n\x1ainitial_gear_check_horizon\x18\x05 \x01(\x04\x12\x1c\n\x14heading_search_range\x18\x06 \x01(\x01\x12\x1b\n\x13heading_track_range\x18\x07 \x01(\x01\x12$\n\x15\x64istance_search_range\x18\x08 \x01(\x01:\x05\x31\x65-06\x12\"\n\x1aheading_offset_to_midpoint\x18\t \x01(\x01\x12\'\n\x1alateral_offset_to_midpoint\x18\n \x01(\x01:\x03\x30.1\x12,\n\x1flongitudinal_offset_to_midpoint\x18\x0b \x01(\x01:\x03\x30.1\x12\x33\n%vehicle_box_iou_threshold_to_midpoint\x18\x0c \x01(\x01:\x04\x30.95\x12-\n linear_velocity_threshold_on_ego\x18\r \x01(\x01:\x03\x30.2\"\x88\x01\n!OpenSpaceTrajectoryProviderConfig\x12\x63\n&open_space_trajectory_optimizer_config\x18\x01 \x01(\x0b\x32\x33.apollo.planning.OpenSpaceTrajectoryOptimizerConfig\"\xb5\x03\n\"OpenSpaceTrajectoryOptimizerConfig\x12@\n\x14hybrid_a_star_config\x18\x01 \x01(\x0b\x32\".apollo.planning.HybridAStarConfig\x12L\n\x1f\x64ual_variable_warm_start_config\x18\x02 \x01(\x0b\x32#.apollo.planning.DualVariableConfig\x12o\n,distance_approach_trajectory_smoother_config\x18\x03 \x01(\x0b\x32\x39.apollo.planning.DistanceApproachTrajectorySmootherConfig\x12\x14\n\x07\x64\x65lta_t\x18\x04 \x01(\x02:\x03\x30.5\x12,\n\x1dis_near_destination_threshold\x18\x05 \x01(\x01:\x05\x30.001\x12J\n\x19planner_open_space_config\x18\x06 \x01(\x0b\x32\'.apollo.planning.PlannerOpenSpaceConfig\"\xf9\x02\n\x11HybridAStarConfig\x12\x1f\n\x12xy_grid_resolution\x18\x01 \x01(\x01:\x03\x30.2\x12!\n\x13phi_grid_resolution\x18\x02 \x01(\x01:\x04\x30.05\x12\x19\n\rnext_node_num\x18\x03 \x01(\x04:\x02\x31\x30\x12\x16\n\tstep_size\x18\x04 \x01(\x01:\x03\x30.5\x12\x1f\n\x14traj_forward_penalty\x18\x05 \x01(\x01:\x01\x30\x12\x1c\n\x11traj_back_penalty\x18\x06 \x01(\x01:\x01\x30\x12$\n\x18traj_gear_switch_penalty\x18\x07 \x01(\x01:\x02\x31\x30\x12\x1f\n\x12traj_steer_penalty\x18\x08 \x01(\x01:\x03\x31\x30\x30\x12%\n\x19traj_steer_change_penalty\x18\t \x01(\x01:\x02\x31\x30\x12&\n\x19grid_a_star_xy_resolution\x18\x0f \x01(\x01:\x03\x30.1\x12\x18\n\x0bnode_radius\x18\x10 \x01(\x01:\x03\x30.5\"\xe5\x01\n\x12\x44ualVariableConfig\x12\x13\n\x08weight_d\x18\x01 \x01(\x01:\x01\x31\x12\x38\n\x0cipopt_config\x18\x02 \x01(\x0b\x32\".apollo.planning.IpoptSolverConfig\x12\x34\n\tqp_format\x18\x03 \x01(\x0e\x32!.apollo.planning.DualVariableMode\x12\x1e\n\x13min_safety_distance\x18\x04 \x01(\x01:\x01\x30\x12\x19\n\ndebug_osqp\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x0f\n\x04\x62\x65ta\x18\x06 \x01(\x01:\x01\x31\"\xa2\x06\n(DistanceApproachTrajectorySmootherConfig\x12\x14\n\x0cweight_steer\x18\x01 \x01(\x01\x12\x10\n\x08weight_a\x18\x02 \x01(\x01\x12\x19\n\x11weight_steer_rate\x18\x03 \x01(\x01\x12\x15\n\rweight_a_rate\x18\x04 \x01(\x01\x12\x10\n\x08weight_x\x18\x05 \x01(\x01\x12\x10\n\x08weight_y\x18\x06 \x01(\x01\x12\x12\n\nweight_phi\x18\x07 \x01(\x01\x12\x10\n\x08weight_v\x18\x08 \x01(\x01\x12\x1e\n\x16weight_steer_stitching\x18\t \x01(\x01\x12\x1a\n\x12weight_a_stitching\x18\n \x01(\x01\x12\x1f\n\x17weight_first_order_time\x18\x0b \x01(\x01\x12 \n\x18weight_second_order_time\x18\x0c \x01(\x01\x12\x1e\n\x13min_safety_distance\x18\r \x01(\x01:\x01\x30\x12\x1c\n\x11max_speed_forward\x18\x0e \x01(\x01:\x01\x33\x12\x1c\n\x11max_speed_reverse\x18\x0f \x01(\x01:\x01\x32\x12#\n\x18max_acceleration_forward\x18\x10 \x01(\x01:\x01\x32\x12#\n\x18max_acceleration_reverse\x18\x11 \x01(\x01:\x01\x32\x12$\n\x17min_time_sample_scaling\x18\x12 \x01(\x01:\x03\x30.1\x12#\n\x17max_time_sample_scaling\x18\x13 \x01(\x01:\x02\x31\x30\x12\x1b\n\x0cuse_fix_time\x18\x14 \x01(\x08:\x05\x66\x61lse\x12\x38\n\x0cipopt_config\x18\x15 \x01(\x0b\x32\".apollo.planning.IpoptSolverConfig\x12\x1f\n\x17\x65nable_constraint_check\x18\x16 \x01(\x08\x12\x1e\n\x16\x65nable_hand_derivative\x18\x17 \x01(\x08\x12\x1f\n\x17\x65nable_derivative_check\x18\x18 \x01(\x08\x12)\n\x1a\x65nable_initial_final_check\x18\x19 \x01(\x08:\x05\x66\x61lse\"\xff\x02\n\x11IpoptSolverConfig\x12\x19\n\x11ipopt_print_level\x18\x01 \x01(\x05\x12\x19\n\x11mumps_mem_percent\x18\x02 \x01(\x05\x12\x14\n\x0cmumps_pivtol\x18\x03 \x01(\x01\x12\x16\n\x0eipopt_max_iter\x18\x04 \x01(\x05\x12\x11\n\tipopt_tol\x18\x05 \x01(\x01\x12(\n ipopt_acceptable_constr_viol_tol\x18\x06 \x01(\x01\x12&\n\x1eipopt_min_hessian_perturbation\x18\x07 \x01(\x01\x12+\n#ipopt_jacobian_regularization_value\x18\x08 \x01(\x01\x12%\n\x1dipopt_print_timing_statistics\x18\t \x01(\t\x12\x19\n\x11ipopt_alpha_for_y\x18\n \x01(\t\x12\x16\n\x0eipopt_recalc_y\x18\x0b \x01(\t\x12\x1a\n\ripopt_mu_init\x18\x0c \x01(\x01:\x03\x30.1*w\n\x10\x44ualVariableMode\x12\x17\n\x13\x44UAL_VARIABLE_IPOPT\x10\x00\x12\x19\n\x15\x44UAL_VARIABLE_IPOPTQP\x10\x01\x12\x16\n\x12\x44UAL_VARIABLE_OSQP\x10\x02\x12\x17\n\x13\x44UAL_VARIABLE_DEBUG\x10\x03'
  ,
  dependencies=[modules_dot_planning_dot_proto_dot_planner__open__space__config__pb2.DESCRIPTOR,])

_DUALVARIABLEMODE = _descriptor.EnumDescriptor(
  name='DualVariableMode',
  full_name='apollo.planning.DualVariableMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DUAL_VARIABLE_IPOPT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DUAL_VARIABLE_IPOPTQP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DUAL_VARIABLE_OSQP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DUAL_VARIABLE_DEBUG', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4240,
  serialized_end=4359,
)
_sym_db.RegisterEnumDescriptor(_DUALVARIABLEMODE)

DualVariableMode = enum_type_wrapper.EnumTypeWrapper(_DUALVARIABLEMODE)
DUAL_VARIABLE_IPOPT = 0
DUAL_VARIABLE_IPOPTQP = 1
DUAL_VARIABLE_OSQP = 2
DUAL_VARIABLE_DEBUG = 3


_OPENSPACEPRESTOPDECIDERCONFIG_STOPTYPE = _descriptor.EnumDescriptor(
  name='StopType',
  full_name='apollo.planning.OpenSpacePreStopDeciderConfig.StopType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_DEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PULL_OVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROW_STREET_U_TURN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=543,
  serialized_end=624,
)
_sym_db.RegisterEnumDescriptor(_OPENSPACEPRESTOPDECIDERCONFIG_STOPTYPE)

_OPENSPACEROIDECIDERCONFIG_ROITYPE = _descriptor.EnumDescriptor(
  name='RoiType',
  full_name='apollo.planning.OpenSpaceRoiDeciderConfig.RoiType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_DEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PULL_OVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARK_AND_GO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROW_STREET_U_TURN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1242,
  serialized_end=1339,
)
_sym_db.RegisterEnumDescriptor(_OPENSPACEROIDECIDERCONFIG_ROITYPE)


_OPENSPACEFALLBACKDECIDERCONFIG = _descriptor.Descriptor(
  name='OpenSpaceFallBackDeciderConfig',
  full_name='apollo.planning.OpenSpaceFallBackDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='open_space_prediction_time_period', full_name='apollo.planning.OpenSpaceFallBackDeciderConfig.open_space_prediction_time_period', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_space_fallback_collision_distance', full_name='apollo.planning.OpenSpaceFallBackDeciderConfig.open_space_fallback_collision_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_space_fallback_stop_distance', full_name='apollo.planning.OpenSpaceFallBackDeciderConfig.open_space_fallback_stop_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_space_fallback_collision_time_buffer', full_name='apollo.planning.OpenSpaceFallBackDeciderConfig.open_space_fallback_collision_time_buffer', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=359,
)


_OPENSPACEPRESTOPDECIDERCONFIG = _descriptor.Descriptor(
  name='OpenSpacePreStopDeciderConfig',
  full_name='apollo.planning.OpenSpacePreStopDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_type', full_name='apollo.planning.OpenSpacePreStopDeciderConfig.stop_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rightaway_stop_distance', full_name='apollo.planning.OpenSpacePreStopDeciderConfig.rightaway_stop_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_distance_to_target', full_name='apollo.planning.OpenSpacePreStopDeciderConfig.stop_distance_to_target', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPENSPACEPRESTOPDECIDERCONFIG_STOPTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=362,
  serialized_end=624,
)


_OPENSPACEROIDECIDERCONFIG = _descriptor.Descriptor(
  name='OpenSpaceRoiDeciderConfig',
  full_name='apollo.planning.OpenSpaceRoiDeciderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='roi_type', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.roi_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_longitudinal_range_start', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.roi_longitudinal_range_start', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_longitudinal_range_end', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.roi_longitudinal_range_end', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_start_range', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.parking_start_range', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(7),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_inwards', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.parking_inwards', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_perception_obstacles', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.enable_perception_obstacles', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_depth_buffer', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.parking_depth_buffer', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_line_segment_min_angle', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.roi_line_segment_min_angle', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_line_segment_length', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.roi_line_segment_length', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_line_segment_length_from_map', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.roi_line_segment_length_from_map', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perception_obstacle_filtering_distance', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.perception_obstacle_filtering_distance', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1000),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perception_obstacle_buffer', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.perception_obstacle_buffer', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curb_heading_tangent_change_upper_limit', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.curb_heading_tangent_change_upper_limit', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_pose_s_distance', full_name='apollo.planning.OpenSpaceRoiDeciderConfig.end_pose_s_distance', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPENSPACEROIDECIDERCONFIG_ROITYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=1339,
)


_OPENSPACETRAJECTORYPARTITIONCONFIG = _descriptor.Descriptor(
  name='OpenSpaceTrajectoryPartitionConfig',
  full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gear_shift_max_t', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.gear_shift_max_t', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_shift_unit_t', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.gear_shift_unit_t', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_shift_period_duration', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.gear_shift_period_duration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interpolated_pieces_num', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.interpolated_pieces_num', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_gear_check_horizon', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.initial_gear_check_horizon', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_search_range', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.heading_search_range', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_track_range', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.heading_track_range', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_search_range', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.distance_search_range', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1e-06),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_offset_to_midpoint', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.heading_offset_to_midpoint', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_offset_to_midpoint', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.lateral_offset_to_midpoint', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitudinal_offset_to_midpoint', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.longitudinal_offset_to_midpoint', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_box_iou_threshold_to_midpoint', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.vehicle_box_iou_threshold_to_midpoint', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.95),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_velocity_threshold_on_ego', full_name='apollo.planning.OpenSpaceTrajectoryPartitionConfig.linear_velocity_threshold_on_ego', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1342,
  serialized_end=1856,
)


_OPENSPACETRAJECTORYPROVIDERCONFIG = _descriptor.Descriptor(
  name='OpenSpaceTrajectoryProviderConfig',
  full_name='apollo.planning.OpenSpaceTrajectoryProviderConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='open_space_trajectory_optimizer_config', full_name='apollo.planning.OpenSpaceTrajectoryProviderConfig.open_space_trajectory_optimizer_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1859,
  serialized_end=1995,
)


_OPENSPACETRAJECTORYOPTIMIZERCONFIG = _descriptor.Descriptor(
  name='OpenSpaceTrajectoryOptimizerConfig',
  full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hybrid_a_star_config', full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig.hybrid_a_star_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dual_variable_warm_start_config', full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig.dual_variable_warm_start_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_approach_trajectory_smoother_config', full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig.distance_approach_trajectory_smoother_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta_t', full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig.delta_t', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_near_destination_threshold', full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig.is_near_destination_threshold', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.001),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='planner_open_space_config', full_name='apollo.planning.OpenSpaceTrajectoryOptimizerConfig.planner_open_space_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1998,
  serialized_end=2435,
)


_HYBRIDASTARCONFIG = _descriptor.Descriptor(
  name='HybridAStarConfig',
  full_name='apollo.planning.HybridAStarConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='xy_grid_resolution', full_name='apollo.planning.HybridAStarConfig.xy_grid_resolution', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phi_grid_resolution', full_name='apollo.planning.HybridAStarConfig.phi_grid_resolution', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.05),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_node_num', full_name='apollo.planning.HybridAStarConfig.next_node_num', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step_size', full_name='apollo.planning.HybridAStarConfig.step_size', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_forward_penalty', full_name='apollo.planning.HybridAStarConfig.traj_forward_penalty', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_back_penalty', full_name='apollo.planning.HybridAStarConfig.traj_back_penalty', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_gear_switch_penalty', full_name='apollo.planning.HybridAStarConfig.traj_gear_switch_penalty', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_steer_penalty', full_name='apollo.planning.HybridAStarConfig.traj_steer_penalty', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(100),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_steer_change_penalty', full_name='apollo.planning.HybridAStarConfig.traj_steer_change_penalty', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grid_a_star_xy_resolution', full_name='apollo.planning.HybridAStarConfig.grid_a_star_xy_resolution', index=9,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_radius', full_name='apollo.planning.HybridAStarConfig.node_radius', index=10,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2438,
  serialized_end=2815,
)


_DUALVARIABLECONFIG = _descriptor.Descriptor(
  name='DualVariableConfig',
  full_name='apollo.planning.DualVariableConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight_d', full_name='apollo.planning.DualVariableConfig.weight_d', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_config', full_name='apollo.planning.DualVariableConfig.ipopt_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qp_format', full_name='apollo.planning.DualVariableConfig.qp_format', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_safety_distance', full_name='apollo.planning.DualVariableConfig.min_safety_distance', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug_osqp', full_name='apollo.planning.DualVariableConfig.debug_osqp', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beta', full_name='apollo.planning.DualVariableConfig.beta', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2818,
  serialized_end=3047,
)


_DISTANCEAPPROACHTRAJECTORYSMOOTHERCONFIG = _descriptor.Descriptor(
  name='DistanceApproachTrajectorySmootherConfig',
  full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight_steer', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_steer', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_a', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_a', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_steer_rate', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_steer_rate', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_a_rate', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_a_rate', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_x', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_x', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_y', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_y', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_phi', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_phi', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_v', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_v', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_steer_stitching', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_steer_stitching', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_a_stitching', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_a_stitching', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_first_order_time', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_first_order_time', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_second_order_time', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.weight_second_order_time', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_safety_distance', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.min_safety_distance', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_speed_forward', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.max_speed_forward', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_speed_reverse', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.max_speed_reverse', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_acceleration_forward', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.max_acceleration_forward', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_acceleration_reverse', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.max_acceleration_reverse', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_time_sample_scaling', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.min_time_sample_scaling', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_time_sample_scaling', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.max_time_sample_scaling', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_fix_time', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.use_fix_time', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_config', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.ipopt_config', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_constraint_check', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.enable_constraint_check', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hand_derivative', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.enable_hand_derivative', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_derivative_check', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.enable_derivative_check', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_initial_final_check', full_name='apollo.planning.DistanceApproachTrajectorySmootherConfig.enable_initial_final_check', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3050,
  serialized_end=3852,
)


_IPOPTSOLVERCONFIG = _descriptor.Descriptor(
  name='IpoptSolverConfig',
  full_name='apollo.planning.IpoptSolverConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipopt_print_level', full_name='apollo.planning.IpoptSolverConfig.ipopt_print_level', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mumps_mem_percent', full_name='apollo.planning.IpoptSolverConfig.mumps_mem_percent', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mumps_pivtol', full_name='apollo.planning.IpoptSolverConfig.mumps_pivtol', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_max_iter', full_name='apollo.planning.IpoptSolverConfig.ipopt_max_iter', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_tol', full_name='apollo.planning.IpoptSolverConfig.ipopt_tol', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_acceptable_constr_viol_tol', full_name='apollo.planning.IpoptSolverConfig.ipopt_acceptable_constr_viol_tol', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_min_hessian_perturbation', full_name='apollo.planning.IpoptSolverConfig.ipopt_min_hessian_perturbation', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_jacobian_regularization_value', full_name='apollo.planning.IpoptSolverConfig.ipopt_jacobian_regularization_value', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_print_timing_statistics', full_name='apollo.planning.IpoptSolverConfig.ipopt_print_timing_statistics', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_alpha_for_y', full_name='apollo.planning.IpoptSolverConfig.ipopt_alpha_for_y', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_recalc_y', full_name='apollo.planning.IpoptSolverConfig.ipopt_recalc_y', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_mu_init', full_name='apollo.planning.IpoptSolverConfig.ipopt_mu_init', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3855,
  serialized_end=4238,
)

_OPENSPACEPRESTOPDECIDERCONFIG.fields_by_name['stop_type'].enum_type = _OPENSPACEPRESTOPDECIDERCONFIG_STOPTYPE
_OPENSPACEPRESTOPDECIDERCONFIG_STOPTYPE.containing_type = _OPENSPACEPRESTOPDECIDERCONFIG
_OPENSPACEROIDECIDERCONFIG.fields_by_name['roi_type'].enum_type = _OPENSPACEROIDECIDERCONFIG_ROITYPE
_OPENSPACEROIDECIDERCONFIG_ROITYPE.containing_type = _OPENSPACEROIDECIDERCONFIG
_OPENSPACETRAJECTORYPROVIDERCONFIG.fields_by_name['open_space_trajectory_optimizer_config'].message_type = _OPENSPACETRAJECTORYOPTIMIZERCONFIG
_OPENSPACETRAJECTORYOPTIMIZERCONFIG.fields_by_name['hybrid_a_star_config'].message_type = _HYBRIDASTARCONFIG
_OPENSPACETRAJECTORYOPTIMIZERCONFIG.fields_by_name['dual_variable_warm_start_config'].message_type = _DUALVARIABLECONFIG
_OPENSPACETRAJECTORYOPTIMIZERCONFIG.fields_by_name['distance_approach_trajectory_smoother_config'].message_type = _DISTANCEAPPROACHTRAJECTORYSMOOTHERCONFIG
_OPENSPACETRAJECTORYOPTIMIZERCONFIG.fields_by_name['planner_open_space_config'].message_type = modules_dot_planning_dot_proto_dot_planner__open__space__config__pb2._PLANNEROPENSPACECONFIG
_DUALVARIABLECONFIG.fields_by_name['ipopt_config'].message_type = _IPOPTSOLVERCONFIG
_DUALVARIABLECONFIG.fields_by_name['qp_format'].enum_type = _DUALVARIABLEMODE
_DISTANCEAPPROACHTRAJECTORYSMOOTHERCONFIG.fields_by_name['ipopt_config'].message_type = _IPOPTSOLVERCONFIG
DESCRIPTOR.message_types_by_name['OpenSpaceFallBackDeciderConfig'] = _OPENSPACEFALLBACKDECIDERCONFIG
DESCRIPTOR.message_types_by_name['OpenSpacePreStopDeciderConfig'] = _OPENSPACEPRESTOPDECIDERCONFIG
DESCRIPTOR.message_types_by_name['OpenSpaceRoiDeciderConfig'] = _OPENSPACEROIDECIDERCONFIG
DESCRIPTOR.message_types_by_name['OpenSpaceTrajectoryPartitionConfig'] = _OPENSPACETRAJECTORYPARTITIONCONFIG
DESCRIPTOR.message_types_by_name['OpenSpaceTrajectoryProviderConfig'] = _OPENSPACETRAJECTORYPROVIDERCONFIG
DESCRIPTOR.message_types_by_name['OpenSpaceTrajectoryOptimizerConfig'] = _OPENSPACETRAJECTORYOPTIMIZERCONFIG
DESCRIPTOR.message_types_by_name['HybridAStarConfig'] = _HYBRIDASTARCONFIG
DESCRIPTOR.message_types_by_name['DualVariableConfig'] = _DUALVARIABLECONFIG
DESCRIPTOR.message_types_by_name['DistanceApproachTrajectorySmootherConfig'] = _DISTANCEAPPROACHTRAJECTORYSMOOTHERCONFIG
DESCRIPTOR.message_types_by_name['IpoptSolverConfig'] = _IPOPTSOLVERCONFIG
DESCRIPTOR.enum_types_by_name['DualVariableMode'] = _DUALVARIABLEMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OpenSpaceFallBackDeciderConfig = _reflection.GeneratedProtocolMessageType('OpenSpaceFallBackDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACEFALLBACKDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OpenSpaceFallBackDeciderConfig)
  })
_sym_db.RegisterMessage(OpenSpaceFallBackDeciderConfig)

OpenSpacePreStopDeciderConfig = _reflection.GeneratedProtocolMessageType('OpenSpacePreStopDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACEPRESTOPDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OpenSpacePreStopDeciderConfig)
  })
_sym_db.RegisterMessage(OpenSpacePreStopDeciderConfig)

OpenSpaceRoiDeciderConfig = _reflection.GeneratedProtocolMessageType('OpenSpaceRoiDeciderConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACEROIDECIDERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OpenSpaceRoiDeciderConfig)
  })
_sym_db.RegisterMessage(OpenSpaceRoiDeciderConfig)

OpenSpaceTrajectoryPartitionConfig = _reflection.GeneratedProtocolMessageType('OpenSpaceTrajectoryPartitionConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACETRAJECTORYPARTITIONCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OpenSpaceTrajectoryPartitionConfig)
  })
_sym_db.RegisterMessage(OpenSpaceTrajectoryPartitionConfig)

OpenSpaceTrajectoryProviderConfig = _reflection.GeneratedProtocolMessageType('OpenSpaceTrajectoryProviderConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACETRAJECTORYPROVIDERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OpenSpaceTrajectoryProviderConfig)
  })
_sym_db.RegisterMessage(OpenSpaceTrajectoryProviderConfig)

OpenSpaceTrajectoryOptimizerConfig = _reflection.GeneratedProtocolMessageType('OpenSpaceTrajectoryOptimizerConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPENSPACETRAJECTORYOPTIMIZERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.OpenSpaceTrajectoryOptimizerConfig)
  })
_sym_db.RegisterMessage(OpenSpaceTrajectoryOptimizerConfig)

HybridAStarConfig = _reflection.GeneratedProtocolMessageType('HybridAStarConfig', (_message.Message,), {
  'DESCRIPTOR' : _HYBRIDASTARCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.HybridAStarConfig)
  })
_sym_db.RegisterMessage(HybridAStarConfig)

DualVariableConfig = _reflection.GeneratedProtocolMessageType('DualVariableConfig', (_message.Message,), {
  'DESCRIPTOR' : _DUALVARIABLECONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.DualVariableConfig)
  })
_sym_db.RegisterMessage(DualVariableConfig)

DistanceApproachTrajectorySmootherConfig = _reflection.GeneratedProtocolMessageType('DistanceApproachTrajectorySmootherConfig', (_message.Message,), {
  'DESCRIPTOR' : _DISTANCEAPPROACHTRAJECTORYSMOOTHERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.DistanceApproachTrajectorySmootherConfig)
  })
_sym_db.RegisterMessage(DistanceApproachTrajectorySmootherConfig)

IpoptSolverConfig = _reflection.GeneratedProtocolMessageType('IpoptSolverConfig', (_message.Message,), {
  'DESCRIPTOR' : _IPOPTSOLVERCONFIG,
  '__module__' : 'modules.planning.proto.open_space_task_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.IpoptSolverConfig)
  })
_sym_db.RegisterMessage(IpoptSolverConfig)


# @@protoc_insertion_point(module_scope)
