# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/tools/prediction/data_pipelines/proto/cruise_model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/tools/prediction/data_pipelines/proto/cruise_model.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@modules/tools/prediction/data_pipelines/proto/cruise_model.proto\"2\n\x0fTensorParameter\x12\x10\n\x04\x64\x61ta\x18\x01 \x03(\x02\x42\x02\x10\x01\x12\r\n\x05shape\x18\x02 \x03(\x05\"D\n\x0eInputParameter\x12\x13\n\x0binput_shape\x18\x01 \x03(\x05\x12\r\n\x05\x64type\x18\x02 \x01(\t\x12\x0e\n\x06sparse\x18\x03 \x01(\x08\"\x84\x01\n\x0f\x43onv1dParameter\x12\r\n\x05shape\x18\x01 \x03(\x05\x12\x10\n\x08use_bias\x18\x02 \x01(\x08\x12 \n\x06kernel\x18\x03 \x01(\x0b\x32\x10.TensorParameter\x12\x1e\n\x04\x62ias\x18\x04 \x01(\x0b\x32\x10.TensorParameter\x12\x0e\n\x06stride\x18\x05 \x01(\x05\"\x88\x01\n\x0e\x44\x65nseParameter\x12\r\n\x05units\x18\x01 \x01(\x05\x12\x12\n\nactivation\x18\x02 \x01(\t\x12\x10\n\x08use_bias\x18\x03 \x01(\x08\x12!\n\x07weights\x18\x04 \x01(\x0b\x32\x10.TensorParameter\x12\x1e\n\x04\x62ias\x18\x05 \x01(\x0b\x32\x10.TensorParameter\")\n\x13\x41\x63tivationParameter\x12\x12\n\nactivation\x18\x01 \x01(\t\"9\n\x12MaxPool1dParameter\x12\x13\n\x0bkernel_size\x18\x01 \x01(\x05\x12\x0e\n\x06stride\x18\x02 \x01(\x05\"9\n\x12\x41vgPool1dParameter\x12\x13\n\x0bkernel_size\x18\x01 \x01(\x05\x12\x0e\n\x06stride\x18\x02 \x01(\x05\"\xde\x01\n\x18LaneFeatureConvParameter\x12\"\n\x08\x63onv1d_0\x18\x01 \x01(\x0b\x32\x10.Conv1dParameter\x12*\n\x0c\x61\x63tivation_1\x18\x02 \x01(\x0b\x32\x14.ActivationParameter\x12\"\n\x08\x63onv1d_2\x18\x03 \x01(\x0b\x32\x10.Conv1dParameter\x12*\n\x0c\x61\x63tivation_3\x18\x04 \x01(\x0b\x32\x14.ActivationParameter\x12\"\n\x08\x63onv1d_4\x18\x05 \x01(\x0b\x32\x10.Conv1dParameter\"\xb5\x01\n\x15ObsFeatureFCParameter\x12!\n\x08linear_0\x18\x01 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_1\x18\x02 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_3\x18\x03 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_4\x18\x04 \x01(\x0b\x32\x14.ActivationParameter\"\xd0\x02\n\x11\x43lassifyParameter\x12!\n\x08linear_0\x18\x01 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_1\x18\x02 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_3\x18\x03 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_4\x18\x04 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_6\x18\x05 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_7\x18\x06 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_9\x18\x07 \x01(\x0b\x32\x0f.DenseParameter\x12+\n\ractivation_10\x18\x08 \x01(\x0b\x32\x14.ActivationParameter\"\xcf\x02\n\x10RegressParameter\x12!\n\x08linear_0\x18\x01 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_1\x18\x02 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_3\x18\x03 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_4\x18\x04 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_6\x18\x05 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_7\x18\x06 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_9\x18\x07 \x01(\x0b\x32\x0f.DenseParameter\x12+\n\ractivation_10\x18\x08 \x01(\x0b\x32\x14.ActivationParameter\"\xac\x02\n\x14\x43ruiseModelParameter\x12\x34\n\x11lane_feature_conv\x18\x01 \x01(\x0b\x32\x19.LaneFeatureConvParameter\x12\x31\n\x14lane_feature_maxpool\x18\x02 \x01(\x0b\x32\x13.MaxPool1dParameter\x12\x31\n\x14lane_feature_avgpool\x18\x03 \x01(\x0b\x32\x13.AvgPool1dParameter\x12.\n\x0eobs_feature_fc\x18\x05 \x01(\x0b\x32\x16.ObsFeatureFCParameter\x12$\n\x08\x63lassify\x18\x06 \x01(\x0b\x32\x12.ClassifyParameter\x12\"\n\x07regress\x18\x07 \x01(\x0b\x32\x11.RegressParameter'
)




_TENSORPARAMETER = _descriptor.Descriptor(
  name='TensorParameter',
  full_name='TensorParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='TensorParameter.data', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='TensorParameter.shape', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=118,
)


_INPUTPARAMETER = _descriptor.Descriptor(
  name='InputParameter',
  full_name='InputParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_shape', full_name='InputParameter.input_shape', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dtype', full_name='InputParameter.dtype', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sparse', full_name='InputParameter.sparse', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=188,
)


_CONV1DPARAMETER = _descriptor.Descriptor(
  name='Conv1dParameter',
  full_name='Conv1dParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shape', full_name='Conv1dParameter.shape', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_bias', full_name='Conv1dParameter.use_bias', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kernel', full_name='Conv1dParameter.kernel', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias', full_name='Conv1dParameter.bias', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stride', full_name='Conv1dParameter.stride', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=323,
)


_DENSEPARAMETER = _descriptor.Descriptor(
  name='DenseParameter',
  full_name='DenseParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='units', full_name='DenseParameter.units', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation', full_name='DenseParameter.activation', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_bias', full_name='DenseParameter.use_bias', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights', full_name='DenseParameter.weights', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias', full_name='DenseParameter.bias', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=462,
)


_ACTIVATIONPARAMETER = _descriptor.Descriptor(
  name='ActivationParameter',
  full_name='ActivationParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='activation', full_name='ActivationParameter.activation', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=464,
  serialized_end=505,
)


_MAXPOOL1DPARAMETER = _descriptor.Descriptor(
  name='MaxPool1dParameter',
  full_name='MaxPool1dParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kernel_size', full_name='MaxPool1dParameter.kernel_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stride', full_name='MaxPool1dParameter.stride', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=507,
  serialized_end=564,
)


_AVGPOOL1DPARAMETER = _descriptor.Descriptor(
  name='AvgPool1dParameter',
  full_name='AvgPool1dParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kernel_size', full_name='AvgPool1dParameter.kernel_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stride', full_name='AvgPool1dParameter.stride', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=623,
)


_LANEFEATURECONVPARAMETER = _descriptor.Descriptor(
  name='LaneFeatureConvParameter',
  full_name='LaneFeatureConvParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='conv1d_0', full_name='LaneFeatureConvParameter.conv1d_0', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_1', full_name='LaneFeatureConvParameter.activation_1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conv1d_2', full_name='LaneFeatureConvParameter.conv1d_2', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_3', full_name='LaneFeatureConvParameter.activation_3', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conv1d_4', full_name='LaneFeatureConvParameter.conv1d_4', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=848,
)


_OBSFEATUREFCPARAMETER = _descriptor.Descriptor(
  name='ObsFeatureFCParameter',
  full_name='ObsFeatureFCParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear_0', full_name='ObsFeatureFCParameter.linear_0', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_1', full_name='ObsFeatureFCParameter.activation_1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_3', full_name='ObsFeatureFCParameter.linear_3', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_4', full_name='ObsFeatureFCParameter.activation_4', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=851,
  serialized_end=1032,
)


_CLASSIFYPARAMETER = _descriptor.Descriptor(
  name='ClassifyParameter',
  full_name='ClassifyParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear_0', full_name='ClassifyParameter.linear_0', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_1', full_name='ClassifyParameter.activation_1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_3', full_name='ClassifyParameter.linear_3', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_4', full_name='ClassifyParameter.activation_4', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_6', full_name='ClassifyParameter.linear_6', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_7', full_name='ClassifyParameter.activation_7', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_9', full_name='ClassifyParameter.linear_9', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_10', full_name='ClassifyParameter.activation_10', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1035,
  serialized_end=1371,
)


_REGRESSPARAMETER = _descriptor.Descriptor(
  name='RegressParameter',
  full_name='RegressParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear_0', full_name='RegressParameter.linear_0', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_1', full_name='RegressParameter.activation_1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_3', full_name='RegressParameter.linear_3', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_4', full_name='RegressParameter.activation_4', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_6', full_name='RegressParameter.linear_6', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_7', full_name='RegressParameter.activation_7', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_9', full_name='RegressParameter.linear_9', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_10', full_name='RegressParameter.activation_10', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1374,
  serialized_end=1709,
)


_CRUISEMODELPARAMETER = _descriptor.Descriptor(
  name='CruiseModelParameter',
  full_name='CruiseModelParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_feature_conv', full_name='CruiseModelParameter.lane_feature_conv', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_feature_maxpool', full_name='CruiseModelParameter.lane_feature_maxpool', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_feature_avgpool', full_name='CruiseModelParameter.lane_feature_avgpool', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obs_feature_fc', full_name='CruiseModelParameter.obs_feature_fc', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classify', full_name='CruiseModelParameter.classify', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regress', full_name='CruiseModelParameter.regress', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1712,
  serialized_end=2012,
)

_CONV1DPARAMETER.fields_by_name['kernel'].message_type = _TENSORPARAMETER
_CONV1DPARAMETER.fields_by_name['bias'].message_type = _TENSORPARAMETER
_DENSEPARAMETER.fields_by_name['weights'].message_type = _TENSORPARAMETER
_DENSEPARAMETER.fields_by_name['bias'].message_type = _TENSORPARAMETER
_LANEFEATURECONVPARAMETER.fields_by_name['conv1d_0'].message_type = _CONV1DPARAMETER
_LANEFEATURECONVPARAMETER.fields_by_name['activation_1'].message_type = _ACTIVATIONPARAMETER
_LANEFEATURECONVPARAMETER.fields_by_name['conv1d_2'].message_type = _CONV1DPARAMETER
_LANEFEATURECONVPARAMETER.fields_by_name['activation_3'].message_type = _ACTIVATIONPARAMETER
_LANEFEATURECONVPARAMETER.fields_by_name['conv1d_4'].message_type = _CONV1DPARAMETER
_OBSFEATUREFCPARAMETER.fields_by_name['linear_0'].message_type = _DENSEPARAMETER
_OBSFEATUREFCPARAMETER.fields_by_name['activation_1'].message_type = _ACTIVATIONPARAMETER
_OBSFEATUREFCPARAMETER.fields_by_name['linear_3'].message_type = _DENSEPARAMETER
_OBSFEATUREFCPARAMETER.fields_by_name['activation_4'].message_type = _ACTIVATIONPARAMETER
_CLASSIFYPARAMETER.fields_by_name['linear_0'].message_type = _DENSEPARAMETER
_CLASSIFYPARAMETER.fields_by_name['activation_1'].message_type = _ACTIVATIONPARAMETER
_CLASSIFYPARAMETER.fields_by_name['linear_3'].message_type = _DENSEPARAMETER
_CLASSIFYPARAMETER.fields_by_name['activation_4'].message_type = _ACTIVATIONPARAMETER
_CLASSIFYPARAMETER.fields_by_name['linear_6'].message_type = _DENSEPARAMETER
_CLASSIFYPARAMETER.fields_by_name['activation_7'].message_type = _ACTIVATIONPARAMETER
_CLASSIFYPARAMETER.fields_by_name['linear_9'].message_type = _DENSEPARAMETER
_CLASSIFYPARAMETER.fields_by_name['activation_10'].message_type = _ACTIVATIONPARAMETER
_REGRESSPARAMETER.fields_by_name['linear_0'].message_type = _DENSEPARAMETER
_REGRESSPARAMETER.fields_by_name['activation_1'].message_type = _ACTIVATIONPARAMETER
_REGRESSPARAMETER.fields_by_name['linear_3'].message_type = _DENSEPARAMETER
_REGRESSPARAMETER.fields_by_name['activation_4'].message_type = _ACTIVATIONPARAMETER
_REGRESSPARAMETER.fields_by_name['linear_6'].message_type = _DENSEPARAMETER
_REGRESSPARAMETER.fields_by_name['activation_7'].message_type = _ACTIVATIONPARAMETER
_REGRESSPARAMETER.fields_by_name['linear_9'].message_type = _DENSEPARAMETER
_REGRESSPARAMETER.fields_by_name['activation_10'].message_type = _ACTIVATIONPARAMETER
_CRUISEMODELPARAMETER.fields_by_name['lane_feature_conv'].message_type = _LANEFEATURECONVPARAMETER
_CRUISEMODELPARAMETER.fields_by_name['lane_feature_maxpool'].message_type = _MAXPOOL1DPARAMETER
_CRUISEMODELPARAMETER.fields_by_name['lane_feature_avgpool'].message_type = _AVGPOOL1DPARAMETER
_CRUISEMODELPARAMETER.fields_by_name['obs_feature_fc'].message_type = _OBSFEATUREFCPARAMETER
_CRUISEMODELPARAMETER.fields_by_name['classify'].message_type = _CLASSIFYPARAMETER
_CRUISEMODELPARAMETER.fields_by_name['regress'].message_type = _REGRESSPARAMETER
DESCRIPTOR.message_types_by_name['TensorParameter'] = _TENSORPARAMETER
DESCRIPTOR.message_types_by_name['InputParameter'] = _INPUTPARAMETER
DESCRIPTOR.message_types_by_name['Conv1dParameter'] = _CONV1DPARAMETER
DESCRIPTOR.message_types_by_name['DenseParameter'] = _DENSEPARAMETER
DESCRIPTOR.message_types_by_name['ActivationParameter'] = _ACTIVATIONPARAMETER
DESCRIPTOR.message_types_by_name['MaxPool1dParameter'] = _MAXPOOL1DPARAMETER
DESCRIPTOR.message_types_by_name['AvgPool1dParameter'] = _AVGPOOL1DPARAMETER
DESCRIPTOR.message_types_by_name['LaneFeatureConvParameter'] = _LANEFEATURECONVPARAMETER
DESCRIPTOR.message_types_by_name['ObsFeatureFCParameter'] = _OBSFEATUREFCPARAMETER
DESCRIPTOR.message_types_by_name['ClassifyParameter'] = _CLASSIFYPARAMETER
DESCRIPTOR.message_types_by_name['RegressParameter'] = _REGRESSPARAMETER
DESCRIPTOR.message_types_by_name['CruiseModelParameter'] = _CRUISEMODELPARAMETER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TensorParameter = _reflection.GeneratedProtocolMessageType('TensorParameter', (_message.Message,), {
  'DESCRIPTOR' : _TENSORPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:TensorParameter)
  })
_sym_db.RegisterMessage(TensorParameter)

InputParameter = _reflection.GeneratedProtocolMessageType('InputParameter', (_message.Message,), {
  'DESCRIPTOR' : _INPUTPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:InputParameter)
  })
_sym_db.RegisterMessage(InputParameter)

Conv1dParameter = _reflection.GeneratedProtocolMessageType('Conv1dParameter', (_message.Message,), {
  'DESCRIPTOR' : _CONV1DPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:Conv1dParameter)
  })
_sym_db.RegisterMessage(Conv1dParameter)

DenseParameter = _reflection.GeneratedProtocolMessageType('DenseParameter', (_message.Message,), {
  'DESCRIPTOR' : _DENSEPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:DenseParameter)
  })
_sym_db.RegisterMessage(DenseParameter)

ActivationParameter = _reflection.GeneratedProtocolMessageType('ActivationParameter', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATIONPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:ActivationParameter)
  })
_sym_db.RegisterMessage(ActivationParameter)

MaxPool1dParameter = _reflection.GeneratedProtocolMessageType('MaxPool1dParameter', (_message.Message,), {
  'DESCRIPTOR' : _MAXPOOL1DPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:MaxPool1dParameter)
  })
_sym_db.RegisterMessage(MaxPool1dParameter)

AvgPool1dParameter = _reflection.GeneratedProtocolMessageType('AvgPool1dParameter', (_message.Message,), {
  'DESCRIPTOR' : _AVGPOOL1DPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:AvgPool1dParameter)
  })
_sym_db.RegisterMessage(AvgPool1dParameter)

LaneFeatureConvParameter = _reflection.GeneratedProtocolMessageType('LaneFeatureConvParameter', (_message.Message,), {
  'DESCRIPTOR' : _LANEFEATURECONVPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:LaneFeatureConvParameter)
  })
_sym_db.RegisterMessage(LaneFeatureConvParameter)

ObsFeatureFCParameter = _reflection.GeneratedProtocolMessageType('ObsFeatureFCParameter', (_message.Message,), {
  'DESCRIPTOR' : _OBSFEATUREFCPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:ObsFeatureFCParameter)
  })
_sym_db.RegisterMessage(ObsFeatureFCParameter)

ClassifyParameter = _reflection.GeneratedProtocolMessageType('ClassifyParameter', (_message.Message,), {
  'DESCRIPTOR' : _CLASSIFYPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:ClassifyParameter)
  })
_sym_db.RegisterMessage(ClassifyParameter)

RegressParameter = _reflection.GeneratedProtocolMessageType('RegressParameter', (_message.Message,), {
  'DESCRIPTOR' : _REGRESSPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:RegressParameter)
  })
_sym_db.RegisterMessage(RegressParameter)

CruiseModelParameter = _reflection.GeneratedProtocolMessageType('CruiseModelParameter', (_message.Message,), {
  'DESCRIPTOR' : _CRUISEMODELPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:CruiseModelParameter)
  })
_sym_db.RegisterMessage(CruiseModelParameter)


_TENSORPARAMETER.fields_by_name['data']._options = None
# @@protoc_insertion_point(module_scope)
