# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/run_mode_conf.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/run_mode_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x63yber/proto/run_mode_conf.proto\x12\x12\x61pollo.cyber.proto\"\x89\x01\n\x0bRunModeConf\x12;\n\x08run_mode\x18\x01 \x01(\x0e\x32\x1b.apollo.cyber.proto.RunMode:\x0cMODE_REALITY\x12=\n\nclock_mode\x18\x02 \x01(\x0e\x32\x1d.apollo.cyber.proto.ClockMode:\nMODE_CYBER*0\n\x07RunMode\x12\x10\n\x0cMODE_REALITY\x10\x00\x12\x13\n\x0fMODE_SIMULATION\x10\x01**\n\tClockMode\x12\x0e\n\nMODE_CYBER\x10\x00\x12\r\n\tMODE_MOCK\x10\x01'
)

_RUNMODE = _descriptor.EnumDescriptor(
  name='RunMode',
  full_name='apollo.cyber.proto.RunMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_REALITY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODE_SIMULATION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=195,
  serialized_end=243,
)
_sym_db.RegisterEnumDescriptor(_RUNMODE)

RunMode = enum_type_wrapper.EnumTypeWrapper(_RUNMODE)
_CLOCKMODE = _descriptor.EnumDescriptor(
  name='ClockMode',
  full_name='apollo.cyber.proto.ClockMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_CYBER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODE_MOCK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=245,
  serialized_end=287,
)
_sym_db.RegisterEnumDescriptor(_CLOCKMODE)

ClockMode = enum_type_wrapper.EnumTypeWrapper(_CLOCKMODE)
MODE_REALITY = 0
MODE_SIMULATION = 1
MODE_CYBER = 0
MODE_MOCK = 1



_RUNMODECONF = _descriptor.Descriptor(
  name='RunModeConf',
  full_name='apollo.cyber.proto.RunModeConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_mode', full_name='apollo.cyber.proto.RunModeConf.run_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock_mode', full_name='apollo.cyber.proto.RunModeConf.clock_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=193,
)

_RUNMODECONF.fields_by_name['run_mode'].enum_type = _RUNMODE
_RUNMODECONF.fields_by_name['clock_mode'].enum_type = _CLOCKMODE
DESCRIPTOR.message_types_by_name['RunModeConf'] = _RUNMODECONF
DESCRIPTOR.enum_types_by_name['RunMode'] = _RUNMODE
DESCRIPTOR.enum_types_by_name['ClockMode'] = _CLOCKMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RunModeConf = _reflection.GeneratedProtocolMessageType('RunModeConf', (_message.Message,), {
  'DESCRIPTOR' : _RUNMODECONF,
  '__module__' : 'cyber.proto.run_mode_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.RunModeConf)
  })
_sym_db.RegisterMessage(RunModeConf)


# @@protoc_insertion_point(module_scope)
