# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/onboard/proto/lane_perception_component.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/onboard/proto/lane_perception_component.proto',
  package='apollo.perception.onboard',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@modules/perception/onboard/proto/lane_perception_component.proto\x12\x19\x61pollo.perception.onboard\"\x87\x07\n\rLaneDetection\x12*\n\x0c\x63\x61mera_names\x18\x01 \x01(\t:\x14\x66ront_6mm,front_12mm\x12p\n\x1ainput_camera_channel_names\x18\x02 \x01(\t:L/apollo/sensor/camera/front_6mm/image,/apollo/sensor/camera/front_12mm/image\x12\x1b\n\x10timestamp_offset\x18\x03 \x01(\x01:\x01\x30\x12?\n\x1f\x63\x61mera_lane_perception_conf_dir\x18\x04 \x01(\t:\x16\x63onf/perception/camera\x12\x31\n camera_lane_perception_conf_file\x18\x05 \x01(\t:\x07lane.pt\x12\x1a\n\x0e\x66rame_capacity\x18\x06 \x01(\x05:\x02\x32\x30\x12\x1c\n\x11image_channel_num\x18\x07 \x01(\x05:\x01\x33\x12\"\n\x13\x65nable_undistortion\x18\x08 \x01(\x08:\x05\x66\x61lse\x12#\n\x14\x65nable_visualization\x18\t \x01(\x08:\x05\x66\x61lse\x12\x34\n\x19output_lanes_channel_name\x18\n \x01(\t:\x11/perception/lanes\x12\x1f\n\x14\x64\x65\x66\x61ult_camera_pitch\x18\x0b \x01(\x01:\x01\x30\x12\"\n\x15\x64\x65\x66\x61ult_camera_height\x18\x0c \x01(\x01:\x03\x31.5\x12\x37\n$lane_calibration_working_sensor_name\x18\r \x01(\t:\tfront_6mm\x12-\n\x11\x63\x61librator_method\x18\x0e \x01(\t:\x12LaneLineCalibrator\x12\x34\n\x12\x63\x61lib_service_name\x18\x0f \x01(\t:\x18OnlineCalibrationService\x12\x1f\n\x11run_calib_service\x18\x10 \x01(\x08:\x04true\x12\x14\n\x07ts_diff\x18\x11 \x01(\x01:\x03\x30.1\x12\x31\n\x13visual_debug_folder\x18\x12 \x01(\t:\x14/apollo/debug_output\x12 \n\rvisual_camera\x18\x13 \x01(\t:\tfront_6mm\x12\x1f\n\x10write_visual_img\x18\x14 \x01(\x08:\x05\x66\x61lse'
)




_LANEDETECTION = _descriptor.Descriptor(
  name='LaneDetection',
  full_name='apollo.perception.onboard.LaneDetection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera_names', full_name='apollo.perception.onboard.LaneDetection.camera_names', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"front_6mm,front_12mm".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_camera_channel_names', full_name='apollo.perception.onboard.LaneDetection.input_camera_channel_names', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/sensor/camera/front_6mm/image,/apollo/sensor/camera/front_12mm/image".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_offset', full_name='apollo.perception.onboard.LaneDetection.timestamp_offset', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_lane_perception_conf_dir', full_name='apollo.perception.onboard.LaneDetection.camera_lane_perception_conf_dir', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"conf/perception/camera".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_lane_perception_conf_file', full_name='apollo.perception.onboard.LaneDetection.camera_lane_perception_conf_file', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"lane.pt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_capacity', full_name='apollo.perception.onboard.LaneDetection.frame_capacity', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=20,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_channel_num', full_name='apollo.perception.onboard.LaneDetection.image_channel_num', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_undistortion', full_name='apollo.perception.onboard.LaneDetection.enable_undistortion', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_visualization', full_name='apollo.perception.onboard.LaneDetection.enable_visualization', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_lanes_channel_name', full_name='apollo.perception.onboard.LaneDetection.output_lanes_channel_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/perception/lanes".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_camera_pitch', full_name='apollo.perception.onboard.LaneDetection.default_camera_pitch', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_camera_height', full_name='apollo.perception.onboard.LaneDetection.default_camera_height', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_calibration_working_sensor_name', full_name='apollo.perception.onboard.LaneDetection.lane_calibration_working_sensor_name', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"front_6mm".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibrator_method', full_name='apollo.perception.onboard.LaneDetection.calibrator_method', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"LaneLineCalibrator".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calib_service_name', full_name='apollo.perception.onboard.LaneDetection.calib_service_name', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"OnlineCalibrationService".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_calib_service', full_name='apollo.perception.onboard.LaneDetection.run_calib_service', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_diff', full_name='apollo.perception.onboard.LaneDetection.ts_diff', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visual_debug_folder', full_name='apollo.perception.onboard.LaneDetection.visual_debug_folder', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/debug_output".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visual_camera', full_name='apollo.perception.onboard.LaneDetection.visual_camera', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"front_6mm".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_visual_img', full_name='apollo.perception.onboard.LaneDetection.write_visual_img', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=999,
)

DESCRIPTOR.message_types_by_name['LaneDetection'] = _LANEDETECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaneDetection = _reflection.GeneratedProtocolMessageType('LaneDetection', (_message.Message,), {
  'DESCRIPTOR' : _LANEDETECTION,
  '__module__' : 'modules.perception.onboard.proto.lane_perception_component_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.onboard.LaneDetection)
  })
_sym_db.RegisterMessage(LaneDetection)


# @@protoc_insertion_point(module_scope)
