# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/onboard/proto/motion_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/onboard/proto/motion_service.proto',
  package='apollo.perception.onboard',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5modules/perception/onboard/proto/motion_service.proto\x12\x19\x61pollo.perception.onboard\"\x85\x02\n\rMotionService\x12\x1f\n\x0c\x63\x61mera_names\x18\x01 \x01(\t:\tfront_6mm\x12I\n\x1ainput_camera_channel_names\x18\x02 \x01(\t:%/apollo/sensor/camera/front_6mm/image\x12\x42\n\x1finput_localization_channel_name\x18\x03 \x01(\t:\x19/apollo/localization/pose\x12\x44\n\x19output_topic_channel_name\x18\x04 \x01(\t:!/apollo/perception/motion_service'
)




_MOTIONSERVICE = _descriptor.Descriptor(
  name='MotionService',
  full_name='apollo.perception.onboard.MotionService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera_names', full_name='apollo.perception.onboard.MotionService.camera_names', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"front_6mm".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_camera_channel_names', full_name='apollo.perception.onboard.MotionService.input_camera_channel_names', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/sensor/camera/front_6mm/image".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_localization_channel_name', full_name='apollo.perception.onboard.MotionService.input_localization_channel_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/localization/pose".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_topic_channel_name', full_name='apollo.perception.onboard.MotionService.output_topic_channel_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/perception/motion_service".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=346,
)

DESCRIPTOR.message_types_by_name['MotionService'] = _MOTIONSERVICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MotionService = _reflection.GeneratedProtocolMessageType('MotionService', (_message.Message,), {
  'DESCRIPTOR' : _MOTIONSERVICE,
  '__module__' : 'modules.perception.onboard.proto.motion_service_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.onboard.MotionService)
  })
_sym_db.RegisterMessage(MotionService)


# @@protoc_insertion_point(module_scope)
