# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/mpc_controller_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.control.proto import calibration_table_pb2 as modules_dot_control_dot_proto_dot_calibration__table__pb2
from modules.control.proto import gain_scheduler_conf_pb2 as modules_dot_control_dot_proto_dot_gain__scheduler__conf__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/mpc_controller_conf.proto',
  package='apollo.control',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/modules/control/proto/mpc_controller_conf.proto\x12\x0e\x61pollo.control\x1a-modules/control/proto/calibration_table.proto\x1a/modules/control/proto/gain_scheduler_conf.proto\"\xbb\x06\n\x11MPCControllerConf\x12\n\n\x02ts\x18\x01 \x01(\x01\x12\n\n\x02\x63\x66\x18\x02 \x01(\x01\x12\n\n\x02\x63r\x18\x03 \x01(\x01\x12\x0f\n\x07mass_fl\x18\x04 \x01(\x05\x12\x0f\n\x07mass_fr\x18\x05 \x01(\x05\x12\x0f\n\x07mass_rl\x18\x06 \x01(\x05\x12\x0f\n\x07mass_rr\x18\x07 \x01(\x05\x12\x0b\n\x03\x65ps\x18\x08 \x01(\x01\x12\x10\n\x08matrix_q\x18\t \x03(\x01\x12\x10\n\x08matrix_r\x18\n \x03(\x01\x12\x13\n\x0b\x63utoff_freq\x18\x0b \x01(\x05\x12\x1f\n\x17mean_filter_window_size\x18\x0c \x01(\x05\x12\x15\n\rmax_iteration\x18\r \x01(\x05\x12 \n\x18max_lateral_acceleration\x18\x0e \x01(\x01\x12\x1f\n\x17standstill_acceleration\x18\x0f \x01(\x01\x12\x1c\n\x14\x62rake_minimum_action\x18\x10 \x01(\x01\x12\x1f\n\x17throttle_minimum_action\x18\x11 \x01(\x01\x12=\n\x16lat_err_gain_scheduler\x18\x12 \x01(\x0b\x32\x1d.apollo.control.GainScheduler\x12\x41\n\x1aheading_err_gain_scheduler\x18\x13 \x01(\x0b\x32\x1d.apollo.control.GainScheduler\x12\x42\n\x1bsteer_weight_gain_scheduler\x18\x14 \x01(\x0b\x32\x1d.apollo.control.GainScheduler\x12\x45\n\x1e\x66\x65\x65\x64\x66orwardterm_gain_scheduler\x18\x15 \x01(\x0b\x32\x1d.apollo.control.GainScheduler\x12S\n\x11\x63\x61libration_table\x18\x16 \x01(\x0b\x32\x38.apollo.control.calibrationtable.ControlCalibrationTable\x12\x32\n#enable_mpc_feedforward_compensation\x18\x17 \x01(\x08:\x05\x66\x61lse\x12(\n unconstrained_control_diff_limit\x18\x18 \x01(\x01'
  ,
  dependencies=[modules_dot_control_dot_proto_dot_calibration__table__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_gain__scheduler__conf__pb2.DESCRIPTOR,])




_MPCCONTROLLERCONF = _descriptor.Descriptor(
  name='MPCControllerConf',
  full_name='apollo.control.MPCControllerConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts', full_name='apollo.control.MPCControllerConf.ts', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cf', full_name='apollo.control.MPCControllerConf.cf', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cr', full_name='apollo.control.MPCControllerConf.cr', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mass_fl', full_name='apollo.control.MPCControllerConf.mass_fl', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mass_fr', full_name='apollo.control.MPCControllerConf.mass_fr', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mass_rl', full_name='apollo.control.MPCControllerConf.mass_rl', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mass_rr', full_name='apollo.control.MPCControllerConf.mass_rr', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps', full_name='apollo.control.MPCControllerConf.eps', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matrix_q', full_name='apollo.control.MPCControllerConf.matrix_q', index=8,
      number=9, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matrix_r', full_name='apollo.control.MPCControllerConf.matrix_r', index=9,
      number=10, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cutoff_freq', full_name='apollo.control.MPCControllerConf.cutoff_freq', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_filter_window_size', full_name='apollo.control.MPCControllerConf.mean_filter_window_size', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_iteration', full_name='apollo.control.MPCControllerConf.max_iteration', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_lateral_acceleration', full_name='apollo.control.MPCControllerConf.max_lateral_acceleration', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='standstill_acceleration', full_name='apollo.control.MPCControllerConf.standstill_acceleration', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_minimum_action', full_name='apollo.control.MPCControllerConf.brake_minimum_action', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_minimum_action', full_name='apollo.control.MPCControllerConf.throttle_minimum_action', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat_err_gain_scheduler', full_name='apollo.control.MPCControllerConf.lat_err_gain_scheduler', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_err_gain_scheduler', full_name='apollo.control.MPCControllerConf.heading_err_gain_scheduler', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_weight_gain_scheduler', full_name='apollo.control.MPCControllerConf.steer_weight_gain_scheduler', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feedforwardterm_gain_scheduler', full_name='apollo.control.MPCControllerConf.feedforwardterm_gain_scheduler', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration_table', full_name='apollo.control.MPCControllerConf.calibration_table', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_mpc_feedforward_compensation', full_name='apollo.control.MPCControllerConf.enable_mpc_feedforward_compensation', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unconstrained_control_diff_limit', full_name='apollo.control.MPCControllerConf.unconstrained_control_diff_limit', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=991,
)

_MPCCONTROLLERCONF.fields_by_name['lat_err_gain_scheduler'].message_type = modules_dot_control_dot_proto_dot_gain__scheduler__conf__pb2._GAINSCHEDULER
_MPCCONTROLLERCONF.fields_by_name['heading_err_gain_scheduler'].message_type = modules_dot_control_dot_proto_dot_gain__scheduler__conf__pb2._GAINSCHEDULER
_MPCCONTROLLERCONF.fields_by_name['steer_weight_gain_scheduler'].message_type = modules_dot_control_dot_proto_dot_gain__scheduler__conf__pb2._GAINSCHEDULER
_MPCCONTROLLERCONF.fields_by_name['feedforwardterm_gain_scheduler'].message_type = modules_dot_control_dot_proto_dot_gain__scheduler__conf__pb2._GAINSCHEDULER
_MPCCONTROLLERCONF.fields_by_name['calibration_table'].message_type = modules_dot_control_dot_proto_dot_calibration__table__pb2._CONTROLCALIBRATIONTABLE
DESCRIPTOR.message_types_by_name['MPCControllerConf'] = _MPCCONTROLLERCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MPCControllerConf = _reflection.GeneratedProtocolMessageType('MPCControllerConf', (_message.Message,), {
  'DESCRIPTOR' : _MPCCONTROLLERCONF,
  '__module__' : 'modules.control.proto.mpc_controller_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.MPCControllerConf)
  })
_sym_db.RegisterMessage(MPCControllerConf)


# @@protoc_insertion_point(module_scope)
