# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/fusion_params.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/fusion_params.proto',
  package='apollo.v2x.ft.fusion',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%modules/v2x/proto/fusion_params.proto\x12\x14\x61pollo.v2x.ft.fusion\"\x1d\n\x08KMParams\x12\x11\n\tmin_score\x18\x01 \x01(\x01\"\x1d\n\x05Param\x12\t\n\x01k\x18\x01 \x01(\x01\x12\t\n\x01\x62\x18\x02 \x01(\x01\"R\n\x11SingleCameraParam\x12\x11\n\tcamera_id\x18\x01 \x01(\x05\x12*\n\x05param\x18\x02 \x03(\x0b\x32\x1b.apollo.v2x.ft.fusion.Param\"\xdc\x01\n\x0bScoreParams\x12\x12\n\nprob_scale\x18\x01 \x01(\x01\x12\x1a\n\x12max_match_distance\x18\x02 \x01(\x01\x12\x11\n\tmin_score\x18\x03 \x01(\x01\x12\'\n\x18use_mahalanobis_distance\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x19\n\ncheck_type\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x46\n\x10\x63onfidence_level\x18\x06 \x01(\x0e\x32%.apollo.v2x.ft.fusion.ConfidenceLevel:\x05\x43\x39\x37\x35P\"\xba\x01\n\x0c\x46usionParams\x12>\n\rfusion_params\x18\x01 \x03(\x0b\x32\'.apollo.v2x.ft.fusion.SingleCameraParam\x12\x31\n\tkm_params\x18\x02 \x01(\x0b\x32\x1e.apollo.v2x.ft.fusion.KMParams\x12\x37\n\x0cscore_params\x18\x03 \x02(\x0b\x32!.apollo.v2x.ft.fusion.ScoreParams*:\n\x0f\x43onfidenceLevel\x12\x08\n\x04\x43\x39\x30P\x10\x00\x12\x08\n\x04\x43\x39\x35P\x10\x01\x12\t\n\x05\x43\x39\x37\x35P\x10\x02\x12\x08\n\x04\x43\x39\x39P\x10\x03'
)

_CONFIDENCELEVEL = _descriptor.EnumDescriptor(
  name='ConfidenceLevel',
  full_name='apollo.v2x.ft.fusion.ConfidenceLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='C90P', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='C95P', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='C975P', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='C99P', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=621,
  serialized_end=679,
)
_sym_db.RegisterEnumDescriptor(_CONFIDENCELEVEL)

ConfidenceLevel = enum_type_wrapper.EnumTypeWrapper(_CONFIDENCELEVEL)
C90P = 0
C95P = 1
C975P = 2
C99P = 3



_KMPARAMS = _descriptor.Descriptor(
  name='KMParams',
  full_name='apollo.v2x.ft.fusion.KMParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_score', full_name='apollo.v2x.ft.fusion.KMParams.min_score', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=92,
)


_PARAM = _descriptor.Descriptor(
  name='Param',
  full_name='apollo.v2x.ft.fusion.Param',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='k', full_name='apollo.v2x.ft.fusion.Param.k', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='apollo.v2x.ft.fusion.Param.b', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=123,
)


_SINGLECAMERAPARAM = _descriptor.Descriptor(
  name='SingleCameraParam',
  full_name='apollo.v2x.ft.fusion.SingleCameraParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera_id', full_name='apollo.v2x.ft.fusion.SingleCameraParam.camera_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='param', full_name='apollo.v2x.ft.fusion.SingleCameraParam.param', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=207,
)


_SCOREPARAMS = _descriptor.Descriptor(
  name='ScoreParams',
  full_name='apollo.v2x.ft.fusion.ScoreParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prob_scale', full_name='apollo.v2x.ft.fusion.ScoreParams.prob_scale', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_match_distance', full_name='apollo.v2x.ft.fusion.ScoreParams.max_match_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_score', full_name='apollo.v2x.ft.fusion.ScoreParams.min_score', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_mahalanobis_distance', full_name='apollo.v2x.ft.fusion.ScoreParams.use_mahalanobis_distance', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='check_type', full_name='apollo.v2x.ft.fusion.ScoreParams.check_type', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence_level', full_name='apollo.v2x.ft.fusion.ScoreParams.confidence_level', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=430,
)


_FUSIONPARAMS = _descriptor.Descriptor(
  name='FusionParams',
  full_name='apollo.v2x.ft.fusion.FusionParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fusion_params', full_name='apollo.v2x.ft.fusion.FusionParams.fusion_params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='km_params', full_name='apollo.v2x.ft.fusion.FusionParams.km_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score_params', full_name='apollo.v2x.ft.fusion.FusionParams.score_params', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=619,
)

_SINGLECAMERAPARAM.fields_by_name['param'].message_type = _PARAM
_SCOREPARAMS.fields_by_name['confidence_level'].enum_type = _CONFIDENCELEVEL
_FUSIONPARAMS.fields_by_name['fusion_params'].message_type = _SINGLECAMERAPARAM
_FUSIONPARAMS.fields_by_name['km_params'].message_type = _KMPARAMS
_FUSIONPARAMS.fields_by_name['score_params'].message_type = _SCOREPARAMS
DESCRIPTOR.message_types_by_name['KMParams'] = _KMPARAMS
DESCRIPTOR.message_types_by_name['Param'] = _PARAM
DESCRIPTOR.message_types_by_name['SingleCameraParam'] = _SINGLECAMERAPARAM
DESCRIPTOR.message_types_by_name['ScoreParams'] = _SCOREPARAMS
DESCRIPTOR.message_types_by_name['FusionParams'] = _FUSIONPARAMS
DESCRIPTOR.enum_types_by_name['ConfidenceLevel'] = _CONFIDENCELEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KMParams = _reflection.GeneratedProtocolMessageType('KMParams', (_message.Message,), {
  'DESCRIPTOR' : _KMPARAMS,
  '__module__' : 'modules.v2x.proto.fusion_params_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.ft.fusion.KMParams)
  })
_sym_db.RegisterMessage(KMParams)

Param = _reflection.GeneratedProtocolMessageType('Param', (_message.Message,), {
  'DESCRIPTOR' : _PARAM,
  '__module__' : 'modules.v2x.proto.fusion_params_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.ft.fusion.Param)
  })
_sym_db.RegisterMessage(Param)

SingleCameraParam = _reflection.GeneratedProtocolMessageType('SingleCameraParam', (_message.Message,), {
  'DESCRIPTOR' : _SINGLECAMERAPARAM,
  '__module__' : 'modules.v2x.proto.fusion_params_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.ft.fusion.SingleCameraParam)
  })
_sym_db.RegisterMessage(SingleCameraParam)

ScoreParams = _reflection.GeneratedProtocolMessageType('ScoreParams', (_message.Message,), {
  'DESCRIPTOR' : _SCOREPARAMS,
  '__module__' : 'modules.v2x.proto.fusion_params_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.ft.fusion.ScoreParams)
  })
_sym_db.RegisterMessage(ScoreParams)

FusionParams = _reflection.GeneratedProtocolMessageType('FusionParams', (_message.Message,), {
  'DESCRIPTOR' : _FUSIONPARAMS,
  '__module__' : 'modules.v2x.proto.fusion_params_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.ft.fusion.FusionParams)
  })
_sym_db.RegisterMessage(FusionParams)


# @@protoc_insertion_point(module_scope)
