# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/perception_config_schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/perception_config_schema.proto',
  package='apollo.perception',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7modules/perception/proto/perception_config_schema.proto\x12\x11\x61pollo.perception\"*\n\x0bKeyValueInt\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05\"-\n\x0eKeyValueString\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\"-\n\x0eKeyValueDouble\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\",\n\rKeyValueFloat\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\"+\n\x0cKeyValueBool\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\"0\n\x10KeyValueArrayInt\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\x05\"3\n\x13KeyValueArrayString\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\x0c\"3\n\x13KeyValueArrayDouble\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\x01\"2\n\x12KeyValueArrayFloat\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\x02\"1\n\x11KeyValueArrayBool\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\x08\"\x9c\x05\n\x10ModelConfigProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x36\n\x0einteger_params\x18\x03 \x03(\x0b\x32\x1e.apollo.perception.KeyValueInt\x12\x38\n\rstring_params\x18\x04 \x03(\x0b\x32!.apollo.perception.KeyValueString\x12\x38\n\rdouble_params\x18\x05 \x03(\x0b\x32!.apollo.perception.KeyValueDouble\x12\x36\n\x0c\x66loat_params\x18\x06 \x03(\x0b\x32 .apollo.perception.KeyValueFloat\x12\x34\n\x0b\x62ool_params\x18\x07 \x03(\x0b\x32\x1f.apollo.perception.KeyValueBool\x12\x41\n\x14\x61rray_integer_params\x18\x08 \x03(\x0b\x32#.apollo.perception.KeyValueArrayInt\x12\x43\n\x13\x61rray_string_params\x18\t \x03(\x0b\x32&.apollo.perception.KeyValueArrayString\x12\x43\n\x13\x61rray_double_params\x18\n \x03(\x0b\x32&.apollo.perception.KeyValueArrayDouble\x12\x41\n\x12\x61rray_float_params\x18\x0b \x03(\x0b\x32%.apollo.perception.KeyValueArrayFloat\x12?\n\x11\x61rray_bool_params\x18\x0c \x03(\x0b\x32$.apollo.perception.KeyValueArrayBool\"S\n\x15MultiModelConfigProto\x12:\n\rmodel_configs\x18\x01 \x03(\x0b\x32#.apollo.perception.ModelConfigProto\"5\n\x18ModelConfigFileListProto\x12\x19\n\x11model_config_path\x18\x01 \x03(\t'
)




_KEYVALUEINT = _descriptor.Descriptor(
  name='KeyValueInt',
  full_name='apollo.perception.KeyValueInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueInt.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.perception.KeyValueInt.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=120,
)


_KEYVALUESTRING = _descriptor.Descriptor(
  name='KeyValueString',
  full_name='apollo.perception.KeyValueString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueString.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.perception.KeyValueString.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=167,
)


_KEYVALUEDOUBLE = _descriptor.Descriptor(
  name='KeyValueDouble',
  full_name='apollo.perception.KeyValueDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueDouble.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.perception.KeyValueDouble.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=214,
)


_KEYVALUEFLOAT = _descriptor.Descriptor(
  name='KeyValueFloat',
  full_name='apollo.perception.KeyValueFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueFloat.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.perception.KeyValueFloat.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=216,
  serialized_end=260,
)


_KEYVALUEBOOL = _descriptor.Descriptor(
  name='KeyValueBool',
  full_name='apollo.perception.KeyValueBool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueBool.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.perception.KeyValueBool.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=305,
)


_KEYVALUEARRAYINT = _descriptor.Descriptor(
  name='KeyValueArrayInt',
  full_name='apollo.perception.KeyValueArrayInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueArrayInt.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='apollo.perception.KeyValueArrayInt.values', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=307,
  serialized_end=355,
)


_KEYVALUEARRAYSTRING = _descriptor.Descriptor(
  name='KeyValueArrayString',
  full_name='apollo.perception.KeyValueArrayString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueArrayString.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='apollo.perception.KeyValueArrayString.values', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=408,
)


_KEYVALUEARRAYDOUBLE = _descriptor.Descriptor(
  name='KeyValueArrayDouble',
  full_name='apollo.perception.KeyValueArrayDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueArrayDouble.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='apollo.perception.KeyValueArrayDouble.values', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=461,
)


_KEYVALUEARRAYFLOAT = _descriptor.Descriptor(
  name='KeyValueArrayFloat',
  full_name='apollo.perception.KeyValueArrayFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueArrayFloat.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='apollo.perception.KeyValueArrayFloat.values', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=513,
)


_KEYVALUEARRAYBOOL = _descriptor.Descriptor(
  name='KeyValueArrayBool',
  full_name='apollo.perception.KeyValueArrayBool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueArrayBool.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='apollo.perception.KeyValueArrayBool.values', index=1,
      number=2, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=564,
)


_MODELCONFIGPROTO = _descriptor.Descriptor(
  name='ModelConfigProto',
  full_name='apollo.perception.ModelConfigProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.ModelConfigProto.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='apollo.perception.ModelConfigProto.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integer_params', full_name='apollo.perception.ModelConfigProto.integer_params', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_params', full_name='apollo.perception.ModelConfigProto.string_params', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_params', full_name='apollo.perception.ModelConfigProto.double_params', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_params', full_name='apollo.perception.ModelConfigProto.float_params', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_params', full_name='apollo.perception.ModelConfigProto.bool_params', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_integer_params', full_name='apollo.perception.ModelConfigProto.array_integer_params', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_string_params', full_name='apollo.perception.ModelConfigProto.array_string_params', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_double_params', full_name='apollo.perception.ModelConfigProto.array_double_params', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_float_params', full_name='apollo.perception.ModelConfigProto.array_float_params', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_bool_params', full_name='apollo.perception.ModelConfigProto.array_bool_params', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=1235,
)


_MULTIMODELCONFIGPROTO = _descriptor.Descriptor(
  name='MultiModelConfigProto',
  full_name='apollo.perception.MultiModelConfigProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_configs', full_name='apollo.perception.MultiModelConfigProto.model_configs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1237,
  serialized_end=1320,
)


_MODELCONFIGFILELISTPROTO = _descriptor.Descriptor(
  name='ModelConfigFileListProto',
  full_name='apollo.perception.ModelConfigFileListProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_config_path', full_name='apollo.perception.ModelConfigFileListProto.model_config_path', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1322,
  serialized_end=1375,
)

_MODELCONFIGPROTO.fields_by_name['integer_params'].message_type = _KEYVALUEINT
_MODELCONFIGPROTO.fields_by_name['string_params'].message_type = _KEYVALUESTRING
_MODELCONFIGPROTO.fields_by_name['double_params'].message_type = _KEYVALUEDOUBLE
_MODELCONFIGPROTO.fields_by_name['float_params'].message_type = _KEYVALUEFLOAT
_MODELCONFIGPROTO.fields_by_name['bool_params'].message_type = _KEYVALUEBOOL
_MODELCONFIGPROTO.fields_by_name['array_integer_params'].message_type = _KEYVALUEARRAYINT
_MODELCONFIGPROTO.fields_by_name['array_string_params'].message_type = _KEYVALUEARRAYSTRING
_MODELCONFIGPROTO.fields_by_name['array_double_params'].message_type = _KEYVALUEARRAYDOUBLE
_MODELCONFIGPROTO.fields_by_name['array_float_params'].message_type = _KEYVALUEARRAYFLOAT
_MODELCONFIGPROTO.fields_by_name['array_bool_params'].message_type = _KEYVALUEARRAYBOOL
_MULTIMODELCONFIGPROTO.fields_by_name['model_configs'].message_type = _MODELCONFIGPROTO
DESCRIPTOR.message_types_by_name['KeyValueInt'] = _KEYVALUEINT
DESCRIPTOR.message_types_by_name['KeyValueString'] = _KEYVALUESTRING
DESCRIPTOR.message_types_by_name['KeyValueDouble'] = _KEYVALUEDOUBLE
DESCRIPTOR.message_types_by_name['KeyValueFloat'] = _KEYVALUEFLOAT
DESCRIPTOR.message_types_by_name['KeyValueBool'] = _KEYVALUEBOOL
DESCRIPTOR.message_types_by_name['KeyValueArrayInt'] = _KEYVALUEARRAYINT
DESCRIPTOR.message_types_by_name['KeyValueArrayString'] = _KEYVALUEARRAYSTRING
DESCRIPTOR.message_types_by_name['KeyValueArrayDouble'] = _KEYVALUEARRAYDOUBLE
DESCRIPTOR.message_types_by_name['KeyValueArrayFloat'] = _KEYVALUEARRAYFLOAT
DESCRIPTOR.message_types_by_name['KeyValueArrayBool'] = _KEYVALUEARRAYBOOL
DESCRIPTOR.message_types_by_name['ModelConfigProto'] = _MODELCONFIGPROTO
DESCRIPTOR.message_types_by_name['MultiModelConfigProto'] = _MULTIMODELCONFIGPROTO
DESCRIPTOR.message_types_by_name['ModelConfigFileListProto'] = _MODELCONFIGFILELISTPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeyValueInt = _reflection.GeneratedProtocolMessageType('KeyValueInt', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEINT,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueInt)
  })
_sym_db.RegisterMessage(KeyValueInt)

KeyValueString = _reflection.GeneratedProtocolMessageType('KeyValueString', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUESTRING,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueString)
  })
_sym_db.RegisterMessage(KeyValueString)

KeyValueDouble = _reflection.GeneratedProtocolMessageType('KeyValueDouble', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEDOUBLE,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueDouble)
  })
_sym_db.RegisterMessage(KeyValueDouble)

KeyValueFloat = _reflection.GeneratedProtocolMessageType('KeyValueFloat', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEFLOAT,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueFloat)
  })
_sym_db.RegisterMessage(KeyValueFloat)

KeyValueBool = _reflection.GeneratedProtocolMessageType('KeyValueBool', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEBOOL,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueBool)
  })
_sym_db.RegisterMessage(KeyValueBool)

KeyValueArrayInt = _reflection.GeneratedProtocolMessageType('KeyValueArrayInt', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEARRAYINT,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueArrayInt)
  })
_sym_db.RegisterMessage(KeyValueArrayInt)

KeyValueArrayString = _reflection.GeneratedProtocolMessageType('KeyValueArrayString', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEARRAYSTRING,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueArrayString)
  })
_sym_db.RegisterMessage(KeyValueArrayString)

KeyValueArrayDouble = _reflection.GeneratedProtocolMessageType('KeyValueArrayDouble', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEARRAYDOUBLE,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueArrayDouble)
  })
_sym_db.RegisterMessage(KeyValueArrayDouble)

KeyValueArrayFloat = _reflection.GeneratedProtocolMessageType('KeyValueArrayFloat', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEARRAYFLOAT,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueArrayFloat)
  })
_sym_db.RegisterMessage(KeyValueArrayFloat)

KeyValueArrayBool = _reflection.GeneratedProtocolMessageType('KeyValueArrayBool', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEARRAYBOOL,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueArrayBool)
  })
_sym_db.RegisterMessage(KeyValueArrayBool)

ModelConfigProto = _reflection.GeneratedProtocolMessageType('ModelConfigProto', (_message.Message,), {
  'DESCRIPTOR' : _MODELCONFIGPROTO,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.ModelConfigProto)
  })
_sym_db.RegisterMessage(ModelConfigProto)

MultiModelConfigProto = _reflection.GeneratedProtocolMessageType('MultiModelConfigProto', (_message.Message,), {
  'DESCRIPTOR' : _MULTIMODELCONFIGPROTO,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.MultiModelConfigProto)
  })
_sym_db.RegisterMessage(MultiModelConfigProto)

ModelConfigFileListProto = _reflection.GeneratedProtocolMessageType('ModelConfigFileListProto', (_message.Message,), {
  'DESCRIPTOR' : _MODELCONFIGFILELISTPROTO,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.ModelConfigFileListProto)
  })
_sym_db.RegisterMessage(ModelConfigFileListProto)


# @@protoc_insertion_point(module_scope)
