# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/control_cmd.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.canbus.proto import chassis_pb2 as modules_dot_canbus_dot_proto_dot_chassis__pb2
from modules.common.proto import drive_state_pb2 as modules_dot_common_dot_proto_dot_drive__state__pb2
from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2
from modules.common.proto import vehicle_signal_pb2 as modules_dot_common_dot_proto_dot_vehicle__signal__pb2
from modules.control.proto import input_debug_pb2 as modules_dot_control_dot_proto_dot_input__debug__pb2
from modules.control.proto import pad_msg_pb2 as modules_dot_control_dot_proto_dot_pad__msg__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/control_cmd.proto',
  package='apollo.control',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'modules/control/proto/control_cmd.proto\x12\x0e\x61pollo.control\x1a\"modules/canbus/proto/chassis.proto\x1a&modules/common/proto/drive_state.proto\x1a!modules/common/proto/header.proto\x1a$modules/common/proto/pnc_point.proto\x1a)modules/common/proto/vehicle_signal.proto\x1a\'modules/control/proto/input_debug.proto\x1a#modules/control/proto/pad_msg.proto\"^\n\x0cLatencyStats\x12\x15\n\rtotal_time_ms\x18\x01 \x01(\x01\x12\x1a\n\x12\x63ontroller_time_ms\x18\x02 \x03(\x01\x12\x1b\n\x13total_time_exceeded\x18\x03 \x01(\x08\"\xb7\x06\n\x0e\x43ontrolCommand\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x10\n\x08throttle\x18\x03 \x01(\x01\x12\r\n\x05\x62rake\x18\x04 \x01(\x01\x12\x15\n\rsteering_rate\x18\x06 \x01(\x01\x12\x17\n\x0fsteering_target\x18\x07 \x01(\x01\x12\x15\n\rparking_brake\x18\x08 \x01(\x08\x12\r\n\x05speed\x18\t \x01(\x01\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\n \x01(\x01\x12\x17\n\x0breset_model\x18\x10 \x01(\x08\x42\x02\x18\x01\x12\x15\n\rengine_on_off\x18\x11 \x01(\x08\x12\x1b\n\x13trajectory_fraction\x18\x12 \x01(\x01\x12<\n\x0c\x64riving_mode\x18\x13 \x01(\x0e\x32\".apollo.canbus.Chassis.DrivingModeB\x02\x18\x01\x12:\n\rgear_location\x18\x14 \x01(\x0e\x32#.apollo.canbus.Chassis.GearPosition\x12$\n\x05\x64\x65\x62ug\x18\x16 \x01(\x0b\x32\x15.apollo.control.Debug\x12,\n\x06signal\x18\x17 \x01(\x0b\x32\x1c.apollo.common.VehicleSignal\x12\x33\n\rlatency_stats\x18\x18 \x01(\x0b\x32\x1c.apollo.control.LatencyStats\x12+\n\x07pad_msg\x18\x19 \x01(\x0b\x32\x1a.apollo.control.PadMessage\x12\x32\n\rengage_advice\x18\x1a \x01(\x0b\x32\x1b.apollo.common.EngageAdvice\x12\x1e\n\x0fis_in_safe_mode\x18\x1b \x01(\x08:\x05\x66\x61lse\x12\x15\n\tleft_turn\x18\r \x01(\x08\x42\x02\x18\x01\x12\x16\n\nright_turn\x18\x0e \x01(\x08\x42\x02\x18\x01\x12\x15\n\thigh_beam\x18\x0b \x01(\x08\x42\x02\x18\x01\x12\x14\n\x08low_beam\x18\x0c \x01(\x08\x42\x02\x18\x01\x12\x10\n\x04horn\x18\x0f \x01(\x08\x42\x02\x18\x01\x12\x32\n\nturnsignal\x18\x15 \x01(\x0e\x32\x1a.apollo.control.TurnSignalB\x02\x18\x01\"\xad\x08\n\x17SimpleLongitudinalDebug\x12\x19\n\x11station_reference\x18\x01 \x01(\x01\x12\x15\n\rstation_error\x18\x02 \x01(\x01\x12\x1d\n\x15station_error_limited\x18\x03 \x01(\x01\x12\x1d\n\x15preview_station_error\x18\x04 \x01(\x01\x12\x17\n\x0fspeed_reference\x18\x05 \x01(\x01\x12\x13\n\x0bspeed_error\x18\x06 \x01(\x01\x12&\n\x1espeed_controller_input_limited\x18\x07 \x01(\x01\x12\x1f\n\x17preview_speed_reference\x18\x08 \x01(\x01\x12\x1b\n\x13preview_speed_error\x18\t \x01(\x01\x12&\n\x1epreview_acceleration_reference\x18\n \x01(\x01\x12\"\n\x1a\x61\x63\x63\x65leration_cmd_closeloop\x18\x0b \x01(\x01\x12\x18\n\x10\x61\x63\x63\x65leration_cmd\x18\x0c \x01(\x01\x12\x1b\n\x13\x61\x63\x63\x65leration_lookup\x18\r \x01(\x01\x12\x14\n\x0cspeed_lookup\x18\x0e \x01(\x01\x12\x19\n\x11\x63\x61libration_value\x18\x0f \x01(\x01\x12\x14\n\x0cthrottle_cmd\x18\x10 \x01(\x01\x12\x11\n\tbrake_cmd\x18\x11 \x01(\x01\x12\x14\n\x0cis_full_stop\x18\x12 \x01(\x08\x12!\n\x19slope_offset_compensation\x18\x13 \x01(\x01\x12\x17\n\x0f\x63urrent_station\x18\x14 \x01(\x01\x12\x13\n\x0bpath_remain\x18\x15 \x01(\x01\x12\x1d\n\x15pid_saturation_status\x18\x16 \x01(\x05\x12!\n\x19leadlag_saturation_status\x18\x17 \x01(\x05\x12\x14\n\x0cspeed_offset\x18\x18 \x01(\x01\x12\x15\n\rcurrent_speed\x18\x19 \x01(\x01\x12\x1e\n\x16\x61\x63\x63\x65leration_reference\x18\x1a \x01(\x01\x12\x1c\n\x14\x63urrent_acceleration\x18\x1b \x01(\x01\x12\x1a\n\x12\x61\x63\x63\x65leration_error\x18\x1c \x01(\x01\x12\x16\n\x0ejerk_reference\x18\x1d \x01(\x01\x12\x14\n\x0c\x63urrent_jerk\x18\x1e \x01(\x01\x12\x12\n\njerk_error\x18\x1f \x01(\x01\x12=\n\x15\x63urrent_matched_point\x18  \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12?\n\x17\x63urrent_reference_point\x18! \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12?\n\x17preview_reference_point\x18\" \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\"\x93\x08\n\x12SimpleLateralDebug\x12\x15\n\rlateral_error\x18\x01 \x01(\x01\x12\x13\n\x0bref_heading\x18\x02 \x01(\x01\x12\x0f\n\x07heading\x18\x03 \x01(\x01\x12\x15\n\rheading_error\x18\x04 \x01(\x01\x12\x1a\n\x12heading_error_rate\x18\x05 \x01(\x01\x12\x1a\n\x12lateral_error_rate\x18\x06 \x01(\x01\x12\x11\n\tcurvature\x18\x07 \x01(\x01\x12\x13\n\x0bsteer_angle\x18\x08 \x01(\x01\x12\x1f\n\x17steer_angle_feedforward\x18\t \x01(\x01\x12(\n steer_angle_lateral_contribution\x18\n \x01(\x01\x12-\n%steer_angle_lateral_rate_contribution\x18\x0b \x01(\x01\x12(\n steer_angle_heading_contribution\x18\x0c \x01(\x01\x12-\n%steer_angle_heading_rate_contribution\x18\r \x01(\x01\x12\x1c\n\x14steer_angle_feedback\x18\x0e \x01(\x01\x12\x19\n\x11steering_position\x18\x0f \x01(\x01\x12\x11\n\tref_speed\x18\x10 \x01(\x01\x12\x1b\n\x13steer_angle_limited\x18\x11 \x01(\x01\x12\x1c\n\x14lateral_acceleration\x18\x12 \x01(\x01\x12\x14\n\x0clateral_jerk\x18\x13 \x01(\x01\x12\x18\n\x10ref_heading_rate\x18\x14 \x01(\x01\x12\x14\n\x0cheading_rate\x18\x15 \x01(\x01\x12 \n\x18ref_heading_acceleration\x18\x16 \x01(\x01\x12\x1c\n\x14heading_acceleration\x18\x17 \x01(\x01\x12\"\n\x1aheading_error_acceleration\x18\x18 \x01(\x01\x12\x18\n\x10ref_heading_jerk\x18\x19 \x01(\x01\x12\x14\n\x0cheading_jerk\x18\x1a \x01(\x01\x12\x1a\n\x12heading_error_jerk\x18\x1b \x01(\x01\x12\x1e\n\x16lateral_error_feedback\x18\x1c \x01(\x01\x12\x1e\n\x16heading_error_feedback\x18\x1d \x01(\x01\x12<\n\x14\x63urrent_target_point\x18\x1e \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12$\n\x1csteer_angle_feedback_augment\x18\x1f \x01(\x01\x12\x33\n\x10steer_mrac_debug\x18  \x01(\x0b\x32\x19.apollo.control.MracDebug\x12 \n\x18steer_mrac_enable_status\x18! \x01(\x08\"\xf2\n\n\x0eSimpleMPCDebug\x12\x15\n\rlateral_error\x18\x01 \x01(\x01\x12\x13\n\x0bref_heading\x18\x02 \x01(\x01\x12\x0f\n\x07heading\x18\x03 \x01(\x01\x12\x15\n\rheading_error\x18\x04 \x01(\x01\x12\x1a\n\x12heading_error_rate\x18\x05 \x01(\x01\x12\x1a\n\x12lateral_error_rate\x18\x06 \x01(\x01\x12\x11\n\tcurvature\x18\x07 \x01(\x01\x12\x13\n\x0bsteer_angle\x18\x08 \x01(\x01\x12\x1f\n\x17steer_angle_feedforward\x18\t \x01(\x01\x12(\n steer_angle_lateral_contribution\x18\n \x01(\x01\x12-\n%steer_angle_lateral_rate_contribution\x18\x0b \x01(\x01\x12(\n steer_angle_heading_contribution\x18\x0c \x01(\x01\x12-\n%steer_angle_heading_rate_contribution\x18\r \x01(\x01\x12\x1c\n\x14steer_angle_feedback\x18\x0e \x01(\x01\x12\x19\n\x11steering_position\x18\x0f \x01(\x01\x12\x11\n\tref_speed\x18\x10 \x01(\x01\x12\x1b\n\x13steer_angle_limited\x18\x11 \x01(\x01\x12\x19\n\x11station_reference\x18\x12 \x01(\x01\x12\x15\n\rstation_error\x18\x13 \x01(\x01\x12\x17\n\x0fspeed_reference\x18\x14 \x01(\x01\x12\x13\n\x0bspeed_error\x18\x15 \x01(\x01\x12\x1e\n\x16\x61\x63\x63\x65leration_reference\x18\x16 \x01(\x01\x12\x14\n\x0cis_full_stop\x18\x17 \x01(\x08\x12\x18\n\x10station_feedback\x18\x18 \x01(\x01\x12\x16\n\x0espeed_feedback\x18\x19 \x01(\x01\x12\"\n\x1a\x61\x63\x63\x65leration_cmd_closeloop\x18\x1a \x01(\x01\x12\x18\n\x10\x61\x63\x63\x65leration_cmd\x18\x1b \x01(\x01\x12\x1b\n\x13\x61\x63\x63\x65leration_lookup\x18\x1c \x01(\x01\x12\x14\n\x0cspeed_lookup\x18\x1d \x01(\x01\x12\x19\n\x11\x63\x61libration_value\x18\x1e \x01(\x01\x12(\n steer_unconstrained_control_diff\x18\x1f \x01(\x01\x12,\n$steer_angle_feedforward_compensation\x18  \x01(\x01\x12\x18\n\x10matrix_q_updated\x18! \x03(\x01\x12\x18\n\x10matrix_r_updated\x18\" \x03(\x01\x12\x1c\n\x14lateral_acceleration\x18# \x01(\x01\x12\x14\n\x0clateral_jerk\x18$ \x01(\x01\x12\x18\n\x10ref_heading_rate\x18% \x01(\x01\x12\x14\n\x0cheading_rate\x18& \x01(\x01\x12 \n\x18ref_heading_acceleration\x18\' \x01(\x01\x12\x1c\n\x14heading_acceleration\x18( \x01(\x01\x12\"\n\x1aheading_error_acceleration\x18) \x01(\x01\x12\x18\n\x10ref_heading_jerk\x18* \x01(\x01\x12\x14\n\x0cheading_jerk\x18+ \x01(\x01\x12\x1a\n\x12heading_error_jerk\x18, \x01(\x01\x12\x1d\n\x15\x61\x63\x63\x65leration_feedback\x18- \x01(\x01\x12\x1a\n\x12\x61\x63\x63\x65leration_error\x18. \x01(\x01\x12\x16\n\x0ejerk_reference\x18/ \x01(\x01\x12\x15\n\rjerk_feedback\x18\x30 \x01(\x01\x12\x12\n\njerk_error\x18\x31 \x01(\x01\"\xed\x01\n\tMracDebug\x12\x18\n\x10mrac_model_order\x18\x01 \x01(\x05\x12\x1c\n\x14mrac_reference_state\x18\x02 \x03(\x01\x12\x18\n\x10mrac_state_error\x18\x03 \x03(\x01\x12<\n\x12mrac_adaptive_gain\x18\x04 \x01(\x0b\x32 .apollo.control.MracAdaptiveGain\x12(\n mrac_reference_saturation_status\x18\x05 \x01(\x05\x12&\n\x1emrac_control_saturation_status\x18\x06 \x01(\x05\"m\n\x10MracAdaptiveGain\x12\x1b\n\x13state_adaptive_gain\x18\x01 \x03(\x01\x12\x1b\n\x13input_adaptive_gain\x18\x02 \x03(\x01\x12\x1f\n\x17nonlinear_adaptive_gain\x18\x03 \x03(\x01\"\xf3\x01\n\x05\x44\x65\x62ug\x12\x41\n\x10simple_lon_debug\x18\x01 \x01(\x0b\x32\'.apollo.control.SimpleLongitudinalDebug\x12<\n\x10simple_lat_debug\x18\x02 \x01(\x0b\x32\".apollo.control.SimpleLateralDebug\x12/\n\x0binput_debug\x18\x03 \x01(\x0b\x32\x1a.apollo.control.InputDebug\x12\x38\n\x10simple_mpc_debug\x18\x04 \x01(\x0b\x32\x1e.apollo.control.SimpleMPCDebug*:\n\nTurnSignal\x12\r\n\tTURN_NONE\x10\x00\x12\r\n\tTURN_LEFT\x10\x01\x12\x0e\n\nTURN_RIGHT\x10\x02'
  ,
  dependencies=[modules_dot_canbus_dot_proto_dot_chassis__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_drive__state__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_vehicle__signal__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_input__debug__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_pad__msg__pb2.DESCRIPTOR,])

_TURNSIGNAL = _descriptor.EnumDescriptor(
  name='TurnSignal',
  full_name='apollo.control.TurnSignal',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TURN_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5363,
  serialized_end=5421,
)
_sym_db.RegisterEnumDescriptor(_TURNSIGNAL)

TurnSignal = enum_type_wrapper.EnumTypeWrapper(_TURNSIGNAL)
TURN_NONE = 0
TURN_LEFT = 1
TURN_RIGHT = 2



_LATENCYSTATS = _descriptor.Descriptor(
  name='LatencyStats',
  full_name='apollo.control.LatencyStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_time_ms', full_name='apollo.control.LatencyStats.total_time_ms', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_time_ms', full_name='apollo.control.LatencyStats.controller_time_ms', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_time_exceeded', full_name='apollo.control.LatencyStats.total_time_exceeded', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=423,
)


_CONTROLCOMMAND = _descriptor.Descriptor(
  name='ControlCommand',
  full_name='apollo.control.ControlCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.control.ControlCommand.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle', full_name='apollo.control.ControlCommand.throttle', index=1,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake', full_name='apollo.control.ControlCommand.brake', index=2,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_rate', full_name='apollo.control.ControlCommand.steering_rate', index=3,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_target', full_name='apollo.control.ControlCommand.steering_target', index=4,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_brake', full_name='apollo.control.ControlCommand.parking_brake', index=5,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.control.ControlCommand.speed', index=6,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='apollo.control.ControlCommand.acceleration', index=7,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reset_model', full_name='apollo.control.ControlCommand.reset_model', index=8,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engine_on_off', full_name='apollo.control.ControlCommand.engine_on_off', index=9,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_fraction', full_name='apollo.control.ControlCommand.trajectory_fraction', index=10,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driving_mode', full_name='apollo.control.ControlCommand.driving_mode', index=11,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_location', full_name='apollo.control.ControlCommand.gear_location', index=12,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug', full_name='apollo.control.ControlCommand.debug', index=13,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal', full_name='apollo.control.ControlCommand.signal', index=14,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency_stats', full_name='apollo.control.ControlCommand.latency_stats', index=15,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pad_msg', full_name='apollo.control.ControlCommand.pad_msg', index=16,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engage_advice', full_name='apollo.control.ControlCommand.engage_advice', index=17,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_in_safe_mode', full_name='apollo.control.ControlCommand.is_in_safe_mode', index=18,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_turn', full_name='apollo.control.ControlCommand.left_turn', index=19,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_turn', full_name='apollo.control.ControlCommand.right_turn', index=20,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high_beam', full_name='apollo.control.ControlCommand.high_beam', index=21,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low_beam', full_name='apollo.control.ControlCommand.low_beam', index=22,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='horn', full_name='apollo.control.ControlCommand.horn', index=23,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turnsignal', full_name='apollo.control.ControlCommand.turnsignal', index=24,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=1249,
)


_SIMPLELONGITUDINALDEBUG = _descriptor.Descriptor(
  name='SimpleLongitudinalDebug',
  full_name='apollo.control.SimpleLongitudinalDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='station_reference', full_name='apollo.control.SimpleLongitudinalDebug.station_reference', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_error', full_name='apollo.control.SimpleLongitudinalDebug.station_error', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_error_limited', full_name='apollo.control.SimpleLongitudinalDebug.station_error_limited', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_station_error', full_name='apollo.control.SimpleLongitudinalDebug.preview_station_error', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_reference', full_name='apollo.control.SimpleLongitudinalDebug.speed_reference', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_error', full_name='apollo.control.SimpleLongitudinalDebug.speed_error', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_controller_input_limited', full_name='apollo.control.SimpleLongitudinalDebug.speed_controller_input_limited', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_speed_reference', full_name='apollo.control.SimpleLongitudinalDebug.preview_speed_reference', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_speed_error', full_name='apollo.control.SimpleLongitudinalDebug.preview_speed_error', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_acceleration_reference', full_name='apollo.control.SimpleLongitudinalDebug.preview_acceleration_reference', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_cmd_closeloop', full_name='apollo.control.SimpleLongitudinalDebug.acceleration_cmd_closeloop', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_cmd', full_name='apollo.control.SimpleLongitudinalDebug.acceleration_cmd', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_lookup', full_name='apollo.control.SimpleLongitudinalDebug.acceleration_lookup', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_lookup', full_name='apollo.control.SimpleLongitudinalDebug.speed_lookup', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration_value', full_name='apollo.control.SimpleLongitudinalDebug.calibration_value', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_cmd', full_name='apollo.control.SimpleLongitudinalDebug.throttle_cmd', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_cmd', full_name='apollo.control.SimpleLongitudinalDebug.brake_cmd', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_full_stop', full_name='apollo.control.SimpleLongitudinalDebug.is_full_stop', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slope_offset_compensation', full_name='apollo.control.SimpleLongitudinalDebug.slope_offset_compensation', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_station', full_name='apollo.control.SimpleLongitudinalDebug.current_station', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_remain', full_name='apollo.control.SimpleLongitudinalDebug.path_remain', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pid_saturation_status', full_name='apollo.control.SimpleLongitudinalDebug.pid_saturation_status', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leadlag_saturation_status', full_name='apollo.control.SimpleLongitudinalDebug.leadlag_saturation_status', index=22,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_offset', full_name='apollo.control.SimpleLongitudinalDebug.speed_offset', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_speed', full_name='apollo.control.SimpleLongitudinalDebug.current_speed', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_reference', full_name='apollo.control.SimpleLongitudinalDebug.acceleration_reference', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_acceleration', full_name='apollo.control.SimpleLongitudinalDebug.current_acceleration', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_error', full_name='apollo.control.SimpleLongitudinalDebug.acceleration_error', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk_reference', full_name='apollo.control.SimpleLongitudinalDebug.jerk_reference', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_jerk', full_name='apollo.control.SimpleLongitudinalDebug.current_jerk', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk_error', full_name='apollo.control.SimpleLongitudinalDebug.jerk_error', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_matched_point', full_name='apollo.control.SimpleLongitudinalDebug.current_matched_point', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_reference_point', full_name='apollo.control.SimpleLongitudinalDebug.current_reference_point', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_reference_point', full_name='apollo.control.SimpleLongitudinalDebug.preview_reference_point', index=33,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1252,
  serialized_end=2321,
)


_SIMPLELATERALDEBUG = _descriptor.Descriptor(
  name='SimpleLateralDebug',
  full_name='apollo.control.SimpleLateralDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lateral_error', full_name='apollo.control.SimpleLateralDebug.lateral_error', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading', full_name='apollo.control.SimpleLateralDebug.ref_heading', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.control.SimpleLateralDebug.heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error', full_name='apollo.control.SimpleLateralDebug.heading_error', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_rate', full_name='apollo.control.SimpleLateralDebug.heading_error_rate', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_error_rate', full_name='apollo.control.SimpleLateralDebug.lateral_error_rate', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature', full_name='apollo.control.SimpleLateralDebug.curvature', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle', full_name='apollo.control.SimpleLateralDebug.steer_angle', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_feedforward', full_name='apollo.control.SimpleLateralDebug.steer_angle_feedforward', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_lateral_contribution', full_name='apollo.control.SimpleLateralDebug.steer_angle_lateral_contribution', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_lateral_rate_contribution', full_name='apollo.control.SimpleLateralDebug.steer_angle_lateral_rate_contribution', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_heading_contribution', full_name='apollo.control.SimpleLateralDebug.steer_angle_heading_contribution', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_heading_rate_contribution', full_name='apollo.control.SimpleLateralDebug.steer_angle_heading_rate_contribution', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_feedback', full_name='apollo.control.SimpleLateralDebug.steer_angle_feedback', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_position', full_name='apollo.control.SimpleLateralDebug.steering_position', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_speed', full_name='apollo.control.SimpleLateralDebug.ref_speed', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_limited', full_name='apollo.control.SimpleLateralDebug.steer_angle_limited', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_acceleration', full_name='apollo.control.SimpleLateralDebug.lateral_acceleration', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_jerk', full_name='apollo.control.SimpleLateralDebug.lateral_jerk', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading_rate', full_name='apollo.control.SimpleLateralDebug.ref_heading_rate', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_rate', full_name='apollo.control.SimpleLateralDebug.heading_rate', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading_acceleration', full_name='apollo.control.SimpleLateralDebug.ref_heading_acceleration', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_acceleration', full_name='apollo.control.SimpleLateralDebug.heading_acceleration', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_acceleration', full_name='apollo.control.SimpleLateralDebug.heading_error_acceleration', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading_jerk', full_name='apollo.control.SimpleLateralDebug.ref_heading_jerk', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_jerk', full_name='apollo.control.SimpleLateralDebug.heading_jerk', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_jerk', full_name='apollo.control.SimpleLateralDebug.heading_error_jerk', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_error_feedback', full_name='apollo.control.SimpleLateralDebug.lateral_error_feedback', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_feedback', full_name='apollo.control.SimpleLateralDebug.heading_error_feedback', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_target_point', full_name='apollo.control.SimpleLateralDebug.current_target_point', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_feedback_augment', full_name='apollo.control.SimpleLateralDebug.steer_angle_feedback_augment', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_mrac_debug', full_name='apollo.control.SimpleLateralDebug.steer_mrac_debug', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_mrac_enable_status', full_name='apollo.control.SimpleLateralDebug.steer_mrac_enable_status', index=32,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2324,
  serialized_end=3367,
)


_SIMPLEMPCDEBUG = _descriptor.Descriptor(
  name='SimpleMPCDebug',
  full_name='apollo.control.SimpleMPCDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lateral_error', full_name='apollo.control.SimpleMPCDebug.lateral_error', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading', full_name='apollo.control.SimpleMPCDebug.ref_heading', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.control.SimpleMPCDebug.heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error', full_name='apollo.control.SimpleMPCDebug.heading_error', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_rate', full_name='apollo.control.SimpleMPCDebug.heading_error_rate', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_error_rate', full_name='apollo.control.SimpleMPCDebug.lateral_error_rate', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature', full_name='apollo.control.SimpleMPCDebug.curvature', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle', full_name='apollo.control.SimpleMPCDebug.steer_angle', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_feedforward', full_name='apollo.control.SimpleMPCDebug.steer_angle_feedforward', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_lateral_contribution', full_name='apollo.control.SimpleMPCDebug.steer_angle_lateral_contribution', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_lateral_rate_contribution', full_name='apollo.control.SimpleMPCDebug.steer_angle_lateral_rate_contribution', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_heading_contribution', full_name='apollo.control.SimpleMPCDebug.steer_angle_heading_contribution', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_heading_rate_contribution', full_name='apollo.control.SimpleMPCDebug.steer_angle_heading_rate_contribution', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_feedback', full_name='apollo.control.SimpleMPCDebug.steer_angle_feedback', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_position', full_name='apollo.control.SimpleMPCDebug.steering_position', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_speed', full_name='apollo.control.SimpleMPCDebug.ref_speed', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_limited', full_name='apollo.control.SimpleMPCDebug.steer_angle_limited', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_reference', full_name='apollo.control.SimpleMPCDebug.station_reference', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_error', full_name='apollo.control.SimpleMPCDebug.station_error', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_reference', full_name='apollo.control.SimpleMPCDebug.speed_reference', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_error', full_name='apollo.control.SimpleMPCDebug.speed_error', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_reference', full_name='apollo.control.SimpleMPCDebug.acceleration_reference', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_full_stop', full_name='apollo.control.SimpleMPCDebug.is_full_stop', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_feedback', full_name='apollo.control.SimpleMPCDebug.station_feedback', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_feedback', full_name='apollo.control.SimpleMPCDebug.speed_feedback', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_cmd_closeloop', full_name='apollo.control.SimpleMPCDebug.acceleration_cmd_closeloop', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_cmd', full_name='apollo.control.SimpleMPCDebug.acceleration_cmd', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_lookup', full_name='apollo.control.SimpleMPCDebug.acceleration_lookup', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_lookup', full_name='apollo.control.SimpleMPCDebug.speed_lookup', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration_value', full_name='apollo.control.SimpleMPCDebug.calibration_value', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_unconstrained_control_diff', full_name='apollo.control.SimpleMPCDebug.steer_unconstrained_control_diff', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_feedforward_compensation', full_name='apollo.control.SimpleMPCDebug.steer_angle_feedforward_compensation', index=31,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matrix_q_updated', full_name='apollo.control.SimpleMPCDebug.matrix_q_updated', index=32,
      number=33, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matrix_r_updated', full_name='apollo.control.SimpleMPCDebug.matrix_r_updated', index=33,
      number=34, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_acceleration', full_name='apollo.control.SimpleMPCDebug.lateral_acceleration', index=34,
      number=35, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_jerk', full_name='apollo.control.SimpleMPCDebug.lateral_jerk', index=35,
      number=36, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading_rate', full_name='apollo.control.SimpleMPCDebug.ref_heading_rate', index=36,
      number=37, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_rate', full_name='apollo.control.SimpleMPCDebug.heading_rate', index=37,
      number=38, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading_acceleration', full_name='apollo.control.SimpleMPCDebug.ref_heading_acceleration', index=38,
      number=39, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_acceleration', full_name='apollo.control.SimpleMPCDebug.heading_acceleration', index=39,
      number=40, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_acceleration', full_name='apollo.control.SimpleMPCDebug.heading_error_acceleration', index=40,
      number=41, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_heading_jerk', full_name='apollo.control.SimpleMPCDebug.ref_heading_jerk', index=41,
      number=42, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_jerk', full_name='apollo.control.SimpleMPCDebug.heading_jerk', index=42,
      number=43, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error_jerk', full_name='apollo.control.SimpleMPCDebug.heading_error_jerk', index=43,
      number=44, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_feedback', full_name='apollo.control.SimpleMPCDebug.acceleration_feedback', index=44,
      number=45, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_error', full_name='apollo.control.SimpleMPCDebug.acceleration_error', index=45,
      number=46, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk_reference', full_name='apollo.control.SimpleMPCDebug.jerk_reference', index=46,
      number=47, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk_feedback', full_name='apollo.control.SimpleMPCDebug.jerk_feedback', index=47,
      number=48, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jerk_error', full_name='apollo.control.SimpleMPCDebug.jerk_error', index=48,
      number=49, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3370,
  serialized_end=4764,
)


_MRACDEBUG = _descriptor.Descriptor(
  name='MracDebug',
  full_name='apollo.control.MracDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mrac_model_order', full_name='apollo.control.MracDebug.mrac_model_order', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mrac_reference_state', full_name='apollo.control.MracDebug.mrac_reference_state', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mrac_state_error', full_name='apollo.control.MracDebug.mrac_state_error', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mrac_adaptive_gain', full_name='apollo.control.MracDebug.mrac_adaptive_gain', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mrac_reference_saturation_status', full_name='apollo.control.MracDebug.mrac_reference_saturation_status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mrac_control_saturation_status', full_name='apollo.control.MracDebug.mrac_control_saturation_status', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4767,
  serialized_end=5004,
)


_MRACADAPTIVEGAIN = _descriptor.Descriptor(
  name='MracAdaptiveGain',
  full_name='apollo.control.MracAdaptiveGain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_adaptive_gain', full_name='apollo.control.MracAdaptiveGain.state_adaptive_gain', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_adaptive_gain', full_name='apollo.control.MracAdaptiveGain.input_adaptive_gain', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonlinear_adaptive_gain', full_name='apollo.control.MracAdaptiveGain.nonlinear_adaptive_gain', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5006,
  serialized_end=5115,
)


_DEBUG = _descriptor.Descriptor(
  name='Debug',
  full_name='apollo.control.Debug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='simple_lon_debug', full_name='apollo.control.Debug.simple_lon_debug', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simple_lat_debug', full_name='apollo.control.Debug.simple_lat_debug', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_debug', full_name='apollo.control.Debug.input_debug', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simple_mpc_debug', full_name='apollo.control.Debug.simple_mpc_debug', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5118,
  serialized_end=5361,
)

_CONTROLCOMMAND.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_CONTROLCOMMAND.fields_by_name['driving_mode'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_DRIVINGMODE
_CONTROLCOMMAND.fields_by_name['gear_location'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_GEARPOSITION
_CONTROLCOMMAND.fields_by_name['debug'].message_type = _DEBUG
_CONTROLCOMMAND.fields_by_name['signal'].message_type = modules_dot_common_dot_proto_dot_vehicle__signal__pb2._VEHICLESIGNAL
_CONTROLCOMMAND.fields_by_name['latency_stats'].message_type = _LATENCYSTATS
_CONTROLCOMMAND.fields_by_name['pad_msg'].message_type = modules_dot_control_dot_proto_dot_pad__msg__pb2._PADMESSAGE
_CONTROLCOMMAND.fields_by_name['engage_advice'].message_type = modules_dot_common_dot_proto_dot_drive__state__pb2._ENGAGEADVICE
_CONTROLCOMMAND.fields_by_name['turnsignal'].enum_type = _TURNSIGNAL
_SIMPLELONGITUDINALDEBUG.fields_by_name['current_matched_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_SIMPLELONGITUDINALDEBUG.fields_by_name['current_reference_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_SIMPLELONGITUDINALDEBUG.fields_by_name['preview_reference_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_SIMPLELATERALDEBUG.fields_by_name['current_target_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_SIMPLELATERALDEBUG.fields_by_name['steer_mrac_debug'].message_type = _MRACDEBUG
_MRACDEBUG.fields_by_name['mrac_adaptive_gain'].message_type = _MRACADAPTIVEGAIN
_DEBUG.fields_by_name['simple_lon_debug'].message_type = _SIMPLELONGITUDINALDEBUG
_DEBUG.fields_by_name['simple_lat_debug'].message_type = _SIMPLELATERALDEBUG
_DEBUG.fields_by_name['input_debug'].message_type = modules_dot_control_dot_proto_dot_input__debug__pb2._INPUTDEBUG
_DEBUG.fields_by_name['simple_mpc_debug'].message_type = _SIMPLEMPCDEBUG
DESCRIPTOR.message_types_by_name['LatencyStats'] = _LATENCYSTATS
DESCRIPTOR.message_types_by_name['ControlCommand'] = _CONTROLCOMMAND
DESCRIPTOR.message_types_by_name['SimpleLongitudinalDebug'] = _SIMPLELONGITUDINALDEBUG
DESCRIPTOR.message_types_by_name['SimpleLateralDebug'] = _SIMPLELATERALDEBUG
DESCRIPTOR.message_types_by_name['SimpleMPCDebug'] = _SIMPLEMPCDEBUG
DESCRIPTOR.message_types_by_name['MracDebug'] = _MRACDEBUG
DESCRIPTOR.message_types_by_name['MracAdaptiveGain'] = _MRACADAPTIVEGAIN
DESCRIPTOR.message_types_by_name['Debug'] = _DEBUG
DESCRIPTOR.enum_types_by_name['TurnSignal'] = _TURNSIGNAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LatencyStats = _reflection.GeneratedProtocolMessageType('LatencyStats', (_message.Message,), {
  'DESCRIPTOR' : _LATENCYSTATS,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.LatencyStats)
  })
_sym_db.RegisterMessage(LatencyStats)

ControlCommand = _reflection.GeneratedProtocolMessageType('ControlCommand', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLCOMMAND,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.ControlCommand)
  })
_sym_db.RegisterMessage(ControlCommand)

SimpleLongitudinalDebug = _reflection.GeneratedProtocolMessageType('SimpleLongitudinalDebug', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLELONGITUDINALDEBUG,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.SimpleLongitudinalDebug)
  })
_sym_db.RegisterMessage(SimpleLongitudinalDebug)

SimpleLateralDebug = _reflection.GeneratedProtocolMessageType('SimpleLateralDebug', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLELATERALDEBUG,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.SimpleLateralDebug)
  })
_sym_db.RegisterMessage(SimpleLateralDebug)

SimpleMPCDebug = _reflection.GeneratedProtocolMessageType('SimpleMPCDebug', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLEMPCDEBUG,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.SimpleMPCDebug)
  })
_sym_db.RegisterMessage(SimpleMPCDebug)

MracDebug = _reflection.GeneratedProtocolMessageType('MracDebug', (_message.Message,), {
  'DESCRIPTOR' : _MRACDEBUG,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.MracDebug)
  })
_sym_db.RegisterMessage(MracDebug)

MracAdaptiveGain = _reflection.GeneratedProtocolMessageType('MracAdaptiveGain', (_message.Message,), {
  'DESCRIPTOR' : _MRACADAPTIVEGAIN,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.MracAdaptiveGain)
  })
_sym_db.RegisterMessage(MracAdaptiveGain)

Debug = _reflection.GeneratedProtocolMessageType('Debug', (_message.Message,), {
  'DESCRIPTOR' : _DEBUG,
  '__module__' : 'modules.control.proto.control_cmd_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.Debug)
  })
_sym_db.RegisterMessage(Debug)


_CONTROLCOMMAND.fields_by_name['reset_model']._options = None
_CONTROLCOMMAND.fields_by_name['driving_mode']._options = None
_CONTROLCOMMAND.fields_by_name['left_turn']._options = None
_CONTROLCOMMAND.fields_by_name['right_turn']._options = None
_CONTROLCOMMAND.fields_by_name['high_beam']._options = None
_CONTROLCOMMAND.fields_by_name['low_beam']._options = None
_CONTROLCOMMAND.fields_by_name['horn']._options = None
_CONTROLCOMMAND.fields_by_name['turnsignal']._options = None
# @@protoc_insertion_point(module_scope)
