# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/component_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cyber.proto import qos_profile_pb2 as cyber_dot_proto_dot_qos__profile__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/component_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n cyber/proto/component_conf.proto\x12\x12\x61pollo.cyber.proto\x1a\x1d\x63yber/proto/qos_profile.proto\"s\n\x0cReaderOption\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\x12\x33\n\x0bqos_profile\x18\x02 \x01(\x0b\x32\x1e.apollo.cyber.proto.QosProfile\x12\x1d\n\x12pending_queue_size\x18\x03 \x01(\r:\x01\x31\"\x84\x01\n\x0f\x43omponentConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10\x63onfig_file_path\x18\x02 \x01(\t\x12\x16\n\x0e\x66lag_file_path\x18\x03 \x01(\t\x12\x31\n\x07readers\x18\x04 \x03(\x0b\x32 .apollo.cyber.proto.ReaderOption\"h\n\x14TimerComponentConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10\x63onfig_file_path\x18\x02 \x01(\t\x12\x16\n\x0e\x66lag_file_path\x18\x03 \x01(\t\x12\x10\n\x08interval\x18\x04 \x01(\r'
  ,
  dependencies=[cyber_dot_proto_dot_qos__profile__pb2.DESCRIPTOR,])




_READEROPTION = _descriptor.Descriptor(
  name='ReaderOption',
  full_name='apollo.cyber.proto.ReaderOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='apollo.cyber.proto.ReaderOption.channel', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qos_profile', full_name='apollo.cyber.proto.ReaderOption.qos_profile', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_queue_size', full_name='apollo.cyber.proto.ReaderOption.pending_queue_size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=202,
)


_COMPONENTCONFIG = _descriptor.Descriptor(
  name='ComponentConfig',
  full_name='apollo.cyber.proto.ComponentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.ComponentConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_file_path', full_name='apollo.cyber.proto.ComponentConfig.config_file_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flag_file_path', full_name='apollo.cyber.proto.ComponentConfig.flag_file_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readers', full_name='apollo.cyber.proto.ComponentConfig.readers', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=337,
)


_TIMERCOMPONENTCONFIG = _descriptor.Descriptor(
  name='TimerComponentConfig',
  full_name='apollo.cyber.proto.TimerComponentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.TimerComponentConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_file_path', full_name='apollo.cyber.proto.TimerComponentConfig.config_file_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flag_file_path', full_name='apollo.cyber.proto.TimerComponentConfig.flag_file_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='apollo.cyber.proto.TimerComponentConfig.interval', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=443,
)

_READEROPTION.fields_by_name['qos_profile'].message_type = cyber_dot_proto_dot_qos__profile__pb2._QOSPROFILE
_COMPONENTCONFIG.fields_by_name['readers'].message_type = _READEROPTION
DESCRIPTOR.message_types_by_name['ReaderOption'] = _READEROPTION
DESCRIPTOR.message_types_by_name['ComponentConfig'] = _COMPONENTCONFIG
DESCRIPTOR.message_types_by_name['TimerComponentConfig'] = _TIMERCOMPONENTCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReaderOption = _reflection.GeneratedProtocolMessageType('ReaderOption', (_message.Message,), {
  'DESCRIPTOR' : _READEROPTION,
  '__module__' : 'cyber.proto.component_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ReaderOption)
  })
_sym_db.RegisterMessage(ReaderOption)

ComponentConfig = _reflection.GeneratedProtocolMessageType('ComponentConfig', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTCONFIG,
  '__module__' : 'cyber.proto.component_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ComponentConfig)
  })
_sym_db.RegisterMessage(ComponentConfig)

TimerComponentConfig = _reflection.GeneratedProtocolMessageType('TimerComponentConfig', (_message.Message,), {
  'DESCRIPTOR' : _TIMERCOMPONENTCONFIG,
  '__module__' : 'cyber.proto.component_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.TimerComponentConfig)
  })
_sym_db.RegisterMessage(TimerComponentConfig)


# @@protoc_insertion_point(module_scope)
