# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/cyber_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cyber.proto import scheduler_conf_pb2 as cyber_dot_proto_dot_scheduler__conf__pb2
from cyber.proto import transport_conf_pb2 as cyber_dot_proto_dot_transport__conf__pb2
from cyber.proto import run_mode_conf_pb2 as cyber_dot_proto_dot_run__mode__conf__pb2
from cyber.proto import perf_conf_pb2 as cyber_dot_proto_dot_perf__conf__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/cyber_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x63yber/proto/cyber_conf.proto\x12\x12\x61pollo.cyber.proto\x1a cyber/proto/scheduler_conf.proto\x1a cyber/proto/transport_conf.proto\x1a\x1f\x63yber/proto/run_mode_conf.proto\x1a\x1b\x63yber/proto/perf_conf.proto\"\xec\x01\n\x0b\x43yberConfig\x12\x39\n\x0escheduler_conf\x18\x01 \x01(\x0b\x32!.apollo.cyber.proto.SchedulerConf\x12\x39\n\x0etransport_conf\x18\x02 \x01(\x0b\x32!.apollo.cyber.proto.TransportConf\x12\x36\n\rrun_mode_conf\x18\x03 \x01(\x0b\x32\x1f.apollo.cyber.proto.RunModeConf\x12/\n\tperf_conf\x18\x04 \x01(\x0b\x32\x1c.apollo.cyber.proto.PerfConf'
  ,
  dependencies=[cyber_dot_proto_dot_scheduler__conf__pb2.DESCRIPTOR,cyber_dot_proto_dot_transport__conf__pb2.DESCRIPTOR,cyber_dot_proto_dot_run__mode__conf__pb2.DESCRIPTOR,cyber_dot_proto_dot_perf__conf__pb2.DESCRIPTOR,])




_CYBERCONFIG = _descriptor.Descriptor(
  name='CyberConfig',
  full_name='apollo.cyber.proto.CyberConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheduler_conf', full_name='apollo.cyber.proto.CyberConfig.scheduler_conf', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_conf', full_name='apollo.cyber.proto.CyberConfig.transport_conf', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_mode_conf', full_name='apollo.cyber.proto.CyberConfig.run_mode_conf', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perf_conf', full_name='apollo.cyber.proto.CyberConfig.perf_conf', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=419,
)

_CYBERCONFIG.fields_by_name['scheduler_conf'].message_type = cyber_dot_proto_dot_scheduler__conf__pb2._SCHEDULERCONF
_CYBERCONFIG.fields_by_name['transport_conf'].message_type = cyber_dot_proto_dot_transport__conf__pb2._TRANSPORTCONF
_CYBERCONFIG.fields_by_name['run_mode_conf'].message_type = cyber_dot_proto_dot_run__mode__conf__pb2._RUNMODECONF
_CYBERCONFIG.fields_by_name['perf_conf'].message_type = cyber_dot_proto_dot_perf__conf__pb2._PERFCONF
DESCRIPTOR.message_types_by_name['CyberConfig'] = _CYBERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CyberConfig = _reflection.GeneratedProtocolMessageType('CyberConfig', (_message.Message,), {
  'DESCRIPTOR' : _CYBERCONFIG,
  '__module__' : 'cyber.proto.cyber_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.CyberConfig)
  })
_sym_db.RegisterMessage(CyberConfig)


# @@protoc_insertion_point(module_scope)
