# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/v2x_traffic_light_policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/v2x_traffic_light_policy.proto',
  package='apollo.v2x',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0modules/v2x/proto/v2x_traffic_light_policy.proto\x12\napollo.v2x\"\"\n\nPosition2D\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\"\x92\x01\n\nConnection\x12;\n\x16\x61llow_driving_behavior\x18\x01 \x01(\x0e\x32\x1b.apollo.v2x.Connection.Type\x12\x10\n\x08phase_id\x18\x02 \x01(\x05\"5\n\x04Type\x12\x0c\n\x08STRAIGHT\x10\x00\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\x12\n\n\x06U_TURN\x10\x03\"u\n\x04Lane\x12\x0f\n\x07lane_id\x18\x01 \x01(\x05\x12/\n\x0fposition_offset\x18\x02 \x03(\x0b\x32\x16.apollo.v2x.Position2D\x12+\n\x0b\x63onnections\x18\x03 \x03(\x0b\x32\x16.apollo.v2x.Connection\"i\n\x04Road\x12\x18\n\x10upstream_node_id\x18\x01 \x01(\x05\x12&\n\x06points\x18\x02 \x01(\x0b\x32\x16.apollo.v2x.Position2D\x12\x1f\n\x05lanes\x18\x03 \x03(\x0b\x32\x10.apollo.v2x.Lane\"e\n\x0cIntersection\x12\n\n\x02id\x18\x01 \x01(\x05\x12(\n\x08position\x18\x02 \x01(\x0b\x32\x16.apollo.v2x.Position2D\x12\x1f\n\x05roads\x18\x03 \x03(\x0b\x32\x10.apollo.v2x.Road\"[\n\x03Map\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0f\n\x07msg_cnt\x18\x02 \x01(\x05\x12/\n\rintersections\x18\x03 \x03(\x0b\x32\x18.apollo.v2x.Intersection\"\xad\x01\n\x05Phase\x12\n\n\x02id\x18\x01 \x01(\x05\x12&\n\x05\x63olor\x18\x02 \x01(\x0e\x32\x17.apollo.v2x.Phase.Color\x12\x1e\n\x16\x63olor_remaining_time_s\x18\x03 \x01(\x05\"P\n\x05\x43olor\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03RED\x10\x01\x12\n\n\x06YELLOW\x10\x02\x12\t\n\x05GREEN\x10\x03\x12\t\n\x05\x42LACK\x10\x04\x12\x0f\n\x0b\x46LASH_GREEN\x10\x05\"x\n\x11IntersectionState\x12\x17\n\x0fintersection_id\x18\x01 \x01(\x05\x12!\n\x06Phases\x18\x02 \x03(\x0b\x32\x11.apollo.v2x.Phase\x12\x0b\n\x03moy\x18\x03 \x01(\x05\x12\x1a\n\x12time_stamp_dsecond\x18\x04 \x01(\x05\"a\n\x04Spat\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0f\n\x07msg_cnt\x18\x02 \x01(\x05\x12\x34\n\rintersections\x18\x03 \x03(\x0b\x32\x1d.apollo.v2x.IntersectionState\"J\n\nPolicyData\x12\x1c\n\x03map\x18\x01 \x01(\x0b\x32\x0f.apollo.v2x.Map\x12\x1e\n\x04spat\x18\x02 \x01(\x0b\x32\x10.apollo.v2x.Spat'
)



_CONNECTION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.v2x.Connection.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STRAIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U_TURN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=194,
  serialized_end=247,
)
_sym_db.RegisterEnumDescriptor(_CONNECTION_TYPE)

_PHASE_COLOR = _descriptor.EnumDescriptor(
  name='Color',
  full_name='apollo.v2x.Phase.Color',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YELLOW', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREEN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLACK', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLASH_GREEN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=765,
  serialized_end=845,
)
_sym_db.RegisterEnumDescriptor(_PHASE_COLOR)


_POSITION2D = _descriptor.Descriptor(
  name='Position2D',
  full_name='apollo.v2x.Position2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.v2x.Position2D.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.v2x.Position2D.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=98,
)


_CONNECTION = _descriptor.Descriptor(
  name='Connection',
  full_name='apollo.v2x.Connection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allow_driving_behavior', full_name='apollo.v2x.Connection.allow_driving_behavior', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_id', full_name='apollo.v2x.Connection.phase_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONNECTION_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=247,
)


_LANE = _descriptor.Descriptor(
  name='Lane',
  full_name='apollo.v2x.Lane',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.v2x.Lane.lane_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_offset', full_name='apollo.v2x.Lane.position_offset', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connections', full_name='apollo.v2x.Lane.connections', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=249,
  serialized_end=366,
)


_ROAD = _descriptor.Descriptor(
  name='Road',
  full_name='apollo.v2x.Road',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upstream_node_id', full_name='apollo.v2x.Road.upstream_node_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points', full_name='apollo.v2x.Road.points', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lanes', full_name='apollo.v2x.Road.lanes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=473,
)


_INTERSECTION = _descriptor.Descriptor(
  name='Intersection',
  full_name='apollo.v2x.Intersection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.v2x.Intersection.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.v2x.Intersection.position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roads', full_name='apollo.v2x.Intersection.roads', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=576,
)


_MAP = _descriptor.Descriptor(
  name='Map',
  full_name='apollo.v2x.Map',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='apollo.v2x.Map.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg_cnt', full_name='apollo.v2x.Map.msg_cnt', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intersections', full_name='apollo.v2x.Map.intersections', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=669,
)


_PHASE = _descriptor.Descriptor(
  name='Phase',
  full_name='apollo.v2x.Phase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.v2x.Phase.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='apollo.v2x.Phase.color', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color_remaining_time_s', full_name='apollo.v2x.Phase.color_remaining_time_s', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PHASE_COLOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=845,
)


_INTERSECTIONSTATE = _descriptor.Descriptor(
  name='IntersectionState',
  full_name='apollo.v2x.IntersectionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intersection_id', full_name='apollo.v2x.IntersectionState.intersection_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Phases', full_name='apollo.v2x.IntersectionState.Phases', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='moy', full_name='apollo.v2x.IntersectionState.moy', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_stamp_dsecond', full_name='apollo.v2x.IntersectionState.time_stamp_dsecond', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=847,
  serialized_end=967,
)


_SPAT = _descriptor.Descriptor(
  name='Spat',
  full_name='apollo.v2x.Spat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='apollo.v2x.Spat.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg_cnt', full_name='apollo.v2x.Spat.msg_cnt', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intersections', full_name='apollo.v2x.Spat.intersections', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1066,
)


_POLICYDATA = _descriptor.Descriptor(
  name='PolicyData',
  full_name='apollo.v2x.PolicyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='map', full_name='apollo.v2x.PolicyData.map', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spat', full_name='apollo.v2x.PolicyData.spat', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1068,
  serialized_end=1142,
)

_CONNECTION.fields_by_name['allow_driving_behavior'].enum_type = _CONNECTION_TYPE
_CONNECTION_TYPE.containing_type = _CONNECTION
_LANE.fields_by_name['position_offset'].message_type = _POSITION2D
_LANE.fields_by_name['connections'].message_type = _CONNECTION
_ROAD.fields_by_name['points'].message_type = _POSITION2D
_ROAD.fields_by_name['lanes'].message_type = _LANE
_INTERSECTION.fields_by_name['position'].message_type = _POSITION2D
_INTERSECTION.fields_by_name['roads'].message_type = _ROAD
_MAP.fields_by_name['intersections'].message_type = _INTERSECTION
_PHASE.fields_by_name['color'].enum_type = _PHASE_COLOR
_PHASE_COLOR.containing_type = _PHASE
_INTERSECTIONSTATE.fields_by_name['Phases'].message_type = _PHASE
_SPAT.fields_by_name['intersections'].message_type = _INTERSECTIONSTATE
_POLICYDATA.fields_by_name['map'].message_type = _MAP
_POLICYDATA.fields_by_name['spat'].message_type = _SPAT
DESCRIPTOR.message_types_by_name['Position2D'] = _POSITION2D
DESCRIPTOR.message_types_by_name['Connection'] = _CONNECTION
DESCRIPTOR.message_types_by_name['Lane'] = _LANE
DESCRIPTOR.message_types_by_name['Road'] = _ROAD
DESCRIPTOR.message_types_by_name['Intersection'] = _INTERSECTION
DESCRIPTOR.message_types_by_name['Map'] = _MAP
DESCRIPTOR.message_types_by_name['Phase'] = _PHASE
DESCRIPTOR.message_types_by_name['IntersectionState'] = _INTERSECTIONSTATE
DESCRIPTOR.message_types_by_name['Spat'] = _SPAT
DESCRIPTOR.message_types_by_name['PolicyData'] = _POLICYDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Position2D = _reflection.GeneratedProtocolMessageType('Position2D', (_message.Message,), {
  'DESCRIPTOR' : _POSITION2D,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Position2D)
  })
_sym_db.RegisterMessage(Position2D)

Connection = _reflection.GeneratedProtocolMessageType('Connection', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTION,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Connection)
  })
_sym_db.RegisterMessage(Connection)

Lane = _reflection.GeneratedProtocolMessageType('Lane', (_message.Message,), {
  'DESCRIPTOR' : _LANE,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Lane)
  })
_sym_db.RegisterMessage(Lane)

Road = _reflection.GeneratedProtocolMessageType('Road', (_message.Message,), {
  'DESCRIPTOR' : _ROAD,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Road)
  })
_sym_db.RegisterMessage(Road)

Intersection = _reflection.GeneratedProtocolMessageType('Intersection', (_message.Message,), {
  'DESCRIPTOR' : _INTERSECTION,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Intersection)
  })
_sym_db.RegisterMessage(Intersection)

Map = _reflection.GeneratedProtocolMessageType('Map', (_message.Message,), {
  'DESCRIPTOR' : _MAP,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Map)
  })
_sym_db.RegisterMessage(Map)

Phase = _reflection.GeneratedProtocolMessageType('Phase', (_message.Message,), {
  'DESCRIPTOR' : _PHASE,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Phase)
  })
_sym_db.RegisterMessage(Phase)

IntersectionState = _reflection.GeneratedProtocolMessageType('IntersectionState', (_message.Message,), {
  'DESCRIPTOR' : _INTERSECTIONSTATE,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.IntersectionState)
  })
_sym_db.RegisterMessage(IntersectionState)

Spat = _reflection.GeneratedProtocolMessageType('Spat', (_message.Message,), {
  'DESCRIPTOR' : _SPAT,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Spat)
  })
_sym_db.RegisterMessage(Spat)

PolicyData = _reflection.GeneratedProtocolMessageType('PolicyData', (_message.Message,), {
  'DESCRIPTOR' : _POLICYDATA,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.PolicyData)
  })
_sym_db.RegisterMessage(PolicyData)


# @@protoc_insertion_point(module_scope)
