# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/canbus/proto/ch.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/canbus/proto/ch.proto',
  package='apollo.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dmodules/canbus/proto/ch.proto\x12\rapollo.canbus\"\xf7\x01\n\x14Throttle_command_110\x12^\n\x16throttle_pedal_en_ctrl\x18\x01 \x01(\x0e\x32>.apollo.canbus.Throttle_command_110.Throttle_pedal_en_ctrlType\x12\x1a\n\x12throttle_pedal_cmd\x18\x02 \x01(\x05\"c\n\x1aThrottle_pedal_en_ctrlType\x12\"\n\x1eTHROTTLE_PEDAL_EN_CTRL_DISABLE\x10\x00\x12!\n\x1dTHROTTLE_PEDAL_EN_CTRL_ENABLE\x10\x01\"\xdf\x01\n\x11\x42rake_command_111\x12U\n\x13\x62rake_pedal_en_ctrl\x18\x01 \x01(\x0e\x32\x38.apollo.canbus.Brake_command_111.Brake_pedal_en_ctrlType\x12\x17\n\x0f\x62rake_pedal_cmd\x18\x02 \x01(\x05\"Z\n\x17\x42rake_pedal_en_ctrlType\x12\x1f\n\x1b\x42RAKE_PEDAL_EN_CTRL_DISABLE\x10\x00\x12\x1e\n\x1a\x42RAKE_PEDAL_EN_CTRL_ENABLE\x10\x01\"\xdf\x01\n\x11Steer_command_112\x12U\n\x13steer_angle_en_ctrl\x18\x01 \x01(\x0e\x32\x38.apollo.canbus.Steer_command_112.Steer_angle_en_ctrlType\x12\x17\n\x0fsteer_angle_cmd\x18\x02 \x01(\x01\"Z\n\x17Steer_angle_en_ctrlType\x12\x1f\n\x1bSTEER_ANGLE_EN_CTRL_DISABLE\x10\x00\x12\x1e\n\x1aSTEER_ANGLE_EN_CTRL_ENABLE\x10\x01\"\xd2\x01\n\x16Turnsignal_command_113\x12R\n\x0fturn_signal_cmd\x18\x01 \x01(\x0e\x32\x39.apollo.canbus.Turnsignal_command_113.Turn_signal_cmdType\"d\n\x13Turn_signal_cmdType\x12\x18\n\x14TURN_SIGNAL_CMD_NONE\x10\x00\x12\x18\n\x14TURN_SIGNAL_CMD_LEFT\x10\x01\x12\x19\n\x15TURN_SIGNAL_CMD_RIGHT\x10\x02\"\xb5\x01\n\x10Gear_command_114\x12>\n\x08gear_cmd\x18\x01 \x01(\x0e\x32,.apollo.canbus.Gear_command_114.Gear_cmdType\"a\n\x0cGear_cmdType\x12\x11\n\rGEAR_CMD_PARK\x10\x01\x12\x14\n\x10GEAR_CMD_REVERSE\x10\x02\x12\x14\n\x10GEAR_CMD_NEUTRAL\x10\x03\x12\x12\n\x0eGEAR_CMD_DRIVE\x10\x04\"\xa1\x01\n\x13\x43ontrol_command_115\x12\x41\n\x08\x63trl_cmd\x18\x01 \x01(\x0e\x32/.apollo.canbus.Control_command_115.Ctrl_cmdType\"G\n\x0c\x43trl_cmdType\x12\x1b\n\x17\x43TRL_CMD_OUT_OF_CONTROL\x10\x00\x12\x1a\n\x16\x43TRL_CMD_UNDER_CONTROL\x10\x01\"\xe3\x04\n\x14Throttle_status__510\x12\\\n\x15throttle_pedal_en_sts\x18\x01 \x01(\x0e\x32=.apollo.canbus.Throttle_status__510.Throttle_pedal_en_stsType\x12\x1a\n\x12throttle_pedal_sts\x18\x02 \x01(\x05\x12P\n\x0f\x64rive_motor_err\x18\x03 \x01(\x0e\x32\x37.apollo.canbus.Throttle_status__510.Drive_motor_errType\x12P\n\x0f\x62\x61ttery_bms_err\x18\x04 \x01(\x0e\x32\x37.apollo.canbus.Throttle_status__510.Battery_bms_errType\"\x84\x01\n\x19Throttle_pedal_en_stsType\x12!\n\x1dTHROTTLE_PEDAL_EN_STS_DISABLE\x10\x00\x12 \n\x1cTHROTTLE_PEDAL_EN_STS_ENABLE\x10\x01\x12\"\n\x1eTHROTTLE_PEDAL_EN_STS_TAKEOVER\x10\x02\"S\n\x13\x44rive_motor_errType\x12\x19\n\x15\x44RIVE_MOTOR_ERR_NOERR\x10\x00\x12!\n\x1d\x44RIVE_MOTOR_ERR_DRV_MOTOR_ERR\x10\x01\"Q\n\x13\x42\x61ttery_bms_errType\x12\x19\n\x15\x42\x41TTERY_BMS_ERR_NOERR\x10\x00\x12\x1f\n\x1b\x42\x41TTERY_BMS_ERR_BATTERY_ERR\x10\x01\"\x87\x08\n\x11\x42rake_status__511\x12S\n\x12\x62rake_pedal_en_sts\x18\x01 \x01(\x0e\x32\x37.apollo.canbus.Brake_status__511.Brake_pedal_en_stsType\x12\x17\n\x0f\x62rake_pedal_sts\x18\x02 \x01(\x05\x12\x41\n\tbrake_err\x18\x03 \x01(\x0e\x32..apollo.canbus.Brake_status__511.Brake_errType\x12Q\n\x11\x65mergency_btn_env\x18\x04 \x01(\x0e\x32\x36.apollo.canbus.Brake_status__511.Emergency_btn_envType\x12K\n\x0e\x66ront_bump_env\x18\x05 \x01(\x0e\x32\x33.apollo.canbus.Brake_status__511.Front_bump_envType\x12I\n\rback_bump_env\x18\x06 \x01(\x0e\x32\x32.apollo.canbus.Brake_status__511.Back_bump_envType\x12\x45\n\x0boverspd_env\x18\x07 \x01(\x0e\x32\x30.apollo.canbus.Brake_status__511.Overspd_envType\"x\n\x16\x42rake_pedal_en_stsType\x12\x1e\n\x1a\x42RAKE_PEDAL_EN_STS_DISABLE\x10\x00\x12\x1d\n\x19\x42RAKE_PEDAL_EN_STS_ENABLE\x10\x01\x12\x1f\n\x1b\x42RAKE_PEDAL_EN_STS_TAKEOVER\x10\x02\"D\n\rBrake_errType\x12\x13\n\x0f\x42RAKE_ERR_NOERR\x10\x00\x12\x1e\n\x1a\x42RAKE_ERR_BRAKE_SYSTEM_ERR\x10\x01\"`\n\x15\x45mergency_btn_envType\x12\x1b\n\x17\x45MERGENCY_BTN_ENV_NOENV\x10\x00\x12*\n&EMERGENCY_BTN_ENV_EMERGENCY_BUTTON_ENV\x10\x01\"S\n\x12\x46ront_bump_envType\x12\x18\n\x14\x46RONT_BUMP_ENV_NOENV\x10\x00\x12#\n\x1f\x46RONT_BUMP_ENV_FRONT_BUMPER_ENV\x10\x01\"O\n\x11\x42\x61\x63k_bump_envType\x12\x17\n\x13\x42\x41\x43K_BUMP_ENV_NOENV\x10\x00\x12!\n\x1d\x42\x41\x43K_BUMP_ENV_BACK_BUMPER_ENV\x10\x01\"G\n\x0fOverspd_envType\x12\x15\n\x11OVERSPD_ENV_NOENV\x10\x00\x12\x1d\n\x19OVERSPD_ENV_OVERSPEED_ENV\x10\x01\"\x91\x04\n\x11Steer_status__512\x12S\n\x12steer_angle_en_sts\x18\x01 \x01(\x0e\x32\x37.apollo.canbus.Steer_status__512.Steer_angle_en_stsType\x12\x17\n\x0fsteer_angle_sts\x18\x02 \x01(\x01\x12\x41\n\tsteer_err\x18\x03 \x01(\x0e\x32..apollo.canbus.Steer_status__512.Steer_errType\x12\x43\n\nsensor_err\x18\x04 \x01(\x0e\x32/.apollo.canbus.Steer_status__512.Sensor_errType\"x\n\x16Steer_angle_en_stsType\x12\x1e\n\x1aSTEER_ANGLE_EN_STS_DISABLE\x10\x00\x12\x1d\n\x19STEER_ANGLE_EN_STS_ENABLE\x10\x01\x12\x1f\n\x1bSTEER_ANGLE_EN_STS_TAKEOVER\x10\x02\"C\n\rSteer_errType\x12\x13\n\x0fSTEER_ERR_NOERR\x10\x00\x12\x1d\n\x19STEER_ERR_STEER_MOTOR_ERR\x10\x01\"G\n\x0eSensor_errType\x12\x14\n\x10SENSOR_ERR_NOERR\x10\x00\x12\x1f\n\x1bSENSOR_ERR_STEER_SENSOR_ERR\x10\x01\"\xd2\x01\n\x16Turnsignal_status__513\x12R\n\x0fturn_signal_sts\x18\x01 \x01(\x0e\x32\x39.apollo.canbus.Turnsignal_status__513.Turn_signal_stsType\"d\n\x13Turn_signal_stsType\x12\x18\n\x14TURN_SIGNAL_STS_NONE\x10\x00\x12\x18\n\x14TURN_SIGNAL_STS_LEFT\x10\x01\x12\x19\n\x15TURN_SIGNAL_STS_RIGHT\x10\x02\"\xb3\x01\n\x0fGear_status_514\x12=\n\x08gear_sts\x18\x01 \x01(\x0e\x32+.apollo.canbus.Gear_status_514.Gear_stsType\"a\n\x0cGear_stsType\x12\x11\n\rGEAR_STS_PARK\x10\x01\x12\x14\n\x10GEAR_STS_REVERSE\x10\x02\x12\x14\n\x10GEAR_STS_NEUTRAL\x10\x03\x12\x12\n\x0eGEAR_STS_DRIVE\x10\x04\"\xe7\x01\n\x10\x45\x63u_status_1_515\x12\r\n\x05speed\x18\x01 \x01(\x01\x12\x11\n\tacc_speed\x18\x02 \x01(\x01\x12>\n\x08\x63trl_sts\x18\x03 \x01(\x0e\x32,.apollo.canbus.Ecu_status_1_515.Ctrl_stsType\x12\x13\n\x0b\x63hassis_sts\x18\x04 \x01(\x05\x12\x13\n\x0b\x63hassis_err\x18\x05 \x01(\x05\"G\n\x0c\x43trl_stsType\x12\x1b\n\x17\x43TRL_STS_OUT_OF_CONTROL\x10\x00\x12\x1a\n\x16\x43TRL_STS_UNDER_CONTROL\x10\x01\"\x90\x01\n\x10\x45\x63u_status_2_516\x12\x13\n\x0b\x62\x61ttery_soc\x18\x01 \x01(\x05\x12\x18\n\x10\x62\x61ttery_capacity\x18\x02 \x01(\x05\x12\x17\n\x0f\x62\x61ttery_voltage\x18\x03 \x01(\x01\x12\x17\n\x0f\x62\x61ttery_current\x18\x04 \x01(\x01\x12\x1b\n\x13\x62\x61ttery_temperature\x18\x05 \x01(\x05\"\xea\x01\n\x10\x45\x63u_status_3_517\x12\x19\n\x11ultrasound_dist_1\x18\x01 \x01(\x01\x12\x19\n\x11ultrasound_dist_2\x18\x02 \x01(\x01\x12\x19\n\x11ultrasound_dist_3\x18\x03 \x01(\x01\x12\x19\n\x11ultrasound_dist_4\x18\x04 \x01(\x01\x12\x19\n\x11ultrasound_dist_5\x18\x05 \x01(\x01\x12\x19\n\x11ultrasound_dist_6\x18\x06 \x01(\x01\x12\x19\n\x11ultrasound_dist_7\x18\x07 \x01(\x01\x12\x19\n\x11ultrasound_dist_8\x18\x08 \x01(\x01\"\xf2\x06\n\x02\x43h\x12\x41\n\x14throttle_command_110\x18\x01 \x01(\x0b\x32#.apollo.canbus.Throttle_command_110\x12;\n\x11\x62rake_command_111\x18\x02 \x01(\x0b\x32 .apollo.canbus.Brake_command_111\x12;\n\x11steer_command_112\x18\x03 \x01(\x0b\x32 .apollo.canbus.Steer_command_112\x12\x45\n\x16turnsignal_command_113\x18\x04 \x01(\x0b\x32%.apollo.canbus.Turnsignal_command_113\x12\x39\n\x10gear_command_114\x18\x05 \x01(\x0b\x32\x1f.apollo.canbus.Gear_command_114\x12?\n\x13\x63ontrol_command_115\x18\x06 \x01(\x0b\x32\".apollo.canbus.Control_command_115\x12\x41\n\x14throttle_status__510\x18\x07 \x01(\x0b\x32#.apollo.canbus.Throttle_status__510\x12;\n\x11\x62rake_status__511\x18\x08 \x01(\x0b\x32 .apollo.canbus.Brake_status__511\x12;\n\x11steer_status__512\x18\t \x01(\x0b\x32 .apollo.canbus.Steer_status__512\x12\x45\n\x16turnsignal_status__513\x18\n \x01(\x0b\x32%.apollo.canbus.Turnsignal_status__513\x12\x37\n\x0fgear_status_514\x18\x0b \x01(\x0b\x32\x1e.apollo.canbus.Gear_status_514\x12\x39\n\x10\x65\x63u_status_1_515\x18\x0c \x01(\x0b\x32\x1f.apollo.canbus.Ecu_status_1_515\x12\x39\n\x10\x65\x63u_status_2_516\x18\r \x01(\x0b\x32\x1f.apollo.canbus.Ecu_status_2_516\x12\x39\n\x10\x65\x63u_status_3_517\x18\x0e \x01(\x0b\x32\x1f.apollo.canbus.Ecu_status_3_517'
)



_THROTTLE_COMMAND_110_THROTTLE_PEDAL_EN_CTRLTYPE = _descriptor.EnumDescriptor(
  name='Throttle_pedal_en_ctrlType',
  full_name='apollo.canbus.Throttle_command_110.Throttle_pedal_en_ctrlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_PEDAL_EN_CTRL_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_PEDAL_EN_CTRL_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=197,
  serialized_end=296,
)
_sym_db.RegisterEnumDescriptor(_THROTTLE_COMMAND_110_THROTTLE_PEDAL_EN_CTRLTYPE)

_BRAKE_COMMAND_111_BRAKE_PEDAL_EN_CTRLTYPE = _descriptor.EnumDescriptor(
  name='Brake_pedal_en_ctrlType',
  full_name='apollo.canbus.Brake_command_111.Brake_pedal_en_ctrlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_PEDAL_EN_CTRL_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_PEDAL_EN_CTRL_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=432,
  serialized_end=522,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_COMMAND_111_BRAKE_PEDAL_EN_CTRLTYPE)

_STEER_COMMAND_112_STEER_ANGLE_EN_CTRLTYPE = _descriptor.EnumDescriptor(
  name='Steer_angle_en_ctrlType',
  full_name='apollo.canbus.Steer_command_112.Steer_angle_en_ctrlType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEER_ANGLE_EN_CTRL_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEER_ANGLE_EN_CTRL_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=658,
  serialized_end=748,
)
_sym_db.RegisterEnumDescriptor(_STEER_COMMAND_112_STEER_ANGLE_EN_CTRLTYPE)

_TURNSIGNAL_COMMAND_113_TURN_SIGNAL_CMDTYPE = _descriptor.EnumDescriptor(
  name='Turn_signal_cmdType',
  full_name='apollo.canbus.Turnsignal_command_113.Turn_signal_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_CMD_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_CMD_LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_CMD_RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=861,
  serialized_end=961,
)
_sym_db.RegisterEnumDescriptor(_TURNSIGNAL_COMMAND_113_TURN_SIGNAL_CMDTYPE)

_GEAR_COMMAND_114_GEAR_CMDTYPE = _descriptor.EnumDescriptor(
  name='Gear_cmdType',
  full_name='apollo.canbus.Gear_command_114.Gear_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_CMD_PARK', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_CMD_REVERSE', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_CMD_NEUTRAL', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_CMD_DRIVE', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1048,
  serialized_end=1145,
)
_sym_db.RegisterEnumDescriptor(_GEAR_COMMAND_114_GEAR_CMDTYPE)

_CONTROL_COMMAND_115_CTRL_CMDTYPE = _descriptor.EnumDescriptor(
  name='Ctrl_cmdType',
  full_name='apollo.canbus.Control_command_115.Ctrl_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CTRL_CMD_OUT_OF_CONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CTRL_CMD_UNDER_CONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1238,
  serialized_end=1309,
)
_sym_db.RegisterEnumDescriptor(_CONTROL_COMMAND_115_CTRL_CMDTYPE)

_THROTTLE_STATUS__510_THROTTLE_PEDAL_EN_STSTYPE = _descriptor.EnumDescriptor(
  name='Throttle_pedal_en_stsType',
  full_name='apollo.canbus.Throttle_status__510.Throttle_pedal_en_stsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_PEDAL_EN_STS_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_PEDAL_EN_STS_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THROTTLE_PEDAL_EN_STS_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1623,
  serialized_end=1755,
)
_sym_db.RegisterEnumDescriptor(_THROTTLE_STATUS__510_THROTTLE_PEDAL_EN_STSTYPE)

_THROTTLE_STATUS__510_DRIVE_MOTOR_ERRTYPE = _descriptor.EnumDescriptor(
  name='Drive_motor_errType',
  full_name='apollo.canbus.Throttle_status__510.Drive_motor_errType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DRIVE_MOTOR_ERR_NOERR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVE_MOTOR_ERR_DRV_MOTOR_ERR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1757,
  serialized_end=1840,
)
_sym_db.RegisterEnumDescriptor(_THROTTLE_STATUS__510_DRIVE_MOTOR_ERRTYPE)

_THROTTLE_STATUS__510_BATTERY_BMS_ERRTYPE = _descriptor.EnumDescriptor(
  name='Battery_bms_errType',
  full_name='apollo.canbus.Throttle_status__510.Battery_bms_errType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BATTERY_BMS_ERR_NOERR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BATTERY_BMS_ERR_BATTERY_ERR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1842,
  serialized_end=1923,
)
_sym_db.RegisterEnumDescriptor(_THROTTLE_STATUS__510_BATTERY_BMS_ERRTYPE)

_BRAKE_STATUS__511_BRAKE_PEDAL_EN_STSTYPE = _descriptor.EnumDescriptor(
  name='Brake_pedal_en_stsType',
  full_name='apollo.canbus.Brake_status__511.Brake_pedal_en_stsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_PEDAL_EN_STS_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_PEDAL_EN_STS_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_PEDAL_EN_STS_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2430,
  serialized_end=2550,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_STATUS__511_BRAKE_PEDAL_EN_STSTYPE)

_BRAKE_STATUS__511_BRAKE_ERRTYPE = _descriptor.EnumDescriptor(
  name='Brake_errType',
  full_name='apollo.canbus.Brake_status__511.Brake_errType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ERR_NOERR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ERR_BRAKE_SYSTEM_ERR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2552,
  serialized_end=2620,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_STATUS__511_BRAKE_ERRTYPE)

_BRAKE_STATUS__511_EMERGENCY_BTN_ENVTYPE = _descriptor.EnumDescriptor(
  name='Emergency_btn_envType',
  full_name='apollo.canbus.Brake_status__511.Emergency_btn_envType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_BTN_ENV_NOENV', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_BTN_ENV_EMERGENCY_BUTTON_ENV', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2622,
  serialized_end=2718,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_STATUS__511_EMERGENCY_BTN_ENVTYPE)

_BRAKE_STATUS__511_FRONT_BUMP_ENVTYPE = _descriptor.EnumDescriptor(
  name='Front_bump_envType',
  full_name='apollo.canbus.Brake_status__511.Front_bump_envType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FRONT_BUMP_ENV_NOENV', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRONT_BUMP_ENV_FRONT_BUMPER_ENV', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2720,
  serialized_end=2803,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_STATUS__511_FRONT_BUMP_ENVTYPE)

_BRAKE_STATUS__511_BACK_BUMP_ENVTYPE = _descriptor.EnumDescriptor(
  name='Back_bump_envType',
  full_name='apollo.canbus.Brake_status__511.Back_bump_envType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BACK_BUMP_ENV_NOENV', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BACK_BUMP_ENV_BACK_BUMPER_ENV', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2805,
  serialized_end=2884,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_STATUS__511_BACK_BUMP_ENVTYPE)

_BRAKE_STATUS__511_OVERSPD_ENVTYPE = _descriptor.EnumDescriptor(
  name='Overspd_envType',
  full_name='apollo.canbus.Brake_status__511.Overspd_envType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OVERSPD_ENV_NOENV', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OVERSPD_ENV_OVERSPEED_ENV', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2886,
  serialized_end=2957,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_STATUS__511_OVERSPD_ENVTYPE)

_STEER_STATUS__512_STEER_ANGLE_EN_STSTYPE = _descriptor.EnumDescriptor(
  name='Steer_angle_en_stsType',
  full_name='apollo.canbus.Steer_status__512.Steer_angle_en_stsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEER_ANGLE_EN_STS_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEER_ANGLE_EN_STS_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEER_ANGLE_EN_STS_TAKEOVER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3227,
  serialized_end=3347,
)
_sym_db.RegisterEnumDescriptor(_STEER_STATUS__512_STEER_ANGLE_EN_STSTYPE)

_STEER_STATUS__512_STEER_ERRTYPE = _descriptor.EnumDescriptor(
  name='Steer_errType',
  full_name='apollo.canbus.Steer_status__512.Steer_errType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEER_ERR_NOERR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEER_ERR_STEER_MOTOR_ERR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3349,
  serialized_end=3416,
)
_sym_db.RegisterEnumDescriptor(_STEER_STATUS__512_STEER_ERRTYPE)

_STEER_STATUS__512_SENSOR_ERRTYPE = _descriptor.EnumDescriptor(
  name='Sensor_errType',
  full_name='apollo.canbus.Steer_status__512.Sensor_errType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SENSOR_ERR_NOERR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SENSOR_ERR_STEER_SENSOR_ERR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3418,
  serialized_end=3489,
)
_sym_db.RegisterEnumDescriptor(_STEER_STATUS__512_SENSOR_ERRTYPE)

_TURNSIGNAL_STATUS__513_TURN_SIGNAL_STSTYPE = _descriptor.EnumDescriptor(
  name='Turn_signal_stsType',
  full_name='apollo.canbus.Turnsignal_status__513.Turn_signal_stsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_STS_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_STS_LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_STS_RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3602,
  serialized_end=3702,
)
_sym_db.RegisterEnumDescriptor(_TURNSIGNAL_STATUS__513_TURN_SIGNAL_STSTYPE)

_GEAR_STATUS_514_GEAR_STSTYPE = _descriptor.EnumDescriptor(
  name='Gear_stsType',
  full_name='apollo.canbus.Gear_status_514.Gear_stsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEAR_STS_PARK', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STS_REVERSE', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STS_NEUTRAL', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEAR_STS_DRIVE', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3787,
  serialized_end=3884,
)
_sym_db.RegisterEnumDescriptor(_GEAR_STATUS_514_GEAR_STSTYPE)

_ECU_STATUS_1_515_CTRL_STSTYPE = _descriptor.EnumDescriptor(
  name='Ctrl_stsType',
  full_name='apollo.canbus.Ecu_status_1_515.Ctrl_stsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CTRL_STS_OUT_OF_CONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CTRL_STS_UNDER_CONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4047,
  serialized_end=4118,
)
_sym_db.RegisterEnumDescriptor(_ECU_STATUS_1_515_CTRL_STSTYPE)


_THROTTLE_COMMAND_110 = _descriptor.Descriptor(
  name='Throttle_command_110',
  full_name='apollo.canbus.Throttle_command_110',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='throttle_pedal_en_ctrl', full_name='apollo.canbus.Throttle_command_110.throttle_pedal_en_ctrl', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_pedal_cmd', full_name='apollo.canbus.Throttle_command_110.throttle_pedal_cmd', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _THROTTLE_COMMAND_110_THROTTLE_PEDAL_EN_CTRLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=296,
)


_BRAKE_COMMAND_111 = _descriptor.Descriptor(
  name='Brake_command_111',
  full_name='apollo.canbus.Brake_command_111',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brake_pedal_en_ctrl', full_name='apollo.canbus.Brake_command_111.brake_pedal_en_ctrl', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_pedal_cmd', full_name='apollo.canbus.Brake_command_111.brake_pedal_cmd', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BRAKE_COMMAND_111_BRAKE_PEDAL_EN_CTRLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=522,
)


_STEER_COMMAND_112 = _descriptor.Descriptor(
  name='Steer_command_112',
  full_name='apollo.canbus.Steer_command_112',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steer_angle_en_ctrl', full_name='apollo.canbus.Steer_command_112.steer_angle_en_ctrl', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_cmd', full_name='apollo.canbus.Steer_command_112.steer_angle_cmd', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STEER_COMMAND_112_STEER_ANGLE_EN_CTRLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=748,
)


_TURNSIGNAL_COMMAND_113 = _descriptor.Descriptor(
  name='Turnsignal_command_113',
  full_name='apollo.canbus.Turnsignal_command_113',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='turn_signal_cmd', full_name='apollo.canbus.Turnsignal_command_113.turn_signal_cmd', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TURNSIGNAL_COMMAND_113_TURN_SIGNAL_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=961,
)


_GEAR_COMMAND_114 = _descriptor.Descriptor(
  name='Gear_command_114',
  full_name='apollo.canbus.Gear_command_114',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gear_cmd', full_name='apollo.canbus.Gear_command_114.gear_cmd', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GEAR_COMMAND_114_GEAR_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=964,
  serialized_end=1145,
)


_CONTROL_COMMAND_115 = _descriptor.Descriptor(
  name='Control_command_115',
  full_name='apollo.canbus.Control_command_115',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ctrl_cmd', full_name='apollo.canbus.Control_command_115.ctrl_cmd', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONTROL_COMMAND_115_CTRL_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1148,
  serialized_end=1309,
)


_THROTTLE_STATUS__510 = _descriptor.Descriptor(
  name='Throttle_status__510',
  full_name='apollo.canbus.Throttle_status__510',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='throttle_pedal_en_sts', full_name='apollo.canbus.Throttle_status__510.throttle_pedal_en_sts', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_pedal_sts', full_name='apollo.canbus.Throttle_status__510.throttle_pedal_sts', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drive_motor_err', full_name='apollo.canbus.Throttle_status__510.drive_motor_err', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery_bms_err', full_name='apollo.canbus.Throttle_status__510.battery_bms_err', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _THROTTLE_STATUS__510_THROTTLE_PEDAL_EN_STSTYPE,
    _THROTTLE_STATUS__510_DRIVE_MOTOR_ERRTYPE,
    _THROTTLE_STATUS__510_BATTERY_BMS_ERRTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1312,
  serialized_end=1923,
)


_BRAKE_STATUS__511 = _descriptor.Descriptor(
  name='Brake_status__511',
  full_name='apollo.canbus.Brake_status__511',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brake_pedal_en_sts', full_name='apollo.canbus.Brake_status__511.brake_pedal_en_sts', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_pedal_sts', full_name='apollo.canbus.Brake_status__511.brake_pedal_sts', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_err', full_name='apollo.canbus.Brake_status__511.brake_err', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emergency_btn_env', full_name='apollo.canbus.Brake_status__511.emergency_btn_env', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_bump_env', full_name='apollo.canbus.Brake_status__511.front_bump_env', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='back_bump_env', full_name='apollo.canbus.Brake_status__511.back_bump_env', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overspd_env', full_name='apollo.canbus.Brake_status__511.overspd_env', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BRAKE_STATUS__511_BRAKE_PEDAL_EN_STSTYPE,
    _BRAKE_STATUS__511_BRAKE_ERRTYPE,
    _BRAKE_STATUS__511_EMERGENCY_BTN_ENVTYPE,
    _BRAKE_STATUS__511_FRONT_BUMP_ENVTYPE,
    _BRAKE_STATUS__511_BACK_BUMP_ENVTYPE,
    _BRAKE_STATUS__511_OVERSPD_ENVTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1926,
  serialized_end=2957,
)


_STEER_STATUS__512 = _descriptor.Descriptor(
  name='Steer_status__512',
  full_name='apollo.canbus.Steer_status__512',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steer_angle_en_sts', full_name='apollo.canbus.Steer_status__512.steer_angle_en_sts', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_sts', full_name='apollo.canbus.Steer_status__512.steer_angle_sts', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_err', full_name='apollo.canbus.Steer_status__512.steer_err', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensor_err', full_name='apollo.canbus.Steer_status__512.sensor_err', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STEER_STATUS__512_STEER_ANGLE_EN_STSTYPE,
    _STEER_STATUS__512_STEER_ERRTYPE,
    _STEER_STATUS__512_SENSOR_ERRTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2960,
  serialized_end=3489,
)


_TURNSIGNAL_STATUS__513 = _descriptor.Descriptor(
  name='Turnsignal_status__513',
  full_name='apollo.canbus.Turnsignal_status__513',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='turn_signal_sts', full_name='apollo.canbus.Turnsignal_status__513.turn_signal_sts', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TURNSIGNAL_STATUS__513_TURN_SIGNAL_STSTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3492,
  serialized_end=3702,
)


_GEAR_STATUS_514 = _descriptor.Descriptor(
  name='Gear_status_514',
  full_name='apollo.canbus.Gear_status_514',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gear_sts', full_name='apollo.canbus.Gear_status_514.gear_sts', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GEAR_STATUS_514_GEAR_STSTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3705,
  serialized_end=3884,
)


_ECU_STATUS_1_515 = _descriptor.Descriptor(
  name='Ecu_status_1_515',
  full_name='apollo.canbus.Ecu_status_1_515',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.canbus.Ecu_status_1_515.speed', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_speed', full_name='apollo.canbus.Ecu_status_1_515.acc_speed', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ctrl_sts', full_name='apollo.canbus.Ecu_status_1_515.ctrl_sts', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chassis_sts', full_name='apollo.canbus.Ecu_status_1_515.chassis_sts', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chassis_err', full_name='apollo.canbus.Ecu_status_1_515.chassis_err', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ECU_STATUS_1_515_CTRL_STSTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3887,
  serialized_end=4118,
)


_ECU_STATUS_2_516 = _descriptor.Descriptor(
  name='Ecu_status_2_516',
  full_name='apollo.canbus.Ecu_status_2_516',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='battery_soc', full_name='apollo.canbus.Ecu_status_2_516.battery_soc', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery_capacity', full_name='apollo.canbus.Ecu_status_2_516.battery_capacity', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery_voltage', full_name='apollo.canbus.Ecu_status_2_516.battery_voltage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery_current', full_name='apollo.canbus.Ecu_status_2_516.battery_current', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery_temperature', full_name='apollo.canbus.Ecu_status_2_516.battery_temperature', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4121,
  serialized_end=4265,
)


_ECU_STATUS_3_517 = _descriptor.Descriptor(
  name='Ecu_status_3_517',
  full_name='apollo.canbus.Ecu_status_3_517',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ultrasound_dist_1', full_name='apollo.canbus.Ecu_status_3_517.ultrasound_dist_1', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ultrasound_dist_2', full_name='apollo.canbus.Ecu_status_3_517.ultrasound_dist_2', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ultrasound_dist_3', full_name='apollo.canbus.Ecu_status_3_517.ultrasound_dist_3', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ultrasound_dist_4', full_name='apollo.canbus.Ecu_status_3_517.ultrasound_dist_4', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ultrasound_dist_5', full_name='apollo.canbus.Ecu_status_3_517.ultrasound_dist_5', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ultrasound_dist_6', full_name='apollo.canbus.Ecu_status_3_517.ultrasound_dist_6', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ultrasound_dist_7', full_name='apollo.canbus.Ecu_status_3_517.ultrasound_dist_7', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ultrasound_dist_8', full_name='apollo.canbus.Ecu_status_3_517.ultrasound_dist_8', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4268,
  serialized_end=4502,
)


_CH = _descriptor.Descriptor(
  name='Ch',
  full_name='apollo.canbus.Ch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='throttle_command_110', full_name='apollo.canbus.Ch.throttle_command_110', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_command_111', full_name='apollo.canbus.Ch.brake_command_111', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_command_112', full_name='apollo.canbus.Ch.steer_command_112', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turnsignal_command_113', full_name='apollo.canbus.Ch.turnsignal_command_113', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_command_114', full_name='apollo.canbus.Ch.gear_command_114', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_command_115', full_name='apollo.canbus.Ch.control_command_115', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_status__510', full_name='apollo.canbus.Ch.throttle_status__510', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_status__511', full_name='apollo.canbus.Ch.brake_status__511', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_status__512', full_name='apollo.canbus.Ch.steer_status__512', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turnsignal_status__513', full_name='apollo.canbus.Ch.turnsignal_status__513', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_status_514', full_name='apollo.canbus.Ch.gear_status_514', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecu_status_1_515', full_name='apollo.canbus.Ch.ecu_status_1_515', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecu_status_2_516', full_name='apollo.canbus.Ch.ecu_status_2_516', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecu_status_3_517', full_name='apollo.canbus.Ch.ecu_status_3_517', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4505,
  serialized_end=5387,
)

_THROTTLE_COMMAND_110.fields_by_name['throttle_pedal_en_ctrl'].enum_type = _THROTTLE_COMMAND_110_THROTTLE_PEDAL_EN_CTRLTYPE
_THROTTLE_COMMAND_110_THROTTLE_PEDAL_EN_CTRLTYPE.containing_type = _THROTTLE_COMMAND_110
_BRAKE_COMMAND_111.fields_by_name['brake_pedal_en_ctrl'].enum_type = _BRAKE_COMMAND_111_BRAKE_PEDAL_EN_CTRLTYPE
_BRAKE_COMMAND_111_BRAKE_PEDAL_EN_CTRLTYPE.containing_type = _BRAKE_COMMAND_111
_STEER_COMMAND_112.fields_by_name['steer_angle_en_ctrl'].enum_type = _STEER_COMMAND_112_STEER_ANGLE_EN_CTRLTYPE
_STEER_COMMAND_112_STEER_ANGLE_EN_CTRLTYPE.containing_type = _STEER_COMMAND_112
_TURNSIGNAL_COMMAND_113.fields_by_name['turn_signal_cmd'].enum_type = _TURNSIGNAL_COMMAND_113_TURN_SIGNAL_CMDTYPE
_TURNSIGNAL_COMMAND_113_TURN_SIGNAL_CMDTYPE.containing_type = _TURNSIGNAL_COMMAND_113
_GEAR_COMMAND_114.fields_by_name['gear_cmd'].enum_type = _GEAR_COMMAND_114_GEAR_CMDTYPE
_GEAR_COMMAND_114_GEAR_CMDTYPE.containing_type = _GEAR_COMMAND_114
_CONTROL_COMMAND_115.fields_by_name['ctrl_cmd'].enum_type = _CONTROL_COMMAND_115_CTRL_CMDTYPE
_CONTROL_COMMAND_115_CTRL_CMDTYPE.containing_type = _CONTROL_COMMAND_115
_THROTTLE_STATUS__510.fields_by_name['throttle_pedal_en_sts'].enum_type = _THROTTLE_STATUS__510_THROTTLE_PEDAL_EN_STSTYPE
_THROTTLE_STATUS__510.fields_by_name['drive_motor_err'].enum_type = _THROTTLE_STATUS__510_DRIVE_MOTOR_ERRTYPE
_THROTTLE_STATUS__510.fields_by_name['battery_bms_err'].enum_type = _THROTTLE_STATUS__510_BATTERY_BMS_ERRTYPE
_THROTTLE_STATUS__510_THROTTLE_PEDAL_EN_STSTYPE.containing_type = _THROTTLE_STATUS__510
_THROTTLE_STATUS__510_DRIVE_MOTOR_ERRTYPE.containing_type = _THROTTLE_STATUS__510
_THROTTLE_STATUS__510_BATTERY_BMS_ERRTYPE.containing_type = _THROTTLE_STATUS__510
_BRAKE_STATUS__511.fields_by_name['brake_pedal_en_sts'].enum_type = _BRAKE_STATUS__511_BRAKE_PEDAL_EN_STSTYPE
_BRAKE_STATUS__511.fields_by_name['brake_err'].enum_type = _BRAKE_STATUS__511_BRAKE_ERRTYPE
_BRAKE_STATUS__511.fields_by_name['emergency_btn_env'].enum_type = _BRAKE_STATUS__511_EMERGENCY_BTN_ENVTYPE
_BRAKE_STATUS__511.fields_by_name['front_bump_env'].enum_type = _BRAKE_STATUS__511_FRONT_BUMP_ENVTYPE
_BRAKE_STATUS__511.fields_by_name['back_bump_env'].enum_type = _BRAKE_STATUS__511_BACK_BUMP_ENVTYPE
_BRAKE_STATUS__511.fields_by_name['overspd_env'].enum_type = _BRAKE_STATUS__511_OVERSPD_ENVTYPE
_BRAKE_STATUS__511_BRAKE_PEDAL_EN_STSTYPE.containing_type = _BRAKE_STATUS__511
_BRAKE_STATUS__511_BRAKE_ERRTYPE.containing_type = _BRAKE_STATUS__511
_BRAKE_STATUS__511_EMERGENCY_BTN_ENVTYPE.containing_type = _BRAKE_STATUS__511
_BRAKE_STATUS__511_FRONT_BUMP_ENVTYPE.containing_type = _BRAKE_STATUS__511
_BRAKE_STATUS__511_BACK_BUMP_ENVTYPE.containing_type = _BRAKE_STATUS__511
_BRAKE_STATUS__511_OVERSPD_ENVTYPE.containing_type = _BRAKE_STATUS__511
_STEER_STATUS__512.fields_by_name['steer_angle_en_sts'].enum_type = _STEER_STATUS__512_STEER_ANGLE_EN_STSTYPE
_STEER_STATUS__512.fields_by_name['steer_err'].enum_type = _STEER_STATUS__512_STEER_ERRTYPE
_STEER_STATUS__512.fields_by_name['sensor_err'].enum_type = _STEER_STATUS__512_SENSOR_ERRTYPE
_STEER_STATUS__512_STEER_ANGLE_EN_STSTYPE.containing_type = _STEER_STATUS__512
_STEER_STATUS__512_STEER_ERRTYPE.containing_type = _STEER_STATUS__512
_STEER_STATUS__512_SENSOR_ERRTYPE.containing_type = _STEER_STATUS__512
_TURNSIGNAL_STATUS__513.fields_by_name['turn_signal_sts'].enum_type = _TURNSIGNAL_STATUS__513_TURN_SIGNAL_STSTYPE
_TURNSIGNAL_STATUS__513_TURN_SIGNAL_STSTYPE.containing_type = _TURNSIGNAL_STATUS__513
_GEAR_STATUS_514.fields_by_name['gear_sts'].enum_type = _GEAR_STATUS_514_GEAR_STSTYPE
_GEAR_STATUS_514_GEAR_STSTYPE.containing_type = _GEAR_STATUS_514
_ECU_STATUS_1_515.fields_by_name['ctrl_sts'].enum_type = _ECU_STATUS_1_515_CTRL_STSTYPE
_ECU_STATUS_1_515_CTRL_STSTYPE.containing_type = _ECU_STATUS_1_515
_CH.fields_by_name['throttle_command_110'].message_type = _THROTTLE_COMMAND_110
_CH.fields_by_name['brake_command_111'].message_type = _BRAKE_COMMAND_111
_CH.fields_by_name['steer_command_112'].message_type = _STEER_COMMAND_112
_CH.fields_by_name['turnsignal_command_113'].message_type = _TURNSIGNAL_COMMAND_113
_CH.fields_by_name['gear_command_114'].message_type = _GEAR_COMMAND_114
_CH.fields_by_name['control_command_115'].message_type = _CONTROL_COMMAND_115
_CH.fields_by_name['throttle_status__510'].message_type = _THROTTLE_STATUS__510
_CH.fields_by_name['brake_status__511'].message_type = _BRAKE_STATUS__511
_CH.fields_by_name['steer_status__512'].message_type = _STEER_STATUS__512
_CH.fields_by_name['turnsignal_status__513'].message_type = _TURNSIGNAL_STATUS__513
_CH.fields_by_name['gear_status_514'].message_type = _GEAR_STATUS_514
_CH.fields_by_name['ecu_status_1_515'].message_type = _ECU_STATUS_1_515
_CH.fields_by_name['ecu_status_2_516'].message_type = _ECU_STATUS_2_516
_CH.fields_by_name['ecu_status_3_517'].message_type = _ECU_STATUS_3_517
DESCRIPTOR.message_types_by_name['Throttle_command_110'] = _THROTTLE_COMMAND_110
DESCRIPTOR.message_types_by_name['Brake_command_111'] = _BRAKE_COMMAND_111
DESCRIPTOR.message_types_by_name['Steer_command_112'] = _STEER_COMMAND_112
DESCRIPTOR.message_types_by_name['Turnsignal_command_113'] = _TURNSIGNAL_COMMAND_113
DESCRIPTOR.message_types_by_name['Gear_command_114'] = _GEAR_COMMAND_114
DESCRIPTOR.message_types_by_name['Control_command_115'] = _CONTROL_COMMAND_115
DESCRIPTOR.message_types_by_name['Throttle_status__510'] = _THROTTLE_STATUS__510
DESCRIPTOR.message_types_by_name['Brake_status__511'] = _BRAKE_STATUS__511
DESCRIPTOR.message_types_by_name['Steer_status__512'] = _STEER_STATUS__512
DESCRIPTOR.message_types_by_name['Turnsignal_status__513'] = _TURNSIGNAL_STATUS__513
DESCRIPTOR.message_types_by_name['Gear_status_514'] = _GEAR_STATUS_514
DESCRIPTOR.message_types_by_name['Ecu_status_1_515'] = _ECU_STATUS_1_515
DESCRIPTOR.message_types_by_name['Ecu_status_2_516'] = _ECU_STATUS_2_516
DESCRIPTOR.message_types_by_name['Ecu_status_3_517'] = _ECU_STATUS_3_517
DESCRIPTOR.message_types_by_name['Ch'] = _CH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Throttle_command_110 = _reflection.GeneratedProtocolMessageType('Throttle_command_110', (_message.Message,), {
  'DESCRIPTOR' : _THROTTLE_COMMAND_110,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Throttle_command_110)
  })
_sym_db.RegisterMessage(Throttle_command_110)

Brake_command_111 = _reflection.GeneratedProtocolMessageType('Brake_command_111', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_COMMAND_111,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_command_111)
  })
_sym_db.RegisterMessage(Brake_command_111)

Steer_command_112 = _reflection.GeneratedProtocolMessageType('Steer_command_112', (_message.Message,), {
  'DESCRIPTOR' : _STEER_COMMAND_112,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steer_command_112)
  })
_sym_db.RegisterMessage(Steer_command_112)

Turnsignal_command_113 = _reflection.GeneratedProtocolMessageType('Turnsignal_command_113', (_message.Message,), {
  'DESCRIPTOR' : _TURNSIGNAL_COMMAND_113,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Turnsignal_command_113)
  })
_sym_db.RegisterMessage(Turnsignal_command_113)

Gear_command_114 = _reflection.GeneratedProtocolMessageType('Gear_command_114', (_message.Message,), {
  'DESCRIPTOR' : _GEAR_COMMAND_114,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Gear_command_114)
  })
_sym_db.RegisterMessage(Gear_command_114)

Control_command_115 = _reflection.GeneratedProtocolMessageType('Control_command_115', (_message.Message,), {
  'DESCRIPTOR' : _CONTROL_COMMAND_115,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Control_command_115)
  })
_sym_db.RegisterMessage(Control_command_115)

Throttle_status__510 = _reflection.GeneratedProtocolMessageType('Throttle_status__510', (_message.Message,), {
  'DESCRIPTOR' : _THROTTLE_STATUS__510,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Throttle_status__510)
  })
_sym_db.RegisterMessage(Throttle_status__510)

Brake_status__511 = _reflection.GeneratedProtocolMessageType('Brake_status__511', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_STATUS__511,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_status__511)
  })
_sym_db.RegisterMessage(Brake_status__511)

Steer_status__512 = _reflection.GeneratedProtocolMessageType('Steer_status__512', (_message.Message,), {
  'DESCRIPTOR' : _STEER_STATUS__512,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steer_status__512)
  })
_sym_db.RegisterMessage(Steer_status__512)

Turnsignal_status__513 = _reflection.GeneratedProtocolMessageType('Turnsignal_status__513', (_message.Message,), {
  'DESCRIPTOR' : _TURNSIGNAL_STATUS__513,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Turnsignal_status__513)
  })
_sym_db.RegisterMessage(Turnsignal_status__513)

Gear_status_514 = _reflection.GeneratedProtocolMessageType('Gear_status_514', (_message.Message,), {
  'DESCRIPTOR' : _GEAR_STATUS_514,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Gear_status_514)
  })
_sym_db.RegisterMessage(Gear_status_514)

Ecu_status_1_515 = _reflection.GeneratedProtocolMessageType('Ecu_status_1_515', (_message.Message,), {
  'DESCRIPTOR' : _ECU_STATUS_1_515,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ecu_status_1_515)
  })
_sym_db.RegisterMessage(Ecu_status_1_515)

Ecu_status_2_516 = _reflection.GeneratedProtocolMessageType('Ecu_status_2_516', (_message.Message,), {
  'DESCRIPTOR' : _ECU_STATUS_2_516,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ecu_status_2_516)
  })
_sym_db.RegisterMessage(Ecu_status_2_516)

Ecu_status_3_517 = _reflection.GeneratedProtocolMessageType('Ecu_status_3_517', (_message.Message,), {
  'DESCRIPTOR' : _ECU_STATUS_3_517,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ecu_status_3_517)
  })
_sym_db.RegisterMessage(Ecu_status_3_517)

Ch = _reflection.GeneratedProtocolMessageType('Ch', (_message.Message,), {
  'DESCRIPTOR' : _CH,
  '__module__' : 'modules.canbus.proto.ch_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ch)
  })
_sym_db.RegisterMessage(Ch)


# @@protoc_insertion_point(module_scope)
