# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/perception_camera.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.perception.proto import perception_obstacle_pb2 as modules_dot_perception_dot_proto_dot_perception__obstacle__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/perception_camera.proto',
  package='apollo.perception.camera',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0modules/perception/proto/perception_camera.proto\x12\x18\x61pollo.perception.camera\x1a#modules/common/proto/geometry.proto\x1a!modules/common/proto/header.proto\x1a\x32modules/perception/proto/perception_obstacle.proto\"n\n\x12LaneLineCubicCurve\x12\x15\n\rlongitude_min\x18\x01 \x01(\x02\x12\x15\n\rlongitude_max\x18\x02 \x01(\x02\x12\t\n\x01\x61\x18\x03 \x01(\x02\x12\t\n\x01\x62\x18\x04 \x01(\x02\x12\t\n\x01\x63\x18\x05 \x01(\x02\x12\t\n\x01\x64\x18\x06 \x01(\x02\"W\n\tEndPoints\x12%\n\x05start\x18\x01 \x01(\x0b\x32\x16.apollo.common.Point2D\x12#\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x16.apollo.common.Point2D\"\xaf\x04\n\x0e\x43\x61meraLaneLine\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.apollo.perception.camera.LaneLineType\x12@\n\x08pos_type\x18\x02 \x01(\x0e\x32..apollo.perception.camera.LaneLinePositionType\x12H\n\x12\x63urve_camera_coord\x18\x03 \x01(\x0b\x32,.apollo.perception.camera.LaneLineCubicCurve\x12G\n\x11\x63urve_image_coord\x18\x04 \x01(\x0b\x32,.apollo.perception.camera.LaneLineCubicCurve\x12\x36\n\x16\x63urve_camera_point_set\x18\x05 \x03(\x0b\x32\x16.apollo.common.Point3D\x12\x35\n\x15\x63urve_image_point_set\x18\x06 \x03(\x0b\x32\x16.apollo.common.Point2D\x12@\n\x13image_end_point_set\x18\x07 \x03(\x0b\x32#.apollo.perception.camera.EndPoints\x12\x10\n\x08track_id\x18\x08 \x01(\x05\x12\x12\n\nconfidence\x18\t \x01(\x02\x12;\n\x08use_type\x18\n \x01(\x0e\x32).apollo.perception.camera.LaneLineUseType\">\n\x10\x43\x61meraCalibrator\x12\x13\n\x0bpitch_angle\x18\x01 \x01(\x02\x12\x15\n\rcamera_height\x18\x02 \x01(\x02\"\xad\x03\n\x0e\x43\x61meraObstacle\x12\x37\n\x08obstacle\x18\x01 \x01(\x0b\x32%.apollo.perception.PerceptionObstacle\x12\x41\n\x04type\x18\x15 \x01(\x0e\x32\x33.apollo.perception.camera.CameraObstacle.CameraType\x12\x12\n\ntype_probs\x18\x16 \x03(\x02\x12*\n\nupper_left\x18\x17 \x01(\x0b\x32\x16.apollo.common.Point2D\x12+\n\x0blower_right\x18\x18 \x01(\x0b\x32\x16.apollo.common.Point2D\x12*\n\nkey_points\x18\x19 \x03(\x0b\x32\x16.apollo.common.Point2D\x12\x15\n\rdebug_message\x18\x1a \x03(\t\"o\n\nCameraType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fUNKNOWN_MOVABLE\x10\x01\x12\x15\n\x11UNKNOWN_UNMOVABLE\x10\x02\x12\x0e\n\nPEDESTRIAN\x10\x03\x12\x0b\n\x07\x42ICYCLE\x10\x04\x12\x0b\n\x07VEHICLE\x10\x05\"\xe2\x02\n\x0b\x43\x61meraDebug\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x14\n\x0csource_topic\x18\x02 \x01(\t\x12I\n\nerror_code\x18\x03 \x01(\x0e\x32).apollo.perception.camera.CameraErrorCode:\nERROR_NONE\x12\x45\n\x11\x63\x61mera_calibrator\x18\x04 \x01(\x0b\x32*.apollo.perception.camera.CameraCalibrator\x12\x41\n\x0f\x63\x61mera_laneline\x18\x05 \x03(\x0b\x32(.apollo.perception.camera.CameraLaneLine\x12\x41\n\x0f\x63\x61mera_obstacle\x18\x06 \x03(\x0b\x32(.apollo.perception.camera.CameraObstacle*4\n\x0f\x43\x61meraErrorCode\x12\x0e\n\nERROR_NONE\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01*V\n\x0cLaneLineType\x12\x10\n\x0cWHITE_DASHED\x10\x00\x12\x0f\n\x0bWHITE_SOLID\x10\x01\x12\x11\n\rYELLOW_DASHED\x10\x02\x12\x10\n\x0cYELLOW_SOLID\x10\x03*\x88\x02\n\x14LaneLinePositionType\x12\x19\n\x0c\x42OLLARD_LEFT\x10\xfb\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x18\n\x0b\x46OURTH_LEFT\x10\xfc\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x17\n\nTHIRD_LEFT\x10\xfd\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1a\n\rADJACENT_LEFT\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x15\n\x08\x45GO_LEFT\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\r\n\tEGO_RIGHT\x10\x01\x12\x12\n\x0e\x41\x44JACENT_RIGHT\x10\x02\x12\x0f\n\x0bTHIRD_RIGHT\x10\x03\x12\x10\n\x0c\x46OURTH_RIGHT\x10\x04\x12\x11\n\rBOLLARD_RIGHT\x10\x05\x12\t\n\x05OTHER\x10\x06\x12\x0b\n\x07UNKNOWN\x10\x07*(\n\x0fLaneLineUseType\x12\x08\n\x04REAL\x10\x00\x12\x0b\n\x07VIRTUAL\x10\x01'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_perception_dot_proto_dot_perception__obstacle__pb2.DESCRIPTOR,])

_CAMERAERRORCODE = _descriptor.EnumDescriptor(
  name='CameraErrorCode',
  full_name='apollo.perception.camera.CameraErrorCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ERROR_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1818,
  serialized_end=1870,
)
_sym_db.RegisterEnumDescriptor(_CAMERAERRORCODE)

CameraErrorCode = enum_type_wrapper.EnumTypeWrapper(_CAMERAERRORCODE)
_LANELINETYPE = _descriptor.EnumDescriptor(
  name='LaneLineType',
  full_name='apollo.perception.camera.LaneLineType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WHITE_DASHED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WHITE_SOLID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YELLOW_DASHED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YELLOW_SOLID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1872,
  serialized_end=1958,
)
_sym_db.RegisterEnumDescriptor(_LANELINETYPE)

LaneLineType = enum_type_wrapper.EnumTypeWrapper(_LANELINETYPE)
_LANELINEPOSITIONTYPE = _descriptor.EnumDescriptor(
  name='LaneLinePositionType',
  full_name='apollo.perception.camera.LaneLinePositionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BOLLARD_LEFT', index=0, number=-5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOURTH_LEFT', index=1, number=-4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THIRD_LEFT', index=2, number=-3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADJACENT_LEFT', index=3, number=-2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EGO_LEFT', index=4, number=-1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EGO_RIGHT', index=5, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADJACENT_RIGHT', index=6, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THIRD_RIGHT', index=7, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOURTH_RIGHT', index=8, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOLLARD_RIGHT', index=9, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=10, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=11, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1961,
  serialized_end=2225,
)
_sym_db.RegisterEnumDescriptor(_LANELINEPOSITIONTYPE)

LaneLinePositionType = enum_type_wrapper.EnumTypeWrapper(_LANELINEPOSITIONTYPE)
_LANELINEUSETYPE = _descriptor.EnumDescriptor(
  name='LaneLineUseType',
  full_name='apollo.perception.camera.LaneLineUseType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIRTUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2227,
  serialized_end=2267,
)
_sym_db.RegisterEnumDescriptor(_LANELINEUSETYPE)

LaneLineUseType = enum_type_wrapper.EnumTypeWrapper(_LANELINEUSETYPE)
ERROR_NONE = 0
ERROR_UNKNOWN = 1
WHITE_DASHED = 0
WHITE_SOLID = 1
YELLOW_DASHED = 2
YELLOW_SOLID = 3
BOLLARD_LEFT = -5
FOURTH_LEFT = -4
THIRD_LEFT = -3
ADJACENT_LEFT = -2
EGO_LEFT = -1
EGO_RIGHT = 1
ADJACENT_RIGHT = 2
THIRD_RIGHT = 3
FOURTH_RIGHT = 4
BOLLARD_RIGHT = 5
OTHER = 6
UNKNOWN = 7
REAL = 0
VIRTUAL = 1


_CAMERAOBSTACLE_CAMERATYPE = _descriptor.EnumDescriptor(
  name='CameraType',
  full_name='apollo.perception.camera.CameraObstacle.CameraType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_MOVABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_UNMOVABLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BICYCLE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEHICLE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1348,
  serialized_end=1459,
)
_sym_db.RegisterEnumDescriptor(_CAMERAOBSTACLE_CAMERATYPE)


_LANELINECUBICCURVE = _descriptor.Descriptor(
  name='LaneLineCubicCurve',
  full_name='apollo.perception.camera.LaneLineCubicCurve',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='longitude_min', full_name='apollo.perception.camera.LaneLineCubicCurve.longitude_min', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_max', full_name='apollo.perception.camera.LaneLineCubicCurve.longitude_max', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a', full_name='apollo.perception.camera.LaneLineCubicCurve.a', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='apollo.perception.camera.LaneLineCubicCurve.b', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c', full_name='apollo.perception.camera.LaneLineCubicCurve.c', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d', full_name='apollo.perception.camera.LaneLineCubicCurve.d', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=312,
)


_ENDPOINTS = _descriptor.Descriptor(
  name='EndPoints',
  full_name='apollo.perception.camera.EndPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='apollo.perception.camera.EndPoints.start', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='apollo.perception.camera.EndPoints.end', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=401,
)


_CAMERALANELINE = _descriptor.Descriptor(
  name='CameraLaneLine',
  full_name='apollo.perception.camera.CameraLaneLine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.perception.camera.CameraLaneLine.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pos_type', full_name='apollo.perception.camera.CameraLaneLine.pos_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=-5,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curve_camera_coord', full_name='apollo.perception.camera.CameraLaneLine.curve_camera_coord', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curve_image_coord', full_name='apollo.perception.camera.CameraLaneLine.curve_image_coord', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curve_camera_point_set', full_name='apollo.perception.camera.CameraLaneLine.curve_camera_point_set', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curve_image_point_set', full_name='apollo.perception.camera.CameraLaneLine.curve_image_point_set', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_end_point_set', full_name='apollo.perception.camera.CameraLaneLine.image_end_point_set', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='track_id', full_name='apollo.perception.camera.CameraLaneLine.track_id', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='apollo.perception.camera.CameraLaneLine.confidence', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_type', full_name='apollo.perception.camera.CameraLaneLine.use_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=963,
)


_CAMERACALIBRATOR = _descriptor.Descriptor(
  name='CameraCalibrator',
  full_name='apollo.perception.camera.CameraCalibrator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pitch_angle', full_name='apollo.perception.camera.CameraCalibrator.pitch_angle', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_height', full_name='apollo.perception.camera.CameraCalibrator.camera_height', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1027,
)


_CAMERAOBSTACLE = _descriptor.Descriptor(
  name='CameraObstacle',
  full_name='apollo.perception.camera.CameraObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obstacle', full_name='apollo.perception.camera.CameraObstacle.obstacle', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.perception.camera.CameraObstacle.type', index=1,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_probs', full_name='apollo.perception.camera.CameraObstacle.type_probs', index=2,
      number=22, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upper_left', full_name='apollo.perception.camera.CameraObstacle.upper_left', index=3,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lower_right', full_name='apollo.perception.camera.CameraObstacle.lower_right', index=4,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_points', full_name='apollo.perception.camera.CameraObstacle.key_points', index=5,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug_message', full_name='apollo.perception.camera.CameraObstacle.debug_message', index=6,
      number=26, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAMERAOBSTACLE_CAMERATYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1030,
  serialized_end=1459,
)


_CAMERADEBUG = _descriptor.Descriptor(
  name='CameraDebug',
  full_name='apollo.perception.camera.CameraDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.perception.camera.CameraDebug.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_topic', full_name='apollo.perception.camera.CameraDebug.source_topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_code', full_name='apollo.perception.camera.CameraDebug.error_code', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_calibrator', full_name='apollo.perception.camera.CameraDebug.camera_calibrator', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_laneline', full_name='apollo.perception.camera.CameraDebug.camera_laneline', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_obstacle', full_name='apollo.perception.camera.CameraDebug.camera_obstacle', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1462,
  serialized_end=1816,
)

_ENDPOINTS.fields_by_name['start'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_ENDPOINTS.fields_by_name['end'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_CAMERALANELINE.fields_by_name['type'].enum_type = _LANELINETYPE
_CAMERALANELINE.fields_by_name['pos_type'].enum_type = _LANELINEPOSITIONTYPE
_CAMERALANELINE.fields_by_name['curve_camera_coord'].message_type = _LANELINECUBICCURVE
_CAMERALANELINE.fields_by_name['curve_image_coord'].message_type = _LANELINECUBICCURVE
_CAMERALANELINE.fields_by_name['curve_camera_point_set'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_CAMERALANELINE.fields_by_name['curve_image_point_set'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_CAMERALANELINE.fields_by_name['image_end_point_set'].message_type = _ENDPOINTS
_CAMERALANELINE.fields_by_name['use_type'].enum_type = _LANELINEUSETYPE
_CAMERAOBSTACLE.fields_by_name['obstacle'].message_type = modules_dot_perception_dot_proto_dot_perception__obstacle__pb2._PERCEPTIONOBSTACLE
_CAMERAOBSTACLE.fields_by_name['type'].enum_type = _CAMERAOBSTACLE_CAMERATYPE
_CAMERAOBSTACLE.fields_by_name['upper_left'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_CAMERAOBSTACLE.fields_by_name['lower_right'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_CAMERAOBSTACLE.fields_by_name['key_points'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT2D
_CAMERAOBSTACLE_CAMERATYPE.containing_type = _CAMERAOBSTACLE
_CAMERADEBUG.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_CAMERADEBUG.fields_by_name['error_code'].enum_type = _CAMERAERRORCODE
_CAMERADEBUG.fields_by_name['camera_calibrator'].message_type = _CAMERACALIBRATOR
_CAMERADEBUG.fields_by_name['camera_laneline'].message_type = _CAMERALANELINE
_CAMERADEBUG.fields_by_name['camera_obstacle'].message_type = _CAMERAOBSTACLE
DESCRIPTOR.message_types_by_name['LaneLineCubicCurve'] = _LANELINECUBICCURVE
DESCRIPTOR.message_types_by_name['EndPoints'] = _ENDPOINTS
DESCRIPTOR.message_types_by_name['CameraLaneLine'] = _CAMERALANELINE
DESCRIPTOR.message_types_by_name['CameraCalibrator'] = _CAMERACALIBRATOR
DESCRIPTOR.message_types_by_name['CameraObstacle'] = _CAMERAOBSTACLE
DESCRIPTOR.message_types_by_name['CameraDebug'] = _CAMERADEBUG
DESCRIPTOR.enum_types_by_name['CameraErrorCode'] = _CAMERAERRORCODE
DESCRIPTOR.enum_types_by_name['LaneLineType'] = _LANELINETYPE
DESCRIPTOR.enum_types_by_name['LaneLinePositionType'] = _LANELINEPOSITIONTYPE
DESCRIPTOR.enum_types_by_name['LaneLineUseType'] = _LANELINEUSETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaneLineCubicCurve = _reflection.GeneratedProtocolMessageType('LaneLineCubicCurve', (_message.Message,), {
  'DESCRIPTOR' : _LANELINECUBICCURVE,
  '__module__' : 'modules.perception.proto.perception_camera_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.LaneLineCubicCurve)
  })
_sym_db.RegisterMessage(LaneLineCubicCurve)

EndPoints = _reflection.GeneratedProtocolMessageType('EndPoints', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTS,
  '__module__' : 'modules.perception.proto.perception_camera_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.EndPoints)
  })
_sym_db.RegisterMessage(EndPoints)

CameraLaneLine = _reflection.GeneratedProtocolMessageType('CameraLaneLine', (_message.Message,), {
  'DESCRIPTOR' : _CAMERALANELINE,
  '__module__' : 'modules.perception.proto.perception_camera_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.CameraLaneLine)
  })
_sym_db.RegisterMessage(CameraLaneLine)

CameraCalibrator = _reflection.GeneratedProtocolMessageType('CameraCalibrator', (_message.Message,), {
  'DESCRIPTOR' : _CAMERACALIBRATOR,
  '__module__' : 'modules.perception.proto.perception_camera_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.CameraCalibrator)
  })
_sym_db.RegisterMessage(CameraCalibrator)

CameraObstacle = _reflection.GeneratedProtocolMessageType('CameraObstacle', (_message.Message,), {
  'DESCRIPTOR' : _CAMERAOBSTACLE,
  '__module__' : 'modules.perception.proto.perception_camera_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.CameraObstacle)
  })
_sym_db.RegisterMessage(CameraObstacle)

CameraDebug = _reflection.GeneratedProtocolMessageType('CameraDebug', (_message.Message,), {
  'DESCRIPTOR' : _CAMERADEBUG,
  '__module__' : 'modules.perception.proto.perception_camera_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.CameraDebug)
  })
_sym_db.RegisterMessage(CameraDebug)


# @@protoc_insertion_point(module_scope)
