# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/canbus/proto/lexus.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/canbus/proto/lexus.proto',
  package='apollo.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n modules/canbus/proto/lexus.proto\x12\rapollo.canbus\"\x8c\x02\n\x15Hazard_lights_rpt_214\x12\x14\n\x0coutput_value\x18\x01 \x01(\x08\x12\x17\n\x0f\x63ommanded_value\x18\x02 \x01(\x08\x12\x14\n\x0cmanual_input\x18\x03 \x01(\x08\x12\x15\n\rvehicle_fault\x18\x04 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x05 \x01(\x08\x12\x17\n\x0foverride_active\x18\x06 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x07 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x08 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\t \x01(\x08\x12\x1c\n\x14\x63ommand_output_fault\x18\n \x01(\x08\"\x93\x01\n\x10Steering_cmd_12c\x12\x18\n\x10ignore_overrides\x18\x01 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x04 \x01(\x08\x12\x10\n\x08position\x18\x05 \x01(\x01\x12\x15\n\rrotation_rate\x18\x06 \x01(\x01\"\x9f\t\n\x1b\x44\x61sh_controls_right_rpt_210\x12Q\n\x0coutput_value\x18\x01 \x01(\x0e\x32;.apollo.canbus.Dash_controls_right_rpt_210.Output_valueType\x12W\n\x0f\x63ommanded_value\x18\x02 \x01(\x0e\x32>.apollo.canbus.Dash_controls_right_rpt_210.Commanded_valueType\x12\x15\n\rvehicle_fault\x18\x03 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x04 \x01(\x08\x12\x17\n\x0foverride_active\x18\x05 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x06 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x07 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x08 \x01(\x08\x12\x1c\n\x14\x63ommand_output_fault\x18\t \x01(\x08\x12Q\n\x0cmanual_input\x18\n \x01(\x0e\x32;.apollo.canbus.Dash_controls_right_rpt_210.Manual_inputType\"\xe7\x01\n\x10Output_valueType\x12\"\n\x1eOUTPUT_VALUE_DASH_CONTROL_NONE\x10\x00\x12 \n\x1cOUTPUT_VALUE_DASH_CONTROL_OK\x10\x01\x12\"\n\x1eOUTPUT_VALUE_DASH_CONTROL_LEFT\x10\x02\x12#\n\x1fOUTPUT_VALUE_DASH_CONTROL_RIGHT\x10\x03\x12 \n\x1cOUTPUT_VALUE_DASH_CONTROL_UP\x10\x04\x12\"\n\x1eOUTPUT_VALUE_DASH_CONTROL_DOWN\x10\x05\"\xfc\x01\n\x13\x43ommanded_valueType\x12%\n!COMMANDED_VALUE_DASH_CONTROL_NONE\x10\x00\x12#\n\x1f\x43OMMANDED_VALUE_DASH_CONTROL_OK\x10\x01\x12%\n!COMMANDED_VALUE_DASH_CONTROL_LEFT\x10\x02\x12&\n\"COMMANDED_VALUE_DASH_CONTROL_RIGHT\x10\x03\x12#\n\x1f\x43OMMANDED_VALUE_DASH_CONTROL_UP\x10\x04\x12%\n!COMMANDED_VALUE_DASH_CONTROL_DOWN\x10\x05\"\xe7\x01\n\x10Manual_inputType\x12\"\n\x1eMANUAL_INPUT_DASH_CONTROL_NONE\x10\x00\x12 \n\x1cMANUAL_INPUT_DASH_CONTROL_OK\x10\x01\x12\"\n\x1eMANUAL_INPUT_DASH_CONTROL_LEFT\x10\x02\x12#\n\x1fMANUAL_INPUT_DASH_CONTROL_RIGHT\x10\x03\x12 \n\x1cMANUAL_INPUT_DASH_CONTROL_UP\x10\x04\x12\"\n\x1eMANUAL_INPUT_DASH_CONTROL_DOWN\x10\x05\"\xf8\x03\n\x1a\x44\x61sh_controls_left_cmd_10c\x12\x18\n\x10ignore_overrides\x18\x01 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x04 \x01(\x08\x12`\n\x14\x64\x61sh_controls_button\x18\x05 \x01(\x0e\x32\x42.apollo.canbus.Dash_controls_left_cmd_10c.Dash_controls_buttonType\"\x9f\x02\n\x18\x44\x61sh_controls_buttonType\x12*\n&DASH_CONTROLS_BUTTON_DASH_CONTROL_NONE\x10\x00\x12(\n$DASH_CONTROLS_BUTTON_DASH_CONTROL_OK\x10\x01\x12*\n&DASH_CONTROLS_BUTTON_DASH_CONTROL_LEFT\x10\x02\x12+\n\'DASH_CONTROLS_BUTTON_DASH_CONTROL_RIGHT\x10\x03\x12(\n$DASH_CONTROLS_BUTTON_DASH_CONTROL_UP\x10\x04\x12*\n&DASH_CONTROLS_BUTTON_DASH_CONTROL_DOWN\x10\x05\"\x87\x02\n\x10Steering_rpt_22c\x12\x15\n\rvehicle_fault\x18\x01 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x02 \x01(\x08\x12\x17\n\x0foverride_active\x18\x03 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x04 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x05 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x06 \x01(\x08\x12\x1c\n\x14\x63ommand_output_fault\x18\x07 \x01(\x08\x12\x14\n\x0cmanual_input\x18\x08 \x01(\x01\x12\x17\n\x0f\x63ommanded_value\x18\t \x01(\x01\x12\x14\n\x0coutput_value\x18\n \x01(\x01\"\xa0\x01\n\x10Turn_aux_rpt_330\x12%\n\x1dpass_blinker_bulb_on_is_valid\x18\x01 \x01(\x08\x12\x1c\n\x14pass_blinker_bulb_on\x18\x02 \x01(\x08\x12\'\n\x1f\x64river_blinker_bulb_on_is_valid\x18\x03 \x01(\x08\x12\x1e\n\x16\x64river_blinker_bulb_on\x18\x04 \x01(\x08\"\xfa\x05\n\x11Headlight_rpt_218\x12\x15\n\rvehicle_fault\x18\x01 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x02 \x01(\x08\x12\x17\n\x0foverride_active\x18\x03 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x04 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x05 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x06 \x01(\x08\x12\x1c\n\x14\x63ommand_output_fault\x18\x07 \x01(\x08\x12G\n\x0coutput_value\x18\x08 \x01(\x0e\x32\x31.apollo.canbus.Headlight_rpt_218.Output_valueType\x12G\n\x0cmanual_input\x18\t \x01(\x0e\x32\x31.apollo.canbus.Headlight_rpt_218.Manual_inputType\x12M\n\x0f\x63ommanded_value\x18\n \x01(\x0e\x32\x34.apollo.canbus.Headlight_rpt_218.Commanded_valueType\"l\n\x10Output_valueType\x12\x1f\n\x1bOUTPUT_VALUE_HEADLIGHTS_OFF\x10\x00\x12\x1a\n\x16OUTPUT_VALUE_LOW_BEAMS\x10\x01\x12\x1b\n\x17OUTPUT_VALUE_HIGH_BEAMS\x10\x02\"l\n\x10Manual_inputType\x12\x1f\n\x1bMANUAL_INPUT_HEADLIGHTS_OFF\x10\x00\x12\x1a\n\x16MANUAL_INPUT_LOW_BEAMS\x10\x01\x12\x1b\n\x17MANUAL_INPUT_HIGH_BEAMS\x10\x02\"x\n\x13\x43ommanded_valueType\x12\"\n\x1e\x43OMMANDED_VALUE_HEADLIGHTS_OFF\x10\x00\x12\x1d\n\x19\x43OMMANDED_VALUE_LOW_BEAMS\x10\x01\x12\x1e\n\x1a\x43OMMANDED_VALUE_HIGH_BEAMS\x10\x02\"\x8a\x01\n\x15Hazard_lights_cmd_114\x12\x19\n\x11hazard_lights_cmd\x18\x01 \x01(\x08\x12\x18\n\x10ignore_overrides\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x04 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x05 \x01(\x08\"\x9b\t\n\x1a\x44\x61sh_controls_left_rpt_20c\x12P\n\x0coutput_value\x18\x01 \x01(\x0e\x32:.apollo.canbus.Dash_controls_left_rpt_20c.Output_valueType\x12V\n\x0f\x63ommanded_value\x18\x02 \x01(\x0e\x32=.apollo.canbus.Dash_controls_left_rpt_20c.Commanded_valueType\x12P\n\x0cmanual_input\x18\x03 \x01(\x0e\x32:.apollo.canbus.Dash_controls_left_rpt_20c.Manual_inputType\x12\x15\n\rvehicle_fault\x18\x04 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x05 \x01(\x08\x12\x17\n\x0foverride_active\x18\x06 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x07 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x08 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\t \x01(\x08\x12\x1c\n\x14\x63ommand_output_fault\x18\n \x01(\x08\"\xe7\x01\n\x10Output_valueType\x12\"\n\x1eOUTPUT_VALUE_DASH_CONTROL_NONE\x10\x00\x12 \n\x1cOUTPUT_VALUE_DASH_CONTROL_OK\x10\x01\x12\"\n\x1eOUTPUT_VALUE_DASH_CONTROL_LEFT\x10\x02\x12#\n\x1fOUTPUT_VALUE_DASH_CONTROL_RIGHT\x10\x03\x12 \n\x1cOUTPUT_VALUE_DASH_CONTROL_UP\x10\x04\x12\"\n\x1eOUTPUT_VALUE_DASH_CONTROL_DOWN\x10\x05\"\xfc\x01\n\x13\x43ommanded_valueType\x12%\n!COMMANDED_VALUE_DASH_CONTROL_NONE\x10\x00\x12#\n\x1f\x43OMMANDED_VALUE_DASH_CONTROL_OK\x10\x01\x12%\n!COMMANDED_VALUE_DASH_CONTROL_LEFT\x10\x02\x12&\n\"COMMANDED_VALUE_DASH_CONTROL_RIGHT\x10\x03\x12#\n\x1f\x43OMMANDED_VALUE_DASH_CONTROL_UP\x10\x04\x12%\n!COMMANDED_VALUE_DASH_CONTROL_DOWN\x10\x05\"\xe7\x01\n\x10Manual_inputType\x12\"\n\x1eMANUAL_INPUT_DASH_CONTROL_NONE\x10\x00\x12 \n\x1cMANUAL_INPUT_DASH_CONTROL_OK\x10\x01\x12\"\n\x1eMANUAL_INPUT_DASH_CONTROL_LEFT\x10\x02\x12#\n\x1fMANUAL_INPUT_DASH_CONTROL_RIGHT\x10\x03\x12 \n\x1cMANUAL_INPUT_DASH_CONTROL_UP\x10\x04\x12\"\n\x1eMANUAL_INPUT_DASH_CONTROL_DOWN\x10\x05\"\x80\x04\n\x15Headlight_aux_rpt_318\x12 \n\x18headlights_mode_is_valid\x18\x01 \x01(\x08\x12Q\n\x0fheadlights_mode\x18\x02 \x01(\x0e\x32\x38.apollo.canbus.Headlight_aux_rpt_318.Headlights_modeType\x12\x1e\n\x16\x66og_lights_on_is_valid\x18\x03 \x01(\x08\x12\x15\n\rfog_lights_on\x18\x04 \x01(\x08\x12%\n\x1dheadlights_on_bright_is_valid\x18\x05 \x01(\x08\x12\x1c\n\x14headlights_on_bright\x18\x06 \x01(\x08\x12\x1e\n\x16headlights_on_is_valid\x18\x07 \x01(\x08\x12\x15\n\rheadlights_on\x18\x08 \x01(\x08\"\xbe\x01\n\x13Headlights_modeType\x12\"\n\x1eHEADLIGHTS_MODE_HEADLIGHTS_OFF\x10\x00\x12\'\n#HEADLIGHTS_MODE_PARKING_LIGHTS_ONLY\x10\x01\x12-\n)HEADLIGHTS_MODE_HEADLIGHTS_ON_MANUAL_MODE\x10\x02\x12+\n\'HEADLIGHTS_MODE_HEADLIGHTS_ON_AUTO_MODE\x10\x03\"\xfa\x03\n\x1b\x44\x61sh_controls_right_cmd_110\x12\x18\n\x10ignore_overrides\x18\x01 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x04 \x01(\x08\x12\x61\n\x14\x64\x61sh_controls_button\x18\x05 \x01(\x0e\x32\x43.apollo.canbus.Dash_controls_right_cmd_110.Dash_controls_buttonType\"\x9f\x02\n\x18\x44\x61sh_controls_buttonType\x12*\n&DASH_CONTROLS_BUTTON_DASH_CONTROL_NONE\x10\x00\x12(\n$DASH_CONTROLS_BUTTON_DASH_CONTROL_OK\x10\x01\x12*\n&DASH_CONTROLS_BUTTON_DASH_CONTROL_LEFT\x10\x02\x12+\n\'DASH_CONTROLS_BUTTON_DASH_CONTROL_RIGHT\x10\x03\x12(\n$DASH_CONTROLS_BUTTON_DASH_CONTROL_UP\x10\x04\x12*\n&DASH_CONTROLS_BUTTON_DASH_CONTROL_DOWN\x10\x05\"\x8f\x03\n\rWiper_cmd_134\x12\x18\n\x10ignore_overrides\x18\x01 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12=\n\twiper_cmd\x18\x04 \x01(\x0e\x32*.apollo.canbus.Wiper_cmd_134.Wiper_cmdType\x12\x14\n\x0c\x63lear_faults\x18\x05 \x01(\x08\"\xe6\x01\n\rWiper_cmdType\x12\x18\n\x14WIPER_CMD_WIPERS_OFF\x10\x00\x12\x1c\n\x18WIPER_CMD_INTERMITTENT_1\x10\x01\x12\x1c\n\x18WIPER_CMD_INTERMITTENT_2\x10\x02\x12\x1c\n\x18WIPER_CMD_INTERMITTENT_3\x10\x03\x12\x1c\n\x18WIPER_CMD_INTERMITTENT_4\x10\x04\x12\x1c\n\x18WIPER_CMD_INTERMITTENT_5\x10\x05\x12\x11\n\rWIPER_CMD_LOW\x10\x06\x12\x12\n\x0eWIPER_CMD_HIGH\x10\x07\"\xbb\t\n\rWiper_rpt_234\x12\x15\n\rvehicle_fault\x18\x01 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x02 \x01(\x08\x12\x17\n\x0foverride_active\x18\x03 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x04 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x05 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x06 \x01(\x08\x12\x1c\n\x14\x63ommand_output_fault\x18\x07 \x01(\x08\x12\x43\n\x0coutput_value\x18\x08 \x01(\x0e\x32-.apollo.canbus.Wiper_rpt_234.Output_valueType\x12I\n\x0f\x63ommanded_value\x18\t \x01(\x0e\x32\x30.apollo.canbus.Wiper_rpt_234.Commanded_valueType\x12\x43\n\x0cmanual_input\x18\n \x01(\x0e\x32-.apollo.canbus.Wiper_rpt_234.Manual_inputType\"\x81\x02\n\x10Output_valueType\x12\x1b\n\x17OUTPUT_VALUE_WIPERS_OFF\x10\x00\x12\x1f\n\x1bOUTPUT_VALUE_INTERMITTENT_1\x10\x01\x12\x1f\n\x1bOUTPUT_VALUE_INTERMITTENT_2\x10\x02\x12\x1f\n\x1bOUTPUT_VALUE_INTERMITTENT_3\x10\x03\x12\x1f\n\x1bOUTPUT_VALUE_INTERMITTENT_4\x10\x04\x12\x1f\n\x1bOUTPUT_VALUE_INTERMITTENT_5\x10\x05\x12\x14\n\x10OUTPUT_VALUE_LOW\x10\x06\x12\x15\n\x11OUTPUT_VALUE_HIGH\x10\x07\"\x9c\x02\n\x13\x43ommanded_valueType\x12\x1e\n\x1a\x43OMMANDED_VALUE_WIPERS_OFF\x10\x00\x12\"\n\x1e\x43OMMANDED_VALUE_INTERMITTENT_1\x10\x01\x12\"\n\x1e\x43OMMANDED_VALUE_INTERMITTENT_2\x10\x02\x12\"\n\x1e\x43OMMANDED_VALUE_INTERMITTENT_3\x10\x03\x12\"\n\x1e\x43OMMANDED_VALUE_INTERMITTENT_4\x10\x04\x12\"\n\x1e\x43OMMANDED_VALUE_INTERMITTENT_5\x10\x05\x12\x17\n\x13\x43OMMANDED_VALUE_LOW\x10\x06\x12\x18\n\x14\x43OMMANDED_VALUE_HIGH\x10\x07\"\x81\x02\n\x10Manual_inputType\x12\x1b\n\x17MANUAL_INPUT_WIPERS_OFF\x10\x00\x12\x1f\n\x1bMANUAL_INPUT_INTERMITTENT_1\x10\x01\x12\x1f\n\x1bMANUAL_INPUT_INTERMITTENT_2\x10\x02\x12\x1f\n\x1bMANUAL_INPUT_INTERMITTENT_3\x10\x03\x12\x1f\n\x1bMANUAL_INPUT_INTERMITTENT_4\x10\x04\x12\x1f\n\x1bMANUAL_INPUT_INTERMITTENT_5\x10\x05\x12\x14\n\x10MANUAL_INPUT_LOW\x10\x06\x12\x15\n\x11MANUAL_INPUT_HIGH\x10\x07\"\xf9\x05\n\x0cTurn_rpt_230\x12\x15\n\rvehicle_fault\x18\x01 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x02 \x01(\x08\x12\x17\n\x0foverride_active\x18\x03 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x04 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x05 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x06 \x01(\x08\x12\x1c\n\x14\x63ommand_output_fault\x18\x07 \x01(\x08\x12\x42\n\x0cmanual_input\x18\x08 \x01(\x0e\x32,.apollo.canbus.Turn_rpt_230.Manual_inputType\x12H\n\x0f\x63ommanded_value\x18\t \x01(\x0e\x32/.apollo.canbus.Turn_rpt_230.Commanded_valueType\x12\x42\n\x0coutput_value\x18\n \x01(\x0e\x32,.apollo.canbus.Turn_rpt_230.Output_valueType\"q\n\x10Manual_inputType\x12\x16\n\x12MANUAL_INPUT_RIGHT\x10\x00\x12\x15\n\x11MANUAL_INPUT_NONE\x10\x01\x12\x15\n\x11MANUAL_INPUT_LEFT\x10\x02\x12\x17\n\x13MANUAL_INPUT_HAZARD\x10\x03\"\x80\x01\n\x13\x43ommanded_valueType\x12\x19\n\x15\x43OMMANDED_VALUE_RIGHT\x10\x00\x12\x18\n\x14\x43OMMANDED_VALUE_NONE\x10\x01\x12\x18\n\x14\x43OMMANDED_VALUE_LEFT\x10\x02\x12\x1a\n\x16\x43OMMANDED_VALUE_HAZARD\x10\x03\"q\n\x10Output_valueType\x12\x16\n\x12OUTPUT_VALUE_RIGHT\x10\x00\x12\x15\n\x11OUTPUT_VALUE_NONE\x10\x01\x12\x15\n\x11OUTPUT_VALUE_LEFT\x10\x02\x12\x17\n\x13OUTPUT_VALUE_HAZARD\x10\x03\"\xa8\x02\n\x11Headlight_cmd_118\x12\x18\n\x10ignore_overrides\x18\x01 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x04 \x01(\x08\x12I\n\rheadlight_cmd\x18\x05 \x01(\x0e\x32\x32.apollo.canbus.Headlight_cmd_118.Headlight_cmdType\"p\n\x11Headlight_cmdType\x12 \n\x1cHEADLIGHT_CMD_HEADLIGHTS_OFF\x10\x00\x12\x1b\n\x17HEADLIGHT_CMD_LOW_BEAMS\x10\x01\x12\x1c\n\x18HEADLIGHT_CMD_HIGH_BEAMS\x10\x02\"\xa7\x03\n\x0c\x44oor_rpt_417\x12\x1f\n\x17\x66uel_door_open_is_valid\x18\x01 \x01(\x08\x12\x1b\n\x13trunk_open_is_valid\x18\x02 \x01(\x08\x12\x1a\n\x12hood_open_is_valid\x18\x03 \x01(\x08\x12$\n\x1crear_pass_door_open_is_valid\x18\x04 \x01(\x08\x12&\n\x1erear_driver_door_open_is_valid\x18\x05 \x01(\x08\x12\x1f\n\x17pass_door_open_is_valid\x18\x06 \x01(\x08\x12!\n\x19\x64river_door_open_is_valid\x18\x07 \x01(\x08\x12\x16\n\x0e\x66uel_door_open\x18\x08 \x01(\x08\x12\x12\n\ntrunk_open\x18\t \x01(\x08\x12\x11\n\thood_open\x18\n \x01(\x08\x12\x1b\n\x13rear_pass_door_open\x18\x0b \x01(\x08\x12\x1d\n\x15rear_driver_door_open\x18\x0c \x01(\x08\x12\x16\n\x0epass_door_open\x18\r \x01(\x08\x12\x18\n\x10\x64river_door_open\x18\x0e \x01(\x08\"\xef\x04\n\x10\x43omponent_rpt_20\x12J\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x32.apollo.canbus.Component_rpt_20.Component_typeType\x12J\n\x0e\x63omponent_func\x18\x02 \x01(\x0e\x32\x32.apollo.canbus.Component_rpt_20.Component_funcType\x12\x0f\n\x07\x63ounter\x18\x03 \x01(\x05\x12\x12\n\ncomplement\x18\x04 \x01(\x05\x12\x14\n\x0c\x63onfig_fault\x18\x05 \x01(\x08\"h\n\x12\x43omponent_typeType\x12\x19\n\x15\x43OMPONENT_TYPE_PACMOD\x10\x00\x12\x1a\n\x16\x43OMPONENT_TYPE_PACMINI\x10\x01\x12\x1b\n\x17\x43OMPONENT_TYPE_PACMICRO\x10\x02\"\x9d\x02\n\x12\x43omponent_funcType\x12\x19\n\x15\x43OMPONENT_FUNC_PACMOD\x10\x00\x12/\n+COMPONENT_FUNC_STEERING_AND_STEERING_COLUMN\x10\x01\x12*\n&COMPONENT_FUNC_ACCELERATOR_AND_BRAKING\x10\x02\x12\x1a\n\x16\x43OMPONENT_FUNC_BRAKING\x10\x03\x12\x1b\n\x17\x43OMPONENT_FUNC_SHIFTING\x10\x04\x12\x1b\n\x17\x43OMPONENT_FUNC_STEERING\x10\x05\x12\x1c\n\x18\x43OMPONENT_FUNC_E_SHIFTER\x10\x06\x12\x1b\n\x17\x43OMPONENT_FUNC_WATCHDOG\x10\x07\"\x8d\x01\n\x13Wheel_speed_rpt_407\x12\x1c\n\x14wheel_spd_rear_right\x18\x01 \x01(\x01\x12\x1b\n\x13wheel_spd_rear_left\x18\x02 \x01(\x01\x12\x1d\n\x15wheel_spd_front_right\x18\x03 \x01(\x01\x12\x1c\n\x14wheel_spd_front_left\x18\x04 \x01(\x01\"G\n\x18Steering_motor_rpt_3_406\x12\x15\n\rtorque_output\x18\x01 \x01(\x01\x12\x14\n\x0ctorque_input\x18\x02 \x01(\x01\"i\n\x18Steering_motor_rpt_2_405\x12\x1b\n\x13\x65ncoder_temperature\x18\x01 \x01(\x05\x12\x19\n\x11motor_temperature\x18\x02 \x01(\x05\x12\x15\n\rangular_speed\x18\x03 \x01(\x01\"I\n\x18Steering_motor_rpt_1_404\x12\x15\n\rmotor_current\x18\x01 \x01(\x01\x12\x16\n\x0eshaft_position\x18\x02 \x01(\x01\"D\n\x15\x42rake_motor_rpt_3_403\x12\x15\n\rtorque_output\x18\x01 \x01(\x01\x12\x14\n\x0ctorque_input\x18\x02 \x01(\x01\"f\n\x15\x42rake_motor_rpt_2_402\x12\x1b\n\x13\x65ncoder_temperature\x18\x01 \x01(\x05\x12\x19\n\x11motor_temperature\x18\x02 \x01(\x05\x12\x15\n\rangular_speed\x18\x03 \x01(\x01\"F\n\x15\x42rake_motor_rpt_1_401\x12\x15\n\rmotor_current\x18\x01 \x01(\x01\x12\x16\n\x0eshaft_position\x18\x02 \x01(\x01\"\xdb\x02\n\x11Wiper_aux_rpt_334\x12\x1c\n\x14spray_empty_is_valid\x18\x01 \x01(\x08\x12\x13\n\x0bspray_empty\x18\x02 \x01(\x08\x12!\n\x19spray_near_empty_is_valid\x18\x03 \x01(\x08\x12\x18\n\x10spray_near_empty\x18\x04 \x01(\x08\x12\x1e\n\x16rear_spraying_is_valid\x18\x05 \x01(\x08\x12\x15\n\rrear_spraying\x18\x06 \x01(\x08\x12\x1c\n\x14rear_wiping_is_valid\x18\x07 \x01(\x08\x12\x13\n\x0brear_wiping\x18\x08 \x01(\x08\x12\x1f\n\x17\x66ront_spraying_is_valid\x18\t \x01(\x08\x12\x16\n\x0e\x66ront_spraying\x18\n \x01(\x08\x12\x1d\n\x15\x66ront_wiping_is_valid\x18\x0b \x01(\x08\x12\x14\n\x0c\x66ront_wiping\x18\x0c \x01(\x08\"\xa1\x02\n\x11Shift_aux_rpt_328\x12\'\n\x1fspeed_interlock_active_is_valid\x18\x01 \x01(\x08\x12\x1e\n\x16speed_interlock_active\x18\x02 \x01(\x08\x12\'\n\x1f\x62rake_interlock_active_is_valid\x18\x03 \x01(\x08\x12\x1e\n\x16\x62rake_interlock_active\x18\x04 \x01(\x08\x12%\n\x1dstay_in_neutral_mode_is_valid\x18\x05 \x01(\x08\x12\x1c\n\x14stay_in_neutral_mode\x18\x06 \x01(\x08\x12\x1e\n\x16\x62\x65tween_gears_is_valid\x18\x07 \x01(\x08\x12\x15\n\rbetween_gears\x18\x08 \x01(\x08\"\x84\x02\n\rAccel_rpt_200\x12\x15\n\rvehicle_fault\x18\x01 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x02 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x03 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x04 \x01(\x08\x12\x1c\n\x14\x63ommand_output_fault\x18\x05 \x01(\x08\x12\x17\n\x0foverride_active\x18\x06 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x07 \x01(\x08\x12\x14\n\x0cmanual_input\x18\x08 \x01(\x01\x12\x17\n\x0f\x63ommanded_value\x18\t \x01(\x01\x12\x14\n\x0coutput_value\x18\n \x01(\x01\"\x84\x02\n\rBrake_rpt_204\x12\x1c\n\x14\x63ommand_output_fault\x18\x01 \x01(\x08\x12\x15\n\rvehicle_fault\x18\x02 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x03 \x01(\x08\x12\x17\n\x0foverride_active\x18\x04 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x05 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x06 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x07 \x01(\x08\x12\x14\n\x0cmanual_input\x18\x08 \x01(\x01\x12\x17\n\x0f\x63ommanded_value\x18\t \x01(\x01\x12\x14\n\x0coutput_value\x18\n \x01(\x01\"\xd5\x01\n\x0cHorn_cmd_11c\x12\x18\n\x10ignore_overrides\x18\x01 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x04 \x01(\x08\x12:\n\x08horn_cmd\x18\x05 \x01(\x0e\x32(.apollo.canbus.Horn_cmd_11c.Horn_cmdType\"1\n\x0cHorn_cmdType\x12\x10\n\x0cHORN_CMD_OFF\x10\x00\x12\x0f\n\x0bHORN_CMD_ON\x10\x01\"\xc7\x06\n\rGlobal_rpt_10\x12\x1b\n\x13\x63onfig_fault_active\x18\x01 \x01(\x08\x12 \n\x18pacmod_subsystem_timeout\x18\x02 \x01(\x08\x12U\n\x15pacmod_system_enabled\x18\x03 \x01(\x0e\x32\x36.apollo.canbus.Global_rpt_10.Pacmod_system_enabledType\x12\x65\n\x1dpacmod_system_override_active\x18\x04 \x01(\x0e\x32>.apollo.canbus.Global_rpt_10.Pacmod_system_override_activeType\x12\"\n\x1apacmod_system_fault_active\x18\x05 \x01(\x08\x12\x17\n\x0fveh_can_timeout\x18\x06 \x01(\x08\x12\x17\n\x0fstr_can_timeout\x18\x07 \x01(\x08\x12I\n\x0f\x62rk_can_timeout\x18\x08 \x01(\x0e\x32\x30.apollo.canbus.Global_rpt_10.Brk_can_timeoutType\x12\x17\n\x0fusr_can_timeout\x18\t \x01(\x08\x12\x1b\n\x13usr_can_read_errors\x18\n \x01(\x05\"r\n\x19Pacmod_system_enabledType\x12*\n&PACMOD_SYSTEM_ENABLED_CONTROL_DISABLED\x10\x00\x12)\n%PACMOD_SYSTEM_ENABLED_CONTROL_ENABLED\x10\x01\"\x83\x01\n!Pacmod_system_override_activeType\x12\x30\n,PACMOD_SYSTEM_OVERRIDE_ACTIVE_NOT_OVERRIDDEN\x10\x00\x12,\n(PACMOD_SYSTEM_OVERRIDE_ACTIVE_OVERRIDDEN\x10\x01\"h\n\x13\x42rk_can_timeoutType\x12)\n%BRK_CAN_TIMEOUT_NO_ACTIVE_CAN_TIMEOUT\x10\x00\x12&\n\"BRK_CAN_TIMEOUT_ACTIVE_CAN_TIMEOUT\x10\x01\"\xc2\x01\n\x11\x41\x63\x63\x65l_aux_rpt_300\x12!\n\x19user_interaction_is_valid\x18\x01 \x01(\x08\x12\x18\n\x10user_interaction\x18\x02 \x01(\x08\x12 \n\x18raw_pedal_force_is_valid\x18\x03 \x01(\x08\x12\x17\n\x0fraw_pedal_force\x18\x04 \x01(\x01\x12\x1e\n\x16raw_pedal_pos_is_valid\x18\x05 \x01(\x08\x12\x15\n\rraw_pedal_pos\x18\x06 \x01(\x01\"\x8c\x0b\n\x1e\x43ruise_control_buttons_rpt_208\x12T\n\x0coutput_value\x18\x01 \x01(\x0e\x32>.apollo.canbus.Cruise_control_buttons_rpt_208.Output_valueType\x12T\n\x0cmanual_input\x18\x02 \x01(\x0e\x32>.apollo.canbus.Cruise_control_buttons_rpt_208.Manual_inputType\x12Z\n\x0f\x63ommanded_value\x18\x03 \x01(\x0e\x32\x41.apollo.canbus.Cruise_control_buttons_rpt_208.Commanded_valueType\x12\x15\n\rvehicle_fault\x18\x04 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x05 \x01(\x08\x12\x17\n\x0foverride_active\x18\x06 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x07 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x08 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\t \x01(\x08\x12\x1c\n\x14\x63ommand_output_fault\x18\n \x01(\x08\"\xb1\x02\n\x10Output_valueType\x12$\n OUTPUT_VALUE_CRUISE_CONTROL_NONE\x10\x00\x12$\n OUTPUT_VALUE_CRUISE_CONTROL_CNCL\x10\x01\x12+\n\'OUTPUT_VALUE_CRUISE_CONTROL_ACC_FURTHER\x10\x02\x12*\n&OUTPUT_VALUE_CRUISE_CONTROL_ACC_CLOSER\x10\x03\x12\'\n#OUTPUT_VALUE_CRUISE_CONTROL_SET_DEC\x10\x04\x12\'\n#OUTPUT_VALUE_CRUISE_CONTROL_RES_INC\x10\x05\x12&\n\"OUTPUT_VALUE_CRUISE_CONTROL_ON_OFF\x10\x06\"\xb1\x02\n\x10Manual_inputType\x12$\n MANUAL_INPUT_CRUISE_CONTROL_NONE\x10\x00\x12$\n MANUAL_INPUT_CRUISE_CONTROL_CNCL\x10\x01\x12+\n\'MANUAL_INPUT_CRUISE_CONTROL_ACC_FURTHER\x10\x02\x12*\n&MANUAL_INPUT_CRUISE_CONTROL_ACC_CLOSER\x10\x03\x12\'\n#MANUAL_INPUT_CRUISE_CONTROL_SET_DEC\x10\x04\x12\'\n#MANUAL_INPUT_CRUISE_CONTROL_RES_INC\x10\x05\x12&\n\"MANUAL_INPUT_CRUISE_CONTROL_ON_OFF\x10\x06\"\xc9\x02\n\x13\x43ommanded_valueType\x12\'\n#COMMANDED_VALUE_CRUISE_CONTROL_NONE\x10\x00\x12\'\n#COMMANDED_VALUE_CRUISE_CONTROL_CNCL\x10\x01\x12.\n*COMMANDED_VALUE_CRUISE_CONTROL_ACC_FURTHER\x10\x02\x12-\n)COMMANDED_VALUE_CRUISE_CONTROL_ACC_CLOSER\x10\x03\x12*\n&COMMANDED_VALUE_CRUISE_CONTROL_SET_DEC\x10\x04\x12*\n&COMMANDED_VALUE_CRUISE_CONTROL_RES_INC\x10\x05\x12)\n%COMMANDED_VALUE_CRUISE_CONTROL_ON_OFF\x10\x06\"\xe4\x01\n\x15Vehicle_speed_rpt_400\x12\x15\n\rvehicle_speed\x18\x01 \x01(\x01\x12Y\n\x13vehicle_speed_valid\x18\x02 \x01(\x0e\x32<.apollo.canbus.Vehicle_speed_rpt_400.Vehicle_speed_validType\"Y\n\x17Vehicle_speed_validType\x12\x1f\n\x1bVEHICLE_SPEED_VALID_INVALID\x10\x00\x12\x1d\n\x19VEHICLE_SPEED_VALID_VALID\x10\x01\"\xb8\x02\n\x11\x42rake_aux_rpt_304\x12\x1d\n\x15\x62rake_on_off_is_valid\x18\x01 \x01(\x08\x12\x14\n\x0c\x62rake_on_off\x18\x02 \x01(\x08\x12!\n\x19user_interaction_is_valid\x18\x03 \x01(\x08\x12\x18\n\x10user_interaction\x18\x04 \x01(\x08\x12#\n\x1braw_brake_pressure_is_valid\x18\x05 \x01(\x08\x12\x1a\n\x12raw_brake_pressure\x18\x06 \x01(\x01\x12 \n\x18raw_pedal_force_is_valid\x18\x07 \x01(\x08\x12\x17\n\x0fraw_pedal_force\x18\x08 \x01(\x01\x12\x1e\n\x16raw_pedal_pos_is_valid\x18\t \x01(\x08\x12\x15\n\rraw_pedal_pos\x18\n \x01(\x01\"\xbc\x04\n\x16Media_controls_cmd_120\x12X\n\x12media_controls_cmd\x18\x01 \x01(\x0e\x32<.apollo.canbus.Media_controls_cmd_120.Media_controls_cmdType\x12\x18\n\x10ignore_overrides\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x04 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x05 \x01(\x08\"\xef\x02\n\x16Media_controls_cmdType\x12)\n%MEDIA_CONTROLS_CMD_MEDIA_CONTROL_NONE\x10\x00\x12\x32\n.MEDIA_CONTROLS_CMD_MEDIA_CONTROL_VOICE_COMMAND\x10\x01\x12)\n%MEDIA_CONTROLS_CMD_MEDIA_CONTROL_MUTE\x10\x02\x12\x36\n2MEDIA_CONTROLS_CMD_MEDIA_CONTROL_PREV_TRACK_ANSWER\x10\x03\x12\x37\n3MEDIA_CONTROLS_CMD_MEDIA_CONTROL_NEXT_TRACK_HANG_UP\x10\x04\x12+\n\'MEDIA_CONTROLS_CMD_MEDIA_CONTROL_VOL_UP\x10\x05\x12-\n)MEDIA_CONTROLS_CMD_MEDIA_CONTROL_VOL_DOWN\x10\x06\"\xdc\x04\n\x1e\x43ruise_control_buttons_cmd_108\x12\x66\n\x15\x63ruise_control_button\x18\x01 \x01(\x0e\x32G.apollo.canbus.Cruise_control_buttons_cmd_108.Cruise_control_buttonType\x12\x18\n\x10ignore_overrides\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x04 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x05 \x01(\x08\"\xf9\x02\n\x19\x43ruise_control_buttonType\x12-\n)CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_NONE\x10\x00\x12-\n)CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_CNCL\x10\x01\x12\x34\n0CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_ACC_FURTHER\x10\x02\x12\x33\n/CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_ACC_CLOSER\x10\x03\x12\x30\n,CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_SET_DEC\x10\x04\x12\x30\n,CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_RES_INC\x10\x05\x12/\n+CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_ON_OFF\x10\x06\"\x8a\x01\n\x15Parking_brake_cmd_124\x12\x18\n\x10ignore_overrides\x18\x01 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12\x19\n\x11parking_brake_cmd\x18\x04 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x05 \x01(\x08\"\xd6\x04\n\x0cHorn_rpt_21c\x12\x15\n\rvehicle_fault\x18\x01 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x02 \x01(\x08\x12\x17\n\x0foverride_active\x18\x03 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x04 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x05 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x06 \x01(\x08\x12\x1c\n\x14\x63ommand_output_fault\x18\x07 \x01(\x08\x12\x42\n\x0coutput_value\x18\x08 \x01(\x0e\x32,.apollo.canbus.Horn_rpt_21c.Output_valueType\x12H\n\x0f\x63ommanded_value\x18\t \x01(\x0e\x32/.apollo.canbus.Horn_rpt_21c.Commanded_valueType\x12\x42\n\x0cmanual_input\x18\n \x01(\x0e\x32,.apollo.canbus.Horn_rpt_21c.Manual_inputType\"=\n\x10Output_valueType\x12\x14\n\x10OUTPUT_VALUE_OFF\x10\x00\x12\x13\n\x0fOUTPUT_VALUE_ON\x10\x01\"F\n\x13\x43ommanded_valueType\x12\x17\n\x13\x43OMMANDED_VALUE_OFF\x10\x00\x12\x16\n\x12\x43OMMANDED_VALUE_ON\x10\x01\"=\n\x10Manual_inputType\x12\x14\n\x10MANUAL_INPUT_OFF\x10\x00\x12\x13\n\x0fMANUAL_INPUT_ON\x10\x01\"\x9d\x08\n\rShift_rpt_228\x12\x15\n\rvehicle_fault\x18\x01 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x02 \x01(\x08\x12\x17\n\x0foverride_active\x18\x03 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x04 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x05 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x06 \x01(\x08\x12\x1c\n\x14\x63ommand_output_fault\x18\x07 \x01(\x08\x12\x43\n\x0cmanual_input\x18\x08 \x01(\x0e\x32-.apollo.canbus.Shift_rpt_228.Manual_inputType\x12I\n\x0f\x63ommanded_value\x18\t \x01(\x0e\x32\x30.apollo.canbus.Shift_rpt_228.Commanded_valueType\x12\x43\n\x0coutput_value\x18\n \x01(\x0e\x32-.apollo.canbus.Shift_rpt_228.Output_valueType\"\xe1\x01\n\x10Manual_inputType\x12\x15\n\x11MANUAL_INPUT_PARK\x10\x00\x12\x18\n\x14MANUAL_INPUT_REVERSE\x10\x01\x12\x18\n\x14MANUAL_INPUT_NEUTRAL\x10\x02\x12\x1d\n\x19MANUAL_INPUT_FORWARD_HIGH\x10\x03\x12\x14\n\x10MANUAL_INPUT_LOW\x10\x04\x12\x1e\n\x1aMANUAL_INPUT_BETWEEN_GEARS\x10\x05\x12\x16\n\x12MANUAL_INPUT_ERROR\x10\x06\x12\x15\n\x11MANUAL_INPUT_NONE\x10\x07\"\xbe\x01\n\x13\x43ommanded_valueType\x12\x18\n\x14\x43OMMANDED_VALUE_PARK\x10\x00\x12\x1b\n\x17\x43OMMANDED_VALUE_REVERSE\x10\x01\x12\x1b\n\x17\x43OMMANDED_VALUE_NEUTRAL\x10\x02\x12 \n\x1c\x43OMMANDED_VALUE_FORWARD_HIGH\x10\x03\x12\x17\n\x13\x43OMMANDED_VALUE_LOW\x10\x04\x12\x18\n\x14\x43OMMANDED_VALUE_NONE\x10\x07\"\xe1\x01\n\x10Output_valueType\x12\x15\n\x11OUTPUT_VALUE_PARK\x10\x00\x12\x18\n\x14OUTPUT_VALUE_REVERSE\x10\x01\x12\x18\n\x14OUTPUT_VALUE_NEUTRAL\x10\x02\x12\x1d\n\x19OUTPUT_VALUE_FORWARD_HIGH\x10\x03\x12\x14\n\x10OUTPUT_VALUE_LOW\x10\x04\x12\x1e\n\x1aOUTPUT_VALUE_BETWEEN_GEARS\x10\x05\x12\x16\n\x12OUTPUT_VALUE_ERROR\x10\x06\x12\x15\n\x11OUTPUT_VALUE_NONE\x10\x07\"\xbd\x02\n\rShift_cmd_128\x12\x18\n\x10ignore_overrides\x18\x01 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x04 \x01(\x08\x12=\n\tshift_cmd\x18\x05 \x01(\x0e\x32*.apollo.canbus.Shift_cmd_128.Shift_cmdType\"\x94\x01\n\rShift_cmdType\x12\x12\n\x0eSHIFT_CMD_PARK\x10\x00\x12\x15\n\x11SHIFT_CMD_REVERSE\x10\x01\x12\x15\n\x11SHIFT_CMD_NEUTRAL\x10\x02\x12\x1a\n\x16SHIFT_CMD_FORWARD_HIGH\x10\x03\x12\x11\n\rSHIFT_CMD_LOW\x10\x04\x12\x12\n\x0eSHIFT_CMD_NONE\x10\x07\"z\n\rAccel_cmd_100\x12\x18\n\x10ignore_overrides\x18\x01 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x04 \x01(\x08\x12\x11\n\taccel_cmd\x18\x05 \x01(\x01\"\x8c\x02\n\x15Parking_brake_rpt_224\x12\x15\n\rvehicle_fault\x18\x01 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x02 \x01(\x08\x12\x17\n\x0foverride_active\x18\x03 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x04 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x05 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x06 \x01(\x08\x12\x1c\n\x14\x63ommand_output_fault\x18\x07 \x01(\x08\x12\x14\n\x0coutput_value\x18\x08 \x01(\x08\x12\x17\n\x0f\x63ommanded_value\x18\t \x01(\x08\x12\x14\n\x0cmanual_input\x18\n \x01(\x08\"z\n\rBrake_cmd_104\x12\x18\n\x10ignore_overrides\x18\x01 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x04 \x01(\x08\x12\x11\n\tbrake_cmd\x18\x05 \x01(\x01\"\x96\x0b\n\x16Media_controls_rpt_220\x12L\n\x0coutput_value\x18\x01 \x01(\x0e\x32\x36.apollo.canbus.Media_controls_rpt_220.Output_valueType\x12R\n\x0f\x63ommanded_value\x18\x02 \x01(\x0e\x32\x39.apollo.canbus.Media_controls_rpt_220.Commanded_valueType\x12L\n\x0cmanual_input\x18\x03 \x01(\x0e\x32\x36.apollo.canbus.Media_controls_rpt_220.Manual_inputType\x12\x15\n\rvehicle_fault\x18\x04 \x01(\x08\x12\x14\n\x0cpacmod_fault\x18\x05 \x01(\x08\x12\x17\n\x0foverride_active\x18\x06 \x01(\x08\x12\x1d\n\x15output_reported_fault\x18\x07 \x01(\x08\x12\x1a\n\x12input_output_fault\x18\x08 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\t \x01(\x08\x12\x1c\n\x14\x63ommand_output_fault\x18\n \x01(\x08\"\xbf\x02\n\x10Output_valueType\x12#\n\x1fOUTPUT_VALUE_MEDIA_CONTROL_NONE\x10\x00\x12,\n(OUTPUT_VALUE_MEDIA_CONTROL_VOICE_COMMAND\x10\x01\x12#\n\x1fOUTPUT_VALUE_MEDIA_CONTROL_MUTE\x10\x02\x12\x30\n,OUTPUT_VALUE_MEDIA_CONTROL_PREV_TRACK_ANSWER\x10\x03\x12\x31\n-OUTPUT_VALUE_MEDIA_CONTROL_NEXT_TRACK_HANG_UP\x10\x04\x12%\n!OUTPUT_VALUE_MEDIA_CONTROL_VOL_UP\x10\x05\x12\'\n#OUTPUT_VALUE_MEDIA_CONTROL_VOL_DOWN\x10\x06\"\xd7\x02\n\x13\x43ommanded_valueType\x12&\n\"COMMANDED_VALUE_MEDIA_CONTROL_NONE\x10\x00\x12/\n+COMMANDED_VALUE_MEDIA_CONTROL_VOICE_COMMAND\x10\x01\x12&\n\"COMMANDED_VALUE_MEDIA_CONTROL_MUTE\x10\x02\x12\x33\n/COMMANDED_VALUE_MEDIA_CONTROL_PREV_TRACK_ANSWER\x10\x03\x12\x34\n0COMMANDED_VALUE_MEDIA_CONTROL_NEXT_TRACK_HANG_UP\x10\x04\x12(\n$COMMANDED_VALUE_MEDIA_CONTROL_VOL_UP\x10\x05\x12*\n&COMMANDED_VALUE_MEDIA_CONTROL_VOL_DOWN\x10\x06\"\xbf\x02\n\x10Manual_inputType\x12#\n\x1fMANUAL_INPUT_MEDIA_CONTROL_NONE\x10\x00\x12,\n(MANUAL_INPUT_MEDIA_CONTROL_VOICE_COMMAND\x10\x01\x12#\n\x1fMANUAL_INPUT_MEDIA_CONTROL_MUTE\x10\x02\x12\x30\n,MANUAL_INPUT_MEDIA_CONTROL_PREV_TRACK_ANSWER\x10\x03\x12\x31\n-MANUAL_INPUT_MEDIA_CONTROL_NEXT_TRACK_HANG_UP\x10\x04\x12%\n!MANUAL_INPUT_MEDIA_CONTROL_VOL_UP\x10\x05\x12\'\n#MANUAL_INPUT_MEDIA_CONTROL_VOL_DOWN\x10\x06\"\xf0\x01\n\x14Steering_aux_rpt_32c\x12!\n\x19user_interaction_is_valid\x18\x01 \x01(\x08\x12\x18\n\x10user_interaction\x18\x02 \x01(\x08\x12\x1e\n\x16rotation_rate_is_valid\x18\x03 \x01(\x08\x12\x15\n\rrotation_rate\x18\x04 \x01(\x01\x12\x1b\n\x13raw_torque_is_valid\x18\x05 \x01(\x08\x12\x12\n\nraw_torque\x18\x06 \x01(\x01\x12\x1d\n\x15raw_position_is_valid\x18\x07 \x01(\x08\x12\x14\n\x0craw_position\x18\x08 \x01(\x01\"\xc9\x01\n\x17Lat_lon_heading_rpt_40e\x12\x0f\n\x07heading\x18\x01 \x01(\x01\x12\x19\n\x11longitude_seconds\x18\x02 \x01(\x05\x12\x19\n\x11longitude_minutes\x18\x03 \x01(\x05\x12\x19\n\x11longitude_degrees\x18\x04 \x01(\x05\x12\x18\n\x10latitude_seconds\x18\x05 \x01(\x05\x12\x18\n\x10latitude_minutes\x18\x06 \x01(\x05\x12\x18\n\x10latitude_degrees\x18\x07 \x01(\x05\"$\n\x10Yaw_rate_rpt_40d\x12\x10\n\x08yaw_rate\x18\x01 \x01(\x01\"\x89\x01\n\x11\x44\x61te_time_rpt_40f\x12\x13\n\x0btime_second\x18\x01 \x01(\x05\x12\x13\n\x0btime_minute\x18\x02 \x01(\x05\x12\x11\n\ttime_hour\x18\x03 \x01(\x05\x12\x10\n\x08\x64\x61te_day\x18\x04 \x01(\x05\x12\x12\n\ndate_month\x18\x05 \x01(\x05\x12\x11\n\tdate_year\x18\x06 \x01(\x05\"L\n\x0bVin_rpt_414\x12\x12\n\nveh_serial\x18\x01 \x01(\x05\x12\x13\n\x0bveh_my_code\x18\x02 \x01(\x05\x12\x14\n\x0cveh_mfg_code\x18\x03 \x01(\x05\"\xb3\x03\n\x11Occupancy_rpt_415\x12&\n\x1erear_seatbelt_buckled_is_valid\x18\x01 \x01(\x08\x12&\n\x1epass_seatbelt_buckled_is_valid\x18\x02 \x01(\x08\x12(\n driver_seatbelt_buckled_is_valid\x18\x03 \x01(\x08\x12#\n\x1brear_seat_occupied_is_valid\x18\x04 \x01(\x08\x12#\n\x1bpass_seat_occupied_is_valid\x18\x05 \x01(\x08\x12%\n\x1d\x64river_seat_occupied_is_valid\x18\x06 \x01(\x08\x12\x1d\n\x15rear_seatbelt_buckled\x18\x07 \x01(\x08\x12\x1d\n\x15pass_seatbelt_buckled\x18\x08 \x01(\x08\x12\x1f\n\x17\x64river_seatbelt_buckled\x18\t \x01(\x08\x12\x1a\n\x12rear_seat_occupied\x18\n \x01(\x08\x12\x1a\n\x12pass_seat_occupied\x18\x0b \x01(\x08\x12\x1c\n\x14\x64river_seat_occupied\x18\x0c \x01(\x08\"\xb6\x05\n\x17Interior_lights_rpt_416\x12\x1a\n\x12\x64im_level_is_valid\x18\x01 \x01(\x08\x12\x1f\n\x17mood_lights_on_is_valid\x18\x02 \x01(\x08\x12$\n\x1crear_dome_lights_on_is_valid\x18\x03 \x01(\x08\x12%\n\x1d\x66ront_dome_lights_on_is_valid\x18\x04 \x01(\x08\x12G\n\tdim_level\x18\x05 \x01(\x0e\x32\x34.apollo.canbus.Interior_lights_rpt_416.Dim_levelType\x12\x16\n\x0emood_lights_on\x18\x06 \x01(\x08\x12\x1b\n\x13rear_dome_lights_on\x18\x07 \x01(\x08\x12\x1c\n\x14\x66ront_dome_lights_on\x18\x08 \x01(\x08\"\xf4\x02\n\rDim_levelType\x12\x1b\n\x17\x44IM_LEVEL_DIM_LEVEL_MIN\x10\x00\x12\x19\n\x15\x44IM_LEVEL_DIM_LEVEL_1\x10\x01\x12\x19\n\x15\x44IM_LEVEL_DIM_LEVEL_2\x10\x02\x12\x19\n\x15\x44IM_LEVEL_DIM_LEVEL_3\x10\x03\x12\x19\n\x15\x44IM_LEVEL_DIM_LEVEL_4\x10\x04\x12\x19\n\x15\x44IM_LEVEL_DIM_LEVEL_5\x10\x05\x12\x19\n\x15\x44IM_LEVEL_DIM_LEVEL_6\x10\x06\x12\x19\n\x15\x44IM_LEVEL_DIM_LEVEL_7\x10\x07\x12\x19\n\x15\x44IM_LEVEL_DIM_LEVEL_8\x10\x08\x12\x19\n\x15\x44IM_LEVEL_DIM_LEVEL_9\x10\t\x12\x1a\n\x16\x44IM_LEVEL_DIM_LEVEL_10\x10\n\x12\x1a\n\x16\x44IM_LEVEL_DIM_LEVEL_11\x10\x0b\x12\x1b\n\x17\x44IM_LEVEL_DIM_LEVEL_MAX\x10\x0c\"\xb3\x02\n\x0cTurn_cmd_130\x12\x18\n\x10ignore_overrides\x18\x01 \x01(\x08\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lear_override\x18\x03 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x04 \x01(\x08\x12H\n\x0fturn_signal_cmd\x18\x05 \x01(\x0e\x32/.apollo.canbus.Turn_cmd_130.Turn_signal_cmdType\"\x80\x01\n\x13Turn_signal_cmdType\x12\x19\n\x15TURN_SIGNAL_CMD_RIGHT\x10\x00\x12\x18\n\x14TURN_SIGNAL_CMD_NONE\x10\x01\x12\x18\n\x14TURN_SIGNAL_CMD_LEFT\x10\x02\x12\x1a\n\x16TURN_SIGNAL_CMD_HAZARD\x10\x03\"h\n\x17\x44\x65tected_object_rpt_411\x12&\n\x1e\x66ront_object_distance_high_res\x18\x01 \x01(\x01\x12%\n\x1d\x66ront_object_distance_low_res\x18\x02 \x01(\x01\"B\n\x16Veh_specific_rpt_1_412\x12\x13\n\x0bshift_pos_2\x18\x01 \x01(\x05\x12\x13\n\x0bshift_pos_1\x18\x02 \x01(\x05\",\n\x14Veh_dynamics_rpt_413\x12\x14\n\x0cveh_g_forces\x18\x01 \x01(\x01\"\x8f\x01\n\x13Rear_lights_rpt_418\x12\"\n\x1areverse_lights_on_is_valid\x18\x01 \x01(\x08\x12 \n\x18\x62rake_lights_on_is_valid\x18\x02 \x01(\x08\x12\x19\n\x11reverse_lights_on\x18\x03 \x01(\x08\x12\x17\n\x0f\x62rake_lights_on\x18\x04 \x01(\x08\"\x97\x1c\n\x05Lexus\x12\x43\n\x15hazard_lights_rpt_214\x18\x01 \x01(\x0b\x32$.apollo.canbus.Hazard_lights_rpt_214\x12\x39\n\x10steering_cmd_12c\x18\x02 \x01(\x0b\x32\x1f.apollo.canbus.Steering_cmd_12c\x12O\n\x1b\x64\x61sh_controls_right_rpt_210\x18\x03 \x01(\x0b\x32*.apollo.canbus.Dash_controls_right_rpt_210\x12M\n\x1a\x64\x61sh_controls_left_cmd_10c\x18\x04 \x01(\x0b\x32).apollo.canbus.Dash_controls_left_cmd_10c\x12\x39\n\x10steering_rpt_22c\x18\x05 \x01(\x0b\x32\x1f.apollo.canbus.Steering_rpt_22c\x12\x39\n\x10turn_aux_rpt_330\x18\x06 \x01(\x0b\x32\x1f.apollo.canbus.Turn_aux_rpt_330\x12;\n\x11headlight_rpt_218\x18\x07 \x01(\x0b\x32 .apollo.canbus.Headlight_rpt_218\x12\x43\n\x15hazard_lights_cmd_114\x18\x08 \x01(\x0b\x32$.apollo.canbus.Hazard_lights_cmd_114\x12M\n\x1a\x64\x61sh_controls_left_rpt_20c\x18\t \x01(\x0b\x32).apollo.canbus.Dash_controls_left_rpt_20c\x12\x43\n\x15headlight_aux_rpt_318\x18\n \x01(\x0b\x32$.apollo.canbus.Headlight_aux_rpt_318\x12O\n\x1b\x64\x61sh_controls_right_cmd_110\x18\x0b \x01(\x0b\x32*.apollo.canbus.Dash_controls_right_cmd_110\x12\x33\n\rwiper_cmd_134\x18\x0c \x01(\x0b\x32\x1c.apollo.canbus.Wiper_cmd_134\x12\x33\n\rwiper_rpt_234\x18\r \x01(\x0b\x32\x1c.apollo.canbus.Wiper_rpt_234\x12\x31\n\x0cturn_rpt_230\x18\x0e \x01(\x0b\x32\x1b.apollo.canbus.Turn_rpt_230\x12;\n\x11headlight_cmd_118\x18\x0f \x01(\x0b\x32 .apollo.canbus.Headlight_cmd_118\x12\x31\n\x0c\x64oor_rpt_417\x18\x10 \x01(\x0b\x32\x1b.apollo.canbus.Door_rpt_417\x12\x39\n\x10\x63omponent_rpt_20\x18\x11 \x01(\x0b\x32\x1f.apollo.canbus.Component_rpt_20\x12?\n\x13wheel_speed_rpt_407\x18\x12 \x01(\x0b\x32\".apollo.canbus.Wheel_speed_rpt_407\x12I\n\x18steering_motor_rpt_3_406\x18\x13 \x01(\x0b\x32\'.apollo.canbus.Steering_motor_rpt_3_406\x12I\n\x18steering_motor_rpt_2_405\x18\x14 \x01(\x0b\x32\'.apollo.canbus.Steering_motor_rpt_2_405\x12I\n\x18steering_motor_rpt_1_404\x18\x15 \x01(\x0b\x32\'.apollo.canbus.Steering_motor_rpt_1_404\x12\x43\n\x15\x62rake_motor_rpt_3_403\x18\x16 \x01(\x0b\x32$.apollo.canbus.Brake_motor_rpt_3_403\x12\x43\n\x15\x62rake_motor_rpt_2_402\x18\x17 \x01(\x0b\x32$.apollo.canbus.Brake_motor_rpt_2_402\x12\x43\n\x15\x62rake_motor_rpt_1_401\x18\x18 \x01(\x0b\x32$.apollo.canbus.Brake_motor_rpt_1_401\x12;\n\x11wiper_aux_rpt_334\x18\x19 \x01(\x0b\x32 .apollo.canbus.Wiper_aux_rpt_334\x12;\n\x11shift_aux_rpt_328\x18\x1a \x01(\x0b\x32 .apollo.canbus.Shift_aux_rpt_328\x12\x33\n\raccel_rpt_200\x18\x1b \x01(\x0b\x32\x1c.apollo.canbus.Accel_rpt_200\x12\x33\n\rbrake_rpt_204\x18\x1c \x01(\x0b\x32\x1c.apollo.canbus.Brake_rpt_204\x12\x31\n\x0chorn_cmd_11c\x18\x1d \x01(\x0b\x32\x1b.apollo.canbus.Horn_cmd_11c\x12\x33\n\rglobal_rpt_10\x18\x1e \x01(\x0b\x32\x1c.apollo.canbus.Global_rpt_10\x12;\n\x11\x61\x63\x63\x65l_aux_rpt_300\x18\x1f \x01(\x0b\x32 .apollo.canbus.Accel_aux_rpt_300\x12U\n\x1e\x63ruise_control_buttons_rpt_208\x18  \x01(\x0b\x32-.apollo.canbus.Cruise_control_buttons_rpt_208\x12\x43\n\x15vehicle_speed_rpt_400\x18! \x01(\x0b\x32$.apollo.canbus.Vehicle_speed_rpt_400\x12;\n\x11\x62rake_aux_rpt_304\x18\" \x01(\x0b\x32 .apollo.canbus.Brake_aux_rpt_304\x12\x45\n\x16media_controls_cmd_120\x18# \x01(\x0b\x32%.apollo.canbus.Media_controls_cmd_120\x12U\n\x1e\x63ruise_control_buttons_cmd_108\x18$ \x01(\x0b\x32-.apollo.canbus.Cruise_control_buttons_cmd_108\x12\x43\n\x15parking_brake_cmd_124\x18% \x01(\x0b\x32$.apollo.canbus.Parking_brake_cmd_124\x12\x31\n\x0chorn_rpt_21c\x18& \x01(\x0b\x32\x1b.apollo.canbus.Horn_rpt_21c\x12\x33\n\rshift_rpt_228\x18\' \x01(\x0b\x32\x1c.apollo.canbus.Shift_rpt_228\x12\x33\n\rshift_cmd_128\x18( \x01(\x0b\x32\x1c.apollo.canbus.Shift_cmd_128\x12\x33\n\raccel_cmd_100\x18) \x01(\x0b\x32\x1c.apollo.canbus.Accel_cmd_100\x12\x43\n\x15parking_brake_rpt_224\x18* \x01(\x0b\x32$.apollo.canbus.Parking_brake_rpt_224\x12\x33\n\rbrake_cmd_104\x18+ \x01(\x0b\x32\x1c.apollo.canbus.Brake_cmd_104\x12\x45\n\x16media_controls_rpt_220\x18, \x01(\x0b\x32%.apollo.canbus.Media_controls_rpt_220\x12\x41\n\x14steering_aux_rpt_32c\x18- \x01(\x0b\x32#.apollo.canbus.Steering_aux_rpt_32c\x12G\n\x17lat_lon_heading_rpt_40e\x18. \x01(\x0b\x32&.apollo.canbus.Lat_lon_heading_rpt_40e\x12\x39\n\x10yaw_rate_rpt_40d\x18/ \x01(\x0b\x32\x1f.apollo.canbus.Yaw_rate_rpt_40d\x12;\n\x11\x64\x61te_time_rpt_40f\x18\x30 \x01(\x0b\x32 .apollo.canbus.Date_time_rpt_40f\x12/\n\x0bvin_rpt_414\x18\x31 \x01(\x0b\x32\x1a.apollo.canbus.Vin_rpt_414\x12;\n\x11occupancy_rpt_415\x18\x32 \x01(\x0b\x32 .apollo.canbus.Occupancy_rpt_415\x12G\n\x17interior_lights_rpt_416\x18\x33 \x01(\x0b\x32&.apollo.canbus.Interior_lights_rpt_416\x12\x31\n\x0cturn_cmd_130\x18\x34 \x01(\x0b\x32\x1b.apollo.canbus.Turn_cmd_130\x12G\n\x17\x64\x65tected_object_rpt_411\x18\x35 \x01(\x0b\x32&.apollo.canbus.Detected_object_rpt_411\x12\x45\n\x16veh_specific_rpt_1_412\x18\x36 \x01(\x0b\x32%.apollo.canbus.Veh_specific_rpt_1_412\x12\x41\n\x14veh_dynamics_rpt_413\x18\x37 \x01(\x0b\x32#.apollo.canbus.Veh_dynamics_rpt_413\x12?\n\x13rear_lights_rpt_418\x18\x38 \x01(\x0b\x32\".apollo.canbus.Rear_lights_rpt_418'
)



_DASH_CONTROLS_RIGHT_RPT_210_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Dash_controls_right_rpt_210.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_DASH_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_DASH_CONTROL_OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_DASH_CONTROL_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_DASH_CONTROL_RIGHT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_DASH_CONTROL_UP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_DASH_CONTROL_DOWN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=936,
  serialized_end=1167,
)
_sym_db.RegisterEnumDescriptor(_DASH_CONTROLS_RIGHT_RPT_210_OUTPUT_VALUETYPE)

_DASH_CONTROLS_RIGHT_RPT_210_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Dash_controls_right_rpt_210.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_DASH_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_DASH_CONTROL_OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_DASH_CONTROL_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_DASH_CONTROL_RIGHT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_DASH_CONTROL_UP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_DASH_CONTROL_DOWN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1170,
  serialized_end=1422,
)
_sym_db.RegisterEnumDescriptor(_DASH_CONTROLS_RIGHT_RPT_210_COMMANDED_VALUETYPE)

_DASH_CONTROLS_RIGHT_RPT_210_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Dash_controls_right_rpt_210.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_DASH_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_DASH_CONTROL_OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_DASH_CONTROL_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_DASH_CONTROL_RIGHT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_DASH_CONTROL_UP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_DASH_CONTROL_DOWN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1425,
  serialized_end=1656,
)
_sym_db.RegisterEnumDescriptor(_DASH_CONTROLS_RIGHT_RPT_210_MANUAL_INPUTTYPE)

_DASH_CONTROLS_LEFT_CMD_10C_DASH_CONTROLS_BUTTONTYPE = _descriptor.EnumDescriptor(
  name='Dash_controls_buttonType',
  full_name='apollo.canbus.Dash_controls_left_cmd_10c.Dash_controls_buttonType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DASH_CONTROLS_BUTTON_DASH_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DASH_CONTROLS_BUTTON_DASH_CONTROL_OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DASH_CONTROLS_BUTTON_DASH_CONTROL_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DASH_CONTROLS_BUTTON_DASH_CONTROL_RIGHT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DASH_CONTROLS_BUTTON_DASH_CONTROL_UP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DASH_CONTROLS_BUTTON_DASH_CONTROL_DOWN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1876,
  serialized_end=2163,
)
_sym_db.RegisterEnumDescriptor(_DASH_CONTROLS_LEFT_CMD_10C_DASH_CONTROLS_BUTTONTYPE)

_HEADLIGHT_RPT_218_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Headlight_rpt_218.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_HEADLIGHTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_LOW_BEAMS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_HIGH_BEAMS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3017,
  serialized_end=3125,
)
_sym_db.RegisterEnumDescriptor(_HEADLIGHT_RPT_218_OUTPUT_VALUETYPE)

_HEADLIGHT_RPT_218_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Headlight_rpt_218.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_HEADLIGHTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_LOW_BEAMS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_HIGH_BEAMS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3127,
  serialized_end=3235,
)
_sym_db.RegisterEnumDescriptor(_HEADLIGHT_RPT_218_MANUAL_INPUTTYPE)

_HEADLIGHT_RPT_218_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Headlight_rpt_218.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_HEADLIGHTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_LOW_BEAMS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_HIGH_BEAMS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3237,
  serialized_end=3357,
)
_sym_db.RegisterEnumDescriptor(_HEADLIGHT_RPT_218_COMMANDED_VALUETYPE)

_DASH_CONTROLS_LEFT_RPT_20C_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Dash_controls_left_rpt_20c.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_DASH_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_DASH_CONTROL_OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_DASH_CONTROL_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_DASH_CONTROL_RIGHT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_DASH_CONTROL_UP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_DASH_CONTROL_DOWN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=936,
  serialized_end=1167,
)
_sym_db.RegisterEnumDescriptor(_DASH_CONTROLS_LEFT_RPT_20C_OUTPUT_VALUETYPE)

_DASH_CONTROLS_LEFT_RPT_20C_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Dash_controls_left_rpt_20c.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_DASH_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_DASH_CONTROL_OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_DASH_CONTROL_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_DASH_CONTROL_RIGHT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_DASH_CONTROL_UP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_DASH_CONTROL_DOWN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1170,
  serialized_end=1422,
)
_sym_db.RegisterEnumDescriptor(_DASH_CONTROLS_LEFT_RPT_20C_COMMANDED_VALUETYPE)

_DASH_CONTROLS_LEFT_RPT_20C_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Dash_controls_left_rpt_20c.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_DASH_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_DASH_CONTROL_OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_DASH_CONTROL_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_DASH_CONTROL_RIGHT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_DASH_CONTROL_UP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_DASH_CONTROL_DOWN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1425,
  serialized_end=1656,
)
_sym_db.RegisterEnumDescriptor(_DASH_CONTROLS_LEFT_RPT_20C_MANUAL_INPUTTYPE)

_HEADLIGHT_AUX_RPT_318_HEADLIGHTS_MODETYPE = _descriptor.EnumDescriptor(
  name='Headlights_modeType',
  full_name='apollo.canbus.Headlight_aux_rpt_318.Headlights_modeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HEADLIGHTS_MODE_HEADLIGHTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEADLIGHTS_MODE_PARKING_LIGHTS_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEADLIGHTS_MODE_HEADLIGHTS_ON_MANUAL_MODE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEADLIGHTS_MODE_HEADLIGHTS_ON_AUTO_MODE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5005,
  serialized_end=5195,
)
_sym_db.RegisterEnumDescriptor(_HEADLIGHT_AUX_RPT_318_HEADLIGHTS_MODETYPE)

_DASH_CONTROLS_RIGHT_CMD_110_DASH_CONTROLS_BUTTONTYPE = _descriptor.EnumDescriptor(
  name='Dash_controls_buttonType',
  full_name='apollo.canbus.Dash_controls_right_cmd_110.Dash_controls_buttonType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DASH_CONTROLS_BUTTON_DASH_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DASH_CONTROLS_BUTTON_DASH_CONTROL_OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DASH_CONTROLS_BUTTON_DASH_CONTROL_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DASH_CONTROLS_BUTTON_DASH_CONTROL_RIGHT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DASH_CONTROLS_BUTTON_DASH_CONTROL_UP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DASH_CONTROLS_BUTTON_DASH_CONTROL_DOWN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1876,
  serialized_end=2163,
)
_sym_db.RegisterEnumDescriptor(_DASH_CONTROLS_RIGHT_CMD_110_DASH_CONTROLS_BUTTONTYPE)

_WIPER_CMD_134_WIPER_CMDTYPE = _descriptor.EnumDescriptor(
  name='Wiper_cmdType',
  full_name='apollo.canbus.Wiper_cmd_134.Wiper_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_WIPERS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_INTERMITTENT_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_INTERMITTENT_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_INTERMITTENT_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_INTERMITTENT_4', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_INTERMITTENT_5', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_LOW', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_HIGH', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5876,
  serialized_end=6106,
)
_sym_db.RegisterEnumDescriptor(_WIPER_CMD_134_WIPER_CMDTYPE)

_WIPER_RPT_234_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Wiper_rpt_234.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_WIPERS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_INTERMITTENT_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_INTERMITTENT_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_INTERMITTENT_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_INTERMITTENT_4', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_INTERMITTENT_5', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_LOW', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_HIGH', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6516,
  serialized_end=6773,
)
_sym_db.RegisterEnumDescriptor(_WIPER_RPT_234_OUTPUT_VALUETYPE)

_WIPER_RPT_234_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Wiper_rpt_234.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_WIPERS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_INTERMITTENT_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_INTERMITTENT_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_INTERMITTENT_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_INTERMITTENT_4', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_INTERMITTENT_5', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_LOW', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_HIGH', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6776,
  serialized_end=7060,
)
_sym_db.RegisterEnumDescriptor(_WIPER_RPT_234_COMMANDED_VALUETYPE)

_WIPER_RPT_234_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Wiper_rpt_234.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_WIPERS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_INTERMITTENT_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_INTERMITTENT_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_INTERMITTENT_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_INTERMITTENT_4', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_INTERMITTENT_5', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_LOW', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_HIGH', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7063,
  serialized_end=7320,
)
_sym_db.RegisterEnumDescriptor(_WIPER_RPT_234_MANUAL_INPUTTYPE)

_TURN_RPT_230_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Turn_rpt_230.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_RIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_HAZARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7725,
  serialized_end=7838,
)
_sym_db.RegisterEnumDescriptor(_TURN_RPT_230_MANUAL_INPUTTYPE)

_TURN_RPT_230_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Turn_rpt_230.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_RIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_HAZARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7841,
  serialized_end=7969,
)
_sym_db.RegisterEnumDescriptor(_TURN_RPT_230_COMMANDED_VALUETYPE)

_TURN_RPT_230_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Turn_rpt_230.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_RIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_HAZARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7971,
  serialized_end=8084,
)
_sym_db.RegisterEnumDescriptor(_TURN_RPT_230_OUTPUT_VALUETYPE)

_HEADLIGHT_CMD_118_HEADLIGHT_CMDTYPE = _descriptor.EnumDescriptor(
  name='Headlight_cmdType',
  full_name='apollo.canbus.Headlight_cmd_118.Headlight_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HEADLIGHT_CMD_HEADLIGHTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEADLIGHT_CMD_LOW_BEAMS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEADLIGHT_CMD_HIGH_BEAMS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8271,
  serialized_end=8383,
)
_sym_db.RegisterEnumDescriptor(_HEADLIGHT_CMD_118_HEADLIGHT_CMDTYPE)

_COMPONENT_RPT_20_COMPONENT_TYPETYPE = _descriptor.EnumDescriptor(
  name='Component_typeType',
  full_name='apollo.canbus.Component_rpt_20.Component_typeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPONENT_TYPE_PACMOD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPONENT_TYPE_PACMINI', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPONENT_TYPE_PACMICRO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9043,
  serialized_end=9147,
)
_sym_db.RegisterEnumDescriptor(_COMPONENT_RPT_20_COMPONENT_TYPETYPE)

_COMPONENT_RPT_20_COMPONENT_FUNCTYPE = _descriptor.EnumDescriptor(
  name='Component_funcType',
  full_name='apollo.canbus.Component_rpt_20.Component_funcType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPONENT_FUNC_PACMOD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPONENT_FUNC_STEERING_AND_STEERING_COLUMN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPONENT_FUNC_ACCELERATOR_AND_BRAKING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPONENT_FUNC_BRAKING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPONENT_FUNC_SHIFTING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPONENT_FUNC_STEERING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPONENT_FUNC_E_SHIFTER', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPONENT_FUNC_WATCHDOG', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9150,
  serialized_end=9435,
)
_sym_db.RegisterEnumDescriptor(_COMPONENT_RPT_20_COMPONENT_FUNCTYPE)

_HORN_CMD_11C_HORN_CMDTYPE = _descriptor.EnumDescriptor(
  name='Horn_cmdType',
  full_name='apollo.canbus.Horn_cmd_11c.Horn_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HORN_CMD_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HORN_CMD_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11415,
  serialized_end=11464,
)
_sym_db.RegisterEnumDescriptor(_HORN_CMD_11C_HORN_CMDTYPE)

_GLOBAL_RPT_10_PACMOD_SYSTEM_ENABLEDTYPE = _descriptor.EnumDescriptor(
  name='Pacmod_system_enabledType',
  full_name='apollo.canbus.Global_rpt_10.Pacmod_system_enabledType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PACMOD_SYSTEM_ENABLED_CONTROL_DISABLED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PACMOD_SYSTEM_ENABLED_CONTROL_ENABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11952,
  serialized_end=12066,
)
_sym_db.RegisterEnumDescriptor(_GLOBAL_RPT_10_PACMOD_SYSTEM_ENABLEDTYPE)

_GLOBAL_RPT_10_PACMOD_SYSTEM_OVERRIDE_ACTIVETYPE = _descriptor.EnumDescriptor(
  name='Pacmod_system_override_activeType',
  full_name='apollo.canbus.Global_rpt_10.Pacmod_system_override_activeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PACMOD_SYSTEM_OVERRIDE_ACTIVE_NOT_OVERRIDDEN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PACMOD_SYSTEM_OVERRIDE_ACTIVE_OVERRIDDEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12069,
  serialized_end=12200,
)
_sym_db.RegisterEnumDescriptor(_GLOBAL_RPT_10_PACMOD_SYSTEM_OVERRIDE_ACTIVETYPE)

_GLOBAL_RPT_10_BRK_CAN_TIMEOUTTYPE = _descriptor.EnumDescriptor(
  name='Brk_can_timeoutType',
  full_name='apollo.canbus.Global_rpt_10.Brk_can_timeoutType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRK_CAN_TIMEOUT_NO_ACTIVE_CAN_TIMEOUT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRK_CAN_TIMEOUT_ACTIVE_CAN_TIMEOUT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12202,
  serialized_end=12306,
)
_sym_db.RegisterEnumDescriptor(_GLOBAL_RPT_10_BRK_CAN_TIMEOUTTYPE)

_CRUISE_CONTROL_BUTTONS_RPT_208_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Cruise_control_buttons_rpt_208.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_CRUISE_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_CRUISE_CONTROL_CNCL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_CRUISE_CONTROL_ACC_FURTHER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_CRUISE_CONTROL_ACC_CLOSER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_CRUISE_CONTROL_SET_DEC', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_CRUISE_CONTROL_RES_INC', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_CRUISE_CONTROL_ON_OFF', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12981,
  serialized_end=13286,
)
_sym_db.RegisterEnumDescriptor(_CRUISE_CONTROL_BUTTONS_RPT_208_OUTPUT_VALUETYPE)

_CRUISE_CONTROL_BUTTONS_RPT_208_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Cruise_control_buttons_rpt_208.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_CRUISE_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_CRUISE_CONTROL_CNCL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_CRUISE_CONTROL_ACC_FURTHER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_CRUISE_CONTROL_ACC_CLOSER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_CRUISE_CONTROL_SET_DEC', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_CRUISE_CONTROL_RES_INC', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_CRUISE_CONTROL_ON_OFF', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13289,
  serialized_end=13594,
)
_sym_db.RegisterEnumDescriptor(_CRUISE_CONTROL_BUTTONS_RPT_208_MANUAL_INPUTTYPE)

_CRUISE_CONTROL_BUTTONS_RPT_208_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Cruise_control_buttons_rpt_208.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_CRUISE_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_CRUISE_CONTROL_CNCL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_CRUISE_CONTROL_ACC_FURTHER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_CRUISE_CONTROL_ACC_CLOSER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_CRUISE_CONTROL_SET_DEC', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_CRUISE_CONTROL_RES_INC', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_CRUISE_CONTROL_ON_OFF', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13597,
  serialized_end=13926,
)
_sym_db.RegisterEnumDescriptor(_CRUISE_CONTROL_BUTTONS_RPT_208_COMMANDED_VALUETYPE)

_VEHICLE_SPEED_RPT_400_VEHICLE_SPEED_VALIDTYPE = _descriptor.EnumDescriptor(
  name='Vehicle_speed_validType',
  full_name='apollo.canbus.Vehicle_speed_rpt_400.Vehicle_speed_validType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VEHICLE_SPEED_VALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEHICLE_SPEED_VALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14068,
  serialized_end=14157,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE_SPEED_RPT_400_VEHICLE_SPEED_VALIDTYPE)

_MEDIA_CONTROLS_CMD_120_MEDIA_CONTROLS_CMDTYPE = _descriptor.EnumDescriptor(
  name='Media_controls_cmdType',
  full_name='apollo.canbus.Media_controls_cmd_120.Media_controls_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MEDIA_CONTROLS_CMD_MEDIA_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDIA_CONTROLS_CMD_MEDIA_CONTROL_VOICE_COMMAND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDIA_CONTROLS_CMD_MEDIA_CONTROL_MUTE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDIA_CONTROLS_CMD_MEDIA_CONTROL_PREV_TRACK_ANSWER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDIA_CONTROLS_CMD_MEDIA_CONTROL_NEXT_TRACK_HANG_UP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDIA_CONTROLS_CMD_MEDIA_CONTROL_VOL_UP', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDIA_CONTROLS_CMD_MEDIA_CONTROL_VOL_DOWN', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14680,
  serialized_end=15047,
)
_sym_db.RegisterEnumDescriptor(_MEDIA_CONTROLS_CMD_120_MEDIA_CONTROLS_CMDTYPE)

_CRUISE_CONTROL_BUTTONS_CMD_108_CRUISE_CONTROL_BUTTONTYPE = _descriptor.EnumDescriptor(
  name='Cruise_control_buttonType',
  full_name='apollo.canbus.Cruise_control_buttons_cmd_108.Cruise_control_buttonType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_CNCL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_ACC_FURTHER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_ACC_CLOSER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_SET_DEC', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_RES_INC', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUISE_CONTROL_BUTTON_CRUISE_CONTROL_ON_OFF', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15277,
  serialized_end=15654,
)
_sym_db.RegisterEnumDescriptor(_CRUISE_CONTROL_BUTTONS_CMD_108_CRUISE_CONTROL_BUTTONTYPE)

_HORN_RPT_21C_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Horn_rpt_21c.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16200,
  serialized_end=16261,
)
_sym_db.RegisterEnumDescriptor(_HORN_RPT_21C_OUTPUT_VALUETYPE)

_HORN_RPT_21C_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Horn_rpt_21c.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16263,
  serialized_end=16333,
)
_sym_db.RegisterEnumDescriptor(_HORN_RPT_21C_COMMANDED_VALUETYPE)

_HORN_RPT_21C_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Horn_rpt_21c.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16335,
  serialized_end=16396,
)
_sym_db.RegisterEnumDescriptor(_HORN_RPT_21C_MANUAL_INPUTTYPE)

_SHIFT_RPT_228_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Shift_rpt_228.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_PARK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_REVERSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_NEUTRAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_FORWARD_HIGH', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_LOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_BETWEEN_GEARS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_ERROR', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_NONE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16806,
  serialized_end=17031,
)
_sym_db.RegisterEnumDescriptor(_SHIFT_RPT_228_MANUAL_INPUTTYPE)

_SHIFT_RPT_228_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Shift_rpt_228.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_PARK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_REVERSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_NEUTRAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_FORWARD_HIGH', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_LOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_NONE', index=5, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17034,
  serialized_end=17224,
)
_sym_db.RegisterEnumDescriptor(_SHIFT_RPT_228_COMMANDED_VALUETYPE)

_SHIFT_RPT_228_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Shift_rpt_228.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_PARK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_REVERSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_NEUTRAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_FORWARD_HIGH', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_LOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_BETWEEN_GEARS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_ERROR', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_NONE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17227,
  serialized_end=17452,
)
_sym_db.RegisterEnumDescriptor(_SHIFT_RPT_228_OUTPUT_VALUETYPE)

_SHIFT_CMD_128_SHIFT_CMDTYPE = _descriptor.EnumDescriptor(
  name='Shift_cmdType',
  full_name='apollo.canbus.Shift_cmd_128.Shift_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHIFT_CMD_PARK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFT_CMD_REVERSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFT_CMD_NEUTRAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFT_CMD_FORWARD_HIGH', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFT_CMD_LOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFT_CMD_NONE', index=5, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17624,
  serialized_end=17772,
)
_sym_db.RegisterEnumDescriptor(_SHIFT_CMD_128_SHIFT_CMDTYPE)

_MEDIA_CONTROLS_RPT_220_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Media_controls_rpt_220.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_MEDIA_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_MEDIA_CONTROL_VOICE_COMMAND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_MEDIA_CONTROL_MUTE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_MEDIA_CONTROL_PREV_TRACK_ANSWER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_MEDIA_CONTROL_NEXT_TRACK_HANG_UP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_MEDIA_CONTROL_VOL_UP', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_MEDIA_CONTROL_VOL_DOWN', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=18737,
  serialized_end=19056,
)
_sym_db.RegisterEnumDescriptor(_MEDIA_CONTROLS_RPT_220_OUTPUT_VALUETYPE)

_MEDIA_CONTROLS_RPT_220_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Media_controls_rpt_220.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_MEDIA_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_MEDIA_CONTROL_VOICE_COMMAND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_MEDIA_CONTROL_MUTE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_MEDIA_CONTROL_PREV_TRACK_ANSWER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_MEDIA_CONTROL_NEXT_TRACK_HANG_UP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_MEDIA_CONTROL_VOL_UP', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_MEDIA_CONTROL_VOL_DOWN', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19059,
  serialized_end=19402,
)
_sym_db.RegisterEnumDescriptor(_MEDIA_CONTROLS_RPT_220_COMMANDED_VALUETYPE)

_MEDIA_CONTROLS_RPT_220_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Media_controls_rpt_220.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_MEDIA_CONTROL_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_MEDIA_CONTROL_VOICE_COMMAND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_MEDIA_CONTROL_MUTE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_MEDIA_CONTROL_PREV_TRACK_ANSWER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_MEDIA_CONTROL_NEXT_TRACK_HANG_UP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_MEDIA_CONTROL_VOL_UP', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_MEDIA_CONTROL_VOL_DOWN', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19405,
  serialized_end=19724,
)
_sym_db.RegisterEnumDescriptor(_MEDIA_CONTROLS_RPT_220_MANUAL_INPUTTYPE)

_INTERIOR_LIGHTS_RPT_416_DIM_LEVELTYPE = _descriptor.EnumDescriptor(
  name='Dim_levelType',
  full_name='apollo.canbus.Interior_lights_rpt_416.Dim_levelType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DIM_LEVEL_DIM_LEVEL_MIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIM_LEVEL_DIM_LEVEL_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIM_LEVEL_DIM_LEVEL_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIM_LEVEL_DIM_LEVEL_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIM_LEVEL_DIM_LEVEL_4', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIM_LEVEL_DIM_LEVEL_5', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIM_LEVEL_DIM_LEVEL_6', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIM_LEVEL_DIM_LEVEL_7', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIM_LEVEL_DIM_LEVEL_8', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIM_LEVEL_DIM_LEVEL_9', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIM_LEVEL_DIM_LEVEL_10', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIM_LEVEL_DIM_LEVEL_11', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIM_LEVEL_DIM_LEVEL_MAX', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21190,
  serialized_end=21562,
)
_sym_db.RegisterEnumDescriptor(_INTERIOR_LIGHTS_RPT_416_DIM_LEVELTYPE)

_TURN_CMD_130_TURN_SIGNAL_CMDTYPE = _descriptor.EnumDescriptor(
  name='Turn_signal_cmdType',
  full_name='apollo.canbus.Turn_cmd_130.Turn_signal_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_CMD_RIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_CMD_NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_CMD_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_CMD_HAZARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21744,
  serialized_end=21872,
)
_sym_db.RegisterEnumDescriptor(_TURN_CMD_130_TURN_SIGNAL_CMDTYPE)


_HAZARD_LIGHTS_RPT_214 = _descriptor.Descriptor(
  name='Hazard_lights_rpt_214',
  full_name='apollo.canbus.Hazard_lights_rpt_214',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Hazard_lights_rpt_214.output_value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Hazard_lights_rpt_214.commanded_value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Hazard_lights_rpt_214.manual_input', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Hazard_lights_rpt_214.vehicle_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Hazard_lights_rpt_214.pacmod_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Hazard_lights_rpt_214.override_active', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Hazard_lights_rpt_214.output_reported_fault', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Hazard_lights_rpt_214.input_output_fault', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Hazard_lights_rpt_214.enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Hazard_lights_rpt_214.command_output_fault', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=320,
)


_STEERING_CMD_12C = _descriptor.Descriptor(
  name='Steering_cmd_12c',
  full_name='apollo.canbus.Steering_cmd_12c',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Steering_cmd_12c.ignore_overrides', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Steering_cmd_12c.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Steering_cmd_12c.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Steering_cmd_12c.clear_faults', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.canbus.Steering_cmd_12c.position', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rotation_rate', full_name='apollo.canbus.Steering_cmd_12c.rotation_rate', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=470,
)


_DASH_CONTROLS_RIGHT_RPT_210 = _descriptor.Descriptor(
  name='Dash_controls_right_rpt_210',
  full_name='apollo.canbus.Dash_controls_right_rpt_210',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Dash_controls_right_rpt_210.output_value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Dash_controls_right_rpt_210.commanded_value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Dash_controls_right_rpt_210.vehicle_fault', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Dash_controls_right_rpt_210.pacmod_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Dash_controls_right_rpt_210.override_active', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Dash_controls_right_rpt_210.output_reported_fault', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Dash_controls_right_rpt_210.input_output_fault', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Dash_controls_right_rpt_210.enabled', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Dash_controls_right_rpt_210.command_output_fault', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Dash_controls_right_rpt_210.manual_input', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DASH_CONTROLS_RIGHT_RPT_210_OUTPUT_VALUETYPE,
    _DASH_CONTROLS_RIGHT_RPT_210_COMMANDED_VALUETYPE,
    _DASH_CONTROLS_RIGHT_RPT_210_MANUAL_INPUTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=1656,
)


_DASH_CONTROLS_LEFT_CMD_10C = _descriptor.Descriptor(
  name='Dash_controls_left_cmd_10c',
  full_name='apollo.canbus.Dash_controls_left_cmd_10c',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Dash_controls_left_cmd_10c.ignore_overrides', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Dash_controls_left_cmd_10c.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Dash_controls_left_cmd_10c.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Dash_controls_left_cmd_10c.clear_faults', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dash_controls_button', full_name='apollo.canbus.Dash_controls_left_cmd_10c.dash_controls_button', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DASH_CONTROLS_LEFT_CMD_10C_DASH_CONTROLS_BUTTONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1659,
  serialized_end=2163,
)


_STEERING_RPT_22C = _descriptor.Descriptor(
  name='Steering_rpt_22c',
  full_name='apollo.canbus.Steering_rpt_22c',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Steering_rpt_22c.vehicle_fault', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Steering_rpt_22c.pacmod_fault', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Steering_rpt_22c.override_active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Steering_rpt_22c.output_reported_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Steering_rpt_22c.input_output_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Steering_rpt_22c.enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Steering_rpt_22c.command_output_fault', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Steering_rpt_22c.manual_input', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Steering_rpt_22c.commanded_value', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Steering_rpt_22c.output_value', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2166,
  serialized_end=2429,
)


_TURN_AUX_RPT_330 = _descriptor.Descriptor(
  name='Turn_aux_rpt_330',
  full_name='apollo.canbus.Turn_aux_rpt_330',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pass_blinker_bulb_on_is_valid', full_name='apollo.canbus.Turn_aux_rpt_330.pass_blinker_bulb_on_is_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pass_blinker_bulb_on', full_name='apollo.canbus.Turn_aux_rpt_330.pass_blinker_bulb_on', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_blinker_bulb_on_is_valid', full_name='apollo.canbus.Turn_aux_rpt_330.driver_blinker_bulb_on_is_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_blinker_bulb_on', full_name='apollo.canbus.Turn_aux_rpt_330.driver_blinker_bulb_on', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2432,
  serialized_end=2592,
)


_HEADLIGHT_RPT_218 = _descriptor.Descriptor(
  name='Headlight_rpt_218',
  full_name='apollo.canbus.Headlight_rpt_218',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Headlight_rpt_218.vehicle_fault', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Headlight_rpt_218.pacmod_fault', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Headlight_rpt_218.override_active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Headlight_rpt_218.output_reported_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Headlight_rpt_218.input_output_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Headlight_rpt_218.enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Headlight_rpt_218.command_output_fault', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Headlight_rpt_218.output_value', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Headlight_rpt_218.manual_input', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Headlight_rpt_218.commanded_value', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HEADLIGHT_RPT_218_OUTPUT_VALUETYPE,
    _HEADLIGHT_RPT_218_MANUAL_INPUTTYPE,
    _HEADLIGHT_RPT_218_COMMANDED_VALUETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2595,
  serialized_end=3357,
)


_HAZARD_LIGHTS_CMD_114 = _descriptor.Descriptor(
  name='Hazard_lights_cmd_114',
  full_name='apollo.canbus.Hazard_lights_cmd_114',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hazard_lights_cmd', full_name='apollo.canbus.Hazard_lights_cmd_114.hazard_lights_cmd', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Hazard_lights_cmd_114.ignore_overrides', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Hazard_lights_cmd_114.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Hazard_lights_cmd_114.enable', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Hazard_lights_cmd_114.clear_faults', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3360,
  serialized_end=3498,
)


_DASH_CONTROLS_LEFT_RPT_20C = _descriptor.Descriptor(
  name='Dash_controls_left_rpt_20c',
  full_name='apollo.canbus.Dash_controls_left_rpt_20c',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Dash_controls_left_rpt_20c.output_value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Dash_controls_left_rpt_20c.commanded_value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Dash_controls_left_rpt_20c.manual_input', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Dash_controls_left_rpt_20c.vehicle_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Dash_controls_left_rpt_20c.pacmod_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Dash_controls_left_rpt_20c.override_active', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Dash_controls_left_rpt_20c.output_reported_fault', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Dash_controls_left_rpt_20c.input_output_fault', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Dash_controls_left_rpt_20c.enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Dash_controls_left_rpt_20c.command_output_fault', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DASH_CONTROLS_LEFT_RPT_20C_OUTPUT_VALUETYPE,
    _DASH_CONTROLS_LEFT_RPT_20C_COMMANDED_VALUETYPE,
    _DASH_CONTROLS_LEFT_RPT_20C_MANUAL_INPUTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3501,
  serialized_end=4680,
)


_HEADLIGHT_AUX_RPT_318 = _descriptor.Descriptor(
  name='Headlight_aux_rpt_318',
  full_name='apollo.canbus.Headlight_aux_rpt_318',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='headlights_mode_is_valid', full_name='apollo.canbus.Headlight_aux_rpt_318.headlights_mode_is_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headlights_mode', full_name='apollo.canbus.Headlight_aux_rpt_318.headlights_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fog_lights_on_is_valid', full_name='apollo.canbus.Headlight_aux_rpt_318.fog_lights_on_is_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fog_lights_on', full_name='apollo.canbus.Headlight_aux_rpt_318.fog_lights_on', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headlights_on_bright_is_valid', full_name='apollo.canbus.Headlight_aux_rpt_318.headlights_on_bright_is_valid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headlights_on_bright', full_name='apollo.canbus.Headlight_aux_rpt_318.headlights_on_bright', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headlights_on_is_valid', full_name='apollo.canbus.Headlight_aux_rpt_318.headlights_on_is_valid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headlights_on', full_name='apollo.canbus.Headlight_aux_rpt_318.headlights_on', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HEADLIGHT_AUX_RPT_318_HEADLIGHTS_MODETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4683,
  serialized_end=5195,
)


_DASH_CONTROLS_RIGHT_CMD_110 = _descriptor.Descriptor(
  name='Dash_controls_right_cmd_110',
  full_name='apollo.canbus.Dash_controls_right_cmd_110',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Dash_controls_right_cmd_110.ignore_overrides', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Dash_controls_right_cmd_110.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Dash_controls_right_cmd_110.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Dash_controls_right_cmd_110.clear_faults', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dash_controls_button', full_name='apollo.canbus.Dash_controls_right_cmd_110.dash_controls_button', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DASH_CONTROLS_RIGHT_CMD_110_DASH_CONTROLS_BUTTONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5198,
  serialized_end=5704,
)


_WIPER_CMD_134 = _descriptor.Descriptor(
  name='Wiper_cmd_134',
  full_name='apollo.canbus.Wiper_cmd_134',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Wiper_cmd_134.ignore_overrides', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Wiper_cmd_134.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Wiper_cmd_134.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wiper_cmd', full_name='apollo.canbus.Wiper_cmd_134.wiper_cmd', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Wiper_cmd_134.clear_faults', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WIPER_CMD_134_WIPER_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5707,
  serialized_end=6106,
)


_WIPER_RPT_234 = _descriptor.Descriptor(
  name='Wiper_rpt_234',
  full_name='apollo.canbus.Wiper_rpt_234',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Wiper_rpt_234.vehicle_fault', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Wiper_rpt_234.pacmod_fault', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Wiper_rpt_234.override_active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Wiper_rpt_234.output_reported_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Wiper_rpt_234.input_output_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Wiper_rpt_234.enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Wiper_rpt_234.command_output_fault', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Wiper_rpt_234.output_value', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Wiper_rpt_234.commanded_value', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Wiper_rpt_234.manual_input', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WIPER_RPT_234_OUTPUT_VALUETYPE,
    _WIPER_RPT_234_COMMANDED_VALUETYPE,
    _WIPER_RPT_234_MANUAL_INPUTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6109,
  serialized_end=7320,
)


_TURN_RPT_230 = _descriptor.Descriptor(
  name='Turn_rpt_230',
  full_name='apollo.canbus.Turn_rpt_230',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Turn_rpt_230.vehicle_fault', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Turn_rpt_230.pacmod_fault', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Turn_rpt_230.override_active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Turn_rpt_230.output_reported_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Turn_rpt_230.input_output_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Turn_rpt_230.enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Turn_rpt_230.command_output_fault', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Turn_rpt_230.manual_input', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Turn_rpt_230.commanded_value', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Turn_rpt_230.output_value', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TURN_RPT_230_MANUAL_INPUTTYPE,
    _TURN_RPT_230_COMMANDED_VALUETYPE,
    _TURN_RPT_230_OUTPUT_VALUETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7323,
  serialized_end=8084,
)


_HEADLIGHT_CMD_118 = _descriptor.Descriptor(
  name='Headlight_cmd_118',
  full_name='apollo.canbus.Headlight_cmd_118',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Headlight_cmd_118.ignore_overrides', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Headlight_cmd_118.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Headlight_cmd_118.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Headlight_cmd_118.clear_faults', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headlight_cmd', full_name='apollo.canbus.Headlight_cmd_118.headlight_cmd', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HEADLIGHT_CMD_118_HEADLIGHT_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8087,
  serialized_end=8383,
)


_DOOR_RPT_417 = _descriptor.Descriptor(
  name='Door_rpt_417',
  full_name='apollo.canbus.Door_rpt_417',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fuel_door_open_is_valid', full_name='apollo.canbus.Door_rpt_417.fuel_door_open_is_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trunk_open_is_valid', full_name='apollo.canbus.Door_rpt_417.trunk_open_is_valid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hood_open_is_valid', full_name='apollo.canbus.Door_rpt_417.hood_open_is_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_pass_door_open_is_valid', full_name='apollo.canbus.Door_rpt_417.rear_pass_door_open_is_valid', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_driver_door_open_is_valid', full_name='apollo.canbus.Door_rpt_417.rear_driver_door_open_is_valid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pass_door_open_is_valid', full_name='apollo.canbus.Door_rpt_417.pass_door_open_is_valid', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_door_open_is_valid', full_name='apollo.canbus.Door_rpt_417.driver_door_open_is_valid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuel_door_open', full_name='apollo.canbus.Door_rpt_417.fuel_door_open', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trunk_open', full_name='apollo.canbus.Door_rpt_417.trunk_open', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hood_open', full_name='apollo.canbus.Door_rpt_417.hood_open', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_pass_door_open', full_name='apollo.canbus.Door_rpt_417.rear_pass_door_open', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_driver_door_open', full_name='apollo.canbus.Door_rpt_417.rear_driver_door_open', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pass_door_open', full_name='apollo.canbus.Door_rpt_417.pass_door_open', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_door_open', full_name='apollo.canbus.Door_rpt_417.driver_door_open', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8386,
  serialized_end=8809,
)


_COMPONENT_RPT_20 = _descriptor.Descriptor(
  name='Component_rpt_20',
  full_name='apollo.canbus.Component_rpt_20',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='component_type', full_name='apollo.canbus.Component_rpt_20.component_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='component_func', full_name='apollo.canbus.Component_rpt_20.component_func', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counter', full_name='apollo.canbus.Component_rpt_20.counter', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='complement', full_name='apollo.canbus.Component_rpt_20.complement', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_fault', full_name='apollo.canbus.Component_rpt_20.config_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPONENT_RPT_20_COMPONENT_TYPETYPE,
    _COMPONENT_RPT_20_COMPONENT_FUNCTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8812,
  serialized_end=9435,
)


_WHEEL_SPEED_RPT_407 = _descriptor.Descriptor(
  name='Wheel_speed_rpt_407',
  full_name='apollo.canbus.Wheel_speed_rpt_407',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wheel_spd_rear_right', full_name='apollo.canbus.Wheel_speed_rpt_407.wheel_spd_rear_right', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_rear_left', full_name='apollo.canbus.Wheel_speed_rpt_407.wheel_spd_rear_left', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_front_right', full_name='apollo.canbus.Wheel_speed_rpt_407.wheel_spd_front_right', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_front_left', full_name='apollo.canbus.Wheel_speed_rpt_407.wheel_spd_front_left', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9438,
  serialized_end=9579,
)


_STEERING_MOTOR_RPT_3_406 = _descriptor.Descriptor(
  name='Steering_motor_rpt_3_406',
  full_name='apollo.canbus.Steering_motor_rpt_3_406',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='torque_output', full_name='apollo.canbus.Steering_motor_rpt_3_406.torque_output', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='torque_input', full_name='apollo.canbus.Steering_motor_rpt_3_406.torque_input', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9581,
  serialized_end=9652,
)


_STEERING_MOTOR_RPT_2_405 = _descriptor.Descriptor(
  name='Steering_motor_rpt_2_405',
  full_name='apollo.canbus.Steering_motor_rpt_2_405',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoder_temperature', full_name='apollo.canbus.Steering_motor_rpt_2_405.encoder_temperature', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motor_temperature', full_name='apollo.canbus.Steering_motor_rpt_2_405.motor_temperature', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_speed', full_name='apollo.canbus.Steering_motor_rpt_2_405.angular_speed', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9654,
  serialized_end=9759,
)


_STEERING_MOTOR_RPT_1_404 = _descriptor.Descriptor(
  name='Steering_motor_rpt_1_404',
  full_name='apollo.canbus.Steering_motor_rpt_1_404',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='motor_current', full_name='apollo.canbus.Steering_motor_rpt_1_404.motor_current', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shaft_position', full_name='apollo.canbus.Steering_motor_rpt_1_404.shaft_position', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9761,
  serialized_end=9834,
)


_BRAKE_MOTOR_RPT_3_403 = _descriptor.Descriptor(
  name='Brake_motor_rpt_3_403',
  full_name='apollo.canbus.Brake_motor_rpt_3_403',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='torque_output', full_name='apollo.canbus.Brake_motor_rpt_3_403.torque_output', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='torque_input', full_name='apollo.canbus.Brake_motor_rpt_3_403.torque_input', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9836,
  serialized_end=9904,
)


_BRAKE_MOTOR_RPT_2_402 = _descriptor.Descriptor(
  name='Brake_motor_rpt_2_402',
  full_name='apollo.canbus.Brake_motor_rpt_2_402',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoder_temperature', full_name='apollo.canbus.Brake_motor_rpt_2_402.encoder_temperature', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motor_temperature', full_name='apollo.canbus.Brake_motor_rpt_2_402.motor_temperature', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_speed', full_name='apollo.canbus.Brake_motor_rpt_2_402.angular_speed', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9906,
  serialized_end=10008,
)


_BRAKE_MOTOR_RPT_1_401 = _descriptor.Descriptor(
  name='Brake_motor_rpt_1_401',
  full_name='apollo.canbus.Brake_motor_rpt_1_401',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='motor_current', full_name='apollo.canbus.Brake_motor_rpt_1_401.motor_current', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shaft_position', full_name='apollo.canbus.Brake_motor_rpt_1_401.shaft_position', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10010,
  serialized_end=10080,
)


_WIPER_AUX_RPT_334 = _descriptor.Descriptor(
  name='Wiper_aux_rpt_334',
  full_name='apollo.canbus.Wiper_aux_rpt_334',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spray_empty_is_valid', full_name='apollo.canbus.Wiper_aux_rpt_334.spray_empty_is_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spray_empty', full_name='apollo.canbus.Wiper_aux_rpt_334.spray_empty', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spray_near_empty_is_valid', full_name='apollo.canbus.Wiper_aux_rpt_334.spray_near_empty_is_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spray_near_empty', full_name='apollo.canbus.Wiper_aux_rpt_334.spray_near_empty', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_spraying_is_valid', full_name='apollo.canbus.Wiper_aux_rpt_334.rear_spraying_is_valid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_spraying', full_name='apollo.canbus.Wiper_aux_rpt_334.rear_spraying', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_wiping_is_valid', full_name='apollo.canbus.Wiper_aux_rpt_334.rear_wiping_is_valid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_wiping', full_name='apollo.canbus.Wiper_aux_rpt_334.rear_wiping', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_spraying_is_valid', full_name='apollo.canbus.Wiper_aux_rpt_334.front_spraying_is_valid', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_spraying', full_name='apollo.canbus.Wiper_aux_rpt_334.front_spraying', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_wiping_is_valid', full_name='apollo.canbus.Wiper_aux_rpt_334.front_wiping_is_valid', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_wiping', full_name='apollo.canbus.Wiper_aux_rpt_334.front_wiping', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10083,
  serialized_end=10430,
)


_SHIFT_AUX_RPT_328 = _descriptor.Descriptor(
  name='Shift_aux_rpt_328',
  full_name='apollo.canbus.Shift_aux_rpt_328',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='speed_interlock_active_is_valid', full_name='apollo.canbus.Shift_aux_rpt_328.speed_interlock_active_is_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_interlock_active', full_name='apollo.canbus.Shift_aux_rpt_328.speed_interlock_active', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_interlock_active_is_valid', full_name='apollo.canbus.Shift_aux_rpt_328.brake_interlock_active_is_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_interlock_active', full_name='apollo.canbus.Shift_aux_rpt_328.brake_interlock_active', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stay_in_neutral_mode_is_valid', full_name='apollo.canbus.Shift_aux_rpt_328.stay_in_neutral_mode_is_valid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stay_in_neutral_mode', full_name='apollo.canbus.Shift_aux_rpt_328.stay_in_neutral_mode', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='between_gears_is_valid', full_name='apollo.canbus.Shift_aux_rpt_328.between_gears_is_valid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='between_gears', full_name='apollo.canbus.Shift_aux_rpt_328.between_gears', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10433,
  serialized_end=10722,
)


_ACCEL_RPT_200 = _descriptor.Descriptor(
  name='Accel_rpt_200',
  full_name='apollo.canbus.Accel_rpt_200',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Accel_rpt_200.vehicle_fault', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Accel_rpt_200.pacmod_fault', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Accel_rpt_200.output_reported_fault', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Accel_rpt_200.input_output_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Accel_rpt_200.command_output_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Accel_rpt_200.override_active', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Accel_rpt_200.enabled', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Accel_rpt_200.manual_input', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Accel_rpt_200.commanded_value', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Accel_rpt_200.output_value', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10725,
  serialized_end=10985,
)


_BRAKE_RPT_204 = _descriptor.Descriptor(
  name='Brake_rpt_204',
  full_name='apollo.canbus.Brake_rpt_204',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Brake_rpt_204.command_output_fault', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Brake_rpt_204.vehicle_fault', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Brake_rpt_204.pacmod_fault', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Brake_rpt_204.override_active', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Brake_rpt_204.output_reported_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Brake_rpt_204.input_output_fault', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Brake_rpt_204.enabled', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Brake_rpt_204.manual_input', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Brake_rpt_204.commanded_value', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Brake_rpt_204.output_value', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10988,
  serialized_end=11248,
)


_HORN_CMD_11C = _descriptor.Descriptor(
  name='Horn_cmd_11c',
  full_name='apollo.canbus.Horn_cmd_11c',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Horn_cmd_11c.ignore_overrides', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Horn_cmd_11c.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Horn_cmd_11c.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Horn_cmd_11c.clear_faults', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='horn_cmd', full_name='apollo.canbus.Horn_cmd_11c.horn_cmd', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HORN_CMD_11C_HORN_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11251,
  serialized_end=11464,
)


_GLOBAL_RPT_10 = _descriptor.Descriptor(
  name='Global_rpt_10',
  full_name='apollo.canbus.Global_rpt_10',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_fault_active', full_name='apollo.canbus.Global_rpt_10.config_fault_active', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_subsystem_timeout', full_name='apollo.canbus.Global_rpt_10.pacmod_subsystem_timeout', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_system_enabled', full_name='apollo.canbus.Global_rpt_10.pacmod_system_enabled', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_system_override_active', full_name='apollo.canbus.Global_rpt_10.pacmod_system_override_active', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_system_fault_active', full_name='apollo.canbus.Global_rpt_10.pacmod_system_fault_active', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='veh_can_timeout', full_name='apollo.canbus.Global_rpt_10.veh_can_timeout', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='str_can_timeout', full_name='apollo.canbus.Global_rpt_10.str_can_timeout', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brk_can_timeout', full_name='apollo.canbus.Global_rpt_10.brk_can_timeout', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usr_can_timeout', full_name='apollo.canbus.Global_rpt_10.usr_can_timeout', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usr_can_read_errors', full_name='apollo.canbus.Global_rpt_10.usr_can_read_errors', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GLOBAL_RPT_10_PACMOD_SYSTEM_ENABLEDTYPE,
    _GLOBAL_RPT_10_PACMOD_SYSTEM_OVERRIDE_ACTIVETYPE,
    _GLOBAL_RPT_10_BRK_CAN_TIMEOUTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11467,
  serialized_end=12306,
)


_ACCEL_AUX_RPT_300 = _descriptor.Descriptor(
  name='Accel_aux_rpt_300',
  full_name='apollo.canbus.Accel_aux_rpt_300',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_interaction_is_valid', full_name='apollo.canbus.Accel_aux_rpt_300.user_interaction_is_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_interaction', full_name='apollo.canbus.Accel_aux_rpt_300.user_interaction', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_pedal_force_is_valid', full_name='apollo.canbus.Accel_aux_rpt_300.raw_pedal_force_is_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_pedal_force', full_name='apollo.canbus.Accel_aux_rpt_300.raw_pedal_force', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_pedal_pos_is_valid', full_name='apollo.canbus.Accel_aux_rpt_300.raw_pedal_pos_is_valid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_pedal_pos', full_name='apollo.canbus.Accel_aux_rpt_300.raw_pedal_pos', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12309,
  serialized_end=12503,
)


_CRUISE_CONTROL_BUTTONS_RPT_208 = _descriptor.Descriptor(
  name='Cruise_control_buttons_rpt_208',
  full_name='apollo.canbus.Cruise_control_buttons_rpt_208',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Cruise_control_buttons_rpt_208.output_value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Cruise_control_buttons_rpt_208.manual_input', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Cruise_control_buttons_rpt_208.commanded_value', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Cruise_control_buttons_rpt_208.vehicle_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Cruise_control_buttons_rpt_208.pacmod_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Cruise_control_buttons_rpt_208.override_active', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Cruise_control_buttons_rpt_208.output_reported_fault', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Cruise_control_buttons_rpt_208.input_output_fault', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Cruise_control_buttons_rpt_208.enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Cruise_control_buttons_rpt_208.command_output_fault', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CRUISE_CONTROL_BUTTONS_RPT_208_OUTPUT_VALUETYPE,
    _CRUISE_CONTROL_BUTTONS_RPT_208_MANUAL_INPUTTYPE,
    _CRUISE_CONTROL_BUTTONS_RPT_208_COMMANDED_VALUETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12506,
  serialized_end=13926,
)


_VEHICLE_SPEED_RPT_400 = _descriptor.Descriptor(
  name='Vehicle_speed_rpt_400',
  full_name='apollo.canbus.Vehicle_speed_rpt_400',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_speed', full_name='apollo.canbus.Vehicle_speed_rpt_400.vehicle_speed', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_speed_valid', full_name='apollo.canbus.Vehicle_speed_rpt_400.vehicle_speed_valid', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VEHICLE_SPEED_RPT_400_VEHICLE_SPEED_VALIDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13929,
  serialized_end=14157,
)


_BRAKE_AUX_RPT_304 = _descriptor.Descriptor(
  name='Brake_aux_rpt_304',
  full_name='apollo.canbus.Brake_aux_rpt_304',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brake_on_off_is_valid', full_name='apollo.canbus.Brake_aux_rpt_304.brake_on_off_is_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_on_off', full_name='apollo.canbus.Brake_aux_rpt_304.brake_on_off', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_interaction_is_valid', full_name='apollo.canbus.Brake_aux_rpt_304.user_interaction_is_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_interaction', full_name='apollo.canbus.Brake_aux_rpt_304.user_interaction', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_brake_pressure_is_valid', full_name='apollo.canbus.Brake_aux_rpt_304.raw_brake_pressure_is_valid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_brake_pressure', full_name='apollo.canbus.Brake_aux_rpt_304.raw_brake_pressure', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_pedal_force_is_valid', full_name='apollo.canbus.Brake_aux_rpt_304.raw_pedal_force_is_valid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_pedal_force', full_name='apollo.canbus.Brake_aux_rpt_304.raw_pedal_force', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_pedal_pos_is_valid', full_name='apollo.canbus.Brake_aux_rpt_304.raw_pedal_pos_is_valid', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_pedal_pos', full_name='apollo.canbus.Brake_aux_rpt_304.raw_pedal_pos', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14160,
  serialized_end=14472,
)


_MEDIA_CONTROLS_CMD_120 = _descriptor.Descriptor(
  name='Media_controls_cmd_120',
  full_name='apollo.canbus.Media_controls_cmd_120',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='media_controls_cmd', full_name='apollo.canbus.Media_controls_cmd_120.media_controls_cmd', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Media_controls_cmd_120.ignore_overrides', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Media_controls_cmd_120.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Media_controls_cmd_120.clear_faults', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Media_controls_cmd_120.enable', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MEDIA_CONTROLS_CMD_120_MEDIA_CONTROLS_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14475,
  serialized_end=15047,
)


_CRUISE_CONTROL_BUTTONS_CMD_108 = _descriptor.Descriptor(
  name='Cruise_control_buttons_cmd_108',
  full_name='apollo.canbus.Cruise_control_buttons_cmd_108',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cruise_control_button', full_name='apollo.canbus.Cruise_control_buttons_cmd_108.cruise_control_button', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Cruise_control_buttons_cmd_108.ignore_overrides', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Cruise_control_buttons_cmd_108.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Cruise_control_buttons_cmd_108.enable', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Cruise_control_buttons_cmd_108.clear_faults', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CRUISE_CONTROL_BUTTONS_CMD_108_CRUISE_CONTROL_BUTTONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15050,
  serialized_end=15654,
)


_PARKING_BRAKE_CMD_124 = _descriptor.Descriptor(
  name='Parking_brake_cmd_124',
  full_name='apollo.canbus.Parking_brake_cmd_124',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Parking_brake_cmd_124.ignore_overrides', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Parking_brake_cmd_124.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Parking_brake_cmd_124.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_brake_cmd', full_name='apollo.canbus.Parking_brake_cmd_124.parking_brake_cmd', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Parking_brake_cmd_124.clear_faults', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15657,
  serialized_end=15795,
)


_HORN_RPT_21C = _descriptor.Descriptor(
  name='Horn_rpt_21c',
  full_name='apollo.canbus.Horn_rpt_21c',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Horn_rpt_21c.vehicle_fault', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Horn_rpt_21c.pacmod_fault', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Horn_rpt_21c.override_active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Horn_rpt_21c.output_reported_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Horn_rpt_21c.input_output_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Horn_rpt_21c.enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Horn_rpt_21c.command_output_fault', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Horn_rpt_21c.output_value', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Horn_rpt_21c.commanded_value', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Horn_rpt_21c.manual_input', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HORN_RPT_21C_OUTPUT_VALUETYPE,
    _HORN_RPT_21C_COMMANDED_VALUETYPE,
    _HORN_RPT_21C_MANUAL_INPUTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15798,
  serialized_end=16396,
)


_SHIFT_RPT_228 = _descriptor.Descriptor(
  name='Shift_rpt_228',
  full_name='apollo.canbus.Shift_rpt_228',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Shift_rpt_228.vehicle_fault', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Shift_rpt_228.pacmod_fault', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Shift_rpt_228.override_active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Shift_rpt_228.output_reported_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Shift_rpt_228.input_output_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Shift_rpt_228.enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Shift_rpt_228.command_output_fault', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Shift_rpt_228.manual_input', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Shift_rpt_228.commanded_value', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Shift_rpt_228.output_value', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SHIFT_RPT_228_MANUAL_INPUTTYPE,
    _SHIFT_RPT_228_COMMANDED_VALUETYPE,
    _SHIFT_RPT_228_OUTPUT_VALUETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16399,
  serialized_end=17452,
)


_SHIFT_CMD_128 = _descriptor.Descriptor(
  name='Shift_cmd_128',
  full_name='apollo.canbus.Shift_cmd_128',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Shift_cmd_128.ignore_overrides', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Shift_cmd_128.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Shift_cmd_128.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Shift_cmd_128.clear_faults', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shift_cmd', full_name='apollo.canbus.Shift_cmd_128.shift_cmd', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SHIFT_CMD_128_SHIFT_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17455,
  serialized_end=17772,
)


_ACCEL_CMD_100 = _descriptor.Descriptor(
  name='Accel_cmd_100',
  full_name='apollo.canbus.Accel_cmd_100',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Accel_cmd_100.ignore_overrides', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Accel_cmd_100.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Accel_cmd_100.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Accel_cmd_100.clear_faults', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accel_cmd', full_name='apollo.canbus.Accel_cmd_100.accel_cmd', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17774,
  serialized_end=17896,
)


_PARKING_BRAKE_RPT_224 = _descriptor.Descriptor(
  name='Parking_brake_rpt_224',
  full_name='apollo.canbus.Parking_brake_rpt_224',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Parking_brake_rpt_224.vehicle_fault', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Parking_brake_rpt_224.pacmod_fault', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Parking_brake_rpt_224.override_active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Parking_brake_rpt_224.output_reported_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Parking_brake_rpt_224.input_output_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Parking_brake_rpt_224.enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Parking_brake_rpt_224.command_output_fault', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Parking_brake_rpt_224.output_value', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Parking_brake_rpt_224.commanded_value', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Parking_brake_rpt_224.manual_input', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17899,
  serialized_end=18167,
)


_BRAKE_CMD_104 = _descriptor.Descriptor(
  name='Brake_cmd_104',
  full_name='apollo.canbus.Brake_cmd_104',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Brake_cmd_104.ignore_overrides', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Brake_cmd_104.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Brake_cmd_104.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Brake_cmd_104.clear_faults', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_cmd', full_name='apollo.canbus.Brake_cmd_104.brake_cmd', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18169,
  serialized_end=18291,
)


_MEDIA_CONTROLS_RPT_220 = _descriptor.Descriptor(
  name='Media_controls_rpt_220',
  full_name='apollo.canbus.Media_controls_rpt_220',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Media_controls_rpt_220.output_value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Media_controls_rpt_220.commanded_value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Media_controls_rpt_220.manual_input', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_fault', full_name='apollo.canbus.Media_controls_rpt_220.vehicle_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pacmod_fault', full_name='apollo.canbus.Media_controls_rpt_220.pacmod_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_active', full_name='apollo.canbus.Media_controls_rpt_220.override_active', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_reported_fault', full_name='apollo.canbus.Media_controls_rpt_220.output_reported_fault', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_output_fault', full_name='apollo.canbus.Media_controls_rpt_220.input_output_fault', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.canbus.Media_controls_rpt_220.enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_output_fault', full_name='apollo.canbus.Media_controls_rpt_220.command_output_fault', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MEDIA_CONTROLS_RPT_220_OUTPUT_VALUETYPE,
    _MEDIA_CONTROLS_RPT_220_COMMANDED_VALUETYPE,
    _MEDIA_CONTROLS_RPT_220_MANUAL_INPUTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18294,
  serialized_end=19724,
)


_STEERING_AUX_RPT_32C = _descriptor.Descriptor(
  name='Steering_aux_rpt_32c',
  full_name='apollo.canbus.Steering_aux_rpt_32c',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_interaction_is_valid', full_name='apollo.canbus.Steering_aux_rpt_32c.user_interaction_is_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_interaction', full_name='apollo.canbus.Steering_aux_rpt_32c.user_interaction', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rotation_rate_is_valid', full_name='apollo.canbus.Steering_aux_rpt_32c.rotation_rate_is_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rotation_rate', full_name='apollo.canbus.Steering_aux_rpt_32c.rotation_rate', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_torque_is_valid', full_name='apollo.canbus.Steering_aux_rpt_32c.raw_torque_is_valid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_torque', full_name='apollo.canbus.Steering_aux_rpt_32c.raw_torque', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_position_is_valid', full_name='apollo.canbus.Steering_aux_rpt_32c.raw_position_is_valid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_position', full_name='apollo.canbus.Steering_aux_rpt_32c.raw_position', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19727,
  serialized_end=19967,
)


_LAT_LON_HEADING_RPT_40E = _descriptor.Descriptor(
  name='Lat_lon_heading_rpt_40e',
  full_name='apollo.canbus.Lat_lon_heading_rpt_40e',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.canbus.Lat_lon_heading_rpt_40e.heading', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_seconds', full_name='apollo.canbus.Lat_lon_heading_rpt_40e.longitude_seconds', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_minutes', full_name='apollo.canbus.Lat_lon_heading_rpt_40e.longitude_minutes', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_degrees', full_name='apollo.canbus.Lat_lon_heading_rpt_40e.longitude_degrees', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude_seconds', full_name='apollo.canbus.Lat_lon_heading_rpt_40e.latitude_seconds', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude_minutes', full_name='apollo.canbus.Lat_lon_heading_rpt_40e.latitude_minutes', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude_degrees', full_name='apollo.canbus.Lat_lon_heading_rpt_40e.latitude_degrees', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19970,
  serialized_end=20171,
)


_YAW_RATE_RPT_40D = _descriptor.Descriptor(
  name='Yaw_rate_rpt_40d',
  full_name='apollo.canbus.Yaw_rate_rpt_40d',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='yaw_rate', full_name='apollo.canbus.Yaw_rate_rpt_40d.yaw_rate', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20173,
  serialized_end=20209,
)


_DATE_TIME_RPT_40F = _descriptor.Descriptor(
  name='Date_time_rpt_40f',
  full_name='apollo.canbus.Date_time_rpt_40f',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_second', full_name='apollo.canbus.Date_time_rpt_40f.time_second', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_minute', full_name='apollo.canbus.Date_time_rpt_40f.time_minute', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_hour', full_name='apollo.canbus.Date_time_rpt_40f.time_hour', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_day', full_name='apollo.canbus.Date_time_rpt_40f.date_day', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_month', full_name='apollo.canbus.Date_time_rpt_40f.date_month', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_year', full_name='apollo.canbus.Date_time_rpt_40f.date_year', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20212,
  serialized_end=20349,
)


_VIN_RPT_414 = _descriptor.Descriptor(
  name='Vin_rpt_414',
  full_name='apollo.canbus.Vin_rpt_414',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='veh_serial', full_name='apollo.canbus.Vin_rpt_414.veh_serial', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='veh_my_code', full_name='apollo.canbus.Vin_rpt_414.veh_my_code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='veh_mfg_code', full_name='apollo.canbus.Vin_rpt_414.veh_mfg_code', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20351,
  serialized_end=20427,
)


_OCCUPANCY_RPT_415 = _descriptor.Descriptor(
  name='Occupancy_rpt_415',
  full_name='apollo.canbus.Occupancy_rpt_415',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rear_seatbelt_buckled_is_valid', full_name='apollo.canbus.Occupancy_rpt_415.rear_seatbelt_buckled_is_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pass_seatbelt_buckled_is_valid', full_name='apollo.canbus.Occupancy_rpt_415.pass_seatbelt_buckled_is_valid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_seatbelt_buckled_is_valid', full_name='apollo.canbus.Occupancy_rpt_415.driver_seatbelt_buckled_is_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_seat_occupied_is_valid', full_name='apollo.canbus.Occupancy_rpt_415.rear_seat_occupied_is_valid', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pass_seat_occupied_is_valid', full_name='apollo.canbus.Occupancy_rpt_415.pass_seat_occupied_is_valid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_seat_occupied_is_valid', full_name='apollo.canbus.Occupancy_rpt_415.driver_seat_occupied_is_valid', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_seatbelt_buckled', full_name='apollo.canbus.Occupancy_rpt_415.rear_seatbelt_buckled', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pass_seatbelt_buckled', full_name='apollo.canbus.Occupancy_rpt_415.pass_seatbelt_buckled', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_seatbelt_buckled', full_name='apollo.canbus.Occupancy_rpt_415.driver_seatbelt_buckled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_seat_occupied', full_name='apollo.canbus.Occupancy_rpt_415.rear_seat_occupied', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pass_seat_occupied', full_name='apollo.canbus.Occupancy_rpt_415.pass_seat_occupied', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_seat_occupied', full_name='apollo.canbus.Occupancy_rpt_415.driver_seat_occupied', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20430,
  serialized_end=20865,
)


_INTERIOR_LIGHTS_RPT_416 = _descriptor.Descriptor(
  name='Interior_lights_rpt_416',
  full_name='apollo.canbus.Interior_lights_rpt_416',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dim_level_is_valid', full_name='apollo.canbus.Interior_lights_rpt_416.dim_level_is_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mood_lights_on_is_valid', full_name='apollo.canbus.Interior_lights_rpt_416.mood_lights_on_is_valid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_dome_lights_on_is_valid', full_name='apollo.canbus.Interior_lights_rpt_416.rear_dome_lights_on_is_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_dome_lights_on_is_valid', full_name='apollo.canbus.Interior_lights_rpt_416.front_dome_lights_on_is_valid', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dim_level', full_name='apollo.canbus.Interior_lights_rpt_416.dim_level', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mood_lights_on', full_name='apollo.canbus.Interior_lights_rpt_416.mood_lights_on', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_dome_lights_on', full_name='apollo.canbus.Interior_lights_rpt_416.rear_dome_lights_on', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_dome_lights_on', full_name='apollo.canbus.Interior_lights_rpt_416.front_dome_lights_on', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INTERIOR_LIGHTS_RPT_416_DIM_LEVELTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20868,
  serialized_end=21562,
)


_TURN_CMD_130 = _descriptor.Descriptor(
  name='Turn_cmd_130',
  full_name='apollo.canbus.Turn_cmd_130',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_overrides', full_name='apollo.canbus.Turn_cmd_130.ignore_overrides', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='apollo.canbus.Turn_cmd_130.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Turn_cmd_130.clear_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_faults', full_name='apollo.canbus.Turn_cmd_130.clear_faults', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_signal_cmd', full_name='apollo.canbus.Turn_cmd_130.turn_signal_cmd', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TURN_CMD_130_TURN_SIGNAL_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21565,
  serialized_end=21872,
)


_DETECTED_OBJECT_RPT_411 = _descriptor.Descriptor(
  name='Detected_object_rpt_411',
  full_name='apollo.canbus.Detected_object_rpt_411',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='front_object_distance_high_res', full_name='apollo.canbus.Detected_object_rpt_411.front_object_distance_high_res', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_object_distance_low_res', full_name='apollo.canbus.Detected_object_rpt_411.front_object_distance_low_res', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21874,
  serialized_end=21978,
)


_VEH_SPECIFIC_RPT_1_412 = _descriptor.Descriptor(
  name='Veh_specific_rpt_1_412',
  full_name='apollo.canbus.Veh_specific_rpt_1_412',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shift_pos_2', full_name='apollo.canbus.Veh_specific_rpt_1_412.shift_pos_2', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shift_pos_1', full_name='apollo.canbus.Veh_specific_rpt_1_412.shift_pos_1', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21980,
  serialized_end=22046,
)


_VEH_DYNAMICS_RPT_413 = _descriptor.Descriptor(
  name='Veh_dynamics_rpt_413',
  full_name='apollo.canbus.Veh_dynamics_rpt_413',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='veh_g_forces', full_name='apollo.canbus.Veh_dynamics_rpt_413.veh_g_forces', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22048,
  serialized_end=22092,
)


_REAR_LIGHTS_RPT_418 = _descriptor.Descriptor(
  name='Rear_lights_rpt_418',
  full_name='apollo.canbus.Rear_lights_rpt_418',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reverse_lights_on_is_valid', full_name='apollo.canbus.Rear_lights_rpt_418.reverse_lights_on_is_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_lights_on_is_valid', full_name='apollo.canbus.Rear_lights_rpt_418.brake_lights_on_is_valid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reverse_lights_on', full_name='apollo.canbus.Rear_lights_rpt_418.reverse_lights_on', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_lights_on', full_name='apollo.canbus.Rear_lights_rpt_418.brake_lights_on', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22095,
  serialized_end=22238,
)


_LEXUS = _descriptor.Descriptor(
  name='Lexus',
  full_name='apollo.canbus.Lexus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hazard_lights_rpt_214', full_name='apollo.canbus.Lexus.hazard_lights_rpt_214', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_cmd_12c', full_name='apollo.canbus.Lexus.steering_cmd_12c', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dash_controls_right_rpt_210', full_name='apollo.canbus.Lexus.dash_controls_right_rpt_210', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dash_controls_left_cmd_10c', full_name='apollo.canbus.Lexus.dash_controls_left_cmd_10c', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_rpt_22c', full_name='apollo.canbus.Lexus.steering_rpt_22c', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_aux_rpt_330', full_name='apollo.canbus.Lexus.turn_aux_rpt_330', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headlight_rpt_218', full_name='apollo.canbus.Lexus.headlight_rpt_218', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hazard_lights_cmd_114', full_name='apollo.canbus.Lexus.hazard_lights_cmd_114', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dash_controls_left_rpt_20c', full_name='apollo.canbus.Lexus.dash_controls_left_rpt_20c', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headlight_aux_rpt_318', full_name='apollo.canbus.Lexus.headlight_aux_rpt_318', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dash_controls_right_cmd_110', full_name='apollo.canbus.Lexus.dash_controls_right_cmd_110', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wiper_cmd_134', full_name='apollo.canbus.Lexus.wiper_cmd_134', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wiper_rpt_234', full_name='apollo.canbus.Lexus.wiper_rpt_234', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_rpt_230', full_name='apollo.canbus.Lexus.turn_rpt_230', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headlight_cmd_118', full_name='apollo.canbus.Lexus.headlight_cmd_118', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='door_rpt_417', full_name='apollo.canbus.Lexus.door_rpt_417', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='component_rpt_20', full_name='apollo.canbus.Lexus.component_rpt_20', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_speed_rpt_407', full_name='apollo.canbus.Lexus.wheel_speed_rpt_407', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_motor_rpt_3_406', full_name='apollo.canbus.Lexus.steering_motor_rpt_3_406', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_motor_rpt_2_405', full_name='apollo.canbus.Lexus.steering_motor_rpt_2_405', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_motor_rpt_1_404', full_name='apollo.canbus.Lexus.steering_motor_rpt_1_404', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_motor_rpt_3_403', full_name='apollo.canbus.Lexus.brake_motor_rpt_3_403', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_motor_rpt_2_402', full_name='apollo.canbus.Lexus.brake_motor_rpt_2_402', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_motor_rpt_1_401', full_name='apollo.canbus.Lexus.brake_motor_rpt_1_401', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wiper_aux_rpt_334', full_name='apollo.canbus.Lexus.wiper_aux_rpt_334', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shift_aux_rpt_328', full_name='apollo.canbus.Lexus.shift_aux_rpt_328', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accel_rpt_200', full_name='apollo.canbus.Lexus.accel_rpt_200', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_rpt_204', full_name='apollo.canbus.Lexus.brake_rpt_204', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='horn_cmd_11c', full_name='apollo.canbus.Lexus.horn_cmd_11c', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_rpt_10', full_name='apollo.canbus.Lexus.global_rpt_10', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accel_aux_rpt_300', full_name='apollo.canbus.Lexus.accel_aux_rpt_300', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cruise_control_buttons_rpt_208', full_name='apollo.canbus.Lexus.cruise_control_buttons_rpt_208', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_speed_rpt_400', full_name='apollo.canbus.Lexus.vehicle_speed_rpt_400', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_aux_rpt_304', full_name='apollo.canbus.Lexus.brake_aux_rpt_304', index=33,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media_controls_cmd_120', full_name='apollo.canbus.Lexus.media_controls_cmd_120', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cruise_control_buttons_cmd_108', full_name='apollo.canbus.Lexus.cruise_control_buttons_cmd_108', index=35,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_brake_cmd_124', full_name='apollo.canbus.Lexus.parking_brake_cmd_124', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='horn_rpt_21c', full_name='apollo.canbus.Lexus.horn_rpt_21c', index=37,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shift_rpt_228', full_name='apollo.canbus.Lexus.shift_rpt_228', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shift_cmd_128', full_name='apollo.canbus.Lexus.shift_cmd_128', index=39,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accel_cmd_100', full_name='apollo.canbus.Lexus.accel_cmd_100', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_brake_rpt_224', full_name='apollo.canbus.Lexus.parking_brake_rpt_224', index=41,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_cmd_104', full_name='apollo.canbus.Lexus.brake_cmd_104', index=42,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media_controls_rpt_220', full_name='apollo.canbus.Lexus.media_controls_rpt_220', index=43,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_aux_rpt_32c', full_name='apollo.canbus.Lexus.steering_aux_rpt_32c', index=44,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat_lon_heading_rpt_40e', full_name='apollo.canbus.Lexus.lat_lon_heading_rpt_40e', index=45,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_rate_rpt_40d', full_name='apollo.canbus.Lexus.yaw_rate_rpt_40d', index=46,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_time_rpt_40f', full_name='apollo.canbus.Lexus.date_time_rpt_40f', index=47,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin_rpt_414', full_name='apollo.canbus.Lexus.vin_rpt_414', index=48,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='occupancy_rpt_415', full_name='apollo.canbus.Lexus.occupancy_rpt_415', index=49,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interior_lights_rpt_416', full_name='apollo.canbus.Lexus.interior_lights_rpt_416', index=50,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_cmd_130', full_name='apollo.canbus.Lexus.turn_cmd_130', index=51,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detected_object_rpt_411', full_name='apollo.canbus.Lexus.detected_object_rpt_411', index=52,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='veh_specific_rpt_1_412', full_name='apollo.canbus.Lexus.veh_specific_rpt_1_412', index=53,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='veh_dynamics_rpt_413', full_name='apollo.canbus.Lexus.veh_dynamics_rpt_413', index=54,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_lights_rpt_418', full_name='apollo.canbus.Lexus.rear_lights_rpt_418', index=55,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22241,
  serialized_end=25848,
)

_DASH_CONTROLS_RIGHT_RPT_210.fields_by_name['output_value'].enum_type = _DASH_CONTROLS_RIGHT_RPT_210_OUTPUT_VALUETYPE
_DASH_CONTROLS_RIGHT_RPT_210.fields_by_name['commanded_value'].enum_type = _DASH_CONTROLS_RIGHT_RPT_210_COMMANDED_VALUETYPE
_DASH_CONTROLS_RIGHT_RPT_210.fields_by_name['manual_input'].enum_type = _DASH_CONTROLS_RIGHT_RPT_210_MANUAL_INPUTTYPE
_DASH_CONTROLS_RIGHT_RPT_210_OUTPUT_VALUETYPE.containing_type = _DASH_CONTROLS_RIGHT_RPT_210
_DASH_CONTROLS_RIGHT_RPT_210_COMMANDED_VALUETYPE.containing_type = _DASH_CONTROLS_RIGHT_RPT_210
_DASH_CONTROLS_RIGHT_RPT_210_MANUAL_INPUTTYPE.containing_type = _DASH_CONTROLS_RIGHT_RPT_210
_DASH_CONTROLS_LEFT_CMD_10C.fields_by_name['dash_controls_button'].enum_type = _DASH_CONTROLS_LEFT_CMD_10C_DASH_CONTROLS_BUTTONTYPE
_DASH_CONTROLS_LEFT_CMD_10C_DASH_CONTROLS_BUTTONTYPE.containing_type = _DASH_CONTROLS_LEFT_CMD_10C
_HEADLIGHT_RPT_218.fields_by_name['output_value'].enum_type = _HEADLIGHT_RPT_218_OUTPUT_VALUETYPE
_HEADLIGHT_RPT_218.fields_by_name['manual_input'].enum_type = _HEADLIGHT_RPT_218_MANUAL_INPUTTYPE
_HEADLIGHT_RPT_218.fields_by_name['commanded_value'].enum_type = _HEADLIGHT_RPT_218_COMMANDED_VALUETYPE
_HEADLIGHT_RPT_218_OUTPUT_VALUETYPE.containing_type = _HEADLIGHT_RPT_218
_HEADLIGHT_RPT_218_MANUAL_INPUTTYPE.containing_type = _HEADLIGHT_RPT_218
_HEADLIGHT_RPT_218_COMMANDED_VALUETYPE.containing_type = _HEADLIGHT_RPT_218
_DASH_CONTROLS_LEFT_RPT_20C.fields_by_name['output_value'].enum_type = _DASH_CONTROLS_LEFT_RPT_20C_OUTPUT_VALUETYPE
_DASH_CONTROLS_LEFT_RPT_20C.fields_by_name['commanded_value'].enum_type = _DASH_CONTROLS_LEFT_RPT_20C_COMMANDED_VALUETYPE
_DASH_CONTROLS_LEFT_RPT_20C.fields_by_name['manual_input'].enum_type = _DASH_CONTROLS_LEFT_RPT_20C_MANUAL_INPUTTYPE
_DASH_CONTROLS_LEFT_RPT_20C_OUTPUT_VALUETYPE.containing_type = _DASH_CONTROLS_LEFT_RPT_20C
_DASH_CONTROLS_LEFT_RPT_20C_COMMANDED_VALUETYPE.containing_type = _DASH_CONTROLS_LEFT_RPT_20C
_DASH_CONTROLS_LEFT_RPT_20C_MANUAL_INPUTTYPE.containing_type = _DASH_CONTROLS_LEFT_RPT_20C
_HEADLIGHT_AUX_RPT_318.fields_by_name['headlights_mode'].enum_type = _HEADLIGHT_AUX_RPT_318_HEADLIGHTS_MODETYPE
_HEADLIGHT_AUX_RPT_318_HEADLIGHTS_MODETYPE.containing_type = _HEADLIGHT_AUX_RPT_318
_DASH_CONTROLS_RIGHT_CMD_110.fields_by_name['dash_controls_button'].enum_type = _DASH_CONTROLS_RIGHT_CMD_110_DASH_CONTROLS_BUTTONTYPE
_DASH_CONTROLS_RIGHT_CMD_110_DASH_CONTROLS_BUTTONTYPE.containing_type = _DASH_CONTROLS_RIGHT_CMD_110
_WIPER_CMD_134.fields_by_name['wiper_cmd'].enum_type = _WIPER_CMD_134_WIPER_CMDTYPE
_WIPER_CMD_134_WIPER_CMDTYPE.containing_type = _WIPER_CMD_134
_WIPER_RPT_234.fields_by_name['output_value'].enum_type = _WIPER_RPT_234_OUTPUT_VALUETYPE
_WIPER_RPT_234.fields_by_name['commanded_value'].enum_type = _WIPER_RPT_234_COMMANDED_VALUETYPE
_WIPER_RPT_234.fields_by_name['manual_input'].enum_type = _WIPER_RPT_234_MANUAL_INPUTTYPE
_WIPER_RPT_234_OUTPUT_VALUETYPE.containing_type = _WIPER_RPT_234
_WIPER_RPT_234_COMMANDED_VALUETYPE.containing_type = _WIPER_RPT_234
_WIPER_RPT_234_MANUAL_INPUTTYPE.containing_type = _WIPER_RPT_234
_TURN_RPT_230.fields_by_name['manual_input'].enum_type = _TURN_RPT_230_MANUAL_INPUTTYPE
_TURN_RPT_230.fields_by_name['commanded_value'].enum_type = _TURN_RPT_230_COMMANDED_VALUETYPE
_TURN_RPT_230.fields_by_name['output_value'].enum_type = _TURN_RPT_230_OUTPUT_VALUETYPE
_TURN_RPT_230_MANUAL_INPUTTYPE.containing_type = _TURN_RPT_230
_TURN_RPT_230_COMMANDED_VALUETYPE.containing_type = _TURN_RPT_230
_TURN_RPT_230_OUTPUT_VALUETYPE.containing_type = _TURN_RPT_230
_HEADLIGHT_CMD_118.fields_by_name['headlight_cmd'].enum_type = _HEADLIGHT_CMD_118_HEADLIGHT_CMDTYPE
_HEADLIGHT_CMD_118_HEADLIGHT_CMDTYPE.containing_type = _HEADLIGHT_CMD_118
_COMPONENT_RPT_20.fields_by_name['component_type'].enum_type = _COMPONENT_RPT_20_COMPONENT_TYPETYPE
_COMPONENT_RPT_20.fields_by_name['component_func'].enum_type = _COMPONENT_RPT_20_COMPONENT_FUNCTYPE
_COMPONENT_RPT_20_COMPONENT_TYPETYPE.containing_type = _COMPONENT_RPT_20
_COMPONENT_RPT_20_COMPONENT_FUNCTYPE.containing_type = _COMPONENT_RPT_20
_HORN_CMD_11C.fields_by_name['horn_cmd'].enum_type = _HORN_CMD_11C_HORN_CMDTYPE
_HORN_CMD_11C_HORN_CMDTYPE.containing_type = _HORN_CMD_11C
_GLOBAL_RPT_10.fields_by_name['pacmod_system_enabled'].enum_type = _GLOBAL_RPT_10_PACMOD_SYSTEM_ENABLEDTYPE
_GLOBAL_RPT_10.fields_by_name['pacmod_system_override_active'].enum_type = _GLOBAL_RPT_10_PACMOD_SYSTEM_OVERRIDE_ACTIVETYPE
_GLOBAL_RPT_10.fields_by_name['brk_can_timeout'].enum_type = _GLOBAL_RPT_10_BRK_CAN_TIMEOUTTYPE
_GLOBAL_RPT_10_PACMOD_SYSTEM_ENABLEDTYPE.containing_type = _GLOBAL_RPT_10
_GLOBAL_RPT_10_PACMOD_SYSTEM_OVERRIDE_ACTIVETYPE.containing_type = _GLOBAL_RPT_10
_GLOBAL_RPT_10_BRK_CAN_TIMEOUTTYPE.containing_type = _GLOBAL_RPT_10
_CRUISE_CONTROL_BUTTONS_RPT_208.fields_by_name['output_value'].enum_type = _CRUISE_CONTROL_BUTTONS_RPT_208_OUTPUT_VALUETYPE
_CRUISE_CONTROL_BUTTONS_RPT_208.fields_by_name['manual_input'].enum_type = _CRUISE_CONTROL_BUTTONS_RPT_208_MANUAL_INPUTTYPE
_CRUISE_CONTROL_BUTTONS_RPT_208.fields_by_name['commanded_value'].enum_type = _CRUISE_CONTROL_BUTTONS_RPT_208_COMMANDED_VALUETYPE
_CRUISE_CONTROL_BUTTONS_RPT_208_OUTPUT_VALUETYPE.containing_type = _CRUISE_CONTROL_BUTTONS_RPT_208
_CRUISE_CONTROL_BUTTONS_RPT_208_MANUAL_INPUTTYPE.containing_type = _CRUISE_CONTROL_BUTTONS_RPT_208
_CRUISE_CONTROL_BUTTONS_RPT_208_COMMANDED_VALUETYPE.containing_type = _CRUISE_CONTROL_BUTTONS_RPT_208
_VEHICLE_SPEED_RPT_400.fields_by_name['vehicle_speed_valid'].enum_type = _VEHICLE_SPEED_RPT_400_VEHICLE_SPEED_VALIDTYPE
_VEHICLE_SPEED_RPT_400_VEHICLE_SPEED_VALIDTYPE.containing_type = _VEHICLE_SPEED_RPT_400
_MEDIA_CONTROLS_CMD_120.fields_by_name['media_controls_cmd'].enum_type = _MEDIA_CONTROLS_CMD_120_MEDIA_CONTROLS_CMDTYPE
_MEDIA_CONTROLS_CMD_120_MEDIA_CONTROLS_CMDTYPE.containing_type = _MEDIA_CONTROLS_CMD_120
_CRUISE_CONTROL_BUTTONS_CMD_108.fields_by_name['cruise_control_button'].enum_type = _CRUISE_CONTROL_BUTTONS_CMD_108_CRUISE_CONTROL_BUTTONTYPE
_CRUISE_CONTROL_BUTTONS_CMD_108_CRUISE_CONTROL_BUTTONTYPE.containing_type = _CRUISE_CONTROL_BUTTONS_CMD_108
_HORN_RPT_21C.fields_by_name['output_value'].enum_type = _HORN_RPT_21C_OUTPUT_VALUETYPE
_HORN_RPT_21C.fields_by_name['commanded_value'].enum_type = _HORN_RPT_21C_COMMANDED_VALUETYPE
_HORN_RPT_21C.fields_by_name['manual_input'].enum_type = _HORN_RPT_21C_MANUAL_INPUTTYPE
_HORN_RPT_21C_OUTPUT_VALUETYPE.containing_type = _HORN_RPT_21C
_HORN_RPT_21C_COMMANDED_VALUETYPE.containing_type = _HORN_RPT_21C
_HORN_RPT_21C_MANUAL_INPUTTYPE.containing_type = _HORN_RPT_21C
_SHIFT_RPT_228.fields_by_name['manual_input'].enum_type = _SHIFT_RPT_228_MANUAL_INPUTTYPE
_SHIFT_RPT_228.fields_by_name['commanded_value'].enum_type = _SHIFT_RPT_228_COMMANDED_VALUETYPE
_SHIFT_RPT_228.fields_by_name['output_value'].enum_type = _SHIFT_RPT_228_OUTPUT_VALUETYPE
_SHIFT_RPT_228_MANUAL_INPUTTYPE.containing_type = _SHIFT_RPT_228
_SHIFT_RPT_228_COMMANDED_VALUETYPE.containing_type = _SHIFT_RPT_228
_SHIFT_RPT_228_OUTPUT_VALUETYPE.containing_type = _SHIFT_RPT_228
_SHIFT_CMD_128.fields_by_name['shift_cmd'].enum_type = _SHIFT_CMD_128_SHIFT_CMDTYPE
_SHIFT_CMD_128_SHIFT_CMDTYPE.containing_type = _SHIFT_CMD_128
_MEDIA_CONTROLS_RPT_220.fields_by_name['output_value'].enum_type = _MEDIA_CONTROLS_RPT_220_OUTPUT_VALUETYPE
_MEDIA_CONTROLS_RPT_220.fields_by_name['commanded_value'].enum_type = _MEDIA_CONTROLS_RPT_220_COMMANDED_VALUETYPE
_MEDIA_CONTROLS_RPT_220.fields_by_name['manual_input'].enum_type = _MEDIA_CONTROLS_RPT_220_MANUAL_INPUTTYPE
_MEDIA_CONTROLS_RPT_220_OUTPUT_VALUETYPE.containing_type = _MEDIA_CONTROLS_RPT_220
_MEDIA_CONTROLS_RPT_220_COMMANDED_VALUETYPE.containing_type = _MEDIA_CONTROLS_RPT_220
_MEDIA_CONTROLS_RPT_220_MANUAL_INPUTTYPE.containing_type = _MEDIA_CONTROLS_RPT_220
_INTERIOR_LIGHTS_RPT_416.fields_by_name['dim_level'].enum_type = _INTERIOR_LIGHTS_RPT_416_DIM_LEVELTYPE
_INTERIOR_LIGHTS_RPT_416_DIM_LEVELTYPE.containing_type = _INTERIOR_LIGHTS_RPT_416
_TURN_CMD_130.fields_by_name['turn_signal_cmd'].enum_type = _TURN_CMD_130_TURN_SIGNAL_CMDTYPE
_TURN_CMD_130_TURN_SIGNAL_CMDTYPE.containing_type = _TURN_CMD_130
_LEXUS.fields_by_name['hazard_lights_rpt_214'].message_type = _HAZARD_LIGHTS_RPT_214
_LEXUS.fields_by_name['steering_cmd_12c'].message_type = _STEERING_CMD_12C
_LEXUS.fields_by_name['dash_controls_right_rpt_210'].message_type = _DASH_CONTROLS_RIGHT_RPT_210
_LEXUS.fields_by_name['dash_controls_left_cmd_10c'].message_type = _DASH_CONTROLS_LEFT_CMD_10C
_LEXUS.fields_by_name['steering_rpt_22c'].message_type = _STEERING_RPT_22C
_LEXUS.fields_by_name['turn_aux_rpt_330'].message_type = _TURN_AUX_RPT_330
_LEXUS.fields_by_name['headlight_rpt_218'].message_type = _HEADLIGHT_RPT_218
_LEXUS.fields_by_name['hazard_lights_cmd_114'].message_type = _HAZARD_LIGHTS_CMD_114
_LEXUS.fields_by_name['dash_controls_left_rpt_20c'].message_type = _DASH_CONTROLS_LEFT_RPT_20C
_LEXUS.fields_by_name['headlight_aux_rpt_318'].message_type = _HEADLIGHT_AUX_RPT_318
_LEXUS.fields_by_name['dash_controls_right_cmd_110'].message_type = _DASH_CONTROLS_RIGHT_CMD_110
_LEXUS.fields_by_name['wiper_cmd_134'].message_type = _WIPER_CMD_134
_LEXUS.fields_by_name['wiper_rpt_234'].message_type = _WIPER_RPT_234
_LEXUS.fields_by_name['turn_rpt_230'].message_type = _TURN_RPT_230
_LEXUS.fields_by_name['headlight_cmd_118'].message_type = _HEADLIGHT_CMD_118
_LEXUS.fields_by_name['door_rpt_417'].message_type = _DOOR_RPT_417
_LEXUS.fields_by_name['component_rpt_20'].message_type = _COMPONENT_RPT_20
_LEXUS.fields_by_name['wheel_speed_rpt_407'].message_type = _WHEEL_SPEED_RPT_407
_LEXUS.fields_by_name['steering_motor_rpt_3_406'].message_type = _STEERING_MOTOR_RPT_3_406
_LEXUS.fields_by_name['steering_motor_rpt_2_405'].message_type = _STEERING_MOTOR_RPT_2_405
_LEXUS.fields_by_name['steering_motor_rpt_1_404'].message_type = _STEERING_MOTOR_RPT_1_404
_LEXUS.fields_by_name['brake_motor_rpt_3_403'].message_type = _BRAKE_MOTOR_RPT_3_403
_LEXUS.fields_by_name['brake_motor_rpt_2_402'].message_type = _BRAKE_MOTOR_RPT_2_402
_LEXUS.fields_by_name['brake_motor_rpt_1_401'].message_type = _BRAKE_MOTOR_RPT_1_401
_LEXUS.fields_by_name['wiper_aux_rpt_334'].message_type = _WIPER_AUX_RPT_334
_LEXUS.fields_by_name['shift_aux_rpt_328'].message_type = _SHIFT_AUX_RPT_328
_LEXUS.fields_by_name['accel_rpt_200'].message_type = _ACCEL_RPT_200
_LEXUS.fields_by_name['brake_rpt_204'].message_type = _BRAKE_RPT_204
_LEXUS.fields_by_name['horn_cmd_11c'].message_type = _HORN_CMD_11C
_LEXUS.fields_by_name['global_rpt_10'].message_type = _GLOBAL_RPT_10
_LEXUS.fields_by_name['accel_aux_rpt_300'].message_type = _ACCEL_AUX_RPT_300
_LEXUS.fields_by_name['cruise_control_buttons_rpt_208'].message_type = _CRUISE_CONTROL_BUTTONS_RPT_208
_LEXUS.fields_by_name['vehicle_speed_rpt_400'].message_type = _VEHICLE_SPEED_RPT_400
_LEXUS.fields_by_name['brake_aux_rpt_304'].message_type = _BRAKE_AUX_RPT_304
_LEXUS.fields_by_name['media_controls_cmd_120'].message_type = _MEDIA_CONTROLS_CMD_120
_LEXUS.fields_by_name['cruise_control_buttons_cmd_108'].message_type = _CRUISE_CONTROL_BUTTONS_CMD_108
_LEXUS.fields_by_name['parking_brake_cmd_124'].message_type = _PARKING_BRAKE_CMD_124
_LEXUS.fields_by_name['horn_rpt_21c'].message_type = _HORN_RPT_21C
_LEXUS.fields_by_name['shift_rpt_228'].message_type = _SHIFT_RPT_228
_LEXUS.fields_by_name['shift_cmd_128'].message_type = _SHIFT_CMD_128
_LEXUS.fields_by_name['accel_cmd_100'].message_type = _ACCEL_CMD_100
_LEXUS.fields_by_name['parking_brake_rpt_224'].message_type = _PARKING_BRAKE_RPT_224
_LEXUS.fields_by_name['brake_cmd_104'].message_type = _BRAKE_CMD_104
_LEXUS.fields_by_name['media_controls_rpt_220'].message_type = _MEDIA_CONTROLS_RPT_220
_LEXUS.fields_by_name['steering_aux_rpt_32c'].message_type = _STEERING_AUX_RPT_32C
_LEXUS.fields_by_name['lat_lon_heading_rpt_40e'].message_type = _LAT_LON_HEADING_RPT_40E
_LEXUS.fields_by_name['yaw_rate_rpt_40d'].message_type = _YAW_RATE_RPT_40D
_LEXUS.fields_by_name['date_time_rpt_40f'].message_type = _DATE_TIME_RPT_40F
_LEXUS.fields_by_name['vin_rpt_414'].message_type = _VIN_RPT_414
_LEXUS.fields_by_name['occupancy_rpt_415'].message_type = _OCCUPANCY_RPT_415
_LEXUS.fields_by_name['interior_lights_rpt_416'].message_type = _INTERIOR_LIGHTS_RPT_416
_LEXUS.fields_by_name['turn_cmd_130'].message_type = _TURN_CMD_130
_LEXUS.fields_by_name['detected_object_rpt_411'].message_type = _DETECTED_OBJECT_RPT_411
_LEXUS.fields_by_name['veh_specific_rpt_1_412'].message_type = _VEH_SPECIFIC_RPT_1_412
_LEXUS.fields_by_name['veh_dynamics_rpt_413'].message_type = _VEH_DYNAMICS_RPT_413
_LEXUS.fields_by_name['rear_lights_rpt_418'].message_type = _REAR_LIGHTS_RPT_418
DESCRIPTOR.message_types_by_name['Hazard_lights_rpt_214'] = _HAZARD_LIGHTS_RPT_214
DESCRIPTOR.message_types_by_name['Steering_cmd_12c'] = _STEERING_CMD_12C
DESCRIPTOR.message_types_by_name['Dash_controls_right_rpt_210'] = _DASH_CONTROLS_RIGHT_RPT_210
DESCRIPTOR.message_types_by_name['Dash_controls_left_cmd_10c'] = _DASH_CONTROLS_LEFT_CMD_10C
DESCRIPTOR.message_types_by_name['Steering_rpt_22c'] = _STEERING_RPT_22C
DESCRIPTOR.message_types_by_name['Turn_aux_rpt_330'] = _TURN_AUX_RPT_330
DESCRIPTOR.message_types_by_name['Headlight_rpt_218'] = _HEADLIGHT_RPT_218
DESCRIPTOR.message_types_by_name['Hazard_lights_cmd_114'] = _HAZARD_LIGHTS_CMD_114
DESCRIPTOR.message_types_by_name['Dash_controls_left_rpt_20c'] = _DASH_CONTROLS_LEFT_RPT_20C
DESCRIPTOR.message_types_by_name['Headlight_aux_rpt_318'] = _HEADLIGHT_AUX_RPT_318
DESCRIPTOR.message_types_by_name['Dash_controls_right_cmd_110'] = _DASH_CONTROLS_RIGHT_CMD_110
DESCRIPTOR.message_types_by_name['Wiper_cmd_134'] = _WIPER_CMD_134
DESCRIPTOR.message_types_by_name['Wiper_rpt_234'] = _WIPER_RPT_234
DESCRIPTOR.message_types_by_name['Turn_rpt_230'] = _TURN_RPT_230
DESCRIPTOR.message_types_by_name['Headlight_cmd_118'] = _HEADLIGHT_CMD_118
DESCRIPTOR.message_types_by_name['Door_rpt_417'] = _DOOR_RPT_417
DESCRIPTOR.message_types_by_name['Component_rpt_20'] = _COMPONENT_RPT_20
DESCRIPTOR.message_types_by_name['Wheel_speed_rpt_407'] = _WHEEL_SPEED_RPT_407
DESCRIPTOR.message_types_by_name['Steering_motor_rpt_3_406'] = _STEERING_MOTOR_RPT_3_406
DESCRIPTOR.message_types_by_name['Steering_motor_rpt_2_405'] = _STEERING_MOTOR_RPT_2_405
DESCRIPTOR.message_types_by_name['Steering_motor_rpt_1_404'] = _STEERING_MOTOR_RPT_1_404
DESCRIPTOR.message_types_by_name['Brake_motor_rpt_3_403'] = _BRAKE_MOTOR_RPT_3_403
DESCRIPTOR.message_types_by_name['Brake_motor_rpt_2_402'] = _BRAKE_MOTOR_RPT_2_402
DESCRIPTOR.message_types_by_name['Brake_motor_rpt_1_401'] = _BRAKE_MOTOR_RPT_1_401
DESCRIPTOR.message_types_by_name['Wiper_aux_rpt_334'] = _WIPER_AUX_RPT_334
DESCRIPTOR.message_types_by_name['Shift_aux_rpt_328'] = _SHIFT_AUX_RPT_328
DESCRIPTOR.message_types_by_name['Accel_rpt_200'] = _ACCEL_RPT_200
DESCRIPTOR.message_types_by_name['Brake_rpt_204'] = _BRAKE_RPT_204
DESCRIPTOR.message_types_by_name['Horn_cmd_11c'] = _HORN_CMD_11C
DESCRIPTOR.message_types_by_name['Global_rpt_10'] = _GLOBAL_RPT_10
DESCRIPTOR.message_types_by_name['Accel_aux_rpt_300'] = _ACCEL_AUX_RPT_300
DESCRIPTOR.message_types_by_name['Cruise_control_buttons_rpt_208'] = _CRUISE_CONTROL_BUTTONS_RPT_208
DESCRIPTOR.message_types_by_name['Vehicle_speed_rpt_400'] = _VEHICLE_SPEED_RPT_400
DESCRIPTOR.message_types_by_name['Brake_aux_rpt_304'] = _BRAKE_AUX_RPT_304
DESCRIPTOR.message_types_by_name['Media_controls_cmd_120'] = _MEDIA_CONTROLS_CMD_120
DESCRIPTOR.message_types_by_name['Cruise_control_buttons_cmd_108'] = _CRUISE_CONTROL_BUTTONS_CMD_108
DESCRIPTOR.message_types_by_name['Parking_brake_cmd_124'] = _PARKING_BRAKE_CMD_124
DESCRIPTOR.message_types_by_name['Horn_rpt_21c'] = _HORN_RPT_21C
DESCRIPTOR.message_types_by_name['Shift_rpt_228'] = _SHIFT_RPT_228
DESCRIPTOR.message_types_by_name['Shift_cmd_128'] = _SHIFT_CMD_128
DESCRIPTOR.message_types_by_name['Accel_cmd_100'] = _ACCEL_CMD_100
DESCRIPTOR.message_types_by_name['Parking_brake_rpt_224'] = _PARKING_BRAKE_RPT_224
DESCRIPTOR.message_types_by_name['Brake_cmd_104'] = _BRAKE_CMD_104
DESCRIPTOR.message_types_by_name['Media_controls_rpt_220'] = _MEDIA_CONTROLS_RPT_220
DESCRIPTOR.message_types_by_name['Steering_aux_rpt_32c'] = _STEERING_AUX_RPT_32C
DESCRIPTOR.message_types_by_name['Lat_lon_heading_rpt_40e'] = _LAT_LON_HEADING_RPT_40E
DESCRIPTOR.message_types_by_name['Yaw_rate_rpt_40d'] = _YAW_RATE_RPT_40D
DESCRIPTOR.message_types_by_name['Date_time_rpt_40f'] = _DATE_TIME_RPT_40F
DESCRIPTOR.message_types_by_name['Vin_rpt_414'] = _VIN_RPT_414
DESCRIPTOR.message_types_by_name['Occupancy_rpt_415'] = _OCCUPANCY_RPT_415
DESCRIPTOR.message_types_by_name['Interior_lights_rpt_416'] = _INTERIOR_LIGHTS_RPT_416
DESCRIPTOR.message_types_by_name['Turn_cmd_130'] = _TURN_CMD_130
DESCRIPTOR.message_types_by_name['Detected_object_rpt_411'] = _DETECTED_OBJECT_RPT_411
DESCRIPTOR.message_types_by_name['Veh_specific_rpt_1_412'] = _VEH_SPECIFIC_RPT_1_412
DESCRIPTOR.message_types_by_name['Veh_dynamics_rpt_413'] = _VEH_DYNAMICS_RPT_413
DESCRIPTOR.message_types_by_name['Rear_lights_rpt_418'] = _REAR_LIGHTS_RPT_418
DESCRIPTOR.message_types_by_name['Lexus'] = _LEXUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Hazard_lights_rpt_214 = _reflection.GeneratedProtocolMessageType('Hazard_lights_rpt_214', (_message.Message,), {
  'DESCRIPTOR' : _HAZARD_LIGHTS_RPT_214,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Hazard_lights_rpt_214)
  })
_sym_db.RegisterMessage(Hazard_lights_rpt_214)

Steering_cmd_12c = _reflection.GeneratedProtocolMessageType('Steering_cmd_12c', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_CMD_12C,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_cmd_12c)
  })
_sym_db.RegisterMessage(Steering_cmd_12c)

Dash_controls_right_rpt_210 = _reflection.GeneratedProtocolMessageType('Dash_controls_right_rpt_210', (_message.Message,), {
  'DESCRIPTOR' : _DASH_CONTROLS_RIGHT_RPT_210,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Dash_controls_right_rpt_210)
  })
_sym_db.RegisterMessage(Dash_controls_right_rpt_210)

Dash_controls_left_cmd_10c = _reflection.GeneratedProtocolMessageType('Dash_controls_left_cmd_10c', (_message.Message,), {
  'DESCRIPTOR' : _DASH_CONTROLS_LEFT_CMD_10C,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Dash_controls_left_cmd_10c)
  })
_sym_db.RegisterMessage(Dash_controls_left_cmd_10c)

Steering_rpt_22c = _reflection.GeneratedProtocolMessageType('Steering_rpt_22c', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_RPT_22C,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_rpt_22c)
  })
_sym_db.RegisterMessage(Steering_rpt_22c)

Turn_aux_rpt_330 = _reflection.GeneratedProtocolMessageType('Turn_aux_rpt_330', (_message.Message,), {
  'DESCRIPTOR' : _TURN_AUX_RPT_330,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Turn_aux_rpt_330)
  })
_sym_db.RegisterMessage(Turn_aux_rpt_330)

Headlight_rpt_218 = _reflection.GeneratedProtocolMessageType('Headlight_rpt_218', (_message.Message,), {
  'DESCRIPTOR' : _HEADLIGHT_RPT_218,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Headlight_rpt_218)
  })
_sym_db.RegisterMessage(Headlight_rpt_218)

Hazard_lights_cmd_114 = _reflection.GeneratedProtocolMessageType('Hazard_lights_cmd_114', (_message.Message,), {
  'DESCRIPTOR' : _HAZARD_LIGHTS_CMD_114,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Hazard_lights_cmd_114)
  })
_sym_db.RegisterMessage(Hazard_lights_cmd_114)

Dash_controls_left_rpt_20c = _reflection.GeneratedProtocolMessageType('Dash_controls_left_rpt_20c', (_message.Message,), {
  'DESCRIPTOR' : _DASH_CONTROLS_LEFT_RPT_20C,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Dash_controls_left_rpt_20c)
  })
_sym_db.RegisterMessage(Dash_controls_left_rpt_20c)

Headlight_aux_rpt_318 = _reflection.GeneratedProtocolMessageType('Headlight_aux_rpt_318', (_message.Message,), {
  'DESCRIPTOR' : _HEADLIGHT_AUX_RPT_318,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Headlight_aux_rpt_318)
  })
_sym_db.RegisterMessage(Headlight_aux_rpt_318)

Dash_controls_right_cmd_110 = _reflection.GeneratedProtocolMessageType('Dash_controls_right_cmd_110', (_message.Message,), {
  'DESCRIPTOR' : _DASH_CONTROLS_RIGHT_CMD_110,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Dash_controls_right_cmd_110)
  })
_sym_db.RegisterMessage(Dash_controls_right_cmd_110)

Wiper_cmd_134 = _reflection.GeneratedProtocolMessageType('Wiper_cmd_134', (_message.Message,), {
  'DESCRIPTOR' : _WIPER_CMD_134,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Wiper_cmd_134)
  })
_sym_db.RegisterMessage(Wiper_cmd_134)

Wiper_rpt_234 = _reflection.GeneratedProtocolMessageType('Wiper_rpt_234', (_message.Message,), {
  'DESCRIPTOR' : _WIPER_RPT_234,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Wiper_rpt_234)
  })
_sym_db.RegisterMessage(Wiper_rpt_234)

Turn_rpt_230 = _reflection.GeneratedProtocolMessageType('Turn_rpt_230', (_message.Message,), {
  'DESCRIPTOR' : _TURN_RPT_230,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Turn_rpt_230)
  })
_sym_db.RegisterMessage(Turn_rpt_230)

Headlight_cmd_118 = _reflection.GeneratedProtocolMessageType('Headlight_cmd_118', (_message.Message,), {
  'DESCRIPTOR' : _HEADLIGHT_CMD_118,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Headlight_cmd_118)
  })
_sym_db.RegisterMessage(Headlight_cmd_118)

Door_rpt_417 = _reflection.GeneratedProtocolMessageType('Door_rpt_417', (_message.Message,), {
  'DESCRIPTOR' : _DOOR_RPT_417,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Door_rpt_417)
  })
_sym_db.RegisterMessage(Door_rpt_417)

Component_rpt_20 = _reflection.GeneratedProtocolMessageType('Component_rpt_20', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENT_RPT_20,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Component_rpt_20)
  })
_sym_db.RegisterMessage(Component_rpt_20)

Wheel_speed_rpt_407 = _reflection.GeneratedProtocolMessageType('Wheel_speed_rpt_407', (_message.Message,), {
  'DESCRIPTOR' : _WHEEL_SPEED_RPT_407,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Wheel_speed_rpt_407)
  })
_sym_db.RegisterMessage(Wheel_speed_rpt_407)

Steering_motor_rpt_3_406 = _reflection.GeneratedProtocolMessageType('Steering_motor_rpt_3_406', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_MOTOR_RPT_3_406,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_motor_rpt_3_406)
  })
_sym_db.RegisterMessage(Steering_motor_rpt_3_406)

Steering_motor_rpt_2_405 = _reflection.GeneratedProtocolMessageType('Steering_motor_rpt_2_405', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_MOTOR_RPT_2_405,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_motor_rpt_2_405)
  })
_sym_db.RegisterMessage(Steering_motor_rpt_2_405)

Steering_motor_rpt_1_404 = _reflection.GeneratedProtocolMessageType('Steering_motor_rpt_1_404', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_MOTOR_RPT_1_404,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_motor_rpt_1_404)
  })
_sym_db.RegisterMessage(Steering_motor_rpt_1_404)

Brake_motor_rpt_3_403 = _reflection.GeneratedProtocolMessageType('Brake_motor_rpt_3_403', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_MOTOR_RPT_3_403,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_motor_rpt_3_403)
  })
_sym_db.RegisterMessage(Brake_motor_rpt_3_403)

Brake_motor_rpt_2_402 = _reflection.GeneratedProtocolMessageType('Brake_motor_rpt_2_402', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_MOTOR_RPT_2_402,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_motor_rpt_2_402)
  })
_sym_db.RegisterMessage(Brake_motor_rpt_2_402)

Brake_motor_rpt_1_401 = _reflection.GeneratedProtocolMessageType('Brake_motor_rpt_1_401', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_MOTOR_RPT_1_401,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_motor_rpt_1_401)
  })
_sym_db.RegisterMessage(Brake_motor_rpt_1_401)

Wiper_aux_rpt_334 = _reflection.GeneratedProtocolMessageType('Wiper_aux_rpt_334', (_message.Message,), {
  'DESCRIPTOR' : _WIPER_AUX_RPT_334,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Wiper_aux_rpt_334)
  })
_sym_db.RegisterMessage(Wiper_aux_rpt_334)

Shift_aux_rpt_328 = _reflection.GeneratedProtocolMessageType('Shift_aux_rpt_328', (_message.Message,), {
  'DESCRIPTOR' : _SHIFT_AUX_RPT_328,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Shift_aux_rpt_328)
  })
_sym_db.RegisterMessage(Shift_aux_rpt_328)

Accel_rpt_200 = _reflection.GeneratedProtocolMessageType('Accel_rpt_200', (_message.Message,), {
  'DESCRIPTOR' : _ACCEL_RPT_200,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Accel_rpt_200)
  })
_sym_db.RegisterMessage(Accel_rpt_200)

Brake_rpt_204 = _reflection.GeneratedProtocolMessageType('Brake_rpt_204', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_RPT_204,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_rpt_204)
  })
_sym_db.RegisterMessage(Brake_rpt_204)

Horn_cmd_11c = _reflection.GeneratedProtocolMessageType('Horn_cmd_11c', (_message.Message,), {
  'DESCRIPTOR' : _HORN_CMD_11C,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Horn_cmd_11c)
  })
_sym_db.RegisterMessage(Horn_cmd_11c)

Global_rpt_10 = _reflection.GeneratedProtocolMessageType('Global_rpt_10', (_message.Message,), {
  'DESCRIPTOR' : _GLOBAL_RPT_10,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Global_rpt_10)
  })
_sym_db.RegisterMessage(Global_rpt_10)

Accel_aux_rpt_300 = _reflection.GeneratedProtocolMessageType('Accel_aux_rpt_300', (_message.Message,), {
  'DESCRIPTOR' : _ACCEL_AUX_RPT_300,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Accel_aux_rpt_300)
  })
_sym_db.RegisterMessage(Accel_aux_rpt_300)

Cruise_control_buttons_rpt_208 = _reflection.GeneratedProtocolMessageType('Cruise_control_buttons_rpt_208', (_message.Message,), {
  'DESCRIPTOR' : _CRUISE_CONTROL_BUTTONS_RPT_208,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Cruise_control_buttons_rpt_208)
  })
_sym_db.RegisterMessage(Cruise_control_buttons_rpt_208)

Vehicle_speed_rpt_400 = _reflection.GeneratedProtocolMessageType('Vehicle_speed_rpt_400', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLE_SPEED_RPT_400,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vehicle_speed_rpt_400)
  })
_sym_db.RegisterMessage(Vehicle_speed_rpt_400)

Brake_aux_rpt_304 = _reflection.GeneratedProtocolMessageType('Brake_aux_rpt_304', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_AUX_RPT_304,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_aux_rpt_304)
  })
_sym_db.RegisterMessage(Brake_aux_rpt_304)

Media_controls_cmd_120 = _reflection.GeneratedProtocolMessageType('Media_controls_cmd_120', (_message.Message,), {
  'DESCRIPTOR' : _MEDIA_CONTROLS_CMD_120,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Media_controls_cmd_120)
  })
_sym_db.RegisterMessage(Media_controls_cmd_120)

Cruise_control_buttons_cmd_108 = _reflection.GeneratedProtocolMessageType('Cruise_control_buttons_cmd_108', (_message.Message,), {
  'DESCRIPTOR' : _CRUISE_CONTROL_BUTTONS_CMD_108,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Cruise_control_buttons_cmd_108)
  })
_sym_db.RegisterMessage(Cruise_control_buttons_cmd_108)

Parking_brake_cmd_124 = _reflection.GeneratedProtocolMessageType('Parking_brake_cmd_124', (_message.Message,), {
  'DESCRIPTOR' : _PARKING_BRAKE_CMD_124,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Parking_brake_cmd_124)
  })
_sym_db.RegisterMessage(Parking_brake_cmd_124)

Horn_rpt_21c = _reflection.GeneratedProtocolMessageType('Horn_rpt_21c', (_message.Message,), {
  'DESCRIPTOR' : _HORN_RPT_21C,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Horn_rpt_21c)
  })
_sym_db.RegisterMessage(Horn_rpt_21c)

Shift_rpt_228 = _reflection.GeneratedProtocolMessageType('Shift_rpt_228', (_message.Message,), {
  'DESCRIPTOR' : _SHIFT_RPT_228,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Shift_rpt_228)
  })
_sym_db.RegisterMessage(Shift_rpt_228)

Shift_cmd_128 = _reflection.GeneratedProtocolMessageType('Shift_cmd_128', (_message.Message,), {
  'DESCRIPTOR' : _SHIFT_CMD_128,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Shift_cmd_128)
  })
_sym_db.RegisterMessage(Shift_cmd_128)

Accel_cmd_100 = _reflection.GeneratedProtocolMessageType('Accel_cmd_100', (_message.Message,), {
  'DESCRIPTOR' : _ACCEL_CMD_100,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Accel_cmd_100)
  })
_sym_db.RegisterMessage(Accel_cmd_100)

Parking_brake_rpt_224 = _reflection.GeneratedProtocolMessageType('Parking_brake_rpt_224', (_message.Message,), {
  'DESCRIPTOR' : _PARKING_BRAKE_RPT_224,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Parking_brake_rpt_224)
  })
_sym_db.RegisterMessage(Parking_brake_rpt_224)

Brake_cmd_104 = _reflection.GeneratedProtocolMessageType('Brake_cmd_104', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_CMD_104,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_cmd_104)
  })
_sym_db.RegisterMessage(Brake_cmd_104)

Media_controls_rpt_220 = _reflection.GeneratedProtocolMessageType('Media_controls_rpt_220', (_message.Message,), {
  'DESCRIPTOR' : _MEDIA_CONTROLS_RPT_220,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Media_controls_rpt_220)
  })
_sym_db.RegisterMessage(Media_controls_rpt_220)

Steering_aux_rpt_32c = _reflection.GeneratedProtocolMessageType('Steering_aux_rpt_32c', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_AUX_RPT_32C,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_aux_rpt_32c)
  })
_sym_db.RegisterMessage(Steering_aux_rpt_32c)

Lat_lon_heading_rpt_40e = _reflection.GeneratedProtocolMessageType('Lat_lon_heading_rpt_40e', (_message.Message,), {
  'DESCRIPTOR' : _LAT_LON_HEADING_RPT_40E,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Lat_lon_heading_rpt_40e)
  })
_sym_db.RegisterMessage(Lat_lon_heading_rpt_40e)

Yaw_rate_rpt_40d = _reflection.GeneratedProtocolMessageType('Yaw_rate_rpt_40d', (_message.Message,), {
  'DESCRIPTOR' : _YAW_RATE_RPT_40D,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Yaw_rate_rpt_40d)
  })
_sym_db.RegisterMessage(Yaw_rate_rpt_40d)

Date_time_rpt_40f = _reflection.GeneratedProtocolMessageType('Date_time_rpt_40f', (_message.Message,), {
  'DESCRIPTOR' : _DATE_TIME_RPT_40F,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Date_time_rpt_40f)
  })
_sym_db.RegisterMessage(Date_time_rpt_40f)

Vin_rpt_414 = _reflection.GeneratedProtocolMessageType('Vin_rpt_414', (_message.Message,), {
  'DESCRIPTOR' : _VIN_RPT_414,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vin_rpt_414)
  })
_sym_db.RegisterMessage(Vin_rpt_414)

Occupancy_rpt_415 = _reflection.GeneratedProtocolMessageType('Occupancy_rpt_415', (_message.Message,), {
  'DESCRIPTOR' : _OCCUPANCY_RPT_415,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Occupancy_rpt_415)
  })
_sym_db.RegisterMessage(Occupancy_rpt_415)

Interior_lights_rpt_416 = _reflection.GeneratedProtocolMessageType('Interior_lights_rpt_416', (_message.Message,), {
  'DESCRIPTOR' : _INTERIOR_LIGHTS_RPT_416,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Interior_lights_rpt_416)
  })
_sym_db.RegisterMessage(Interior_lights_rpt_416)

Turn_cmd_130 = _reflection.GeneratedProtocolMessageType('Turn_cmd_130', (_message.Message,), {
  'DESCRIPTOR' : _TURN_CMD_130,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Turn_cmd_130)
  })
_sym_db.RegisterMessage(Turn_cmd_130)

Detected_object_rpt_411 = _reflection.GeneratedProtocolMessageType('Detected_object_rpt_411', (_message.Message,), {
  'DESCRIPTOR' : _DETECTED_OBJECT_RPT_411,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Detected_object_rpt_411)
  })
_sym_db.RegisterMessage(Detected_object_rpt_411)

Veh_specific_rpt_1_412 = _reflection.GeneratedProtocolMessageType('Veh_specific_rpt_1_412', (_message.Message,), {
  'DESCRIPTOR' : _VEH_SPECIFIC_RPT_1_412,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Veh_specific_rpt_1_412)
  })
_sym_db.RegisterMessage(Veh_specific_rpt_1_412)

Veh_dynamics_rpt_413 = _reflection.GeneratedProtocolMessageType('Veh_dynamics_rpt_413', (_message.Message,), {
  'DESCRIPTOR' : _VEH_DYNAMICS_RPT_413,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Veh_dynamics_rpt_413)
  })
_sym_db.RegisterMessage(Veh_dynamics_rpt_413)

Rear_lights_rpt_418 = _reflection.GeneratedProtocolMessageType('Rear_lights_rpt_418', (_message.Message,), {
  'DESCRIPTOR' : _REAR_LIGHTS_RPT_418,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Rear_lights_rpt_418)
  })
_sym_db.RegisterMessage(Rear_lights_rpt_418)

Lexus = _reflection.GeneratedProtocolMessageType('Lexus', (_message.Message,), {
  'DESCRIPTOR' : _LEXUS,
  '__module__' : 'modules.canbus.proto.lexus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Lexus)
  })
_sym_db.RegisterMessage(Lexus)


# @@protoc_insertion_point(module_scope)
