# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/canbus/proto/chassis_detail.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.configs.proto import vehicle_config_pb2 as modules_dot_common_dot_configs_dot_proto_dot_vehicle__config__pb2
from modules.canbus.proto import chassis_pb2 as modules_dot_canbus_dot_proto_dot_chassis__pb2
from modules.canbus.proto import ch_pb2 as modules_dot_canbus_dot_proto_dot_ch__pb2
from modules.canbus.proto import devkit_pb2 as modules_dot_canbus_dot_proto_dot_devkit__pb2
from modules.canbus.proto import ge3_pb2 as modules_dot_canbus_dot_proto_dot_ge3__pb2
from modules.canbus.proto import lexus_pb2 as modules_dot_canbus_dot_proto_dot_lexus__pb2
from modules.canbus.proto import transit_pb2 as modules_dot_canbus_dot_proto_dot_transit__pb2
from modules.canbus.proto import wey_pb2 as modules_dot_canbus_dot_proto_dot_wey__pb2
from modules.canbus.proto import zhongyun_pb2 as modules_dot_canbus_dot_proto_dot_zhongyun__pb2
from modules.canbus.proto import neolix_edu_pb2 as modules_dot_canbus_dot_proto_dot_neolix__edu__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/canbus/proto/chassis_detail.proto',
  package='apollo.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)modules/canbus/proto/chassis_detail.proto\x12\rapollo.canbus\x1a\x31modules/common/configs/proto/vehicle_config.proto\x1a\"modules/canbus/proto/chassis.proto\x1a\x1dmodules/canbus/proto/ch.proto\x1a!modules/canbus/proto/devkit.proto\x1a\x1emodules/canbus/proto/ge3.proto\x1a modules/canbus/proto/lexus.proto\x1a\"modules/canbus/proto/transit.proto\x1a\x1emodules/canbus/proto/wey.proto\x1a#modules/canbus/proto/zhongyun.proto\x1a%modules/canbus/proto/neolix_edu.proto\"\xf4\x08\n\rChassisDetail\x12\x33\n\x08\x63\x61r_type\x18\x01 \x01(\x0e\x32!.apollo.canbus.ChassisDetail.Type\x12\'\n\x05\x62\x61sic\x18\x02 \x01(\x0b\x32\x18.apollo.canbus.BasicInfo\x12%\n\x06safety\x18\x03 \x01(\x0b\x32\x15.apollo.canbus.Safety\x12!\n\x04gear\x18\x04 \x01(\x0b\x32\x13.apollo.canbus.Gear\x12\x1f\n\x03\x65ms\x18\x05 \x01(\x0b\x32\x12.apollo.canbus.Ems\x12\x1f\n\x03\x65sp\x18\x06 \x01(\x0b\x32\x12.apollo.canbus.Esp\x12\x1f\n\x03gas\x18\x07 \x01(\x0b\x32\x12.apollo.canbus.Gas\x12\x1f\n\x03\x65pb\x18\x08 \x01(\x0b\x32\x12.apollo.canbus.Epb\x12#\n\x05\x62rake\x18\t \x01(\x0b\x32\x14.apollo.canbus.Brake\x12\x31\n\x0c\x64\x65\x63\x65leration\x18\n \x01(\x0b\x32\x1b.apollo.canbus.Deceleration\x12.\n\x0bvehicle_spd\x18\x0b \x01(\x0b\x32\x19.apollo.canbus.VehicleSpd\x12\x1f\n\x03\x65ps\x18\x0c \x01(\x0b\x32\x12.apollo.canbus.Eps\x12#\n\x05light\x18\r \x01(\x0b\x32\x14.apollo.canbus.Light\x12\'\n\x07\x62\x61ttery\x18\x0e \x01(\x0b\x32\x16.apollo.canbus.Battery\x12:\n\x0e\x63heck_response\x18\x0f \x01(\x0b\x32\".apollo.canbus.CheckResponseSignal\x12+\n\x07license\x18\x10 \x01(\x0b\x32\x16.apollo.canbus.LicenseB\x02\x18\x01\x12)\n\x08surround\x18\x11 \x01(\x0b\x32\x17.apollo.canbus.Surround\x12\x1f\n\x03gem\x18\x12 \x01(\x0b\x32\x12.apollo.canbus.Gem\x12#\n\x05lexus\x18\x13 \x01(\x0b\x32\x14.apollo.canbus.Lexus\x12\'\n\x07transit\x18\x14 \x01(\x0b\x32\x16.apollo.canbus.Transit\x12\x1f\n\x03ge3\x18\x15 \x01(\x0b\x32\x12.apollo.canbus.Ge3\x12\x1f\n\x03wey\x18\x16 \x01(\x0b\x32\x12.apollo.canbus.Wey\x12)\n\x08zhongyun\x18\x17 \x01(\x0b\x32\x17.apollo.canbus.Zhongyun\x12\x1d\n\x02\x63h\x18\x18 \x01(\x0b\x32\x11.apollo.canbus.Ch\x12%\n\x06\x64\x65vkit\x18\x19 \x01(\x0b\x32\x15.apollo.canbus.Devkit\x12-\n\nneolix_edu\x18\x1a \x01(\x0b\x32\x19.apollo.canbus.Neolix_edu\x12,\n\nvehicle_id\x18\x65 \x01(\x0b\x32\x18.apollo.common.VehicleID\"-\n\x04Type\x12\x0f\n\x0bQIRUI_EQ_15\x10\x00\x12\x14\n\x10\x43HANGAN_RUICHENG\x10\x01\"\xeb\x01\n\x13\x43heckResponseSignal\x12\x1c\n\ris_eps_online\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\ris_epb_online\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\ris_esp_online\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x1d\n\x0eis_vtog_online\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\ris_scu_online\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x10is_switch_online\x18\x06 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\ris_vcu_online\x18\x07 \x01(\x08:\x05\x66\x61lse\"6\n\x07\x42\x61ttery\x12\x17\n\x0f\x62\x61ttery_percent\x18\x01 \x01(\x01\x12\x12\n\nfuel_level\x18\x02 \x01(\x01\"\xb1\t\n\x05Light\x12;\n\x0fturn_light_type\x18\x01 \x01(\x0e\x32\".apollo.canbus.Light.TurnLightType\x12\x39\n\x0e\x62\x65\x61m_lamp_type\x18\x02 \x01(\x0e\x32!.apollo.canbus.Light.BeamLampType\x12\x18\n\x10is_brake_lamp_on\x18\x03 \x01(\x08\x12\x15\n\ris_auto_light\x18\x04 \x01(\x08\x12\x12\n\nwiper_gear\x18\x05 \x01(\x05\x12\x13\n\x0blotion_gear\x18\x06 \x01(\x05\x12\x12\n\nis_horn_on\x18\x07 \x01(\x08\x12?\n\x11lincoln_lamp_type\x18\x08 \x01(\x0e\x32$.apollo.canbus.Light.LincolnLampType\x12<\n\rlincoln_wiper\x18\t \x01(\x0e\x32%.apollo.canbus.Light.LincolnWiperType\x12@\n\x0flincoln_ambient\x18\n \x01(\x0e\x32\'.apollo.canbus.Light.LincolnAmbientType\"[\n\rTurnLightType\x12\x12\n\x0eTURN_LIGHT_OFF\x10\x00\x12\x10\n\x0cTURN_LEFT_ON\x10\x01\x12\x11\n\rTURN_RIGHT_ON\x10\x02\x12\x11\n\rTURN_LIGHT_ON\x10\x03\"?\n\x0c\x42\x65\x61mLampType\x12\x0c\n\x08\x42\x45\x41M_OFF\x10\x00\x12\x10\n\x0cHIGH_BEAM_ON\x10\x01\x12\x0f\n\x0bLOW_BEAM_ON\x10\x02\"Y\n\x0fLincolnLampType\x12\r\n\tBEAM_NULL\x10\x00\x12\x16\n\x12\x42\x45\x41M_FLASH_TO_PASS\x10\x01\x12\r\n\tBEAM_HIGH\x10\x02\x12\x10\n\x0c\x42\x45\x41M_INVALID\x10\x03\"\xdc\x02\n\x10LincolnWiperType\x12\r\n\tWIPER_OFF\x10\x00\x12\x12\n\x0eWIPER_AUTO_OFF\x10\x01\x12\x14\n\x10WIPER_OFF_MOVING\x10\x02\x12\x14\n\x10WIPER_MANUAL_OFF\x10\x03\x12\x13\n\x0fWIPER_MANUAL_ON\x10\x04\x12\x14\n\x10WIPER_MANUAL_LOW\x10\x05\x12\x15\n\x11WIPER_MANUAL_HIGH\x10\x06\x12\x14\n\x10WIPER_MIST_FLICK\x10\x07\x12\x0e\n\nWIPER_WASH\x10\x08\x12\x12\n\x0eWIPER_AUTO_LOW\x10\t\x12\x13\n\x0fWIPER_AUTO_HIGH\x10\n\x12\x17\n\x13WIPER_COURTESY_WIPE\x10\x0b\x12\x15\n\x11WIPER_AUTO_ADJUST\x10\x0c\x12\x12\n\x0eWIPER_RESERVED\x10\r\x12\x11\n\rWIPER_STALLED\x10\x0e\x12\x11\n\rWIPER_NO_DATA\x10\x0f\"\xa8\x01\n\x12LincolnAmbientType\x12\x10\n\x0c\x41MBIENT_DARK\x10\x00\x12\x11\n\rAMBIENT_LIGHT\x10\x01\x12\x14\n\x10\x41MBIENT_TWILIGHT\x10\x02\x12\x15\n\x11\x41MBIENT_TUNNEL_ON\x10\x03\x12\x16\n\x12\x41MBIENT_TUNNEL_OFF\x10\x04\x12\x13\n\x0f\x41MBIENT_INVALID\x10\x05\x12\x13\n\x0f\x41MBIENT_NO_DATA\x10\x07\"\x85\x06\n\x03\x45ps\x12\x13\n\x0bis_eps_fail\x18\x01 \x01(\x08\x12\x32\n\x11\x65ps_control_state\x18\x02 \x01(\x0e\x32\x17.apollo.canbus.Eps.Type\x12\x1c\n\x14\x65ps_driver_hand_torq\x18\x03 \x01(\x01\x12\x1f\n\x17is_steering_angle_valid\x18\x04 \x01(\x08\x12\x16\n\x0esteering_angle\x18\x05 \x01(\x01\x12\x1a\n\x12steering_angle_spd\x18\x06 \x01(\x01\x12\x1a\n\x12is_trimming_status\x18\x07 \x01(\x08\x12\x1d\n\x15is_calibration_status\x18\x08 \x01(\x08\x12\x19\n\x11is_failure_status\x18\t \x01(\x08\x12#\n\x1b\x61llow_enter_autonomous_mode\x18\n \x01(\x05\x12\x1c\n\x14\x63urrent_driving_mode\x18\x0b \x01(\x05\x12\x1a\n\x12steering_angle_cmd\x18\x0c \x01(\x01\x12\x15\n\rvehicle_speed\x18\r \x01(\x01\x12\x13\n\x0b\x65pas_torque\x18\x0e \x01(\x01\x12\x18\n\x10steering_enabled\x18\x0f \x01(\x08\x12\x17\n\x0f\x64river_override\x18\x10 \x01(\x08\x12\x17\n\x0f\x64river_activity\x18\x11 \x01(\x08\x12\x16\n\x0ewatchdog_fault\x18\x12 \x01(\x08\x12\x17\n\x0f\x63hannel_1_fault\x18\x13 \x01(\x08\x12\x17\n\x0f\x63hannel_2_fault\x18\x14 \x01(\x08\x12\x19\n\x11\x63\x61libration_fault\x18\x15 \x01(\x08\x12\x17\n\x0f\x63onnector_fault\x18\x16 \x01(\x08\x12\x14\n\x0ctimestamp_65\x18\x17 \x01(\x01\x12\x15\n\rmajor_version\x18\x18 \x01(\x05\x12\x15\n\rminor_version\x18\x19 \x01(\x05\x12\x14\n\x0c\x62uild_number\x18\x1a \x01(\x05\"=\n\x04Type\x12\x11\n\rNOT_AVAILABLE\x10\x00\x12\t\n\x05READY\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0b\n\x07INVALID\x10\x03\"\xeb\x06\n\nVehicleSpd\x12\x1d\n\x15is_vehicle_standstill\x18\x01 \x01(\x08\x12\x1c\n\x14is_vehicle_spd_valid\x18\x02 \x01(\x08\x12\x16\n\x0bvehicle_spd\x18\x03 \x01(\x01:\x01\x30\x12\x1d\n\x15is_wheel_spd_rr_valid\x18\x04 \x01(\x08\x12\x44\n\x12wheel_direction_rr\x18\x05 \x01(\x0e\x32(.apollo.canbus.WheelSpeed.WheelSpeedType\x12\x14\n\x0cwheel_spd_rr\x18\x06 \x01(\x01\x12\x1d\n\x15is_wheel_spd_rl_valid\x18\x07 \x01(\x08\x12\x44\n\x12wheel_direction_rl\x18\x08 \x01(\x0e\x32(.apollo.canbus.WheelSpeed.WheelSpeedType\x12\x14\n\x0cwheel_spd_rl\x18\t \x01(\x01\x12\x1d\n\x15is_wheel_spd_fr_valid\x18\n \x01(\x08\x12\x44\n\x12wheel_direction_fr\x18\x0b \x01(\x0e\x32(.apollo.canbus.WheelSpeed.WheelSpeedType\x12\x14\n\x0cwheel_spd_fr\x18\x0c \x01(\x01\x12\x1d\n\x15is_wheel_spd_fl_valid\x18\r \x01(\x08\x12\x44\n\x12wheel_direction_fl\x18\x0e \x01(\x0e\x32(.apollo.canbus.WheelSpeed.WheelSpeedType\x12\x14\n\x0cwheel_spd_fl\x18\x0f \x01(\x01\x12\x19\n\x11is_yaw_rate_valid\x18\x10 \x01(\x08\x12\x10\n\x08yaw_rate\x18\x11 \x01(\x01\x12\x17\n\x0fyaw_rate_offset\x18\x12 \x01(\x01\x12\x13\n\x0bis_ax_valid\x18\x13 \x01(\x08\x12\n\n\x02\x61x\x18\x14 \x01(\x01\x12\x11\n\tax_offset\x18\x15 \x01(\x01\x12\x13\n\x0bis_ay_valid\x18\x16 \x01(\x08\x12\n\n\x02\x61y\x18\x17 \x01(\x01\x12\x11\n\tay_offset\x18\x18 \x01(\x01\x12\x0f\n\x07lat_acc\x18\x19 \x01(\x01\x12\x10\n\x08long_acc\x18\x1a \x01(\x01\x12\x10\n\x08vert_acc\x18\x1b \x01(\x01\x12\x11\n\troll_rate\x18\x1c \x01(\x01\x12\x0f\n\x07\x61\x63\x63_est\x18\x1d \x01(\x01\x12\x15\n\rtimestamp_sec\x18\x1e \x01(\x01\"\xd2\x01\n\x0c\x44\x65\x63\x65leration\x12!\n\x19is_deceleration_available\x18\x01 \x01(\x08\x12\x1e\n\x16is_deceleration_active\x18\x02 \x01(\x08\x12\x17\n\x0c\x64\x65\x63\x65leration\x18\x03 \x01(\x01:\x01\x30\x12\x13\n\x0bis_evb_fail\x18\x04 \x01(\x01\x12\x17\n\x0c\x65vb_pressure\x18\x05 \x01(\x01:\x01\x30\x12\x19\n\x0e\x62rake_pressure\x18\x06 \x01(\x01:\x01\x30\x12\x1d\n\x12\x62rake_pressure_spd\x18\x07 \x01(\x01:\x01\x30\"\xb6\x08\n\x05\x42rake\x12%\n\x16is_brake_pedal_pressed\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\x14is_brake_force_exist\x18\x02 \x01(\x08\x12\x1a\n\x12is_brake_over_heat\x18\x03 \x01(\x08\x12\x18\n\x10is_hand_brake_on\x18\x04 \x01(\x08\x12\x1c\n\x14\x62rake_pedal_position\x18\x05 \x01(\x01\x12\x16\n\x0eis_brake_valid\x18\x06 \x01(\x08\x12\x13\n\x0b\x62rake_input\x18\x07 \x01(\x01\x12\x11\n\tbrake_cmd\x18\x08 \x01(\x01\x12\x14\n\x0c\x62rake_output\x18\t \x01(\x01\x12\x11\n\tboo_input\x18\n \x01(\x08\x12\x0f\n\x07\x62oo_cmd\x18\x0b \x01(\x08\x12\x12\n\nboo_output\x18\x0c \x01(\x08\x12 \n\x18watchdog_applying_brakes\x18\r \x01(\x08\x12\x17\n\x0fwatchdog_source\x18\x0e \x01(\x05\x12\x15\n\rbrake_enabled\x18\x0f \x01(\x08\x12\x17\n\x0f\x64river_override\x18\x10 \x01(\x08\x12\x17\n\x0f\x64river_activity\x18\x11 \x01(\x08\x12\x16\n\x0ewatchdog_fault\x18\x12 \x01(\x08\x12\x17\n\x0f\x63hannel_1_fault\x18\x13 \x01(\x08\x12\x17\n\x0f\x63hannel_2_fault\x18\x14 \x01(\x08\x12\x11\n\tboo_fault\x18\x15 \x01(\x08\x12\x17\n\x0f\x63onnector_fault\x18\x16 \x01(\x08\x12\x18\n\x10\x62rake_torque_req\x18\x17 \x01(\x01\x12\x36\n\nhsa_status\x18\x18 \x01(\x0e\x32\".apollo.canbus.Brake.HSAStatusType\x12\x18\n\x10\x62rake_torque_act\x18\x19 \x01(\x01\x12\x32\n\x08hsa_mode\x18\x1a \x01(\x0e\x32 .apollo.canbus.Brake.HSAModeType\x12\x18\n\x10wheel_torque_act\x18\x1b \x01(\x01\x12\x15\n\rmajor_version\x18\x1c \x01(\x05\x12\x15\n\rminor_version\x18\x1d \x01(\x05\x12\x14\n\x0c\x62uild_number\x18\x1e \x01(\x05\"\xbb\x01\n\rHSAStatusType\x12\x10\n\x0cHSA_INACTIVE\x10\x00\x12\x18\n\x14HSA_FINDING_GRADIENT\x10\x01\x12\x16\n\x12HSA_ACTIVE_PRESSED\x10\x02\x12\x17\n\x13HSA_ACTIVE_RELEASED\x10\x03\x12\x14\n\x10HSA_FAST_RELEASE\x10\x04\x12\x14\n\x10HSA_SLOW_RELEASE\x10\x05\x12\x0e\n\nHSA_FAILED\x10\x06\x12\x11\n\rHSA_UNDEFINED\x10\x07\"P\n\x0bHSAModeType\x12\x0b\n\x07HSA_OFF\x10\x00\x12\x0c\n\x08HSA_AUTO\x10\x01\x12\x0e\n\nHSA_MANUAL\x10\x02\x12\x16\n\x12HSA_MODE_UNDEFINED\x10\x03\"\xdb\x01\n\x03\x45pb\x12\x14\n\x0cis_epb_error\x18\x01 \x01(\x08\x12\x17\n\x0fis_epb_released\x18\x02 \x01(\x08\x12\x12\n\nepb_status\x18\x03 \x01(\x05\x12;\n\x14parking_brake_status\x18\x04 \x01(\x0e\x32\x1d.apollo.canbus.Epb.PBrakeType\"T\n\nPBrakeType\x12\x0e\n\nPBRAKE_OFF\x10\x00\x12\x15\n\x11PBRAKE_TRANSITION\x10\x01\x12\r\n\tPBRAKE_ON\x10\x02\x12\x10\n\x0cPBRAKE_FAULT\x10\x03\"\x8e\x04\n\x03Gas\x12\x1a\n\x12is_gas_pedal_error\x18\x01 \x01(\x08\x12!\n\x19is_gas_pedal_pressed_more\x18\x02 \x01(\x08\x12\x1d\n\x12gas_pedal_position\x18\x03 \x01(\x01:\x01\x30\x12\x1b\n\x0cis_gas_valid\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x16\n\x0ethrottle_input\x18\x05 \x01(\x01\x12\x14\n\x0cthrottle_cmd\x18\x06 \x01(\x01\x12\x17\n\x0fthrottle_output\x18\x07 \x01(\x01\x12\x17\n\x0fwatchdog_source\x18\x08 \x01(\x05\x12\x18\n\x10throttle_enabled\x18\t \x01(\x08\x12\x17\n\x0f\x64river_override\x18\n \x01(\x08\x12\x17\n\x0f\x64river_activity\x18\x0b \x01(\x08\x12\x16\n\x0ewatchdog_fault\x18\x0c \x01(\x08\x12\x17\n\x0f\x63hannel_1_fault\x18\r \x01(\x08\x12\x17\n\x0f\x63hannel_2_fault\x18\x0e \x01(\x08\x12\x17\n\x0f\x63onnector_fault\x18\x0f \x01(\x08\x12\x19\n\x11\x61\x63\x63\x65lerator_pedal\x18\x10 \x01(\x01\x12\x1e\n\x16\x61\x63\x63\x65lerator_pedal_rate\x18\x11 \x01(\x01\x12\x15\n\rmajor_version\x18\x12 \x01(\x05\x12\x15\n\rminor_version\x18\x13 \x01(\x05\x12\x14\n\x0c\x62uild_number\x18\x14 \x01(\x05\"\x88\x02\n\x03\x45sp\x12\x18\n\x10is_esp_acc_error\x18\x01 \x01(\x08\x12\x11\n\tis_esp_on\x18\x02 \x01(\x08\x12\x15\n\ris_esp_active\x18\x03 \x01(\x08\x12\x14\n\x0cis_abs_error\x18\x04 \x01(\x08\x12\x15\n\ris_abs_active\x18\x05 \x01(\x08\x12\x16\n\x0eis_tcsvdc_fail\x18\x06 \x01(\x08\x12\x16\n\x0eis_abs_enabled\x18\x07 \x01(\x08\x12\x16\n\x0eis_stab_active\x18\x08 \x01(\x08\x12\x17\n\x0fis_stab_enabled\x18\t \x01(\x08\x12\x16\n\x0eis_trac_active\x18\n \x01(\x08\x12\x17\n\x0fis_trac_enabled\x18\x0b \x01(\x08\"\x8d\x03\n\x03\x45ms\x12\x1f\n\x17is_engine_acc_available\x18\x01 \x01(\x08\x12\x1b\n\x13is_engine_acc_error\x18\x02 \x01(\x08\x12-\n\x0c\x65ngine_state\x18\x03 \x01(\x0e\x32\x17.apollo.canbus.Ems.Type\x12\x1f\n\x17max_engine_torq_percent\x18\x04 \x01(\x01\x12\x1f\n\x17min_engine_torq_percent\x18\x05 \x01(\x01\x12!\n\x19\x62\x61se_engine_torq_constant\x18\x06 \x01(\x05\x12\x1d\n\x15is_engine_speed_error\x18\x07 \x01(\x08\x12\x14\n\x0c\x65ngine_speed\x18\x08 \x01(\x01\x12\x15\n\rengine_torque\x18\t \x01(\x05\x12\x1d\n\x15is_over_engine_torque\x18\n \x01(\x08\x12\x12\n\nengine_rpm\x18\x0b \x01(\x01\"5\n\x04Type\x12\x08\n\x04STOP\x10\x00\x12\t\n\x05\x43RANK\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0b\n\x07INVALID\x10\x03\"\xc6\x01\n\x04Gear\x12\x1f\n\x17is_shift_position_valid\x18\x01 \x01(\x08\x12\x37\n\ngear_state\x18\x02 \x01(\x0e\x32#.apollo.canbus.Chassis.GearPosition\x12\x17\n\x0f\x64river_override\x18\x03 \x01(\x08\x12\x35\n\x08gear_cmd\x18\x04 \x01(\x0e\x32#.apollo.canbus.Chassis.GearPosition\x12\x14\n\x0c\x63\x61nbus_fault\x18\x05 \x01(\x08\"\xee\x05\n\x06Safety\x12 \n\x18is_driver_car_door_close\x18\x01 \x01(\x08\x12\x19\n\x11is_driver_buckled\x18\x02 \x01(\x08\x12\x18\n\x10\x65mergency_button\x18\x03 \x01(\x05\x12\x18\n\thas_error\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x17is_motor_invertor_fault\x18\x05 \x01(\x08\x12\x17\n\x0fis_system_fault\x18\x06 \x01(\x08\x12\x1e\n\x16is_power_battery_fault\x18\x07 \x01(\x08\x12*\n\"is_motor_invertor_over_temperature\x18\x08 \x01(\x08\x12/\n\'is_small_battery_charge_discharge_fault\x18\t \x01(\x08\x12\x14\n\x0c\x64riving_mode\x18\n \x01(\x05\x12\x1e\n\x16is_passenger_door_open\x18\x0b \x01(\x08\x12\x1d\n\x15is_rearleft_door_open\x18\x0c \x01(\x08\x12\x1e\n\x16is_rearright_door_open\x18\r \x01(\x08\x12\x14\n\x0cis_hood_open\x18\x0e \x01(\x08\x12\x15\n\ris_trunk_open\x18\x0f \x01(\x08\x12\x1d\n\x15is_passenger_detected\x18\x10 \x01(\x08\x12#\n\x1bis_passenger_airbag_enabled\x18\x11 \x01(\x08\x12\x1c\n\x14is_passenger_buckled\x18\x12 \x01(\x08\x12\x1d\n\x15\x66ront_left_tire_press\x18\x13 \x01(\x05\x12\x1e\n\x16\x66ront_right_tire_press\x18\x14 \x01(\x05\x12\x1c\n\x14rear_left_tire_press\x18\x15 \x01(\x05\x12\x1d\n\x15rear_right_tire_press\x18\x16 \x01(\x05\x12<\n\x10\x63\x61r_driving_mode\x18\x17 \x01(\x0e\x32\".apollo.canbus.Chassis.DrivingMode\"\xbc\x07\n\tBasicInfo\x12\x14\n\x0cis_auto_mode\x18\x01 \x01(\x08\x12\x32\n\x0bpower_state\x18\x02 \x01(\x0e\x32\x1d.apollo.canbus.BasicInfo.Type\x12\x1b\n\x13is_air_bag_deployed\x18\x03 \x01(\x08\x12\x11\n\todo_meter\x18\x04 \x01(\x01\x12\x13\n\x0b\x64rive_range\x18\x05 \x01(\x01\x12\x17\n\x0fis_system_error\x18\x06 \x01(\x08\x12\x1a\n\x12is_human_interrupt\x18\x07 \x01(\x08\x12\x15\n\racc_on_button\x18\x08 \x01(\x08\x12\x16\n\x0e\x61\x63\x63_off_button\x18\t \x01(\x08\x12\x16\n\x0e\x61\x63\x63_res_button\x18\n \x01(\x08\x12\x19\n\x11\x61\x63\x63_cancel_button\x18\x0b \x01(\x08\x12\x19\n\x11\x61\x63\x63_on_off_button\x18\x0c \x01(\x08\x12\x1d\n\x15\x61\x63\x63_res_cancel_button\x18\r \x01(\x08\x12\x1a\n\x12\x61\x63\x63_inc_spd_button\x18\x0e \x01(\x08\x12\x1a\n\x12\x61\x63\x63_dec_spd_button\x18\x0f \x01(\x08\x12\x1a\n\x12\x61\x63\x63_inc_gap_button\x18\x10 \x01(\x08\x12\x1a\n\x12\x61\x63\x63_dec_gap_button\x18\x11 \x01(\x08\x12\x12\n\nlka_button\x18\x12 \x01(\x08\x12\x14\n\x0c\x63\x61nbus_fault\x18\x13 \x01(\x08\x12\x10\n\x08latitude\x18\x14 \x01(\x01\x12\x11\n\tlongitude\x18\x15 \x01(\x01\x12\x11\n\tgps_valid\x18\x16 \x01(\x08\x12\x0c\n\x04year\x18\x17 \x01(\x05\x12\r\n\x05month\x18\x18 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x19 \x01(\x05\x12\r\n\x05hours\x18\x1a \x01(\x05\x12\x0f\n\x07minutes\x18\x1b \x01(\x05\x12\x0f\n\x07seconds\x18\x1c \x01(\x05\x12\x19\n\x11\x63ompass_direction\x18\x1d \x01(\x01\x12\x0c\n\x04pdop\x18\x1e \x01(\x01\x12\x14\n\x0cis_gps_fault\x18\x1f \x01(\x08\x12\x13\n\x0bis_inferred\x18  \x01(\x08\x12\x10\n\x08\x61ltitude\x18! \x01(\x01\x12\x0f\n\x07heading\x18\" \x01(\x01\x12\x0c\n\x04hdop\x18# \x01(\x01\x12\x0c\n\x04vdop\x18$ \x01(\x01\x12*\n\x07quality\x18% \x01(\x0e\x32\x19.apollo.canbus.GpsQuality\x12\x16\n\x0enum_satellites\x18& \x01(\x05\x12\x11\n\tgps_speed\x18\' \x01(\x01\"8\n\x04Type\x12\x07\n\x03OFF\x10\x00\x12\x07\n\x03\x41\x43\x43\x10\x01\x12\x06\n\x02ON\x10\x02\x12\t\n\x05START\x10\x03\x12\x0b\n\x07INVALID\x10\x04\"\xf5\x04\n\rGlobal_rpt_6a\x12\x45\n\rpacmod_status\x18\x01 \x01(\x0e\x32..apollo.canbus.Global_rpt_6a.Pacmod_statusType\x12I\n\x0foverride_status\x18\x02 \x01(\x0e\x32\x30.apollo.canbus.Global_rpt_6a.Override_statusType\x12\x17\n\x0fveh_can_timeout\x18\x03 \x01(\x08\x12\x17\n\x0fstr_can_timeout\x18\x04 \x01(\x08\x12I\n\x0f\x62rk_can_timeout\x18\x05 \x01(\x0e\x32\x30.apollo.canbus.Global_rpt_6a.Brk_can_timeoutType\x12\x17\n\x0fusr_can_timeout\x18\x06 \x01(\x08\x12\x1b\n\x13usr_can_read_errors\x18\x07 \x01(\x05\"Z\n\x11Pacmod_statusType\x12\"\n\x1ePACMOD_STATUS_CONTROL_DISABLED\x10\x00\x12!\n\x1dPACMOD_STATUS_CONTROL_ENABLED\x10\x01\"Y\n\x13Override_statusType\x12\"\n\x1eOVERRIDE_STATUS_NOT_OVERRIDDEN\x10\x00\x12\x1e\n\x1aOVERRIDE_STATUS_OVERRIDDEN\x10\x01\"h\n\x13\x42rk_can_timeoutType\x12)\n%BRK_CAN_TIMEOUT_NO_ACTIVE_CAN_TIMEOUT\x10\x00\x12&\n\"BRK_CAN_TIMEOUT_ACTIVE_CAN_TIMEOUT\x10\x01\"!\n\x0c\x42rake_cmd_6b\x12\x11\n\tbrake_cmd\x18\x01 \x01(\x01\"\xd6\x01\n\x0c\x42rake_rpt_6c\x12\x14\n\x0cmanual_input\x18\x01 \x01(\x01\x12\x17\n\x0f\x63ommanded_value\x18\x02 \x01(\x01\x12\x14\n\x0coutput_value\x18\x03 \x01(\x01\x12\x42\n\x0c\x62rake_on_off\x18\x04 \x01(\x0e\x32,.apollo.canbus.Brake_rpt_6c.Brake_on_offType\"=\n\x10\x42rake_on_offType\x12\x14\n\x10\x42RAKE_ON_OFF_OFF\x10\x00\x12\x13\n\x0f\x42RAKE_ON_OFF_ON\x10\x01\">\n\x0fSteering_cmd_6d\x12\x16\n\x0eposition_value\x18\x01 \x01(\x01\x12\x13\n\x0bspeed_limit\x18\x02 \x01(\x01\"X\n\x11Steering_rpt_1_6e\x12\x14\n\x0cmanual_input\x18\x01 \x01(\x01\x12\x17\n\x0f\x63ommanded_value\x18\x02 \x01(\x01\x12\x14\n\x0coutput_value\x18\x03 \x01(\x01\"\x8c\x01\n\x12Wheel_speed_rpt_7a\x12\x1c\n\x14wheel_spd_rear_right\x18\x01 \x01(\x05\x12\x1b\n\x13wheel_spd_rear_left\x18\x02 \x01(\x05\x12\x1d\n\x15wheel_spd_front_right\x18\x03 \x01(\x05\x12\x1c\n\x14wheel_spd_front_left\x18\x04 \x01(\x05\"\x88\x01\n\x10\x44\x61te_time_rpt_83\x12\x13\n\x0btime_second\x18\x01 \x01(\x05\x12\x13\n\x0btime_minute\x18\x02 \x01(\x05\x12\x11\n\ttime_hour\x18\x03 \x01(\x05\x12\x10\n\x08\x64\x61te_day\x18\x04 \x01(\x05\x12\x12\n\ndate_month\x18\x05 \x01(\x05\x12\x11\n\tdate_year\x18\x06 \x01(\x05\"E\n\x14\x42rake_motor_rpt_1_70\x12\x15\n\rmotor_current\x18\x01 \x01(\x01\x12\x16\n\x0eshaft_position\x18\x02 \x01(\x01\"\xc6\x04\n\x10Headlight_rpt_77\x12\x46\n\x0coutput_value\x18\x01 \x01(\x0e\x32\x30.apollo.canbus.Headlight_rpt_77.Output_valueType\x12\x46\n\x0cmanual_input\x18\x02 \x01(\x0e\x32\x30.apollo.canbus.Headlight_rpt_77.Manual_inputType\x12L\n\x0f\x63ommanded_value\x18\x03 \x01(\x0e\x32\x33.apollo.canbus.Headlight_rpt_77.Commanded_valueType\"l\n\x10Output_valueType\x12\x1f\n\x1bOUTPUT_VALUE_HEADLIGHTS_OFF\x10\x00\x12\x1a\n\x16OUTPUT_VALUE_LOW_BEAMS\x10\x01\x12\x1b\n\x17OUTPUT_VALUE_HIGH_BEAMS\x10\x02\"l\n\x10Manual_inputType\x12\x1f\n\x1bMANUAL_INPUT_HEADLIGHTS_OFF\x10\x00\x12\x1a\n\x16MANUAL_INPUT_LOW_BEAMS\x10\x01\x12\x1b\n\x17MANUAL_INPUT_HIGH_BEAMS\x10\x02\"x\n\x13\x43ommanded_valueType\x12\"\n\x1e\x43OMMANDED_VALUE_HEADLIGHTS_OFF\x10\x00\x12\x1d\n\x19\x43OMMANDED_VALUE_LOW_BEAMS\x10\x01\x12\x1e\n\x1a\x43OMMANDED_VALUE_HIGH_BEAMS\x10\x02\"S\n\x0c\x41\x63\x63\x65l_rpt_68\x12\x14\n\x0cmanual_input\x18\x01 \x01(\x01\x12\x17\n\x0f\x63ommanded_value\x18\x02 \x01(\x01\x12\x14\n\x0coutput_value\x18\x03 \x01(\x01\"F\n\x17Steering_motor_rpt_3_75\x12\x15\n\rtorque_output\x18\x01 \x01(\x01\x12\x14\n\x0ctorque_input\x18\x02 \x01(\x01\"\xd9\x01\n\x0bTurn_cmd_63\x12G\n\x0fturn_signal_cmd\x18\x01 \x01(\x0e\x32..apollo.canbus.Turn_cmd_63.Turn_signal_cmdType\"\x80\x01\n\x13Turn_signal_cmdType\x12\x19\n\x15TURN_SIGNAL_CMD_RIGHT\x10\x00\x12\x18\n\x14TURN_SIGNAL_CMD_NONE\x10\x01\x12\x18\n\x14TURN_SIGNAL_CMD_LEFT\x10\x02\x12\x1a\n\x16TURN_SIGNAL_CMD_HAZARD\x10\x03\"\xc5\x04\n\x0bTurn_rpt_64\x12\x41\n\x0cmanual_input\x18\x01 \x01(\x0e\x32+.apollo.canbus.Turn_rpt_64.Manual_inputType\x12G\n\x0f\x63ommanded_value\x18\x02 \x01(\x0e\x32..apollo.canbus.Turn_rpt_64.Commanded_valueType\x12\x41\n\x0coutput_value\x18\x03 \x01(\x0e\x32+.apollo.canbus.Turn_rpt_64.Output_valueType\"q\n\x10Manual_inputType\x12\x16\n\x12MANUAL_INPUT_RIGHT\x10\x00\x12\x15\n\x11MANUAL_INPUT_NONE\x10\x01\x12\x15\n\x11MANUAL_INPUT_LEFT\x10\x02\x12\x17\n\x13MANUAL_INPUT_HAZARD\x10\x03\"\x80\x01\n\x13\x43ommanded_valueType\x12\x19\n\x15\x43OMMANDED_VALUE_RIGHT\x10\x00\x12\x18\n\x14\x43OMMANDED_VALUE_NONE\x10\x01\x12\x18\n\x14\x43OMMANDED_VALUE_LEFT\x10\x02\x12\x1a\n\x16\x43OMMANDED_VALUE_HAZARD\x10\x03\"q\n\x10Output_valueType\x12\x16\n\x12OUTPUT_VALUE_RIGHT\x10\x00\x12\x15\n\x11OUTPUT_VALUE_NONE\x10\x01\x12\x15\n\x11OUTPUT_VALUE_LEFT\x10\x02\x12\x17\n\x13OUTPUT_VALUE_HAZARD\x10\x03\"\xc9\x01\n\x0cShift_cmd_65\x12<\n\tshift_cmd\x18\x01 \x01(\x0e\x32).apollo.canbus.Shift_cmd_65.Shift_cmdType\"{\n\rShift_cmdType\x12\x12\n\x0eSHIFT_CMD_PARK\x10\x00\x12\x15\n\x11SHIFT_CMD_REVERSE\x10\x01\x12\x15\n\x11SHIFT_CMD_NEUTRAL\x10\x02\x12\x15\n\x11SHIFT_CMD_FORWARD\x10\x03\x12\x11\n\rSHIFT_CMD_LOW\x10\x04\"\xa5\x05\n\x0cShift_rpt_66\x12\x42\n\x0cmanual_input\x18\x01 \x01(\x0e\x32,.apollo.canbus.Shift_rpt_66.Manual_inputType\x12H\n\x0f\x63ommanded_value\x18\x02 \x01(\x0e\x32/.apollo.canbus.Shift_rpt_66.Commanded_valueType\x12\x42\n\x0coutput_value\x18\x03 \x01(\x0e\x32,.apollo.canbus.Shift_rpt_66.Output_valueType\"\x8e\x01\n\x10Manual_inputType\x12\x15\n\x11MANUAL_INPUT_PARK\x10\x00\x12\x18\n\x14MANUAL_INPUT_REVERSE\x10\x01\x12\x18\n\x14MANUAL_INPUT_NEUTRAL\x10\x02\x12\x18\n\x14MANUAL_INPUT_FORWARD\x10\x03\x12\x15\n\x11MANUAL_INPUT_HIGH\x10\x04\"\xa0\x01\n\x13\x43ommanded_valueType\x12\x18\n\x14\x43OMMANDED_VALUE_PARK\x10\x00\x12\x1b\n\x17\x43OMMANDED_VALUE_REVERSE\x10\x01\x12\x1b\n\x17\x43OMMANDED_VALUE_NEUTRAL\x10\x02\x12\x1b\n\x17\x43OMMANDED_VALUE_FORWARD\x10\x03\x12\x18\n\x14\x43OMMANDED_VALUE_HIGH\x10\x04\"\x8e\x01\n\x10Output_valueType\x12\x15\n\x11OUTPUT_VALUE_PARK\x10\x00\x12\x18\n\x14OUTPUT_VALUE_REVERSE\x10\x01\x12\x18\n\x14OUTPUT_VALUE_NEUTRAL\x10\x02\x12\x18\n\x14OUTPUT_VALUE_FORWARD\x10\x03\x12\x15\n\x11OUTPUT_VALUE_HIGH\x10\x04\"!\n\x0c\x41\x63\x63\x65l_cmd_67\x12\x11\n\taccel_cmd\x18\x01 \x01(\x01\"\xc8\x01\n\x16Lat_lon_heading_rpt_82\x12\x0f\n\x07heading\x18\x01 \x01(\x01\x12\x19\n\x11longitude_seconds\x18\x02 \x01(\x05\x12\x19\n\x11longitude_minutes\x18\x03 \x01(\x05\x12\x19\n\x11longitude_degrees\x18\x04 \x01(\x05\x12\x18\n\x10latitude_seconds\x18\x05 \x01(\x05\x12\x18\n\x10latitude_minutes\x18\x06 \x01(\x05\x12\x18\n\x10latitude_degrees\x18\x07 \x01(\x05\"\xab\x04\n\rGlobal_cmd_69\x12\x45\n\rpacmod_enable\x18\x01 \x01(\x0e\x32..apollo.canbus.Global_cmd_69.Pacmod_enableType\x12G\n\x0e\x63lear_override\x18\x02 \x01(\x0e\x32/.apollo.canbus.Global_cmd_69.Clear_overrideType\x12I\n\x0fignore_override\x18\x03 \x01(\x0e\x32\x30.apollo.canbus.Global_cmd_69.Ignore_overrideType\"Z\n\x11Pacmod_enableType\x12\"\n\x1ePACMOD_ENABLE_CONTROL_DISABLED\x10\x00\x12!\n\x1dPACMOD_ENABLE_CONTROL_ENABLED\x10\x01\"p\n\x12\x43lear_overrideType\x12/\n+CLEAR_OVERRIDE_DON_T_CLEAR_ACTIVE_OVERRIDES\x10\x00\x12)\n%CLEAR_OVERRIDE_CLEAR_ACTIVE_OVERRIDES\x10\x01\"q\n\x13Ignore_overrideType\x12/\n+IGNORE_OVERRIDE_DON_T_IGNORE_USER_OVERRIDES\x10\x00\x12)\n%IGNORE_OVERRIDE_IGNORE_USER_OVERRIDES\x10\x01\"\xdc\x01\n\x1bParking_brake_status_rpt_80\x12\x63\n\x15parking_brake_enabled\x18\x01 \x01(\x0e\x32\x44.apollo.canbus.Parking_brake_status_rpt_80.Parking_brake_enabledType\"X\n\x19Parking_brake_enabledType\x12\x1d\n\x19PARKING_BRAKE_ENABLED_OFF\x10\x00\x12\x1c\n\x18PARKING_BRAKE_ENABLED_ON\x10\x01\"#\n\x0fYaw_rate_rpt_81\x12\x10\n\x08yaw_rate\x18\x01 \x01(\x01\"\xa2\x03\n\x0bHorn_rpt_79\x12\x41\n\x0coutput_value\x18\x01 \x01(\x0e\x32+.apollo.canbus.Horn_rpt_79.Output_valueType\x12G\n\x0f\x63ommanded_value\x18\x02 \x01(\x0e\x32..apollo.canbus.Horn_rpt_79.Commanded_valueType\x12\x41\n\x0cmanual_input\x18\x03 \x01(\x0e\x32+.apollo.canbus.Horn_rpt_79.Manual_inputType\"=\n\x10Output_valueType\x12\x14\n\x10OUTPUT_VALUE_OFF\x10\x00\x12\x13\n\x0fOUTPUT_VALUE_ON\x10\x01\"F\n\x13\x43ommanded_valueType\x12\x17\n\x13\x43OMMANDED_VALUE_OFF\x10\x00\x12\x16\n\x12\x43OMMANDED_VALUE_ON\x10\x01\"=\n\x10Manual_inputType\x12\x14\n\x10MANUAL_INPUT_OFF\x10\x00\x12\x13\n\x0fMANUAL_INPUT_ON\x10\x01\"{\n\x0bHorn_cmd_78\x12\x39\n\x08horn_cmd\x18\x01 \x01(\x0e\x32\'.apollo.canbus.Horn_cmd_78.Horn_cmdType\"1\n\x0cHorn_cmdType\x12\x10\n\x0cHORN_CMD_OFF\x10\x00\x12\x0f\n\x0bHORN_CMD_ON\x10\x01\"\x87\x08\n\x0cWiper_rpt_91\x12\x42\n\x0coutput_value\x18\x01 \x01(\x0e\x32,.apollo.canbus.Wiper_rpt_91.Output_valueType\x12H\n\x0f\x63ommanded_value\x18\x02 \x01(\x0e\x32/.apollo.canbus.Wiper_rpt_91.Commanded_valueType\x12\x42\n\x0cmanual_input\x18\x03 \x01(\x0e\x32,.apollo.canbus.Wiper_rpt_91.Manual_inputType\"\x81\x02\n\x10Output_valueType\x12\x1b\n\x17OUTPUT_VALUE_WIPERS_OFF\x10\x00\x12\x1f\n\x1bOUTPUT_VALUE_INTERMITTENT_1\x10\x01\x12\x1f\n\x1bOUTPUT_VALUE_INTERMITTENT_2\x10\x02\x12\x1f\n\x1bOUTPUT_VALUE_INTERMITTENT_3\x10\x03\x12\x1f\n\x1bOUTPUT_VALUE_INTERMITTENT_4\x10\x04\x12\x1f\n\x1bOUTPUT_VALUE_INTERMITTENT_5\x10\x05\x12\x14\n\x10OUTPUT_VALUE_LOW\x10\x06\x12\x15\n\x11OUTPUT_VALUE_HIGH\x10\x07\"\x9c\x02\n\x13\x43ommanded_valueType\x12\x1e\n\x1a\x43OMMANDED_VALUE_WIPERS_OFF\x10\x00\x12\"\n\x1e\x43OMMANDED_VALUE_INTERMITTENT_1\x10\x01\x12\"\n\x1e\x43OMMANDED_VALUE_INTERMITTENT_2\x10\x02\x12\"\n\x1e\x43OMMANDED_VALUE_INTERMITTENT_3\x10\x03\x12\"\n\x1e\x43OMMANDED_VALUE_INTERMITTENT_4\x10\x04\x12\"\n\x1e\x43OMMANDED_VALUE_INTERMITTENT_5\x10\x05\x12\x17\n\x13\x43OMMANDED_VALUE_LOW\x10\x06\x12\x18\n\x14\x43OMMANDED_VALUE_HIGH\x10\x07\"\x81\x02\n\x10Manual_inputType\x12\x1b\n\x17MANUAL_INPUT_WIPERS_OFF\x10\x00\x12\x1f\n\x1bMANUAL_INPUT_INTERMITTENT_1\x10\x01\x12\x1f\n\x1bMANUAL_INPUT_INTERMITTENT_2\x10\x02\x12\x1f\n\x1bMANUAL_INPUT_INTERMITTENT_3\x10\x03\x12\x1f\n\x1bMANUAL_INPUT_INTERMITTENT_4\x10\x04\x12\x1f\n\x1bMANUAL_INPUT_INTERMITTENT_5\x10\x05\x12\x14\n\x10MANUAL_INPUT_LOW\x10\x06\x12\x15\n\x11MANUAL_INPUT_HIGH\x10\x07\"\xe2\x01\n\x14Vehicle_speed_rpt_6f\x12\x15\n\rvehicle_speed\x18\x01 \x01(\x01\x12X\n\x13vehicle_speed_valid\x18\x02 \x01(\x0e\x32;.apollo.canbus.Vehicle_speed_rpt_6f.Vehicle_speed_validType\"Y\n\x17Vehicle_speed_validType\x12\x1f\n\x1bVEHICLE_SPEED_VALID_INVALID\x10\x00\x12\x1d\n\x19VEHICLE_SPEED_VALID_VALID\x10\x01\"\xce\x01\n\x10Headlight_cmd_76\x12H\n\rheadlight_cmd\x18\x01 \x01(\x0e\x32\x31.apollo.canbus.Headlight_cmd_76.Headlight_cmdType\"p\n\x11Headlight_cmdType\x12 \n\x1cHEADLIGHT_CMD_HEADLIGHTS_OFF\x10\x00\x12\x1b\n\x17HEADLIGHT_CMD_LOW_BEAMS\x10\x01\x12\x1c\n\x18HEADLIGHT_CMD_HIGH_BEAMS\x10\x02\"h\n\x17Steering_motor_rpt_2_74\x12\x1b\n\x13\x65ncoder_temperature\x18\x01 \x01(\x05\x12\x19\n\x11motor_temperature\x18\x02 \x01(\x05\x12\x15\n\rangular_speed\x18\x03 \x01(\x01\"e\n\x14\x42rake_motor_rpt_2_71\x12\x1b\n\x13\x65ncoder_temperature\x18\x01 \x01(\x05\x12\x19\n\x11motor_temperature\x18\x02 \x01(\x05\x12\x15\n\rangular_speed\x18\x03 \x01(\x01\"H\n\x17Steering_motor_rpt_1_73\x12\x15\n\rmotor_current\x18\x01 \x01(\x01\x12\x16\n\x0eshaft_position\x18\x02 \x01(\x01\"\xb5\x02\n\x0cWiper_cmd_90\x12<\n\twiper_cmd\x18\x01 \x01(\x0e\x32).apollo.canbus.Wiper_cmd_90.Wiper_cmdType\"\xe6\x01\n\rWiper_cmdType\x12\x18\n\x14WIPER_CMD_WIPERS_OFF\x10\x00\x12\x1c\n\x18WIPER_CMD_INTERMITTENT_1\x10\x01\x12\x1c\n\x18WIPER_CMD_INTERMITTENT_2\x10\x02\x12\x1c\n\x18WIPER_CMD_INTERMITTENT_3\x10\x03\x12\x1c\n\x18WIPER_CMD_INTERMITTENT_4\x10\x04\x12\x1c\n\x18WIPER_CMD_INTERMITTENT_5\x10\x05\x12\x11\n\rWIPER_CMD_LOW\x10\x06\x12\x12\n\x0eWIPER_CMD_HIGH\x10\x07\"C\n\x14\x42rake_motor_rpt_3_72\x12\x15\n\rtorque_output\x18\x01 \x01(\x01\x12\x14\n\x0ctorque_input\x18\x02 \x01(\x01\"\xe9\r\n\x03Gem\x12\x33\n\rglobal_rpt_6a\x18\x01 \x01(\x0b\x32\x1c.apollo.canbus.Global_rpt_6a\x12\x31\n\x0c\x62rake_cmd_6b\x18\x02 \x01(\x0b\x32\x1b.apollo.canbus.Brake_cmd_6b\x12\x31\n\x0c\x62rake_rpt_6c\x18\x03 \x01(\x0b\x32\x1b.apollo.canbus.Brake_rpt_6c\x12\x37\n\x0fsteering_cmd_6d\x18\x04 \x01(\x0b\x32\x1e.apollo.canbus.Steering_cmd_6d\x12;\n\x11steering_rpt_1_6e\x18\x05 \x01(\x0b\x32 .apollo.canbus.Steering_rpt_1_6e\x12=\n\x12wheel_speed_rpt_7a\x18\x06 \x01(\x0b\x32!.apollo.canbus.Wheel_speed_rpt_7a\x12\x39\n\x10\x64\x61te_time_rpt_83\x18\x07 \x01(\x0b\x32\x1f.apollo.canbus.Date_time_rpt_83\x12\x41\n\x14\x62rake_motor_rpt_1_70\x18\x08 \x01(\x0b\x32#.apollo.canbus.Brake_motor_rpt_1_70\x12\x39\n\x10headlight_rpt_77\x18\t \x01(\x0b\x32\x1f.apollo.canbus.Headlight_rpt_77\x12\x31\n\x0c\x61\x63\x63\x65l_rpt_68\x18\n \x01(\x0b\x32\x1b.apollo.canbus.Accel_rpt_68\x12G\n\x17steering_motor_rpt_3_75\x18\x0b \x01(\x0b\x32&.apollo.canbus.Steering_motor_rpt_3_75\x12/\n\x0bturn_cmd_63\x18\x0c \x01(\x0b\x32\x1a.apollo.canbus.Turn_cmd_63\x12/\n\x0bturn_rpt_64\x18\r \x01(\x0b\x32\x1a.apollo.canbus.Turn_rpt_64\x12\x31\n\x0cshift_cmd_65\x18\x0e \x01(\x0b\x32\x1b.apollo.canbus.Shift_cmd_65\x12\x31\n\x0cshift_rpt_66\x18\x0f \x01(\x0b\x32\x1b.apollo.canbus.Shift_rpt_66\x12\x31\n\x0c\x61\x63\x63\x65l_cmd_67\x18\x10 \x01(\x0b\x32\x1b.apollo.canbus.Accel_cmd_67\x12\x45\n\x16lat_lon_heading_rpt_82\x18\x11 \x01(\x0b\x32%.apollo.canbus.Lat_lon_heading_rpt_82\x12\x33\n\rglobal_cmd_69\x18\x12 \x01(\x0b\x32\x1c.apollo.canbus.Global_cmd_69\x12O\n\x1bparking_brake_status_rpt_80\x18\x13 \x01(\x0b\x32*.apollo.canbus.Parking_brake_status_rpt_80\x12\x37\n\x0fyaw_rate_rpt_81\x18\x14 \x01(\x0b\x32\x1e.apollo.canbus.Yaw_rate_rpt_81\x12/\n\x0bhorn_rpt_79\x18\x15 \x01(\x0b\x32\x1a.apollo.canbus.Horn_rpt_79\x12/\n\x0bhorn_cmd_78\x18\x16 \x01(\x0b\x32\x1a.apollo.canbus.Horn_cmd_78\x12\x31\n\x0cwiper_rpt_91\x18\x17 \x01(\x0b\x32\x1b.apollo.canbus.Wiper_rpt_91\x12\x41\n\x14vehicle_speed_rpt_6f\x18\x18 \x01(\x0b\x32#.apollo.canbus.Vehicle_speed_rpt_6f\x12\x39\n\x10headlight_cmd_76\x18\x19 \x01(\x0b\x32\x1f.apollo.canbus.Headlight_cmd_76\x12G\n\x17steering_motor_rpt_2_74\x18\x1a \x01(\x0b\x32&.apollo.canbus.Steering_motor_rpt_2_74\x12\x41\n\x14\x62rake_motor_rpt_2_71\x18\x1b \x01(\x0b\x32#.apollo.canbus.Brake_motor_rpt_2_71\x12G\n\x17steering_motor_rpt_1_73\x18\x1c \x01(\x0b\x32&.apollo.canbus.Steering_motor_rpt_1_73\x12\x31\n\x0cwiper_cmd_90\x18\x1d \x01(\x0b\x32\x1b.apollo.canbus.Wiper_cmd_90\x12\x41\n\x14\x62rake_motor_rpt_3_72\x18\x1e \x01(\x0b\x32#.apollo.canbus.Brake_motor_rpt_3_72'
  ,
  dependencies=[modules_dot_common_dot_configs_dot_proto_dot_vehicle__config__pb2.DESCRIPTOR,modules_dot_canbus_dot_proto_dot_chassis__pb2.DESCRIPTOR,modules_dot_canbus_dot_proto_dot_ch__pb2.DESCRIPTOR,modules_dot_canbus_dot_proto_dot_devkit__pb2.DESCRIPTOR,modules_dot_canbus_dot_proto_dot_ge3__pb2.DESCRIPTOR,modules_dot_canbus_dot_proto_dot_lexus__pb2.DESCRIPTOR,modules_dot_canbus_dot_proto_dot_transit__pb2.DESCRIPTOR,modules_dot_canbus_dot_proto_dot_wey__pb2.DESCRIPTOR,modules_dot_canbus_dot_proto_dot_zhongyun__pb2.DESCRIPTOR,modules_dot_canbus_dot_proto_dot_neolix__edu__pb2.DESCRIPTOR,])



_CHASSISDETAIL_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.canbus.ChassisDetail.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='QIRUI_EQ_15', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANGAN_RUICHENG', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1519,
  serialized_end=1564,
)
_sym_db.RegisterEnumDescriptor(_CHASSISDETAIL_TYPE)

_LIGHT_TURNLIGHTTYPE = _descriptor.EnumDescriptor(
  name='TurnLightType',
  full_name='apollo.canbus.Light.TurnLightType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TURN_LIGHT_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_LEFT_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_RIGHT_ON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_LIGHT_ON', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2293,
  serialized_end=2384,
)
_sym_db.RegisterEnumDescriptor(_LIGHT_TURNLIGHTTYPE)

_LIGHT_BEAMLAMPTYPE = _descriptor.EnumDescriptor(
  name='BeamLampType',
  full_name='apollo.canbus.Light.BeamLampType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BEAM_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH_BEAM_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOW_BEAM_ON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2386,
  serialized_end=2449,
)
_sym_db.RegisterEnumDescriptor(_LIGHT_BEAMLAMPTYPE)

_LIGHT_LINCOLNLAMPTYPE = _descriptor.EnumDescriptor(
  name='LincolnLampType',
  full_name='apollo.canbus.Light.LincolnLampType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BEAM_NULL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEAM_FLASH_TO_PASS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEAM_HIGH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEAM_INVALID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2451,
  serialized_end=2540,
)
_sym_db.RegisterEnumDescriptor(_LIGHT_LINCOLNLAMPTYPE)

_LIGHT_LINCOLNWIPERTYPE = _descriptor.EnumDescriptor(
  name='LincolnWiperType',
  full_name='apollo.canbus.Light.LincolnWiperType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WIPER_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_AUTO_OFF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_OFF_MOVING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_MANUAL_OFF', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_MANUAL_ON', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_MANUAL_LOW', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_MANUAL_HIGH', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_MIST_FLICK', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_WASH', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_AUTO_LOW', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_AUTO_HIGH', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_COURTESY_WIPE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_AUTO_ADJUST', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_RESERVED', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_STALLED', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_NO_DATA', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2543,
  serialized_end=2891,
)
_sym_db.RegisterEnumDescriptor(_LIGHT_LINCOLNWIPERTYPE)

_LIGHT_LINCOLNAMBIENTTYPE = _descriptor.EnumDescriptor(
  name='LincolnAmbientType',
  full_name='apollo.canbus.Light.LincolnAmbientType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AMBIENT_DARK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AMBIENT_LIGHT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AMBIENT_TWILIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AMBIENT_TUNNEL_ON', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AMBIENT_TUNNEL_OFF', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AMBIENT_INVALID', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AMBIENT_NO_DATA', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2894,
  serialized_end=3062,
)
_sym_db.RegisterEnumDescriptor(_LIGHT_LINCOLNAMBIENTTYPE)

_EPS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.canbus.Eps.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_AVAILABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3777,
  serialized_end=3838,
)
_sym_db.RegisterEnumDescriptor(_EPS_TYPE)

_BRAKE_HSASTATUSTYPE = _descriptor.EnumDescriptor(
  name='HSAStatusType',
  full_name='apollo.canbus.Brake.HSAStatusType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HSA_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HSA_FINDING_GRADIENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HSA_ACTIVE_PRESSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HSA_ACTIVE_RELEASED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HSA_FAST_RELEASE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HSA_SLOW_RELEASE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HSA_FAILED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HSA_UNDEFINED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5741,
  serialized_end=5928,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_HSASTATUSTYPE)

_BRAKE_HSAMODETYPE = _descriptor.EnumDescriptor(
  name='HSAModeType',
  full_name='apollo.canbus.Brake.HSAModeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HSA_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HSA_AUTO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HSA_MANUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HSA_MODE_UNDEFINED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5930,
  serialized_end=6010,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_HSAMODETYPE)

_EPB_PBRAKETYPE = _descriptor.EnumDescriptor(
  name='PBrakeType',
  full_name='apollo.canbus.Epb.PBrakeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PBRAKE_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PBRAKE_TRANSITION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PBRAKE_ON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PBRAKE_FAULT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6148,
  serialized_end=6232,
)
_sym_db.RegisterEnumDescriptor(_EPB_PBRAKETYPE)

_EMS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.canbus.Ems.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STOP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRANK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7375,
  serialized_end=7428,
)
_sym_db.RegisterEnumDescriptor(_EMS_TYPE)

_BASICINFO_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.canbus.BasicInfo.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='START', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9285,
  serialized_end=9341,
)
_sym_db.RegisterEnumDescriptor(_BASICINFO_TYPE)

_GLOBAL_RPT_6A_PACMOD_STATUSTYPE = _descriptor.EnumDescriptor(
  name='Pacmod_statusType',
  full_name='apollo.canbus.Global_rpt_6a.Pacmod_statusType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PACMOD_STATUS_CONTROL_DISABLED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PACMOD_STATUS_CONTROL_ENABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9686,
  serialized_end=9776,
)
_sym_db.RegisterEnumDescriptor(_GLOBAL_RPT_6A_PACMOD_STATUSTYPE)

_GLOBAL_RPT_6A_OVERRIDE_STATUSTYPE = _descriptor.EnumDescriptor(
  name='Override_statusType',
  full_name='apollo.canbus.Global_rpt_6a.Override_statusType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OVERRIDE_STATUS_NOT_OVERRIDDEN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OVERRIDE_STATUS_OVERRIDDEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9778,
  serialized_end=9867,
)
_sym_db.RegisterEnumDescriptor(_GLOBAL_RPT_6A_OVERRIDE_STATUSTYPE)

_GLOBAL_RPT_6A_BRK_CAN_TIMEOUTTYPE = _descriptor.EnumDescriptor(
  name='Brk_can_timeoutType',
  full_name='apollo.canbus.Global_rpt_6a.Brk_can_timeoutType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRK_CAN_TIMEOUT_NO_ACTIVE_CAN_TIMEOUT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRK_CAN_TIMEOUT_ACTIVE_CAN_TIMEOUT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9869,
  serialized_end=9973,
)
_sym_db.RegisterEnumDescriptor(_GLOBAL_RPT_6A_BRK_CAN_TIMEOUTTYPE)

_BRAKE_RPT_6C_BRAKE_ON_OFFTYPE = _descriptor.EnumDescriptor(
  name='Brake_on_offType',
  full_name='apollo.canbus.Brake_rpt_6c.Brake_on_offType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ON_OFF_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKE_ON_OFF_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10164,
  serialized_end=10225,
)
_sym_db.RegisterEnumDescriptor(_BRAKE_RPT_6C_BRAKE_ON_OFFTYPE)

_HEADLIGHT_RPT_77_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Headlight_rpt_77.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_HEADLIGHTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_LOW_BEAMS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_HIGH_BEAMS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10977,
  serialized_end=11085,
)
_sym_db.RegisterEnumDescriptor(_HEADLIGHT_RPT_77_OUTPUT_VALUETYPE)

_HEADLIGHT_RPT_77_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Headlight_rpt_77.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_HEADLIGHTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_LOW_BEAMS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_HIGH_BEAMS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11087,
  serialized_end=11195,
)
_sym_db.RegisterEnumDescriptor(_HEADLIGHT_RPT_77_MANUAL_INPUTTYPE)

_HEADLIGHT_RPT_77_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Headlight_rpt_77.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_HEADLIGHTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_LOW_BEAMS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_HIGH_BEAMS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11197,
  serialized_end=11317,
)
_sym_db.RegisterEnumDescriptor(_HEADLIGHT_RPT_77_COMMANDED_VALUETYPE)

_TURN_CMD_63_TURN_SIGNAL_CMDTYPE = _descriptor.EnumDescriptor(
  name='Turn_signal_cmdType',
  full_name='apollo.canbus.Turn_cmd_63.Turn_signal_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_CMD_RIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_CMD_NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_CMD_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_SIGNAL_CMD_HAZARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11566,
  serialized_end=11694,
)
_sym_db.RegisterEnumDescriptor(_TURN_CMD_63_TURN_SIGNAL_CMDTYPE)

_TURN_RPT_64_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Turn_rpt_64.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_RIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_HAZARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11919,
  serialized_end=12032,
)
_sym_db.RegisterEnumDescriptor(_TURN_RPT_64_MANUAL_INPUTTYPE)

_TURN_RPT_64_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Turn_rpt_64.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_RIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_HAZARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12035,
  serialized_end=12163,
)
_sym_db.RegisterEnumDescriptor(_TURN_RPT_64_COMMANDED_VALUETYPE)

_TURN_RPT_64_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Turn_rpt_64.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_RIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_HAZARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12165,
  serialized_end=12278,
)
_sym_db.RegisterEnumDescriptor(_TURN_RPT_64_OUTPUT_VALUETYPE)

_SHIFT_CMD_65_SHIFT_CMDTYPE = _descriptor.EnumDescriptor(
  name='Shift_cmdType',
  full_name='apollo.canbus.Shift_cmd_65.Shift_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHIFT_CMD_PARK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFT_CMD_REVERSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFT_CMD_NEUTRAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFT_CMD_FORWARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFT_CMD_LOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12359,
  serialized_end=12482,
)
_sym_db.RegisterEnumDescriptor(_SHIFT_CMD_65_SHIFT_CMDTYPE)

_SHIFT_RPT_66_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Shift_rpt_66.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_PARK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_REVERSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_NEUTRAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_FORWARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_HIGH', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12712,
  serialized_end=12854,
)
_sym_db.RegisterEnumDescriptor(_SHIFT_RPT_66_MANUAL_INPUTTYPE)

_SHIFT_RPT_66_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Shift_rpt_66.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_PARK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_REVERSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_NEUTRAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_FORWARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_HIGH', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12857,
  serialized_end=13017,
)
_sym_db.RegisterEnumDescriptor(_SHIFT_RPT_66_COMMANDED_VALUETYPE)

_SHIFT_RPT_66_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Shift_rpt_66.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_PARK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_REVERSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_NEUTRAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_FORWARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_HIGH', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13020,
  serialized_end=13162,
)
_sym_db.RegisterEnumDescriptor(_SHIFT_RPT_66_OUTPUT_VALUETYPE)

_GLOBAL_CMD_69_PACMOD_ENABLETYPE = _descriptor.EnumDescriptor(
  name='Pacmod_enableType',
  full_name='apollo.canbus.Global_cmd_69.Pacmod_enableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PACMOD_ENABLE_CONTROL_DISABLED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PACMOD_ENABLE_CONTROL_ENABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13639,
  serialized_end=13729,
)
_sym_db.RegisterEnumDescriptor(_GLOBAL_CMD_69_PACMOD_ENABLETYPE)

_GLOBAL_CMD_69_CLEAR_OVERRIDETYPE = _descriptor.EnumDescriptor(
  name='Clear_overrideType',
  full_name='apollo.canbus.Global_cmd_69.Clear_overrideType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLEAR_OVERRIDE_DON_T_CLEAR_ACTIVE_OVERRIDES', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEAR_OVERRIDE_CLEAR_ACTIVE_OVERRIDES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13731,
  serialized_end=13843,
)
_sym_db.RegisterEnumDescriptor(_GLOBAL_CMD_69_CLEAR_OVERRIDETYPE)

_GLOBAL_CMD_69_IGNORE_OVERRIDETYPE = _descriptor.EnumDescriptor(
  name='Ignore_overrideType',
  full_name='apollo.canbus.Global_cmd_69.Ignore_overrideType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IGNORE_OVERRIDE_DON_T_IGNORE_USER_OVERRIDES', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IGNORE_OVERRIDE_IGNORE_USER_OVERRIDES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13845,
  serialized_end=13958,
)
_sym_db.RegisterEnumDescriptor(_GLOBAL_CMD_69_IGNORE_OVERRIDETYPE)

_PARKING_BRAKE_STATUS_RPT_80_PARKING_BRAKE_ENABLEDTYPE = _descriptor.EnumDescriptor(
  name='Parking_brake_enabledType',
  full_name='apollo.canbus.Parking_brake_status_rpt_80.Parking_brake_enabledType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARKING_BRAKE_ENABLED_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_BRAKE_ENABLED_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14093,
  serialized_end=14181,
)
_sym_db.RegisterEnumDescriptor(_PARKING_BRAKE_STATUS_RPT_80_PARKING_BRAKE_ENABLEDTYPE)

_HORN_RPT_79_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Horn_rpt_79.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14443,
  serialized_end=14504,
)
_sym_db.RegisterEnumDescriptor(_HORN_RPT_79_OUTPUT_VALUETYPE)

_HORN_RPT_79_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Horn_rpt_79.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14506,
  serialized_end=14576,
)
_sym_db.RegisterEnumDescriptor(_HORN_RPT_79_COMMANDED_VALUETYPE)

_HORN_RPT_79_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Horn_rpt_79.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14578,
  serialized_end=14639,
)
_sym_db.RegisterEnumDescriptor(_HORN_RPT_79_MANUAL_INPUTTYPE)

_HORN_CMD_78_HORN_CMDTYPE = _descriptor.EnumDescriptor(
  name='Horn_cmdType',
  full_name='apollo.canbus.Horn_cmd_78.Horn_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HORN_CMD_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HORN_CMD_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14715,
  serialized_end=14764,
)
_sym_db.RegisterEnumDescriptor(_HORN_CMD_78_HORN_CMDTYPE)

_WIPER_RPT_91_OUTPUT_VALUETYPE = _descriptor.EnumDescriptor(
  name='Output_valueType',
  full_name='apollo.canbus.Wiper_rpt_91.Output_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_WIPERS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_INTERMITTENT_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_INTERMITTENT_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_INTERMITTENT_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_INTERMITTENT_4', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_INTERMITTENT_5', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_LOW', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_VALUE_HIGH', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14994,
  serialized_end=15251,
)
_sym_db.RegisterEnumDescriptor(_WIPER_RPT_91_OUTPUT_VALUETYPE)

_WIPER_RPT_91_COMMANDED_VALUETYPE = _descriptor.EnumDescriptor(
  name='Commanded_valueType',
  full_name='apollo.canbus.Wiper_rpt_91.Commanded_valueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_WIPERS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_INTERMITTENT_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_INTERMITTENT_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_INTERMITTENT_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_INTERMITTENT_4', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_INTERMITTENT_5', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_LOW', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMANDED_VALUE_HIGH', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15254,
  serialized_end=15538,
)
_sym_db.RegisterEnumDescriptor(_WIPER_RPT_91_COMMANDED_VALUETYPE)

_WIPER_RPT_91_MANUAL_INPUTTYPE = _descriptor.EnumDescriptor(
  name='Manual_inputType',
  full_name='apollo.canbus.Wiper_rpt_91.Manual_inputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_WIPERS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_INTERMITTENT_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_INTERMITTENT_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_INTERMITTENT_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_INTERMITTENT_4', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_INTERMITTENT_5', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_LOW', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_INPUT_HIGH', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15541,
  serialized_end=15798,
)
_sym_db.RegisterEnumDescriptor(_WIPER_RPT_91_MANUAL_INPUTTYPE)

_VEHICLE_SPEED_RPT_6F_VEHICLE_SPEED_VALIDTYPE = _descriptor.EnumDescriptor(
  name='Vehicle_speed_validType',
  full_name='apollo.canbus.Vehicle_speed_rpt_6f.Vehicle_speed_validType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VEHICLE_SPEED_VALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEHICLE_SPEED_VALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15938,
  serialized_end=16027,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE_SPEED_RPT_6F_VEHICLE_SPEED_VALIDTYPE)

_HEADLIGHT_CMD_76_HEADLIGHT_CMDTYPE = _descriptor.EnumDescriptor(
  name='Headlight_cmdType',
  full_name='apollo.canbus.Headlight_cmd_76.Headlight_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HEADLIGHT_CMD_HEADLIGHTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEADLIGHT_CMD_LOW_BEAMS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEADLIGHT_CMD_HIGH_BEAMS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16124,
  serialized_end=16236,
)
_sym_db.RegisterEnumDescriptor(_HEADLIGHT_CMD_76_HEADLIGHT_CMDTYPE)

_WIPER_CMD_90_WIPER_CMDTYPE = _descriptor.EnumDescriptor(
  name='Wiper_cmdType',
  full_name='apollo.canbus.Wiper_cmd_90.Wiper_cmdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_WIPERS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_INTERMITTENT_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_INTERMITTENT_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_INTERMITTENT_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_INTERMITTENT_4', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_INTERMITTENT_5', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_LOW', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIPER_CMD_HIGH', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16601,
  serialized_end=16831,
)
_sym_db.RegisterEnumDescriptor(_WIPER_CMD_90_WIPER_CMDTYPE)


_CHASSISDETAIL = _descriptor.Descriptor(
  name='ChassisDetail',
  full_name='apollo.canbus.ChassisDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='car_type', full_name='apollo.canbus.ChassisDetail.car_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basic', full_name='apollo.canbus.ChassisDetail.basic', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safety', full_name='apollo.canbus.ChassisDetail.safety', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear', full_name='apollo.canbus.ChassisDetail.gear', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ems', full_name='apollo.canbus.ChassisDetail.ems', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esp', full_name='apollo.canbus.ChassisDetail.esp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gas', full_name='apollo.canbus.ChassisDetail.gas', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epb', full_name='apollo.canbus.ChassisDetail.epb', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake', full_name='apollo.canbus.ChassisDetail.brake', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deceleration', full_name='apollo.canbus.ChassisDetail.deceleration', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_spd', full_name='apollo.canbus.ChassisDetail.vehicle_spd', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps', full_name='apollo.canbus.ChassisDetail.eps', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='light', full_name='apollo.canbus.ChassisDetail.light', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery', full_name='apollo.canbus.ChassisDetail.battery', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='check_response', full_name='apollo.canbus.ChassisDetail.check_response', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='license', full_name='apollo.canbus.ChassisDetail.license', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='surround', full_name='apollo.canbus.ChassisDetail.surround', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gem', full_name='apollo.canbus.ChassisDetail.gem', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lexus', full_name='apollo.canbus.ChassisDetail.lexus', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transit', full_name='apollo.canbus.ChassisDetail.transit', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ge3', full_name='apollo.canbus.ChassisDetail.ge3', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wey', full_name='apollo.canbus.ChassisDetail.wey', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zhongyun', full_name='apollo.canbus.ChassisDetail.zhongyun', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ch', full_name='apollo.canbus.ChassisDetail.ch', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='devkit', full_name='apollo.canbus.ChassisDetail.devkit', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='neolix_edu', full_name='apollo.canbus.ChassisDetail.neolix_edu', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_id', full_name='apollo.canbus.ChassisDetail.vehicle_id', index=26,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHASSISDETAIL_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=1564,
)


_CHECKRESPONSESIGNAL = _descriptor.Descriptor(
  name='CheckResponseSignal',
  full_name='apollo.canbus.CheckResponseSignal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_eps_online', full_name='apollo.canbus.CheckResponseSignal.is_eps_online', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_epb_online', full_name='apollo.canbus.CheckResponseSignal.is_epb_online', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_esp_online', full_name='apollo.canbus.CheckResponseSignal.is_esp_online', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_vtog_online', full_name='apollo.canbus.CheckResponseSignal.is_vtog_online', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_scu_online', full_name='apollo.canbus.CheckResponseSignal.is_scu_online', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_switch_online', full_name='apollo.canbus.CheckResponseSignal.is_switch_online', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_vcu_online', full_name='apollo.canbus.CheckResponseSignal.is_vcu_online', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1802,
)


_BATTERY = _descriptor.Descriptor(
  name='Battery',
  full_name='apollo.canbus.Battery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='battery_percent', full_name='apollo.canbus.Battery.battery_percent', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fuel_level', full_name='apollo.canbus.Battery.fuel_level', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1804,
  serialized_end=1858,
)


_LIGHT = _descriptor.Descriptor(
  name='Light',
  full_name='apollo.canbus.Light',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='turn_light_type', full_name='apollo.canbus.Light.turn_light_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beam_lamp_type', full_name='apollo.canbus.Light.beam_lamp_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_brake_lamp_on', full_name='apollo.canbus.Light.is_brake_lamp_on', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_auto_light', full_name='apollo.canbus.Light.is_auto_light', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wiper_gear', full_name='apollo.canbus.Light.wiper_gear', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lotion_gear', full_name='apollo.canbus.Light.lotion_gear', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_horn_on', full_name='apollo.canbus.Light.is_horn_on', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lincoln_lamp_type', full_name='apollo.canbus.Light.lincoln_lamp_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lincoln_wiper', full_name='apollo.canbus.Light.lincoln_wiper', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lincoln_ambient', full_name='apollo.canbus.Light.lincoln_ambient', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LIGHT_TURNLIGHTTYPE,
    _LIGHT_BEAMLAMPTYPE,
    _LIGHT_LINCOLNLAMPTYPE,
    _LIGHT_LINCOLNWIPERTYPE,
    _LIGHT_LINCOLNAMBIENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1861,
  serialized_end=3062,
)


_EPS = _descriptor.Descriptor(
  name='Eps',
  full_name='apollo.canbus.Eps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_eps_fail', full_name='apollo.canbus.Eps.is_eps_fail', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps_control_state', full_name='apollo.canbus.Eps.eps_control_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps_driver_hand_torq', full_name='apollo.canbus.Eps.eps_driver_hand_torq', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_steering_angle_valid', full_name='apollo.canbus.Eps.is_steering_angle_valid', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_angle', full_name='apollo.canbus.Eps.steering_angle', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_angle_spd', full_name='apollo.canbus.Eps.steering_angle_spd', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_trimming_status', full_name='apollo.canbus.Eps.is_trimming_status', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_calibration_status', full_name='apollo.canbus.Eps.is_calibration_status', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_failure_status', full_name='apollo.canbus.Eps.is_failure_status', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_enter_autonomous_mode', full_name='apollo.canbus.Eps.allow_enter_autonomous_mode', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_driving_mode', full_name='apollo.canbus.Eps.current_driving_mode', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_angle_cmd', full_name='apollo.canbus.Eps.steering_angle_cmd', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_speed', full_name='apollo.canbus.Eps.vehicle_speed', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epas_torque', full_name='apollo.canbus.Eps.epas_torque', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_enabled', full_name='apollo.canbus.Eps.steering_enabled', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_override', full_name='apollo.canbus.Eps.driver_override', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_activity', full_name='apollo.canbus.Eps.driver_activity', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watchdog_fault', full_name='apollo.canbus.Eps.watchdog_fault', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_1_fault', full_name='apollo.canbus.Eps.channel_1_fault', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_2_fault', full_name='apollo.canbus.Eps.channel_2_fault', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration_fault', full_name='apollo.canbus.Eps.calibration_fault', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connector_fault', full_name='apollo.canbus.Eps.connector_fault', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_65', full_name='apollo.canbus.Eps.timestamp_65', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='major_version', full_name='apollo.canbus.Eps.major_version', index=23,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor_version', full_name='apollo.canbus.Eps.minor_version', index=24,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_number', full_name='apollo.canbus.Eps.build_number', index=25,
      number=26, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EPS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3065,
  serialized_end=3838,
)


_VEHICLESPD = _descriptor.Descriptor(
  name='VehicleSpd',
  full_name='apollo.canbus.VehicleSpd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_vehicle_standstill', full_name='apollo.canbus.VehicleSpd.is_vehicle_standstill', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_vehicle_spd_valid', full_name='apollo.canbus.VehicleSpd.is_vehicle_spd_valid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_spd', full_name='apollo.canbus.VehicleSpd.vehicle_spd', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_wheel_spd_rr_valid', full_name='apollo.canbus.VehicleSpd.is_wheel_spd_rr_valid', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_direction_rr', full_name='apollo.canbus.VehicleSpd.wheel_direction_rr', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_rr', full_name='apollo.canbus.VehicleSpd.wheel_spd_rr', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_wheel_spd_rl_valid', full_name='apollo.canbus.VehicleSpd.is_wheel_spd_rl_valid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_direction_rl', full_name='apollo.canbus.VehicleSpd.wheel_direction_rl', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_rl', full_name='apollo.canbus.VehicleSpd.wheel_spd_rl', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_wheel_spd_fr_valid', full_name='apollo.canbus.VehicleSpd.is_wheel_spd_fr_valid', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_direction_fr', full_name='apollo.canbus.VehicleSpd.wheel_direction_fr', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_fr', full_name='apollo.canbus.VehicleSpd.wheel_spd_fr', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_wheel_spd_fl_valid', full_name='apollo.canbus.VehicleSpd.is_wheel_spd_fl_valid', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_direction_fl', full_name='apollo.canbus.VehicleSpd.wheel_direction_fl', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_fl', full_name='apollo.canbus.VehicleSpd.wheel_spd_fl', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_yaw_rate_valid', full_name='apollo.canbus.VehicleSpd.is_yaw_rate_valid', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_rate', full_name='apollo.canbus.VehicleSpd.yaw_rate', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_rate_offset', full_name='apollo.canbus.VehicleSpd.yaw_rate_offset', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_ax_valid', full_name='apollo.canbus.VehicleSpd.is_ax_valid', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ax', full_name='apollo.canbus.VehicleSpd.ax', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ax_offset', full_name='apollo.canbus.VehicleSpd.ax_offset', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_ay_valid', full_name='apollo.canbus.VehicleSpd.is_ay_valid', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ay', full_name='apollo.canbus.VehicleSpd.ay', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ay_offset', full_name='apollo.canbus.VehicleSpd.ay_offset', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat_acc', full_name='apollo.canbus.VehicleSpd.lat_acc', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long_acc', full_name='apollo.canbus.VehicleSpd.long_acc', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vert_acc', full_name='apollo.canbus.VehicleSpd.vert_acc', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roll_rate', full_name='apollo.canbus.VehicleSpd.roll_rate', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_est', full_name='apollo.canbus.VehicleSpd.acc_est', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_sec', full_name='apollo.canbus.VehicleSpd.timestamp_sec', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3841,
  serialized_end=4716,
)


_DECELERATION = _descriptor.Descriptor(
  name='Deceleration',
  full_name='apollo.canbus.Deceleration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_deceleration_available', full_name='apollo.canbus.Deceleration.is_deceleration_available', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_deceleration_active', full_name='apollo.canbus.Deceleration.is_deceleration_active', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deceleration', full_name='apollo.canbus.Deceleration.deceleration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_evb_fail', full_name='apollo.canbus.Deceleration.is_evb_fail', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evb_pressure', full_name='apollo.canbus.Deceleration.evb_pressure', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_pressure', full_name='apollo.canbus.Deceleration.brake_pressure', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_pressure_spd', full_name='apollo.canbus.Deceleration.brake_pressure_spd', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4719,
  serialized_end=4929,
)


_BRAKE = _descriptor.Descriptor(
  name='Brake',
  full_name='apollo.canbus.Brake',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_brake_pedal_pressed', full_name='apollo.canbus.Brake.is_brake_pedal_pressed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_brake_force_exist', full_name='apollo.canbus.Brake.is_brake_force_exist', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_brake_over_heat', full_name='apollo.canbus.Brake.is_brake_over_heat', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_hand_brake_on', full_name='apollo.canbus.Brake.is_hand_brake_on', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_pedal_position', full_name='apollo.canbus.Brake.brake_pedal_position', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_brake_valid', full_name='apollo.canbus.Brake.is_brake_valid', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_input', full_name='apollo.canbus.Brake.brake_input', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_cmd', full_name='apollo.canbus.Brake.brake_cmd', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_output', full_name='apollo.canbus.Brake.brake_output', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boo_input', full_name='apollo.canbus.Brake.boo_input', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boo_cmd', full_name='apollo.canbus.Brake.boo_cmd', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boo_output', full_name='apollo.canbus.Brake.boo_output', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watchdog_applying_brakes', full_name='apollo.canbus.Brake.watchdog_applying_brakes', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watchdog_source', full_name='apollo.canbus.Brake.watchdog_source', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_enabled', full_name='apollo.canbus.Brake.brake_enabled', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_override', full_name='apollo.canbus.Brake.driver_override', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_activity', full_name='apollo.canbus.Brake.driver_activity', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watchdog_fault', full_name='apollo.canbus.Brake.watchdog_fault', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_1_fault', full_name='apollo.canbus.Brake.channel_1_fault', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_2_fault', full_name='apollo.canbus.Brake.channel_2_fault', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boo_fault', full_name='apollo.canbus.Brake.boo_fault', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connector_fault', full_name='apollo.canbus.Brake.connector_fault', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_torque_req', full_name='apollo.canbus.Brake.brake_torque_req', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hsa_status', full_name='apollo.canbus.Brake.hsa_status', index=23,
      number=24, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_torque_act', full_name='apollo.canbus.Brake.brake_torque_act', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hsa_mode', full_name='apollo.canbus.Brake.hsa_mode', index=25,
      number=26, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_torque_act', full_name='apollo.canbus.Brake.wheel_torque_act', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='major_version', full_name='apollo.canbus.Brake.major_version', index=27,
      number=28, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor_version', full_name='apollo.canbus.Brake.minor_version', index=28,
      number=29, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_number', full_name='apollo.canbus.Brake.build_number', index=29,
      number=30, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BRAKE_HSASTATUSTYPE,
    _BRAKE_HSAMODETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4932,
  serialized_end=6010,
)


_EPB = _descriptor.Descriptor(
  name='Epb',
  full_name='apollo.canbus.Epb',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_epb_error', full_name='apollo.canbus.Epb.is_epb_error', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_epb_released', full_name='apollo.canbus.Epb.is_epb_released', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epb_status', full_name='apollo.canbus.Epb.epb_status', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_brake_status', full_name='apollo.canbus.Epb.parking_brake_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EPB_PBRAKETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6013,
  serialized_end=6232,
)


_GAS = _descriptor.Descriptor(
  name='Gas',
  full_name='apollo.canbus.Gas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_gas_pedal_error', full_name='apollo.canbus.Gas.is_gas_pedal_error', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_gas_pedal_pressed_more', full_name='apollo.canbus.Gas.is_gas_pedal_pressed_more', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gas_pedal_position', full_name='apollo.canbus.Gas.gas_pedal_position', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_gas_valid', full_name='apollo.canbus.Gas.is_gas_valid', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_input', full_name='apollo.canbus.Gas.throttle_input', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_cmd', full_name='apollo.canbus.Gas.throttle_cmd', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_output', full_name='apollo.canbus.Gas.throttle_output', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watchdog_source', full_name='apollo.canbus.Gas.watchdog_source', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_enabled', full_name='apollo.canbus.Gas.throttle_enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_override', full_name='apollo.canbus.Gas.driver_override', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_activity', full_name='apollo.canbus.Gas.driver_activity', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watchdog_fault', full_name='apollo.canbus.Gas.watchdog_fault', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_1_fault', full_name='apollo.canbus.Gas.channel_1_fault', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_2_fault', full_name='apollo.canbus.Gas.channel_2_fault', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connector_fault', full_name='apollo.canbus.Gas.connector_fault', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerator_pedal', full_name='apollo.canbus.Gas.accelerator_pedal', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerator_pedal_rate', full_name='apollo.canbus.Gas.accelerator_pedal_rate', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='major_version', full_name='apollo.canbus.Gas.major_version', index=17,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor_version', full_name='apollo.canbus.Gas.minor_version', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_number', full_name='apollo.canbus.Gas.build_number', index=19,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6235,
  serialized_end=6761,
)


_ESP = _descriptor.Descriptor(
  name='Esp',
  full_name='apollo.canbus.Esp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_esp_acc_error', full_name='apollo.canbus.Esp.is_esp_acc_error', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_esp_on', full_name='apollo.canbus.Esp.is_esp_on', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_esp_active', full_name='apollo.canbus.Esp.is_esp_active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_abs_error', full_name='apollo.canbus.Esp.is_abs_error', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_abs_active', full_name='apollo.canbus.Esp.is_abs_active', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_tcsvdc_fail', full_name='apollo.canbus.Esp.is_tcsvdc_fail', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_abs_enabled', full_name='apollo.canbus.Esp.is_abs_enabled', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_stab_active', full_name='apollo.canbus.Esp.is_stab_active', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_stab_enabled', full_name='apollo.canbus.Esp.is_stab_enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_trac_active', full_name='apollo.canbus.Esp.is_trac_active', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_trac_enabled', full_name='apollo.canbus.Esp.is_trac_enabled', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6764,
  serialized_end=7028,
)


_EMS = _descriptor.Descriptor(
  name='Ems',
  full_name='apollo.canbus.Ems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_engine_acc_available', full_name='apollo.canbus.Ems.is_engine_acc_available', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_engine_acc_error', full_name='apollo.canbus.Ems.is_engine_acc_error', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engine_state', full_name='apollo.canbus.Ems.engine_state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_engine_torq_percent', full_name='apollo.canbus.Ems.max_engine_torq_percent', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_engine_torq_percent', full_name='apollo.canbus.Ems.min_engine_torq_percent', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_engine_torq_constant', full_name='apollo.canbus.Ems.base_engine_torq_constant', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_engine_speed_error', full_name='apollo.canbus.Ems.is_engine_speed_error', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engine_speed', full_name='apollo.canbus.Ems.engine_speed', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engine_torque', full_name='apollo.canbus.Ems.engine_torque', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_over_engine_torque', full_name='apollo.canbus.Ems.is_over_engine_torque', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engine_rpm', full_name='apollo.canbus.Ems.engine_rpm', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EMS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7031,
  serialized_end=7428,
)


_GEAR = _descriptor.Descriptor(
  name='Gear',
  full_name='apollo.canbus.Gear',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_shift_position_valid', full_name='apollo.canbus.Gear.is_shift_position_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_state', full_name='apollo.canbus.Gear.gear_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_override', full_name='apollo.canbus.Gear.driver_override', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_cmd', full_name='apollo.canbus.Gear.gear_cmd', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='canbus_fault', full_name='apollo.canbus.Gear.canbus_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7431,
  serialized_end=7629,
)


_SAFETY = _descriptor.Descriptor(
  name='Safety',
  full_name='apollo.canbus.Safety',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_driver_car_door_close', full_name='apollo.canbus.Safety.is_driver_car_door_close', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_driver_buckled', full_name='apollo.canbus.Safety.is_driver_buckled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emergency_button', full_name='apollo.canbus.Safety.emergency_button', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_error', full_name='apollo.canbus.Safety.has_error', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_motor_invertor_fault', full_name='apollo.canbus.Safety.is_motor_invertor_fault', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_system_fault', full_name='apollo.canbus.Safety.is_system_fault', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_power_battery_fault', full_name='apollo.canbus.Safety.is_power_battery_fault', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_motor_invertor_over_temperature', full_name='apollo.canbus.Safety.is_motor_invertor_over_temperature', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_small_battery_charge_discharge_fault', full_name='apollo.canbus.Safety.is_small_battery_charge_discharge_fault', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driving_mode', full_name='apollo.canbus.Safety.driving_mode', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_passenger_door_open', full_name='apollo.canbus.Safety.is_passenger_door_open', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_rearleft_door_open', full_name='apollo.canbus.Safety.is_rearleft_door_open', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_rearright_door_open', full_name='apollo.canbus.Safety.is_rearright_door_open', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_hood_open', full_name='apollo.canbus.Safety.is_hood_open', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_trunk_open', full_name='apollo.canbus.Safety.is_trunk_open', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_passenger_detected', full_name='apollo.canbus.Safety.is_passenger_detected', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_passenger_airbag_enabled', full_name='apollo.canbus.Safety.is_passenger_airbag_enabled', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_passenger_buckled', full_name='apollo.canbus.Safety.is_passenger_buckled', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_left_tire_press', full_name='apollo.canbus.Safety.front_left_tire_press', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_right_tire_press', full_name='apollo.canbus.Safety.front_right_tire_press', index=19,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_left_tire_press', full_name='apollo.canbus.Safety.rear_left_tire_press', index=20,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_right_tire_press', full_name='apollo.canbus.Safety.rear_right_tire_press', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='car_driving_mode', full_name='apollo.canbus.Safety.car_driving_mode', index=22,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7632,
  serialized_end=8382,
)


_BASICINFO = _descriptor.Descriptor(
  name='BasicInfo',
  full_name='apollo.canbus.BasicInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_auto_mode', full_name='apollo.canbus.BasicInfo.is_auto_mode', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='power_state', full_name='apollo.canbus.BasicInfo.power_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_air_bag_deployed', full_name='apollo.canbus.BasicInfo.is_air_bag_deployed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='odo_meter', full_name='apollo.canbus.BasicInfo.odo_meter', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drive_range', full_name='apollo.canbus.BasicInfo.drive_range', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_system_error', full_name='apollo.canbus.BasicInfo.is_system_error', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_human_interrupt', full_name='apollo.canbus.BasicInfo.is_human_interrupt', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_on_button', full_name='apollo.canbus.BasicInfo.acc_on_button', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_off_button', full_name='apollo.canbus.BasicInfo.acc_off_button', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_res_button', full_name='apollo.canbus.BasicInfo.acc_res_button', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_cancel_button', full_name='apollo.canbus.BasicInfo.acc_cancel_button', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_on_off_button', full_name='apollo.canbus.BasicInfo.acc_on_off_button', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_res_cancel_button', full_name='apollo.canbus.BasicInfo.acc_res_cancel_button', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_inc_spd_button', full_name='apollo.canbus.BasicInfo.acc_inc_spd_button', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_dec_spd_button', full_name='apollo.canbus.BasicInfo.acc_dec_spd_button', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_inc_gap_button', full_name='apollo.canbus.BasicInfo.acc_inc_gap_button', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_dec_gap_button', full_name='apollo.canbus.BasicInfo.acc_dec_gap_button', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lka_button', full_name='apollo.canbus.BasicInfo.lka_button', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='canbus_fault', full_name='apollo.canbus.BasicInfo.canbus_fault', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='apollo.canbus.BasicInfo.latitude', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='apollo.canbus.BasicInfo.longitude', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gps_valid', full_name='apollo.canbus.BasicInfo.gps_valid', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='year', full_name='apollo.canbus.BasicInfo.year', index=22,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='apollo.canbus.BasicInfo.month', index=23,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='apollo.canbus.BasicInfo.day', index=24,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hours', full_name='apollo.canbus.BasicInfo.hours', index=25,
      number=26, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minutes', full_name='apollo.canbus.BasicInfo.minutes', index=26,
      number=27, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds', full_name='apollo.canbus.BasicInfo.seconds', index=27,
      number=28, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compass_direction', full_name='apollo.canbus.BasicInfo.compass_direction', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdop', full_name='apollo.canbus.BasicInfo.pdop', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_gps_fault', full_name='apollo.canbus.BasicInfo.is_gps_fault', index=30,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_inferred', full_name='apollo.canbus.BasicInfo.is_inferred', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='altitude', full_name='apollo.canbus.BasicInfo.altitude', index=32,
      number=33, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.canbus.BasicInfo.heading', index=33,
      number=34, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hdop', full_name='apollo.canbus.BasicInfo.hdop', index=34,
      number=35, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vdop', full_name='apollo.canbus.BasicInfo.vdop', index=35,
      number=36, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='apollo.canbus.BasicInfo.quality', index=36,
      number=37, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_satellites', full_name='apollo.canbus.BasicInfo.num_satellites', index=37,
      number=38, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gps_speed', full_name='apollo.canbus.BasicInfo.gps_speed', index=38,
      number=39, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BASICINFO_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8385,
  serialized_end=9341,
)


_GLOBAL_RPT_6A = _descriptor.Descriptor(
  name='Global_rpt_6a',
  full_name='apollo.canbus.Global_rpt_6a',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pacmod_status', full_name='apollo.canbus.Global_rpt_6a.pacmod_status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_status', full_name='apollo.canbus.Global_rpt_6a.override_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='veh_can_timeout', full_name='apollo.canbus.Global_rpt_6a.veh_can_timeout', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='str_can_timeout', full_name='apollo.canbus.Global_rpt_6a.str_can_timeout', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brk_can_timeout', full_name='apollo.canbus.Global_rpt_6a.brk_can_timeout', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usr_can_timeout', full_name='apollo.canbus.Global_rpt_6a.usr_can_timeout', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usr_can_read_errors', full_name='apollo.canbus.Global_rpt_6a.usr_can_read_errors', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GLOBAL_RPT_6A_PACMOD_STATUSTYPE,
    _GLOBAL_RPT_6A_OVERRIDE_STATUSTYPE,
    _GLOBAL_RPT_6A_BRK_CAN_TIMEOUTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9344,
  serialized_end=9973,
)


_BRAKE_CMD_6B = _descriptor.Descriptor(
  name='Brake_cmd_6b',
  full_name='apollo.canbus.Brake_cmd_6b',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brake_cmd', full_name='apollo.canbus.Brake_cmd_6b.brake_cmd', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9975,
  serialized_end=10008,
)


_BRAKE_RPT_6C = _descriptor.Descriptor(
  name='Brake_rpt_6c',
  full_name='apollo.canbus.Brake_rpt_6c',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Brake_rpt_6c.manual_input', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Brake_rpt_6c.commanded_value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Brake_rpt_6c.output_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_on_off', full_name='apollo.canbus.Brake_rpt_6c.brake_on_off', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BRAKE_RPT_6C_BRAKE_ON_OFFTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10011,
  serialized_end=10225,
)


_STEERING_CMD_6D = _descriptor.Descriptor(
  name='Steering_cmd_6d',
  full_name='apollo.canbus.Steering_cmd_6d',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position_value', full_name='apollo.canbus.Steering_cmd_6d.position_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_limit', full_name='apollo.canbus.Steering_cmd_6d.speed_limit', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10227,
  serialized_end=10289,
)


_STEERING_RPT_1_6E = _descriptor.Descriptor(
  name='Steering_rpt_1_6e',
  full_name='apollo.canbus.Steering_rpt_1_6e',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Steering_rpt_1_6e.manual_input', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Steering_rpt_1_6e.commanded_value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Steering_rpt_1_6e.output_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10291,
  serialized_end=10379,
)


_WHEEL_SPEED_RPT_7A = _descriptor.Descriptor(
  name='Wheel_speed_rpt_7a',
  full_name='apollo.canbus.Wheel_speed_rpt_7a',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wheel_spd_rear_right', full_name='apollo.canbus.Wheel_speed_rpt_7a.wheel_spd_rear_right', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_rear_left', full_name='apollo.canbus.Wheel_speed_rpt_7a.wheel_spd_rear_left', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_front_right', full_name='apollo.canbus.Wheel_speed_rpt_7a.wheel_spd_front_right', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_spd_front_left', full_name='apollo.canbus.Wheel_speed_rpt_7a.wheel_spd_front_left', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10382,
  serialized_end=10522,
)


_DATE_TIME_RPT_83 = _descriptor.Descriptor(
  name='Date_time_rpt_83',
  full_name='apollo.canbus.Date_time_rpt_83',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_second', full_name='apollo.canbus.Date_time_rpt_83.time_second', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_minute', full_name='apollo.canbus.Date_time_rpt_83.time_minute', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_hour', full_name='apollo.canbus.Date_time_rpt_83.time_hour', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_day', full_name='apollo.canbus.Date_time_rpt_83.date_day', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_month', full_name='apollo.canbus.Date_time_rpt_83.date_month', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_year', full_name='apollo.canbus.Date_time_rpt_83.date_year', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10525,
  serialized_end=10661,
)


_BRAKE_MOTOR_RPT_1_70 = _descriptor.Descriptor(
  name='Brake_motor_rpt_1_70',
  full_name='apollo.canbus.Brake_motor_rpt_1_70',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='motor_current', full_name='apollo.canbus.Brake_motor_rpt_1_70.motor_current', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shaft_position', full_name='apollo.canbus.Brake_motor_rpt_1_70.shaft_position', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10663,
  serialized_end=10732,
)


_HEADLIGHT_RPT_77 = _descriptor.Descriptor(
  name='Headlight_rpt_77',
  full_name='apollo.canbus.Headlight_rpt_77',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Headlight_rpt_77.output_value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Headlight_rpt_77.manual_input', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Headlight_rpt_77.commanded_value', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HEADLIGHT_RPT_77_OUTPUT_VALUETYPE,
    _HEADLIGHT_RPT_77_MANUAL_INPUTTYPE,
    _HEADLIGHT_RPT_77_COMMANDED_VALUETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10735,
  serialized_end=11317,
)


_ACCEL_RPT_68 = _descriptor.Descriptor(
  name='Accel_rpt_68',
  full_name='apollo.canbus.Accel_rpt_68',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Accel_rpt_68.manual_input', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Accel_rpt_68.commanded_value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Accel_rpt_68.output_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11319,
  serialized_end=11402,
)


_STEERING_MOTOR_RPT_3_75 = _descriptor.Descriptor(
  name='Steering_motor_rpt_3_75',
  full_name='apollo.canbus.Steering_motor_rpt_3_75',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='torque_output', full_name='apollo.canbus.Steering_motor_rpt_3_75.torque_output', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='torque_input', full_name='apollo.canbus.Steering_motor_rpt_3_75.torque_input', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11404,
  serialized_end=11474,
)


_TURN_CMD_63 = _descriptor.Descriptor(
  name='Turn_cmd_63',
  full_name='apollo.canbus.Turn_cmd_63',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='turn_signal_cmd', full_name='apollo.canbus.Turn_cmd_63.turn_signal_cmd', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TURN_CMD_63_TURN_SIGNAL_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11477,
  serialized_end=11694,
)


_TURN_RPT_64 = _descriptor.Descriptor(
  name='Turn_rpt_64',
  full_name='apollo.canbus.Turn_rpt_64',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Turn_rpt_64.manual_input', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Turn_rpt_64.commanded_value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Turn_rpt_64.output_value', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TURN_RPT_64_MANUAL_INPUTTYPE,
    _TURN_RPT_64_COMMANDED_VALUETYPE,
    _TURN_RPT_64_OUTPUT_VALUETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11697,
  serialized_end=12278,
)


_SHIFT_CMD_65 = _descriptor.Descriptor(
  name='Shift_cmd_65',
  full_name='apollo.canbus.Shift_cmd_65',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shift_cmd', full_name='apollo.canbus.Shift_cmd_65.shift_cmd', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SHIFT_CMD_65_SHIFT_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12281,
  serialized_end=12482,
)


_SHIFT_RPT_66 = _descriptor.Descriptor(
  name='Shift_rpt_66',
  full_name='apollo.canbus.Shift_rpt_66',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Shift_rpt_66.manual_input', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Shift_rpt_66.commanded_value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Shift_rpt_66.output_value', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SHIFT_RPT_66_MANUAL_INPUTTYPE,
    _SHIFT_RPT_66_COMMANDED_VALUETYPE,
    _SHIFT_RPT_66_OUTPUT_VALUETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12485,
  serialized_end=13162,
)


_ACCEL_CMD_67 = _descriptor.Descriptor(
  name='Accel_cmd_67',
  full_name='apollo.canbus.Accel_cmd_67',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accel_cmd', full_name='apollo.canbus.Accel_cmd_67.accel_cmd', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13164,
  serialized_end=13197,
)


_LAT_LON_HEADING_RPT_82 = _descriptor.Descriptor(
  name='Lat_lon_heading_rpt_82',
  full_name='apollo.canbus.Lat_lon_heading_rpt_82',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.canbus.Lat_lon_heading_rpt_82.heading', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_seconds', full_name='apollo.canbus.Lat_lon_heading_rpt_82.longitude_seconds', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_minutes', full_name='apollo.canbus.Lat_lon_heading_rpt_82.longitude_minutes', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_degrees', full_name='apollo.canbus.Lat_lon_heading_rpt_82.longitude_degrees', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude_seconds', full_name='apollo.canbus.Lat_lon_heading_rpt_82.latitude_seconds', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude_minutes', full_name='apollo.canbus.Lat_lon_heading_rpt_82.latitude_minutes', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude_degrees', full_name='apollo.canbus.Lat_lon_heading_rpt_82.latitude_degrees', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13200,
  serialized_end=13400,
)


_GLOBAL_CMD_69 = _descriptor.Descriptor(
  name='Global_cmd_69',
  full_name='apollo.canbus.Global_cmd_69',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pacmod_enable', full_name='apollo.canbus.Global_cmd_69.pacmod_enable', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_override', full_name='apollo.canbus.Global_cmd_69.clear_override', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_override', full_name='apollo.canbus.Global_cmd_69.ignore_override', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GLOBAL_CMD_69_PACMOD_ENABLETYPE,
    _GLOBAL_CMD_69_CLEAR_OVERRIDETYPE,
    _GLOBAL_CMD_69_IGNORE_OVERRIDETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13403,
  serialized_end=13958,
)


_PARKING_BRAKE_STATUS_RPT_80 = _descriptor.Descriptor(
  name='Parking_brake_status_rpt_80',
  full_name='apollo.canbus.Parking_brake_status_rpt_80',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parking_brake_enabled', full_name='apollo.canbus.Parking_brake_status_rpt_80.parking_brake_enabled', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PARKING_BRAKE_STATUS_RPT_80_PARKING_BRAKE_ENABLEDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13961,
  serialized_end=14181,
)


_YAW_RATE_RPT_81 = _descriptor.Descriptor(
  name='Yaw_rate_rpt_81',
  full_name='apollo.canbus.Yaw_rate_rpt_81',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='yaw_rate', full_name='apollo.canbus.Yaw_rate_rpt_81.yaw_rate', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14183,
  serialized_end=14218,
)


_HORN_RPT_79 = _descriptor.Descriptor(
  name='Horn_rpt_79',
  full_name='apollo.canbus.Horn_rpt_79',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Horn_rpt_79.output_value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Horn_rpt_79.commanded_value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Horn_rpt_79.manual_input', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HORN_RPT_79_OUTPUT_VALUETYPE,
    _HORN_RPT_79_COMMANDED_VALUETYPE,
    _HORN_RPT_79_MANUAL_INPUTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14221,
  serialized_end=14639,
)


_HORN_CMD_78 = _descriptor.Descriptor(
  name='Horn_cmd_78',
  full_name='apollo.canbus.Horn_cmd_78',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='horn_cmd', full_name='apollo.canbus.Horn_cmd_78.horn_cmd', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HORN_CMD_78_HORN_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14641,
  serialized_end=14764,
)


_WIPER_RPT_91 = _descriptor.Descriptor(
  name='Wiper_rpt_91',
  full_name='apollo.canbus.Wiper_rpt_91',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_value', full_name='apollo.canbus.Wiper_rpt_91.output_value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commanded_value', full_name='apollo.canbus.Wiper_rpt_91.commanded_value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_input', full_name='apollo.canbus.Wiper_rpt_91.manual_input', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WIPER_RPT_91_OUTPUT_VALUETYPE,
    _WIPER_RPT_91_COMMANDED_VALUETYPE,
    _WIPER_RPT_91_MANUAL_INPUTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14767,
  serialized_end=15798,
)


_VEHICLE_SPEED_RPT_6F = _descriptor.Descriptor(
  name='Vehicle_speed_rpt_6f',
  full_name='apollo.canbus.Vehicle_speed_rpt_6f',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_speed', full_name='apollo.canbus.Vehicle_speed_rpt_6f.vehicle_speed', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_speed_valid', full_name='apollo.canbus.Vehicle_speed_rpt_6f.vehicle_speed_valid', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VEHICLE_SPEED_RPT_6F_VEHICLE_SPEED_VALIDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15801,
  serialized_end=16027,
)


_HEADLIGHT_CMD_76 = _descriptor.Descriptor(
  name='Headlight_cmd_76',
  full_name='apollo.canbus.Headlight_cmd_76',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='headlight_cmd', full_name='apollo.canbus.Headlight_cmd_76.headlight_cmd', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HEADLIGHT_CMD_76_HEADLIGHT_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16030,
  serialized_end=16236,
)


_STEERING_MOTOR_RPT_2_74 = _descriptor.Descriptor(
  name='Steering_motor_rpt_2_74',
  full_name='apollo.canbus.Steering_motor_rpt_2_74',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoder_temperature', full_name='apollo.canbus.Steering_motor_rpt_2_74.encoder_temperature', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motor_temperature', full_name='apollo.canbus.Steering_motor_rpt_2_74.motor_temperature', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_speed', full_name='apollo.canbus.Steering_motor_rpt_2_74.angular_speed', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16238,
  serialized_end=16342,
)


_BRAKE_MOTOR_RPT_2_71 = _descriptor.Descriptor(
  name='Brake_motor_rpt_2_71',
  full_name='apollo.canbus.Brake_motor_rpt_2_71',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoder_temperature', full_name='apollo.canbus.Brake_motor_rpt_2_71.encoder_temperature', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motor_temperature', full_name='apollo.canbus.Brake_motor_rpt_2_71.motor_temperature', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_speed', full_name='apollo.canbus.Brake_motor_rpt_2_71.angular_speed', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16344,
  serialized_end=16445,
)


_STEERING_MOTOR_RPT_1_73 = _descriptor.Descriptor(
  name='Steering_motor_rpt_1_73',
  full_name='apollo.canbus.Steering_motor_rpt_1_73',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='motor_current', full_name='apollo.canbus.Steering_motor_rpt_1_73.motor_current', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shaft_position', full_name='apollo.canbus.Steering_motor_rpt_1_73.shaft_position', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16447,
  serialized_end=16519,
)


_WIPER_CMD_90 = _descriptor.Descriptor(
  name='Wiper_cmd_90',
  full_name='apollo.canbus.Wiper_cmd_90',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wiper_cmd', full_name='apollo.canbus.Wiper_cmd_90.wiper_cmd', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WIPER_CMD_90_WIPER_CMDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16522,
  serialized_end=16831,
)


_BRAKE_MOTOR_RPT_3_72 = _descriptor.Descriptor(
  name='Brake_motor_rpt_3_72',
  full_name='apollo.canbus.Brake_motor_rpt_3_72',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='torque_output', full_name='apollo.canbus.Brake_motor_rpt_3_72.torque_output', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='torque_input', full_name='apollo.canbus.Brake_motor_rpt_3_72.torque_input', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16833,
  serialized_end=16900,
)


_GEM = _descriptor.Descriptor(
  name='Gem',
  full_name='apollo.canbus.Gem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='global_rpt_6a', full_name='apollo.canbus.Gem.global_rpt_6a', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_cmd_6b', full_name='apollo.canbus.Gem.brake_cmd_6b', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_rpt_6c', full_name='apollo.canbus.Gem.brake_rpt_6c', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_cmd_6d', full_name='apollo.canbus.Gem.steering_cmd_6d', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_rpt_1_6e', full_name='apollo.canbus.Gem.steering_rpt_1_6e', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel_speed_rpt_7a', full_name='apollo.canbus.Gem.wheel_speed_rpt_7a', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_time_rpt_83', full_name='apollo.canbus.Gem.date_time_rpt_83', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_motor_rpt_1_70', full_name='apollo.canbus.Gem.brake_motor_rpt_1_70', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headlight_rpt_77', full_name='apollo.canbus.Gem.headlight_rpt_77', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accel_rpt_68', full_name='apollo.canbus.Gem.accel_rpt_68', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_motor_rpt_3_75', full_name='apollo.canbus.Gem.steering_motor_rpt_3_75', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_cmd_63', full_name='apollo.canbus.Gem.turn_cmd_63', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_rpt_64', full_name='apollo.canbus.Gem.turn_rpt_64', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shift_cmd_65', full_name='apollo.canbus.Gem.shift_cmd_65', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shift_rpt_66', full_name='apollo.canbus.Gem.shift_rpt_66', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accel_cmd_67', full_name='apollo.canbus.Gem.accel_cmd_67', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat_lon_heading_rpt_82', full_name='apollo.canbus.Gem.lat_lon_heading_rpt_82', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_cmd_69', full_name='apollo.canbus.Gem.global_cmd_69', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_brake_status_rpt_80', full_name='apollo.canbus.Gem.parking_brake_status_rpt_80', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_rate_rpt_81', full_name='apollo.canbus.Gem.yaw_rate_rpt_81', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='horn_rpt_79', full_name='apollo.canbus.Gem.horn_rpt_79', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='horn_cmd_78', full_name='apollo.canbus.Gem.horn_cmd_78', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wiper_rpt_91', full_name='apollo.canbus.Gem.wiper_rpt_91', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_speed_rpt_6f', full_name='apollo.canbus.Gem.vehicle_speed_rpt_6f', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headlight_cmd_76', full_name='apollo.canbus.Gem.headlight_cmd_76', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_motor_rpt_2_74', full_name='apollo.canbus.Gem.steering_motor_rpt_2_74', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_motor_rpt_2_71', full_name='apollo.canbus.Gem.brake_motor_rpt_2_71', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_motor_rpt_1_73', full_name='apollo.canbus.Gem.steering_motor_rpt_1_73', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wiper_cmd_90', full_name='apollo.canbus.Gem.wiper_cmd_90', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_motor_rpt_3_72', full_name='apollo.canbus.Gem.brake_motor_rpt_3_72', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16903,
  serialized_end=18672,
)

_CHASSISDETAIL.fields_by_name['car_type'].enum_type = _CHASSISDETAIL_TYPE
_CHASSISDETAIL.fields_by_name['basic'].message_type = _BASICINFO
_CHASSISDETAIL.fields_by_name['safety'].message_type = _SAFETY
_CHASSISDETAIL.fields_by_name['gear'].message_type = _GEAR
_CHASSISDETAIL.fields_by_name['ems'].message_type = _EMS
_CHASSISDETAIL.fields_by_name['esp'].message_type = _ESP
_CHASSISDETAIL.fields_by_name['gas'].message_type = _GAS
_CHASSISDETAIL.fields_by_name['epb'].message_type = _EPB
_CHASSISDETAIL.fields_by_name['brake'].message_type = _BRAKE
_CHASSISDETAIL.fields_by_name['deceleration'].message_type = _DECELERATION
_CHASSISDETAIL.fields_by_name['vehicle_spd'].message_type = _VEHICLESPD
_CHASSISDETAIL.fields_by_name['eps'].message_type = _EPS
_CHASSISDETAIL.fields_by_name['light'].message_type = _LIGHT
_CHASSISDETAIL.fields_by_name['battery'].message_type = _BATTERY
_CHASSISDETAIL.fields_by_name['check_response'].message_type = _CHECKRESPONSESIGNAL
_CHASSISDETAIL.fields_by_name['license'].message_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._LICENSE
_CHASSISDETAIL.fields_by_name['surround'].message_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._SURROUND
_CHASSISDETAIL.fields_by_name['gem'].message_type = _GEM
_CHASSISDETAIL.fields_by_name['lexus'].message_type = modules_dot_canbus_dot_proto_dot_lexus__pb2._LEXUS
_CHASSISDETAIL.fields_by_name['transit'].message_type = modules_dot_canbus_dot_proto_dot_transit__pb2._TRANSIT
_CHASSISDETAIL.fields_by_name['ge3'].message_type = modules_dot_canbus_dot_proto_dot_ge3__pb2._GE3
_CHASSISDETAIL.fields_by_name['wey'].message_type = modules_dot_canbus_dot_proto_dot_wey__pb2._WEY
_CHASSISDETAIL.fields_by_name['zhongyun'].message_type = modules_dot_canbus_dot_proto_dot_zhongyun__pb2._ZHONGYUN
_CHASSISDETAIL.fields_by_name['ch'].message_type = modules_dot_canbus_dot_proto_dot_ch__pb2._CH
_CHASSISDETAIL.fields_by_name['devkit'].message_type = modules_dot_canbus_dot_proto_dot_devkit__pb2._DEVKIT
_CHASSISDETAIL.fields_by_name['neolix_edu'].message_type = modules_dot_canbus_dot_proto_dot_neolix__edu__pb2._NEOLIX_EDU
_CHASSISDETAIL.fields_by_name['vehicle_id'].message_type = modules_dot_common_dot_configs_dot_proto_dot_vehicle__config__pb2._VEHICLEID
_CHASSISDETAIL_TYPE.containing_type = _CHASSISDETAIL
_LIGHT.fields_by_name['turn_light_type'].enum_type = _LIGHT_TURNLIGHTTYPE
_LIGHT.fields_by_name['beam_lamp_type'].enum_type = _LIGHT_BEAMLAMPTYPE
_LIGHT.fields_by_name['lincoln_lamp_type'].enum_type = _LIGHT_LINCOLNLAMPTYPE
_LIGHT.fields_by_name['lincoln_wiper'].enum_type = _LIGHT_LINCOLNWIPERTYPE
_LIGHT.fields_by_name['lincoln_ambient'].enum_type = _LIGHT_LINCOLNAMBIENTTYPE
_LIGHT_TURNLIGHTTYPE.containing_type = _LIGHT
_LIGHT_BEAMLAMPTYPE.containing_type = _LIGHT
_LIGHT_LINCOLNLAMPTYPE.containing_type = _LIGHT
_LIGHT_LINCOLNWIPERTYPE.containing_type = _LIGHT
_LIGHT_LINCOLNAMBIENTTYPE.containing_type = _LIGHT
_EPS.fields_by_name['eps_control_state'].enum_type = _EPS_TYPE
_EPS_TYPE.containing_type = _EPS
_VEHICLESPD.fields_by_name['wheel_direction_rr'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._WHEELSPEED_WHEELSPEEDTYPE
_VEHICLESPD.fields_by_name['wheel_direction_rl'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._WHEELSPEED_WHEELSPEEDTYPE
_VEHICLESPD.fields_by_name['wheel_direction_fr'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._WHEELSPEED_WHEELSPEEDTYPE
_VEHICLESPD.fields_by_name['wheel_direction_fl'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._WHEELSPEED_WHEELSPEEDTYPE
_BRAKE.fields_by_name['hsa_status'].enum_type = _BRAKE_HSASTATUSTYPE
_BRAKE.fields_by_name['hsa_mode'].enum_type = _BRAKE_HSAMODETYPE
_BRAKE_HSASTATUSTYPE.containing_type = _BRAKE
_BRAKE_HSAMODETYPE.containing_type = _BRAKE
_EPB.fields_by_name['parking_brake_status'].enum_type = _EPB_PBRAKETYPE
_EPB_PBRAKETYPE.containing_type = _EPB
_EMS.fields_by_name['engine_state'].enum_type = _EMS_TYPE
_EMS_TYPE.containing_type = _EMS
_GEAR.fields_by_name['gear_state'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_GEARPOSITION
_GEAR.fields_by_name['gear_cmd'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_GEARPOSITION
_SAFETY.fields_by_name['car_driving_mode'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_DRIVINGMODE
_BASICINFO.fields_by_name['power_state'].enum_type = _BASICINFO_TYPE
_BASICINFO.fields_by_name['quality'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._GPSQUALITY
_BASICINFO_TYPE.containing_type = _BASICINFO
_GLOBAL_RPT_6A.fields_by_name['pacmod_status'].enum_type = _GLOBAL_RPT_6A_PACMOD_STATUSTYPE
_GLOBAL_RPT_6A.fields_by_name['override_status'].enum_type = _GLOBAL_RPT_6A_OVERRIDE_STATUSTYPE
_GLOBAL_RPT_6A.fields_by_name['brk_can_timeout'].enum_type = _GLOBAL_RPT_6A_BRK_CAN_TIMEOUTTYPE
_GLOBAL_RPT_6A_PACMOD_STATUSTYPE.containing_type = _GLOBAL_RPT_6A
_GLOBAL_RPT_6A_OVERRIDE_STATUSTYPE.containing_type = _GLOBAL_RPT_6A
_GLOBAL_RPT_6A_BRK_CAN_TIMEOUTTYPE.containing_type = _GLOBAL_RPT_6A
_BRAKE_RPT_6C.fields_by_name['brake_on_off'].enum_type = _BRAKE_RPT_6C_BRAKE_ON_OFFTYPE
_BRAKE_RPT_6C_BRAKE_ON_OFFTYPE.containing_type = _BRAKE_RPT_6C
_HEADLIGHT_RPT_77.fields_by_name['output_value'].enum_type = _HEADLIGHT_RPT_77_OUTPUT_VALUETYPE
_HEADLIGHT_RPT_77.fields_by_name['manual_input'].enum_type = _HEADLIGHT_RPT_77_MANUAL_INPUTTYPE
_HEADLIGHT_RPT_77.fields_by_name['commanded_value'].enum_type = _HEADLIGHT_RPT_77_COMMANDED_VALUETYPE
_HEADLIGHT_RPT_77_OUTPUT_VALUETYPE.containing_type = _HEADLIGHT_RPT_77
_HEADLIGHT_RPT_77_MANUAL_INPUTTYPE.containing_type = _HEADLIGHT_RPT_77
_HEADLIGHT_RPT_77_COMMANDED_VALUETYPE.containing_type = _HEADLIGHT_RPT_77
_TURN_CMD_63.fields_by_name['turn_signal_cmd'].enum_type = _TURN_CMD_63_TURN_SIGNAL_CMDTYPE
_TURN_CMD_63_TURN_SIGNAL_CMDTYPE.containing_type = _TURN_CMD_63
_TURN_RPT_64.fields_by_name['manual_input'].enum_type = _TURN_RPT_64_MANUAL_INPUTTYPE
_TURN_RPT_64.fields_by_name['commanded_value'].enum_type = _TURN_RPT_64_COMMANDED_VALUETYPE
_TURN_RPT_64.fields_by_name['output_value'].enum_type = _TURN_RPT_64_OUTPUT_VALUETYPE
_TURN_RPT_64_MANUAL_INPUTTYPE.containing_type = _TURN_RPT_64
_TURN_RPT_64_COMMANDED_VALUETYPE.containing_type = _TURN_RPT_64
_TURN_RPT_64_OUTPUT_VALUETYPE.containing_type = _TURN_RPT_64
_SHIFT_CMD_65.fields_by_name['shift_cmd'].enum_type = _SHIFT_CMD_65_SHIFT_CMDTYPE
_SHIFT_CMD_65_SHIFT_CMDTYPE.containing_type = _SHIFT_CMD_65
_SHIFT_RPT_66.fields_by_name['manual_input'].enum_type = _SHIFT_RPT_66_MANUAL_INPUTTYPE
_SHIFT_RPT_66.fields_by_name['commanded_value'].enum_type = _SHIFT_RPT_66_COMMANDED_VALUETYPE
_SHIFT_RPT_66.fields_by_name['output_value'].enum_type = _SHIFT_RPT_66_OUTPUT_VALUETYPE
_SHIFT_RPT_66_MANUAL_INPUTTYPE.containing_type = _SHIFT_RPT_66
_SHIFT_RPT_66_COMMANDED_VALUETYPE.containing_type = _SHIFT_RPT_66
_SHIFT_RPT_66_OUTPUT_VALUETYPE.containing_type = _SHIFT_RPT_66
_GLOBAL_CMD_69.fields_by_name['pacmod_enable'].enum_type = _GLOBAL_CMD_69_PACMOD_ENABLETYPE
_GLOBAL_CMD_69.fields_by_name['clear_override'].enum_type = _GLOBAL_CMD_69_CLEAR_OVERRIDETYPE
_GLOBAL_CMD_69.fields_by_name['ignore_override'].enum_type = _GLOBAL_CMD_69_IGNORE_OVERRIDETYPE
_GLOBAL_CMD_69_PACMOD_ENABLETYPE.containing_type = _GLOBAL_CMD_69
_GLOBAL_CMD_69_CLEAR_OVERRIDETYPE.containing_type = _GLOBAL_CMD_69
_GLOBAL_CMD_69_IGNORE_OVERRIDETYPE.containing_type = _GLOBAL_CMD_69
_PARKING_BRAKE_STATUS_RPT_80.fields_by_name['parking_brake_enabled'].enum_type = _PARKING_BRAKE_STATUS_RPT_80_PARKING_BRAKE_ENABLEDTYPE
_PARKING_BRAKE_STATUS_RPT_80_PARKING_BRAKE_ENABLEDTYPE.containing_type = _PARKING_BRAKE_STATUS_RPT_80
_HORN_RPT_79.fields_by_name['output_value'].enum_type = _HORN_RPT_79_OUTPUT_VALUETYPE
_HORN_RPT_79.fields_by_name['commanded_value'].enum_type = _HORN_RPT_79_COMMANDED_VALUETYPE
_HORN_RPT_79.fields_by_name['manual_input'].enum_type = _HORN_RPT_79_MANUAL_INPUTTYPE
_HORN_RPT_79_OUTPUT_VALUETYPE.containing_type = _HORN_RPT_79
_HORN_RPT_79_COMMANDED_VALUETYPE.containing_type = _HORN_RPT_79
_HORN_RPT_79_MANUAL_INPUTTYPE.containing_type = _HORN_RPT_79
_HORN_CMD_78.fields_by_name['horn_cmd'].enum_type = _HORN_CMD_78_HORN_CMDTYPE
_HORN_CMD_78_HORN_CMDTYPE.containing_type = _HORN_CMD_78
_WIPER_RPT_91.fields_by_name['output_value'].enum_type = _WIPER_RPT_91_OUTPUT_VALUETYPE
_WIPER_RPT_91.fields_by_name['commanded_value'].enum_type = _WIPER_RPT_91_COMMANDED_VALUETYPE
_WIPER_RPT_91.fields_by_name['manual_input'].enum_type = _WIPER_RPT_91_MANUAL_INPUTTYPE
_WIPER_RPT_91_OUTPUT_VALUETYPE.containing_type = _WIPER_RPT_91
_WIPER_RPT_91_COMMANDED_VALUETYPE.containing_type = _WIPER_RPT_91
_WIPER_RPT_91_MANUAL_INPUTTYPE.containing_type = _WIPER_RPT_91
_VEHICLE_SPEED_RPT_6F.fields_by_name['vehicle_speed_valid'].enum_type = _VEHICLE_SPEED_RPT_6F_VEHICLE_SPEED_VALIDTYPE
_VEHICLE_SPEED_RPT_6F_VEHICLE_SPEED_VALIDTYPE.containing_type = _VEHICLE_SPEED_RPT_6F
_HEADLIGHT_CMD_76.fields_by_name['headlight_cmd'].enum_type = _HEADLIGHT_CMD_76_HEADLIGHT_CMDTYPE
_HEADLIGHT_CMD_76_HEADLIGHT_CMDTYPE.containing_type = _HEADLIGHT_CMD_76
_WIPER_CMD_90.fields_by_name['wiper_cmd'].enum_type = _WIPER_CMD_90_WIPER_CMDTYPE
_WIPER_CMD_90_WIPER_CMDTYPE.containing_type = _WIPER_CMD_90
_GEM.fields_by_name['global_rpt_6a'].message_type = _GLOBAL_RPT_6A
_GEM.fields_by_name['brake_cmd_6b'].message_type = _BRAKE_CMD_6B
_GEM.fields_by_name['brake_rpt_6c'].message_type = _BRAKE_RPT_6C
_GEM.fields_by_name['steering_cmd_6d'].message_type = _STEERING_CMD_6D
_GEM.fields_by_name['steering_rpt_1_6e'].message_type = _STEERING_RPT_1_6E
_GEM.fields_by_name['wheel_speed_rpt_7a'].message_type = _WHEEL_SPEED_RPT_7A
_GEM.fields_by_name['date_time_rpt_83'].message_type = _DATE_TIME_RPT_83
_GEM.fields_by_name['brake_motor_rpt_1_70'].message_type = _BRAKE_MOTOR_RPT_1_70
_GEM.fields_by_name['headlight_rpt_77'].message_type = _HEADLIGHT_RPT_77
_GEM.fields_by_name['accel_rpt_68'].message_type = _ACCEL_RPT_68
_GEM.fields_by_name['steering_motor_rpt_3_75'].message_type = _STEERING_MOTOR_RPT_3_75
_GEM.fields_by_name['turn_cmd_63'].message_type = _TURN_CMD_63
_GEM.fields_by_name['turn_rpt_64'].message_type = _TURN_RPT_64
_GEM.fields_by_name['shift_cmd_65'].message_type = _SHIFT_CMD_65
_GEM.fields_by_name['shift_rpt_66'].message_type = _SHIFT_RPT_66
_GEM.fields_by_name['accel_cmd_67'].message_type = _ACCEL_CMD_67
_GEM.fields_by_name['lat_lon_heading_rpt_82'].message_type = _LAT_LON_HEADING_RPT_82
_GEM.fields_by_name['global_cmd_69'].message_type = _GLOBAL_CMD_69
_GEM.fields_by_name['parking_brake_status_rpt_80'].message_type = _PARKING_BRAKE_STATUS_RPT_80
_GEM.fields_by_name['yaw_rate_rpt_81'].message_type = _YAW_RATE_RPT_81
_GEM.fields_by_name['horn_rpt_79'].message_type = _HORN_RPT_79
_GEM.fields_by_name['horn_cmd_78'].message_type = _HORN_CMD_78
_GEM.fields_by_name['wiper_rpt_91'].message_type = _WIPER_RPT_91
_GEM.fields_by_name['vehicle_speed_rpt_6f'].message_type = _VEHICLE_SPEED_RPT_6F
_GEM.fields_by_name['headlight_cmd_76'].message_type = _HEADLIGHT_CMD_76
_GEM.fields_by_name['steering_motor_rpt_2_74'].message_type = _STEERING_MOTOR_RPT_2_74
_GEM.fields_by_name['brake_motor_rpt_2_71'].message_type = _BRAKE_MOTOR_RPT_2_71
_GEM.fields_by_name['steering_motor_rpt_1_73'].message_type = _STEERING_MOTOR_RPT_1_73
_GEM.fields_by_name['wiper_cmd_90'].message_type = _WIPER_CMD_90
_GEM.fields_by_name['brake_motor_rpt_3_72'].message_type = _BRAKE_MOTOR_RPT_3_72
DESCRIPTOR.message_types_by_name['ChassisDetail'] = _CHASSISDETAIL
DESCRIPTOR.message_types_by_name['CheckResponseSignal'] = _CHECKRESPONSESIGNAL
DESCRIPTOR.message_types_by_name['Battery'] = _BATTERY
DESCRIPTOR.message_types_by_name['Light'] = _LIGHT
DESCRIPTOR.message_types_by_name['Eps'] = _EPS
DESCRIPTOR.message_types_by_name['VehicleSpd'] = _VEHICLESPD
DESCRIPTOR.message_types_by_name['Deceleration'] = _DECELERATION
DESCRIPTOR.message_types_by_name['Brake'] = _BRAKE
DESCRIPTOR.message_types_by_name['Epb'] = _EPB
DESCRIPTOR.message_types_by_name['Gas'] = _GAS
DESCRIPTOR.message_types_by_name['Esp'] = _ESP
DESCRIPTOR.message_types_by_name['Ems'] = _EMS
DESCRIPTOR.message_types_by_name['Gear'] = _GEAR
DESCRIPTOR.message_types_by_name['Safety'] = _SAFETY
DESCRIPTOR.message_types_by_name['BasicInfo'] = _BASICINFO
DESCRIPTOR.message_types_by_name['Global_rpt_6a'] = _GLOBAL_RPT_6A
DESCRIPTOR.message_types_by_name['Brake_cmd_6b'] = _BRAKE_CMD_6B
DESCRIPTOR.message_types_by_name['Brake_rpt_6c'] = _BRAKE_RPT_6C
DESCRIPTOR.message_types_by_name['Steering_cmd_6d'] = _STEERING_CMD_6D
DESCRIPTOR.message_types_by_name['Steering_rpt_1_6e'] = _STEERING_RPT_1_6E
DESCRIPTOR.message_types_by_name['Wheel_speed_rpt_7a'] = _WHEEL_SPEED_RPT_7A
DESCRIPTOR.message_types_by_name['Date_time_rpt_83'] = _DATE_TIME_RPT_83
DESCRIPTOR.message_types_by_name['Brake_motor_rpt_1_70'] = _BRAKE_MOTOR_RPT_1_70
DESCRIPTOR.message_types_by_name['Headlight_rpt_77'] = _HEADLIGHT_RPT_77
DESCRIPTOR.message_types_by_name['Accel_rpt_68'] = _ACCEL_RPT_68
DESCRIPTOR.message_types_by_name['Steering_motor_rpt_3_75'] = _STEERING_MOTOR_RPT_3_75
DESCRIPTOR.message_types_by_name['Turn_cmd_63'] = _TURN_CMD_63
DESCRIPTOR.message_types_by_name['Turn_rpt_64'] = _TURN_RPT_64
DESCRIPTOR.message_types_by_name['Shift_cmd_65'] = _SHIFT_CMD_65
DESCRIPTOR.message_types_by_name['Shift_rpt_66'] = _SHIFT_RPT_66
DESCRIPTOR.message_types_by_name['Accel_cmd_67'] = _ACCEL_CMD_67
DESCRIPTOR.message_types_by_name['Lat_lon_heading_rpt_82'] = _LAT_LON_HEADING_RPT_82
DESCRIPTOR.message_types_by_name['Global_cmd_69'] = _GLOBAL_CMD_69
DESCRIPTOR.message_types_by_name['Parking_brake_status_rpt_80'] = _PARKING_BRAKE_STATUS_RPT_80
DESCRIPTOR.message_types_by_name['Yaw_rate_rpt_81'] = _YAW_RATE_RPT_81
DESCRIPTOR.message_types_by_name['Horn_rpt_79'] = _HORN_RPT_79
DESCRIPTOR.message_types_by_name['Horn_cmd_78'] = _HORN_CMD_78
DESCRIPTOR.message_types_by_name['Wiper_rpt_91'] = _WIPER_RPT_91
DESCRIPTOR.message_types_by_name['Vehicle_speed_rpt_6f'] = _VEHICLE_SPEED_RPT_6F
DESCRIPTOR.message_types_by_name['Headlight_cmd_76'] = _HEADLIGHT_CMD_76
DESCRIPTOR.message_types_by_name['Steering_motor_rpt_2_74'] = _STEERING_MOTOR_RPT_2_74
DESCRIPTOR.message_types_by_name['Brake_motor_rpt_2_71'] = _BRAKE_MOTOR_RPT_2_71
DESCRIPTOR.message_types_by_name['Steering_motor_rpt_1_73'] = _STEERING_MOTOR_RPT_1_73
DESCRIPTOR.message_types_by_name['Wiper_cmd_90'] = _WIPER_CMD_90
DESCRIPTOR.message_types_by_name['Brake_motor_rpt_3_72'] = _BRAKE_MOTOR_RPT_3_72
DESCRIPTOR.message_types_by_name['Gem'] = _GEM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChassisDetail = _reflection.GeneratedProtocolMessageType('ChassisDetail', (_message.Message,), {
  'DESCRIPTOR' : _CHASSISDETAIL,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.ChassisDetail)
  })
_sym_db.RegisterMessage(ChassisDetail)

CheckResponseSignal = _reflection.GeneratedProtocolMessageType('CheckResponseSignal', (_message.Message,), {
  'DESCRIPTOR' : _CHECKRESPONSESIGNAL,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.CheckResponseSignal)
  })
_sym_db.RegisterMessage(CheckResponseSignal)

Battery = _reflection.GeneratedProtocolMessageType('Battery', (_message.Message,), {
  'DESCRIPTOR' : _BATTERY,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Battery)
  })
_sym_db.RegisterMessage(Battery)

Light = _reflection.GeneratedProtocolMessageType('Light', (_message.Message,), {
  'DESCRIPTOR' : _LIGHT,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Light)
  })
_sym_db.RegisterMessage(Light)

Eps = _reflection.GeneratedProtocolMessageType('Eps', (_message.Message,), {
  'DESCRIPTOR' : _EPS,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Eps)
  })
_sym_db.RegisterMessage(Eps)

VehicleSpd = _reflection.GeneratedProtocolMessageType('VehicleSpd', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLESPD,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.VehicleSpd)
  })
_sym_db.RegisterMessage(VehicleSpd)

Deceleration = _reflection.GeneratedProtocolMessageType('Deceleration', (_message.Message,), {
  'DESCRIPTOR' : _DECELERATION,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Deceleration)
  })
_sym_db.RegisterMessage(Deceleration)

Brake = _reflection.GeneratedProtocolMessageType('Brake', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake)
  })
_sym_db.RegisterMessage(Brake)

Epb = _reflection.GeneratedProtocolMessageType('Epb', (_message.Message,), {
  'DESCRIPTOR' : _EPB,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Epb)
  })
_sym_db.RegisterMessage(Epb)

Gas = _reflection.GeneratedProtocolMessageType('Gas', (_message.Message,), {
  'DESCRIPTOR' : _GAS,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Gas)
  })
_sym_db.RegisterMessage(Gas)

Esp = _reflection.GeneratedProtocolMessageType('Esp', (_message.Message,), {
  'DESCRIPTOR' : _ESP,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Esp)
  })
_sym_db.RegisterMessage(Esp)

Ems = _reflection.GeneratedProtocolMessageType('Ems', (_message.Message,), {
  'DESCRIPTOR' : _EMS,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ems)
  })
_sym_db.RegisterMessage(Ems)

Gear = _reflection.GeneratedProtocolMessageType('Gear', (_message.Message,), {
  'DESCRIPTOR' : _GEAR,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Gear)
  })
_sym_db.RegisterMessage(Gear)

Safety = _reflection.GeneratedProtocolMessageType('Safety', (_message.Message,), {
  'DESCRIPTOR' : _SAFETY,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Safety)
  })
_sym_db.RegisterMessage(Safety)

BasicInfo = _reflection.GeneratedProtocolMessageType('BasicInfo', (_message.Message,), {
  'DESCRIPTOR' : _BASICINFO,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.BasicInfo)
  })
_sym_db.RegisterMessage(BasicInfo)

Global_rpt_6a = _reflection.GeneratedProtocolMessageType('Global_rpt_6a', (_message.Message,), {
  'DESCRIPTOR' : _GLOBAL_RPT_6A,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Global_rpt_6a)
  })
_sym_db.RegisterMessage(Global_rpt_6a)

Brake_cmd_6b = _reflection.GeneratedProtocolMessageType('Brake_cmd_6b', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_CMD_6B,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_cmd_6b)
  })
_sym_db.RegisterMessage(Brake_cmd_6b)

Brake_rpt_6c = _reflection.GeneratedProtocolMessageType('Brake_rpt_6c', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_RPT_6C,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_rpt_6c)
  })
_sym_db.RegisterMessage(Brake_rpt_6c)

Steering_cmd_6d = _reflection.GeneratedProtocolMessageType('Steering_cmd_6d', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_CMD_6D,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_cmd_6d)
  })
_sym_db.RegisterMessage(Steering_cmd_6d)

Steering_rpt_1_6e = _reflection.GeneratedProtocolMessageType('Steering_rpt_1_6e', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_RPT_1_6E,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_rpt_1_6e)
  })
_sym_db.RegisterMessage(Steering_rpt_1_6e)

Wheel_speed_rpt_7a = _reflection.GeneratedProtocolMessageType('Wheel_speed_rpt_7a', (_message.Message,), {
  'DESCRIPTOR' : _WHEEL_SPEED_RPT_7A,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Wheel_speed_rpt_7a)
  })
_sym_db.RegisterMessage(Wheel_speed_rpt_7a)

Date_time_rpt_83 = _reflection.GeneratedProtocolMessageType('Date_time_rpt_83', (_message.Message,), {
  'DESCRIPTOR' : _DATE_TIME_RPT_83,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Date_time_rpt_83)
  })
_sym_db.RegisterMessage(Date_time_rpt_83)

Brake_motor_rpt_1_70 = _reflection.GeneratedProtocolMessageType('Brake_motor_rpt_1_70', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_MOTOR_RPT_1_70,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_motor_rpt_1_70)
  })
_sym_db.RegisterMessage(Brake_motor_rpt_1_70)

Headlight_rpt_77 = _reflection.GeneratedProtocolMessageType('Headlight_rpt_77', (_message.Message,), {
  'DESCRIPTOR' : _HEADLIGHT_RPT_77,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Headlight_rpt_77)
  })
_sym_db.RegisterMessage(Headlight_rpt_77)

Accel_rpt_68 = _reflection.GeneratedProtocolMessageType('Accel_rpt_68', (_message.Message,), {
  'DESCRIPTOR' : _ACCEL_RPT_68,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Accel_rpt_68)
  })
_sym_db.RegisterMessage(Accel_rpt_68)

Steering_motor_rpt_3_75 = _reflection.GeneratedProtocolMessageType('Steering_motor_rpt_3_75', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_MOTOR_RPT_3_75,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_motor_rpt_3_75)
  })
_sym_db.RegisterMessage(Steering_motor_rpt_3_75)

Turn_cmd_63 = _reflection.GeneratedProtocolMessageType('Turn_cmd_63', (_message.Message,), {
  'DESCRIPTOR' : _TURN_CMD_63,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Turn_cmd_63)
  })
_sym_db.RegisterMessage(Turn_cmd_63)

Turn_rpt_64 = _reflection.GeneratedProtocolMessageType('Turn_rpt_64', (_message.Message,), {
  'DESCRIPTOR' : _TURN_RPT_64,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Turn_rpt_64)
  })
_sym_db.RegisterMessage(Turn_rpt_64)

Shift_cmd_65 = _reflection.GeneratedProtocolMessageType('Shift_cmd_65', (_message.Message,), {
  'DESCRIPTOR' : _SHIFT_CMD_65,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Shift_cmd_65)
  })
_sym_db.RegisterMessage(Shift_cmd_65)

Shift_rpt_66 = _reflection.GeneratedProtocolMessageType('Shift_rpt_66', (_message.Message,), {
  'DESCRIPTOR' : _SHIFT_RPT_66,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Shift_rpt_66)
  })
_sym_db.RegisterMessage(Shift_rpt_66)

Accel_cmd_67 = _reflection.GeneratedProtocolMessageType('Accel_cmd_67', (_message.Message,), {
  'DESCRIPTOR' : _ACCEL_CMD_67,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Accel_cmd_67)
  })
_sym_db.RegisterMessage(Accel_cmd_67)

Lat_lon_heading_rpt_82 = _reflection.GeneratedProtocolMessageType('Lat_lon_heading_rpt_82', (_message.Message,), {
  'DESCRIPTOR' : _LAT_LON_HEADING_RPT_82,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Lat_lon_heading_rpt_82)
  })
_sym_db.RegisterMessage(Lat_lon_heading_rpt_82)

Global_cmd_69 = _reflection.GeneratedProtocolMessageType('Global_cmd_69', (_message.Message,), {
  'DESCRIPTOR' : _GLOBAL_CMD_69,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Global_cmd_69)
  })
_sym_db.RegisterMessage(Global_cmd_69)

Parking_brake_status_rpt_80 = _reflection.GeneratedProtocolMessageType('Parking_brake_status_rpt_80', (_message.Message,), {
  'DESCRIPTOR' : _PARKING_BRAKE_STATUS_RPT_80,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Parking_brake_status_rpt_80)
  })
_sym_db.RegisterMessage(Parking_brake_status_rpt_80)

Yaw_rate_rpt_81 = _reflection.GeneratedProtocolMessageType('Yaw_rate_rpt_81', (_message.Message,), {
  'DESCRIPTOR' : _YAW_RATE_RPT_81,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Yaw_rate_rpt_81)
  })
_sym_db.RegisterMessage(Yaw_rate_rpt_81)

Horn_rpt_79 = _reflection.GeneratedProtocolMessageType('Horn_rpt_79', (_message.Message,), {
  'DESCRIPTOR' : _HORN_RPT_79,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Horn_rpt_79)
  })
_sym_db.RegisterMessage(Horn_rpt_79)

Horn_cmd_78 = _reflection.GeneratedProtocolMessageType('Horn_cmd_78', (_message.Message,), {
  'DESCRIPTOR' : _HORN_CMD_78,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Horn_cmd_78)
  })
_sym_db.RegisterMessage(Horn_cmd_78)

Wiper_rpt_91 = _reflection.GeneratedProtocolMessageType('Wiper_rpt_91', (_message.Message,), {
  'DESCRIPTOR' : _WIPER_RPT_91,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Wiper_rpt_91)
  })
_sym_db.RegisterMessage(Wiper_rpt_91)

Vehicle_speed_rpt_6f = _reflection.GeneratedProtocolMessageType('Vehicle_speed_rpt_6f', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLE_SPEED_RPT_6F,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vehicle_speed_rpt_6f)
  })
_sym_db.RegisterMessage(Vehicle_speed_rpt_6f)

Headlight_cmd_76 = _reflection.GeneratedProtocolMessageType('Headlight_cmd_76', (_message.Message,), {
  'DESCRIPTOR' : _HEADLIGHT_CMD_76,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Headlight_cmd_76)
  })
_sym_db.RegisterMessage(Headlight_cmd_76)

Steering_motor_rpt_2_74 = _reflection.GeneratedProtocolMessageType('Steering_motor_rpt_2_74', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_MOTOR_RPT_2_74,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_motor_rpt_2_74)
  })
_sym_db.RegisterMessage(Steering_motor_rpt_2_74)

Brake_motor_rpt_2_71 = _reflection.GeneratedProtocolMessageType('Brake_motor_rpt_2_71', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_MOTOR_RPT_2_71,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_motor_rpt_2_71)
  })
_sym_db.RegisterMessage(Brake_motor_rpt_2_71)

Steering_motor_rpt_1_73 = _reflection.GeneratedProtocolMessageType('Steering_motor_rpt_1_73', (_message.Message,), {
  'DESCRIPTOR' : _STEERING_MOTOR_RPT_1_73,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Steering_motor_rpt_1_73)
  })
_sym_db.RegisterMessage(Steering_motor_rpt_1_73)

Wiper_cmd_90 = _reflection.GeneratedProtocolMessageType('Wiper_cmd_90', (_message.Message,), {
  'DESCRIPTOR' : _WIPER_CMD_90,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Wiper_cmd_90)
  })
_sym_db.RegisterMessage(Wiper_cmd_90)

Brake_motor_rpt_3_72 = _reflection.GeneratedProtocolMessageType('Brake_motor_rpt_3_72', (_message.Message,), {
  'DESCRIPTOR' : _BRAKE_MOTOR_RPT_3_72,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Brake_motor_rpt_3_72)
  })
_sym_db.RegisterMessage(Brake_motor_rpt_3_72)

Gem = _reflection.GeneratedProtocolMessageType('Gem', (_message.Message,), {
  'DESCRIPTOR' : _GEM,
  '__module__' : 'modules.canbus.proto.chassis_detail_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Gem)
  })
_sym_db.RegisterMessage(Gem)


_CHASSISDETAIL.fields_by_name['license']._options = None
# @@protoc_insertion_point(module_scope)
